(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    644816,      34633]*)
(*NotebookOutlinePosition[    645481,      34656]*)
(*  CellTagsIndexPosition[    645437,      34652]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Stokesian Dynamic Simulation of Sedimenting Spheres in a \
Newtonian Fluid", "Subsubtitle",
    FontSize->18,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Author's Data",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[": ",
    FontSize->14],
  StyleBox["Housam BINOUS\nDepartment of Chemical Engineering\nNational \
Institute of Applied Sciences and Technology\nTunis, TUNISIA\nEmail: \
binoushousam@yahoo.com ",
    FontSize->14,
    FontWeight->"Plain"]
}], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.605478, 0.996109, 0.605478]],

Cell[TextData[{
  StyleBox["Acknowledgement :",
    FontWeight->"Bold"],
  "\nThis program was originally written by Professor Ron Phillips during his \
PhD thesis at MIT in 1989. The code was adapted from Fortran 77 to ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  StyleBox["by Housam Binous",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[". ",
    FontSlant->"Italic"],
  StyleBox["Permission was given by Professor Phillips to post this work in \
the WEB. Using Euler's integration scheme was one simplification, of the \
original code, that was performed by Housam Binous. \n\nThe code call a .m \
file called NEWTON2.m, which needs three files ",
    FontVariations->{"CompatibilityType"->0}],
  "TEMPM.m, FTMOB.m and SSI.m as well as a data file called data.m. \n\n1/ \
NEWTON2.m computes far-field and adds to it lubrication; it then computes the \
velocities of the spheres using the mobility matrix and the applied forces.\n \
\n2/ TEMPM.m computes far-field mobility. \n\n3/ SSI.m creates two-body \
resistance matrix. To do so, it uses interpolation of values found data.m as \
well as analytical expressions. The program then subtracts the two-body \
far-field mobility from the two-body resistance matrix. The result is the \
lubrification matrix.\n\n4/ FTMOB.m creates the two-body far-field mobility. \
\n"
}], "Subsubtitle",
  Background->RGBColor[0.773449, 0.996109, 0.996109]],

Cell[TextData[{
  StyleBox["Important Note:",
    FontWeight->"Bold"],
  " All files should be placed in the C: drive in the folder \
StokesianDynamics. If not, some changes to the Get instructions (<<) should \
be done by users.",
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->0}]
}], "Subsubtitle",
  Background->RGBColor[1, 0.666667, 1]],

Cell["\<\
Stokesian Dynamics, a method developed by Brady and Bossis in the 80s, \
simulate the 3D motion of hydrodynamically interacting spheres at low \
Reynolds numbers.\
\>", "Subsubtitle",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell["\<\
Two spheres sedimenting in a Newtonian fluid. Since the line of centers of \
the spheres has a y-component, they present lateral motion as they fall.\
\>", "Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["<<Graphics`Graphics3D`", "Input"],

Cell["FU={0,0,-10,0,0,-10,0,0,0,0,0,0};", "Input"],

Cell["X[1]=0;Y[1]=1;Z[1]=0;X[2]=0;Y[2]=0;Z[2]=3;", "Input"],

Cell["dt=0.1;", "Input"],

Cell["NSPHR=2;NDIM=6 NSPHR;Ng=3 NSPHR; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\StokesianDynamics\\\\data.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\StokesianDynamics\\data.m", 6]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<100,{<<\"C:\\\\StokesianDynamics\\\\NEWTON2.m\";
X[1,t]=X[1,t-1]+UNEW[1]*dt;Y[1,t]=Y[1,t-1]+UNEW[2]*dt;Z[1,t]=Z[1,t-1]+UNEW[3]*\
dt;X[2,t]=X[2,t-1]+UNEW[4]*dt;Y[2,t]=Y[2,t-1]+UNEW[5]*dt;Z[2,t]=Z[2,t-1]+UNEW[\
6]*dt;Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "b1=ScatterPlot3D[Table[{X[1,t],Y[1,t],Z[1,t]},{t,0,99}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined -> True,PlotStyle -> \
{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "b2=ScatterPlot3D[Table[{X[2,t],Y[2,t],Z[2,t]},{t,0,99}],",
  StyleBox["BoxRatios", "MR",
    FontWeight->"Bold"],
  " ",
  StyleBox["->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined -> True,\nPlotStyle -> \
{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[b1,b2,ViewPoint->{1,1,1},DisplayFunction\[Rule]$DisplayFunction]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98974 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0773503 1.1547 -7.69241e-017 1.1547 [
[.49137 1.00206 -6.02771 0 ]
[.49137 1.00206 5.97229 9 ]
[.3981 .97914 -12.6627 0 ]
[.3981 .97914 11.3373 9 ]
[.29001 .95253 -3.34641 0 ]
[.29001 .95253 2.65359 9 ]
[.16328 .92127 -10.6956 0 ]
[.16328 .92127 7.30441 9 ]
[.01264 .88402 -3.83546 0 ]
[.01264 .88402 2.16454 9 ]
[.13651 .35752 -6 -7.12586 ]
[.13651 .35752 0 1.87414 ]
[.22931 .26079 -6 -7.57237 ]
[.22931 .26079 0 1.42763 ]
[.34344 .14195 -6 -8.20185 ]
[.34344 .14195 0 .79815 ]
[.48718 -0.00748 -5.89965 -9 ]
[.48718 -0.00748 .10035 0 ]
[.90152 .47369 0 -6.74889 ]
[.90152 .47369 24 2.25111 ]
[.94741 .63205 0 -6.26825 ]
[.94741 .63205 18 2.73175 ]
[1.0053 .83237 0 -5.69638 ]
[1.0053 .83237 6 3.30362 ]
[ 0 0 0 0 ]
[ 1 .98974 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .98974 m
0 .86603 L
s
.49144 .98762 m
.49147 .98041 L
s
[(-1)] .49137 1.00206 .00462 -1 Mshowa
.3989 .96473 m
.3993 .95752 L
s
[(-0.5)] .3981 .97914 .05522 -1 Mshowa
.29167 .93819 m
.29249 .93102 L
s
[(0)] .29001 .95253 .11547 -1 Mshowa
.16595 .90709 m
.16728 .89999 L
s
[(0.5)] .16328 .92127 .1884 -1 Mshowa
.01651 .87011 m
.01845 .86316 L
s
[(1)] .01264 .88402 .27849 -1 Mshowa
.125 Mabswid
.47396 .9833 m
.47402 .97897 L
s
.45599 .97885 m
.45609 .97452 L
s
.4375 .97428 m
.43765 .96995 L
s
.41848 .96957 m
.41867 .96525 L
s
.37873 .95974 m
.37902 .95542 L
s
.35795 .9546 m
.35829 .95028 L
s
.33654 .9493 m
.33693 .94498 L
s
.31445 .94383 m
.31489 .93952 L
s
.26815 .93237 m
.2687 .92808 L
s
.24385 .92636 m
.24447 .92208 L
s
.21875 .92015 m
.21942 .91587 L
s
.1928 .91373 m
.19353 .90946 L
s
.13816 .90021 m
.13903 .89597 L
s
.10938 .89309 m
.11031 .88886 L
s
.07955 .88571 m
.08056 .8815 L
s
.04861 .87805 m
.0497 .87386 L
s
.25 Mabswid
.14286 .37115 m
.5 0 L
s
.14897 .3648 m
.15521 .36844 L
s
[(0)] .13651 .35752 1 .58353 Mshowa
.24123 .26892 m
.24719 .27299 L
s
[(2)] .22931 .26079 1 .68275 Mshowa
.35458 .15112 m
.36016 .15571 L
s
[(4)] .34344 .14195 1 .82263 Mshowa
.49721 .0029 m
.50223 .00809 L
s
[(6)] .48718 -0.00748 .96655 1 Mshowa
.125 Mabswid
.17039 .34254 m
.17409 .34479 L
s
.19285 .3192 m
.19651 .32151 L
s
.21643 .29469 m
.22006 .29706 L
s
.26733 .2418 m
.27085 .24431 L
s
.29484 .21321 m
.29831 .2158 L
s
.32388 .18303 m
.32729 .1857 L
s
.38709 .11734 m
.39036 .12017 L
s
.42157 .0815 m
.42477 .08443 L
s
.45821 .04343 m
.46132 .04645 L
s
.25 Mabswid
.85714 .37115 m
1 .86603 L
s
.8886 .48014 m
.88215 .48337 L
s
[(-100)] .90152 .47369 -1 .49975 Mshowa
.93398 .63733 m
.92726 .63997 L
s
[(-50)] .94741 .63205 -1 .39294 Mshowa
.99135 .83608 m
.98438 .83793 L
s
[(0)] 1.0053 .83237 -1 .26586 Mshowa
.125 Mabswid
.8969 .50889 m
.893 .51076 L
s
.90557 .5389 m
.90163 .54071 L
s
.91462 .57024 m
.91065 .57198 L
s
.92408 .60302 m
.92008 .60468 L
s
.94436 .67328 m
.9403 .67478 L
s
.95524 .71098 m
.95115 .7124 L
s
.96668 .75059 m
.96255 .7519 L
s
.9787 .79223 m
.97454 .79345 L
s
.88064 .45257 m
.8768 .45456 L
s
.873 .4261 m
.86919 .42815 L
s
.86566 .40067 m
.86188 .40278 L
s
.85861 .37623 m
.85485 .37838 L
s
.25 Mabswid
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
.85714 .37115 m
.5 .57735 L
s
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.14286 .37115 m
.5 .57735 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
0 0 m
1 0 L
1 .98974 L
0 .98974 L
closepath
clip
newpath
.875 .531 .824 r
.015 w
.62198 .30165 m
.62511 .29561 L
s
.61886 .30769 m
.62198 .30165 L
s
.61573 .31373 m
.61886 .30769 L
s
.6126 .31978 m
.61573 .31373 L
s
.60947 .32584 m
.6126 .31978 L
s
.60633 .3319 m
.60947 .32584 L
s
.60319 .33797 m
.60633 .3319 L
s
.60005 .34405 m
.60319 .33797 L
s
.5969 .35013 m
.60005 .34405 L
s
.59376 .35621 m
.5969 .35013 L
s
.59061 .3623 m
.59376 .35621 L
s
.58745 .3684 m
.59061 .3623 L
s
.5843 .3745 m
.58745 .3684 L
s
.58114 .38061 m
.5843 .3745 L
s
.57797 .38672 m
.58114 .38061 L
s
.57481 .39284 m
.57797 .38672 L
s
.57164 .39896 m
.57481 .39284 L
s
.56847 .40509 m
.57164 .39896 L
s
.5653 .41123 m
.56847 .40509 L
s
.56212 .41737 m
.5653 .41123 L
s
.55894 .42352 m
.56212 .41737 L
s
.55576 .42967 m
.55894 .42352 L
s
.55257 .43583 m
.55576 .42967 L
s
.54938 .44199 m
.55257 .43583 L
s
.54619 .44816 m
.54938 .44199 L
s
.543 .45433 m
.54619 .44816 L
s
.5398 .46051 m
.543 .45433 L
s
.5366 .4667 m
.5398 .46051 L
s
.5334 .47289 m
.5366 .4667 L
s
.53019 .47909 m
.5334 .47289 L
s
.52698 .48529 m
.53019 .47909 L
s
.52377 .4915 m
.52698 .48529 L
s
.52056 .49772 m
.52377 .4915 L
s
.51734 .50394 m
.52056 .49772 L
s
.51412 .51017 m
.51734 .50394 L
s
.51089 .5164 m
.51412 .51017 L
s
.50767 .52264 m
.51089 .5164 L
s
.50444 .52888 m
.50767 .52264 L
s
.5012 .53513 m
.50444 .52888 L
s
.49797 .54138 m
.5012 .53513 L
s
.49473 .54765 m
.49797 .54138 L
s
.49149 .55391 m
.49473 .54765 L
s
.48824 .56019 m
.49149 .55391 L
s
.48499 .56646 m
.48824 .56019 L
s
.48174 .57275 m
.48499 .56646 L
s
.47849 .57904 m
.48174 .57275 L
s
.47523 .58534 m
.47849 .57904 L
s
.47197 .59164 m
.47523 .58534 L
s
.46871 .59795 m
.47197 .59164 L
s
.46544 .60426 m
.46871 .59795 L
s
.46217 .61058 m
.46544 .60426 L
s
.4589 .6169 m
.46217 .61058 L
s
.45563 .62324 m
.4589 .6169 L
s
.45235 .62957 m
.45563 .62324 L
s
.44907 .63592 m
.45235 .62957 L
s
.44578 .64227 m
.44907 .63592 L
s
.44249 .64862 m
.44578 .64227 L
s
.4392 .65498 m
.44249 .64862 L
s
.43591 .66135 m
.4392 .65498 L
s
.43261 .66772 m
.43591 .66135 L
s
.42931 .6741 m
.43261 .66772 L
s
.42601 .68049 m
.42931 .6741 L
s
.4227 .68688 m
.42601 .68049 L
s
.41939 .69327 m
.4227 .68688 L
s
.41608 .69968 m
.41939 .69327 L
s
.41277 .70609 m
.41608 .69968 L
s
.40945 .7125 m
.41277 .70609 L
s
.40613 .71892 m
.40945 .7125 L
s
.4028 .72535 m
.40613 .71892 L
s
.39947 .73178 m
.4028 .72535 L
s
.39614 .73822 m
.39947 .73178 L
s
.39281 .74467 m
.39614 .73822 L
s
.38947 .75112 m
.39281 .74467 L
s
.38613 .75758 m
.38947 .75112 L
s
.38279 .76404 m
.38613 .75758 L
s
.37944 .77051 m
.38279 .76404 L
s
.37609 .77698 m
.37944 .77051 L
s
.37274 .78347 m
.37609 .77698 L
s
.36938 .78995 m
.37274 .78347 L
s
.36602 .79645 m
.36938 .78995 L
s
.36266 .80295 m
.36602 .79645 L
s
.3593 .80945 m
.36266 .80295 L
s
.35593 .81597 m
.3593 .80945 L
s
.35255 .82249 m
.35593 .81597 L
s
.34918 .82901 m
.35255 .82249 L
s
.3458 .83554 m
.34918 .82901 L
s
.34242 .84208 m
.3458 .83554 L
s
.33903 .84862 m
.34242 .84208 L
s
.33565 .85517 m
.33903 .84862 L
s
.33225 .86173 m
.33565 .85517 L
s
.32886 .86829 m
.33225 .86173 L
s
.32546 .87486 m
.32886 .86829 L
s
.32206 .88143 m
.32546 .87486 L
s
.31866 .88801 m
.32206 .88143 L
s
.31525 .8946 m
.31866 .88801 L
s
.31184 .90119 m
.31525 .8946 L
s
.30842 .90779 m
.31184 .90119 L
s
.30501 .9144 m
.30842 .90779 L
s
.30159 .92101 m
.30501 .9144 L
s
.491 .676 .021 r
.69518 .23998 m
.69841 .23369 L
s
.69194 .24628 m
.69518 .23998 L
s
.6887 .25258 m
.69194 .24628 L
s
.68546 .25889 m
.6887 .25258 L
s
.68221 .2652 m
.68546 .25889 L
s
.67896 .27152 m
.68221 .2652 L
s
.67571 .27785 m
.67896 .27152 L
s
.67245 .28418 m
.67571 .27785 L
s
.66919 .29052 m
.67245 .28418 L
s
.66593 .29687 m
.66919 .29052 L
s
.66266 .30322 m
.66593 .29687 L
s
.65939 .30958 m
.66266 .30322 L
s
.65612 .31594 m
.65939 .30958 L
s
.65285 .32231 m
.65612 .31594 L
s
.64957 .32868 m
.65285 .32231 L
s
.64629 .33507 m
.64957 .32868 L
s
.643 .34145 m
.64629 .33507 L
s
.63972 .34785 m
.643 .34145 L
s
.63643 .35425 m
.63972 .34785 L
s
.63313 .36065 m
.63643 .35425 L
s
.62984 .36707 m
.63313 .36065 L
s
.62653 .37348 m
.62984 .36707 L
s
.62323 .37991 m
.62653 .37348 L
s
.61992 .38634 m
.62323 .37991 L
s
.61662 .39278 m
.61992 .38634 L
s
.6133 .39922 m
.61662 .39278 L
s
.60999 .40567 m
.6133 .39922 L
s
.60667 .41213 m
.60999 .40567 L
s
.60334 .41859 m
.60667 .41213 L
s
.60002 .42506 m
.60334 .41859 L
s
.59669 .43153 m
.60002 .42506 L
s
.59336 .43801 m
.59669 .43153 L
s
.59002 .4445 m
.59336 .43801 L
s
.58668 .45099 m
.59002 .4445 L
s
.58334 .45749 m
.58668 .45099 L
s
.58 .464 m
.58334 .45749 L
s
.57665 .47051 m
.58 .464 L
s
.5733 .47703 m
.57665 .47051 L
s
.56994 .48355 m
.5733 .47703 L
s
.56658 .49009 m
.56994 .48355 L
s
.56322 .49662 m
.56658 .49009 L
s
.55986 .50317 m
.56322 .49662 L
s
.55649 .50972 m
.55986 .50317 L
s
.55312 .51627 m
.55649 .50972 L
s
.54974 .52284 m
.55312 .51627 L
s
.54636 .52941 m
.54974 .52284 L
s
.54298 .53598 m
.54636 .52941 L
s
.5396 .54257 m
.54298 .53598 L
s
.53621 .54915 m
.5396 .54257 L
s
.53282 .55575 m
.53621 .54915 L
s
.52943 .56235 m
.53282 .55575 L
s
.52603 .56896 m
.52943 .56235 L
s
.52263 .57557 m
.52603 .56896 L
s
.51922 .58219 m
.52263 .57557 L
s
.51581 .58882 m
.51922 .58219 L
s
.5124 .59546 m
.51581 .58882 L
s
.50899 .6021 m
.5124 .59546 L
s
.50557 .60874 m
.50899 .6021 L
s
.50215 .6154 m
.50557 .60874 L
s
.49873 .62206 m
.50215 .6154 L
s
.4953 .62872 m
.49873 .62206 L
s
.49187 .6354 m
.4953 .62872 L
s
.48843 .64208 m
.49187 .6354 L
s
.48499 .64876 m
.48843 .64208 L
s
.48155 .65546 m
.48499 .64876 L
s
.47811 .66216 m
.48155 .65546 L
s
.47466 .66886 m
.47811 .66216 L
s
.47121 .67558 m
.47466 .66886 L
s
.46775 .68229 m
.47121 .67558 L
s
.4643 .68902 m
.46775 .68229 L
s
.46083 .69575 m
.4643 .68902 L
s
.45737 .70249 m
.46083 .69575 L
s
.4539 .70924 m
.45737 .70249 L
s
.45043 .71599 m
.4539 .70924 L
s
.44695 .72275 m
.45043 .71599 L
s
.44347 .72952 m
.44695 .72275 L
s
.43999 .73629 m
.44347 .72952 L
s
.43651 .74307 m
.43999 .73629 L
s
.43302 .74985 m
.43651 .74307 L
s
.42953 .75665 m
.43302 .74985 L
s
.42603 .76345 m
.42953 .75665 L
s
.42253 .77025 m
.42603 .76345 L
s
.41903 .77707 m
.42253 .77025 L
s
.41552 .78389 m
.41903 .77707 L
s
.41201 .79071 m
.41552 .78389 L
s
.4085 .79755 m
.41201 .79071 L
s
.40498 .80439 m
.4085 .79755 L
s
.40146 .81123 m
.40498 .80439 L
s
.39793 .81809 m
.40146 .81123 L
s
.39441 .82495 m
.39793 .81809 L
s
.39088 .83181 m
.39441 .82495 L
s
.38734 .83869 m
.39088 .83181 L
s
.3838 .84557 m
.38734 .83869 L
s
.38026 .85246 m
.3838 .84557 L
s
.37672 .85935 m
.38026 .85246 L
s
.37317 .86625 m
.37672 .85935 L
s
.36962 .87316 m
.37317 .86625 L
s
.36606 .88008 m
.36962 .87316 L
s
.3625 .887 m
.36606 .88008 L
s
0 g
.25 Mabswid
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{264.813, 262.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004800011Q000`40O003h00Oogoo2Goo001hOol3
002=Ool007Qoo`04001oogoo002<Ool007Qoo`04001oogoo002<Ool007Qoo`<008eoo`00NGoo00<0
07ooOol0S7oo001iOol3002<Ool00?moo`Uoo`00ogoo2Goo003oOol9Ool00?moo`Uoo`00P7oo00<0
07ooOol0QGoo001oOol30026Ool007ioo`03001oo`00008008Eoo`00OGoo00@007ooOol0009oo`03
001oogoo089oo`00O7oo00D007ooOomoo`0000=oo`03001oogoo085oo`00Ngoo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0P7oo001jOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`1oOol007Uoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo07ioo`00N7oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol0OGoo001gOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`1lOol007Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo07]oo`00MGoo0`0027oo
00<007ooOol027oo00<007ooOol0NWoo001eOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`1jOol007Aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo07Uoo`00Lgoo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol0N7oo001bOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`1gOol0075oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo07Ioo`00L7oo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol0MGoo001_Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`1dOol006ioo`03001oogoo00moo`03001oogoo00moo`03001oogoo07=oo`00KGoo00<0
07ooOol047oo00<007ooOol047oo00<007ooOol0LWoo001/Ool00`00Ool0000AOol00`00Oomoo`0A
Ool00`00Oomoo`1aOol006]oo`03001oogoo019oo`03001oogoo019oo`03001oogoo071oo`00JWoo
00<007ooOol04goo00<007ooOol04goo00<007ooOol0Kgoo001YOol00`00Oomoo`0DOol00`00Oomo
o`0DOol00`00Oomoo`1^Ool006Qoo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo06eoo`00
Igoo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol0K7oo001GOol3000<Ool00`00Oomoo`0G
Ool00`00Oomoo`0GOol00`00Oomoo`1[Ool005Qoo`03001oogoo00Yoo`03001oogoo01Qoo`03001o
ogoo01Qoo`03001oogoo06Yoo`00EGoo1@002Woo00<007oo00006Goo00<007ooOol06Goo00<007oo
Ool0JGoo001EOol01000Oomoo`002Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol0J7oo
001FOol00`00Ool00009Ool00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`1WOol005Moo`80
00Qoo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo06Ioo`00H7oo00<007ooOol07Goo00<0
07ooOol07Goo00<007ooOol0IGoo001POol00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomoo`1U
Ool005moo`03001oogoo01ioo`03001oogoo01ioo`03001oogoo06Aoo`00GWoo00<007ooOol07goo
00<007ooOol07goo00<007ooOol0Hgoo001MOol00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomo
o`1ROol005aoo`03001oo`00025oo`03001oogoo025oo`03001oogoo065oo`00Fgoo00<007ooOol0
8Woo00<007ooOol08Woo00<007ooOol0H7oo001JOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00
Oomoo`1OOol005Uoo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo05ioo`00F7oo00<007oo
Ool09Goo00<007ooOol09Goo00<007ooOol0GGoo001GOol00`00Oomoo`0VOol00`00Oomoo`0VOol0
0`00Oomoo`1LOol005Ioo`03001oogoo02Moo`03001oogoo02Moo`03001oogoo05]oo`00EGoo00<0
07oo0000:7oo00<007ooOol0:7oo00<007ooOol0FWoo001DOol00`00Oomoo`0YOol00`00Oomoo`0Y
Ool00`00Oomoo`1IOol005=oo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo05Qoo`00DWoo
00<007ooOol0:goo00<007ooOol0:goo00<007ooOol0Egoo001AOol00`00Oomoo`0/Ool00`00Oomo
o`0/Ool00`00Oomoo`1FOol0051oo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo05Eoo`00
Cgoo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0E7oo001>Ool3000_Ool00`00Oomoo`0_
Ool00`00Oomoo`1COol004eoo`03001oogoo031oo`03001oogoo031oo`03001oogoo059oo`00C7oo
00<007ooOol0<Goo00<007ooOol0<Goo00<007ooOol0DGoo001;Ool00`00Oomoo`0bOol00`00Oomo
o`0/Ool00cjQ>X0nX@03Ool00`00Oomoo`1@Ool004Yoo`03001oogoo03=oo`03001oogoo02]oo`04
?Z4jP3jQ>X04Ool00`00Oomoo`1?Ool003Yoo`@000aoo`03001oogoo03=oo`03001oogoo02]oo`03
>X0nXCjQ00Eoo`03001oogoo04moo`00>Woo00<007ooOol02goo0P00=Woo00<007ooOol0:Woo00@j
P3jQ>X0nX@Ioo`03001oogoo04ioo`00>goo00<007ooOol02Woo0P00=Woo00<007ooOol0:Goo00@j
P3jQ?Z4nX@Qoo`03001oogoo04eoo`00?7oo00<007ooOol027oo00<007ooOol0=Woo00<007ooOol0
:Woo00<jP3jQ>X002Goo00<007ooOol0C7oo000jOol01000Oomoo`0027oo00<007ooOol0=goo00<0
07ooOol0:Goo0SjQ00<jP3jQOol02Goo00<007ooOol0Bgoo000kOol20008Ool00`00Oomoo`0hOol0
0`00Oomoo`0YOol013jQ>X0nXCZ02goo00<007ooOol0BWoo0014Ool00`00Oomoo`0iOol00`00Oomo
o`0XOol013jQ>X0nXCjQ3Goo00<007ooOol0BGoo0013Ool00`00Oomoo`0jOol00`00Oomoo`0WOol0
13jQ>X0nXCZ03goo00<007ooOol0B7oo0012Ool00`00Oomoo`0kOol00`00Oomoo`0WOol00cZ0?Z4n
X@0AOol00`00Oomoo`17Ool0045oo`03001oo`0003aoo`03001oogoo02Ioo`04>X0nXCZ0?Z4BOol0
0`00Oomoo`16Ool0041oo`03001oogoo03eoo`03001oogoo02Eoo`04>X0nXCjQ?Z4DOol00`00Oomo
o`15Ool003moo`03001oogoo03ioo`03001oogoo02Ioo`03>X0nXCZ001Eoo`03001oogoo04Aoo`00
?Woo00<007ooOol0?goo00<007ooOol09Goo0SjQ00<jP3jQOol05Goo00<007ooOol0@goo000mOol0
0`00Oomoo`10Ool00`00Oomoo`0JOol00fhIKQYYn@07Ool01CZ0?Z4jP3jQ>X005goo00<007ooOol0
@Woo000lOol00`00Oomoo`11Ool00`00Oomoo`0JOol3KQT7Ool00cjQ>X0nX@0JOol00`00Oomoo`11
Ool003]oo`03001oo`00049oo`03001oogoo01Yoo`03JOU^6VhI00Ioo`04?Z4jP3jQ>X0KOol00`00
Oomoo`10Ool003Yoo`03001oogoo04=oo`03001oogoo01Uoo`A^6@Eoo`04?Z4jP3jQ?Z4MOol00`00
Oomoo`0oOol003Uoo`03001oogoo04Aoo`03001oogoo01Qoo`05JOU^6VhIKQYYn@06Ool00cjQ>X0n
X@0NOol00`00Oomoo`0nOol003Qoo`03001oogoo04Eoo`03001oogoo01Qoo`=^6@Moo`<nX@03>X1o
ogoo01eoo`03001oogoo03eoo`00=goo00<007ooOol0AWoo00<007ooOol05goo00A^6VhIKQYYn@Io
o`05?Z4jP3jQ>X0nX@0POol00`00Oomoo`0lOol003Ioo`03001oogoo04Moo`03001oogoo01Ioo`A^
6@Moo`8nX@03>X1oogoo025oo`03001oogoo03]oo`00=Goo00<007oo0000B7oo00<007ooOol05goo
00=^6VWiKQX01Woo00@jP3jQ>X0nXBAoo`03001oogoo03Yoo`00=Goo00<007ooOol0B7oo00<007oo
Ool05Woo16hI1Goo0SjQ00<jP3jQOol097oo00<007ooOol0>Woo000dOol00`00Oomoo`19Ool00`00
Oomoo`0EOol01FhJJOU^6VhIKQX01Goo00<nXCZ0?Z409goo00<007ooOol0>Goo000UOol2000<Ool0
0`00Oomoo`1:Ool00`00Oomoo`0EOol3KQT6Ool013jQ>X0nXCjQ:7oo00<007ooOol0>7oo000TOol0
1000Oomoo`002Woo00<007ooOol0Bgoo00<007ooOol057oo00AYnFhJKQU^6PIoo`04>X0nXCZ0?Z4Y
Ool00`00Oomoo`0gOol002Aoo`04001oogoo0009Ool2001=Ool00`00Oomoo`0COol4KQT7Ool3?Z40
0cZ0Oomoo`0XOol00`00Oomoo`0fOol002Aoo`04001oogoo0008Ool00`00Oomoo`1=Ool00`00Oomo
o`0COol016hJKQU^6VWi1Woo00@nXCZ0?Z4jP2aoo`03001oogoo03Eoo`0097oo00@007ooOol000Mo
o`03001oogoo04ioo`03001oogoo01=oo`A^6@Eoo`<nX@03>X1oogoo02aoo`03001oogoo03Aoo`00
9Goo0P001goo00<007ooOol0Cgoo00<007ooOol04Woo00A^6FhJJOU^6PIoo`03>X0nXCZ0031oo`03
001oogoo03=oo`00;Goo00<007ooOol0D7oo00<007ooOol04Goo16hI1Woo0SjQ00<jP3jQOol0<7oo
00<007ooOol0<Woo000/Ool00`00Oomoo`1AOol00`00Oomoo`0AOol00fhJJOU^6P07Ool00cjQ>X0n
X@0cOol00`00Oomoo`0aOol002]oo`03001oo`00059oo`03001oogoo011oo`A^6@Ioo`04?Z4jP3jQ
?Z4dOol00`00Oomoo`0`Ool002Yoo`03001oogoo05=oo`03001oogoo00moo`04KQYYnFhJKQT7Ool0
13Z0?Z4jP3jQ=Goo00<007ooOol0;goo000ZOol3001COol00`00Oomoo`0@Ool3KQT7Ool3?Z400cZ0
Oomoo`0aOol4000`Ool002Uoo`04001oogooOol2001AOol00`00Oomoo`0?Ool016hJKQU^6VWi1Woo
00@nXCZ0?Z4jP39oo`8000=oo`03001oogoo02ioo`00:Goo00<007ooOol00goo0P00Cgoo00<007oo
Ool03Woo1FhI1Goo0cjQ00<jP7ooOol0;goo0P001Goo00<007ooOol0;Woo000YOol00`00Oomoo`05
Ool00`00Oomoo`1<Ool00`00Oomoo`0>Ool00fhIKQYYn@07Ool00cZ0?Z4jP00aOol00`00Oomoo`05
Ool00`00Oomoo`0^Ool002Uoo`03001oogoo00Ioo`8004aoo`03001oogoo00eoo`A^6@Ioo`8nX@03
>X0nXGoo02ioo`8000Qoo`03001oogoo02ioo`00:7oo00<007ooOol02Goo0P00BWoo00<007ooOol0
37oo00A^6FhJJOU^6PIoo`04>X0nXCZ0?Z4^Ool2000;Ool00`00Oomoo`0]Ool002Qoo`03001oogoo
00]oo`8004Qoo`03001oogoo00eoo`=^6@Moo`03>X0nXCjQ02aoo`8000aoo`8002moo`00:7oo00<0
07ooOol03Goo00<007ooOol0AGoo00<007ooOol037oo00AYnFhJKQU^6PIoo`04>X0nXCZ0?Z4[Ool0
0`00Oomoo`0=Ool00`00Oomoo`0]Ool002Moo`03001oogoo00moo`8004Eoo`03001oogoo00]oo`E^
6@Eoo`05>X0nXCjQ?Z4jP00YOol2000AOol00`00Oomoo`0/Ool002Moo`03001oogoo015oo`8004=o
o`03001oogoo00]oo`03KQY^6FhJ00Moo`03?Z4jP3jQ02Uoo`8001=oo`03001oogoo02aoo`009goo
00<007ooOol04goo0P00@Goo00<007ooOol02Woo16hI1Woo0cjQ00<jP7ooOol09Goo0P005Goo00<0
07ooOol0;7oo000WOol00`00Oomoo`0EOol00`00Oomoo`0nOol00`00Oomoo`09Ool016hJKQU^6VWi
1goo00<jP3jQ>X009goo00<007ooOol05Woo00<007ooOol0:goo000VOol00`00Oomoo`0GOol2000n
Ool00`00Oomoo`0:Ool3KQT6Ool2?Z400cZ0?Z5oo`0TOol2000HOol2000]Ool002Ioo`03001oogoo
01Uoo`8003aoo`03001oogoo00Uoo`04KQYYnFhJKQT5Ool013Z0?Z4jP3jQ97oo0P006goo00<007oo
Ool0:goo000VOol00`00Oomoo`0KOol2000jOol00`00Oomoo`08Ool5KQT6Ool00cZ0?Z4nX@0ROol2
000MOol00`00Oomoo`0[Ool002Eoo`03001oogoo01ioo`03001oogoo03Moo`03001oogoo00Qoo`03
JOU^6VhI00Moo`04>X0nXCZ0?Z4QOol00`00Oomoo`0NOol00`00Oomoo`0ZOol002Eoo`03001oogoo
01moo`8003Moo`03001oogoo00Moo`A^6@Ioo`05>X0nXCjQ?Z4jP00OOol2000QOol00`00Oomoo`0Z
Ool002Eoo`03001oogoo025oo`8003Eoo`03001oogoo00Ioo`04JOU^6VhIKQX7Ool00cjQ>X0nX@0O
Ool2000SOol00`00Oomoo`0ZOol002Eoo`03001oogoo02=oo`8003=oo`03001oogoo00Moo`=^6@Io
o`<nX@03>X1oogoo01]oo`8002Ioo`03001oogoo00Uoo`D0009oo`8000Aoo`80015oo`0097oo00<0
07ooOol09Woo00<007ooOol0<7oo00<007ooOol01Woo00A^6FhJJOU^6PEoo`04?Z4jP3jQ>X0MOol0
0`00Oomoo`0UOol2000=Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00ioo`00
97oo00<007ooOol09goo0P00<7oo00<007ooOol01Goo1FhI1Goo0SjQ00<jP7ooOol06Woo0P00:Goo
00<007ooOol02goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0>Ool002Aoo`03
001oogoo02Uoo`8002ioo`03001oogoo00Eoo`03KQYYnFhJ00Ioo`04>X0nXCZ0?Z4JOol2000[Ool0
0`00Oomoo`03Ool40004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00ioo`00
8goo00<007ooOol0;7oo0P00;7oo00<007ooOol017oo16hI1Woo00@nXCZ0?Z4nXAQoo`8002ioo`03
001oogoo00Yoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol03Woo000SOol00`00
Oomoo`0^Ool00`00Oomoo`0YOol00`00Oomoo`03Ool016hJJOU^6VhI1goo00@jP3jQ>X0nXAMoo`03
001oogoo02ioo`03001oogoo00Uoo`8000Aoo`8000Aoo`80015oo`008goo00<007ooOol0;goo0P00
:Goo00<007ooOol00goo0fhI1goo00@jP3jQ?Z4nXAIoo`80035oo`03001oogoo02Qoo`008goo00<0
07ooOol0<Goo0P009goo00<007ooOol00Woo00AYnFhJKQU^6PMoo`03?Z4jP3jQ01Eoo`8003Aoo`03
001oogoo02Moo`008Woo00<007ooOol0=7oo0P009Goo00<007ooOol00Woo16hI1Woo0cjQ00<jP7oo
Ool04Goo0P00=7oo0`00:Goo000ROol00`00Oomoo`0fOol2000SOol00`00Oomoo`02Ool016hIKQYY
nFhJ1Goo00@nXCZ0?Z4jP19oo`8003Qoo`03001oogoo02Moo`008Woo00<007ooOol0>7oo00<007oo
Ool087oo00@007ooOomoo`A^6@Ioo`8nX@03>X1oogoo011oo`03001oogoo03Uoo`03001oogoo02Io
o`008Goo00<007ooOol0>Woo0P0087oo00L007ooOom^6FhJJOU^6P06Ool013Z0?Z4jP3jQ47oo0P00
?7oo00<007ooOol09Woo000QOol00`00Oomoo`0lOol2000NOol00`00Oomoo`03KQT7Ool013jQ>X0n
XCjQ3Woo0P00?Woo00<007ooOol09Woo000QOol00`00Oomoo`0nOol2000LOol01P00Oom^6VWiKQY^
6@Moo`04>X0nXCZ0?Z4<Ool20010Ool00`00Oomoo`0VOol0025oo`03001oogoo041oo`03001oogoo
01Uoo`03001oofhI00=^6@Ioo`04>X0nXCjQ?Z4<Ool00`00Oomoo`10Ool2000WOol0021oo`03001o
ogoo049oo`8001Uoo`06001oofhJKQU^6VWi1Woo00<nXCZ0?Z402goo0P00A7oo00<007ooOol09Goo
000POol00`00Oomoo`14Ool2000GOol00`00KQU^6@02KQT6Ool3?Z400cZ0Oomoo`07Ool20016Ool0
0`00Oomoo`0UOol0021oo`03001oogoo04Ioo`8001Eoo`04001^6FhJJOT6Ool013jQ>X0nXCZ027oo
0P00BGoo00<007ooOol097oo000OOol00`00Oomoo`19Ool00`00Oomoo`0BOol00`00KQU^6@07Ool2
?Z400cZ0Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0TOol001moo`03001oogoo04Yoo`80015o
o`04KQT006WiKQX6Ool013Z0?Z4jP3jQ1Woo0P00C7oo00<007ooOol097oo000OOol00`00Oomoo`1<
Ool2000>Ool2KQT00`00KQUoo`06Ool013jQ>X0nXCjQ17oo0P00CWoo00<007ooOol097oo000OOol0
0`00Oomoo`1>Ool2000=Ool00fWi001^6@07Ool013Z0?Z4jP3jQ0Woo0P00D7oo0P009Goo000NOol0
0`00Oomoo`1AOol00`00Oomoo`09Ool2KQT00`00KQUoo`05Ool013Z0?Z4nXCjQ0Woo00<007ooOol0
DGoo00<007ooOol08goo000NOol00`00Oomoo`1BOol20008Ool01FWiKQY^6@00JOT01Goo00DjP3jQ
>X0nXGoo008005Aoo`03001oogoo02=oo`007Woo00<007ooOol0E7oo0P001Woo0fhI00<007ooOol0
17oo0cjQ0P00Egoo00<007ooOol08Woo000MOol00`00Oomoo`1GOol20003Ool01FhJKQU^6VWi0000
1Goo00@nXCZ0?Z4jP5Uoo`03001oogoo029oo`007Goo00<007ooOol0FGoo00<007ooKQT00fhI00=o
o`00Ool017oo0SjQ00<jP7ooOol0F7oo00<007ooOol08Woo000MOol00`00Oomoo`1JOol200001FhJ
JOU^6Woo000017oo00@jP3jQ>X0nXE]oo`03001oogoo025oo`007Goo00<007ooOol0Fgoo16hI00Eo
o`00Oomoo`00008nX@03>X0nXGoo05]oo`03001oogoo025oo`0077oo00<007ooOol0Fgoo00E^6VWi
KQY^6FhJ00@0009oo`03>X0nXCZ005]oo`8002=oo`0077oo00<007ooOol0Fgoo0fhI0goo00D007oo
OomoocZ000<nXEaoo`03001oogoo025oo`0077oo00<007ooOol0FWoo00EYnFhJKQU^6Woo00D00005
>X0nXCZ0?Z4jP01MOol00`00Oomoo`0POol001]oo`03001oogoo05Yoo`A^6@80009oo`03001oogoo
00800003?Z5oogoo05eoo`03001oogoo021oo`006goo00<007ooOol0FWoo00A^6VhIKQX000Aoo`05
001oocjQ>X0nX@02001NOol00`00Oomoo`0POol001]oo`03001oogoo05Uoo`9^6@8000Eoo`05001o
ocjQ?Z4jP002Ool00`00Oomoo`1LOol00`00Oomoo`0OOol001]oo`03001oogoo05Uoo`800003JOU^
6Woo00Aoo`05000jP3jQ>X0nX@03Ool2001LOol00`00Oomoo`0OOol001Yoo`03001oogoo05Qoo`80
00A^6@Eoo`8nX@03>X0nXGoo00Eoo`8005Yoo`03001oogoo01moo`006Woo00<007ooOol0Egoo00H0
07ooKQYYnFhJKQT6Ool01000>X0nXCZ027oo00<007ooOol0EWoo0P008Goo000JOol00`00Oomoo`1E
Ool200000gooKQU^6@02KQT7Ool013Z0?Z4nXCjQ2Goo0P00F7oo00<007ooOol07Woo000IOol00`00
Oomoo`1DOol20003Ool00fWiKQY^6@07Ool01CZ0?Z4jP3jQ>X002goo0P00EWoo00<007ooOol02Woo
0P0017oo0P0037oo000IOol00`00Oomoo`1COol00`00Oomoo`02Ool4KQT7Ool3?Z4?Ool2001DOol0
0`00Oomoo`09Ool01000Oomoo`000Woo00@007ooOol000]oo`006Goo00<007ooOol0DGoo0P0017oo
00AYnFhJKQU^6PMoo`04?Z4jP3jQ>X0AOol00`00Oomoo`1BOol00`00Oomoo`0;Ool01000Oomoo`00
0Woo00<007ooOol02Goo000IOol00`00Oomoo`1?Ool20007Ool3KQT7Ool2?Z400cZ0Oomoo`0AOol2
001BOol00`00Oomoo`02Ool40003Ool20003Ool01000Oomoo`002goo000HOol00`00Oomoo`1>Ool2
0008Ool016hIKQYYnFhJ1Woo00@jP3jQ>X0nXAEoo`80051oo`03001oogoo00Uoo`03001oogoo009o
o`04001oogoo000;Ool001Qoo`03001oogoo04eoo`03001oogoo00Moo`E^6@Eoo`8nX@03>X0nX@00
01Moo`8004moo`03001oogoo00Qoo`<000=oo`8000aoo`0067oo00<007ooOol0Bgoo0P002Woo00=^
6VWiKQX01goo00DnXCZ0?Z5oo`0001Uoo`03001oogoo04Yoo`<001ioo`005goo00<007ooOol0BWoo
0P002goo16hI1Woo00HnXCZ0?Z4nXGoo000JOol2001<Ool00`00Oomoo`0LOol001Moo`03001oogoo
04Uoo`03001oogoo00Yoo`04KQYYnFhJKQT7Ool01SZ0?Z4jP3jQOol001aoo`8004Yoo`03001oogoo
01aoo`005goo00<007ooOol0Agoo0P003Woo0fhI1goo0cjQ00<jP7oo00007Woo00<007ooOol0B7oo
00<007ooOol06goo000GOol00`00Oomoo`15Ool2000?Ool016hJKQU^6VWi1Woo00@nXCZ0?Z4jP09o
o`03001oogoo01eoo`8004Qoo`03001oogoo01]oo`005Woo00<007ooOol0A7oo0P0047oo1FhI1Woo
0SjQ00DjP7ooOomoo`00025oo`8004Ioo`03001oogoo01]oo`005Woo00<007ooOol0@goo00<007oo
Ool047oo00=^6FhJJOT01goo00@jP3jQ>X0nX@=oo`03001oogoo025oo`8004Eoo`03001oogoo01Yo
o`005Woo00<007ooOol0@Goo0P004Woo16hI1Woo0SjQ00<jP3jQOol00goo00<007ooOol08goo00<0
07ooOol0@Woo00<007ooOol06Woo000EOol00`00Oomoo`10Ool2000DOol00fhJJOU^6P07Ool00cjQ
>X0nX@05Ool00`00Oomoo`0TOol20012Ool00`00Oomoo`0JOol001Eoo`03001oogoo03moo`03001o
ogoo01=oo`A^6@Ioo`04?Z4jP3jQ?Z45Ool00`00Oomoo`0VOol2000oOol2000LOol001Eoo`03001o
ogoo03eoo`8001Eoo`04KQYYnFhJKQT6Ool013jQ>X0nXCZ01Woo00<007ooOol0:7oo0P00?goo00<0
07ooOol06Goo000EOol00`00Oomoo`0kOol2000HOol3KQT7Ool3?Z46Ool00`00Oomoo`0ZOol00`00
Oomoo`0lOol00`00Oomoo`0IOol001Aoo`03001oogoo03Yoo`8001Uoo`04KQY^6FhJJOT6Ool013jQ
>X0nXCZ01Woo00<007ooOol0:goo0P00?7oo00<007ooOol06Goo000DOol00`00Oomoo`0iOol00`00
Oomoo`0HOol5KQT6Ool2?Z400cZ0?Z5oo`05Ool00`00Oomoo`0]Ool2000kOol00`00Oomoo`0HOol0
01Aoo`03001oogoo03Moo`8001]oo`03KQU^6VWi00Moo`04>X0nXCZ0?Z47Ool00`00Oomoo`0_Ool0
0`00Oomoo`0hOol00`00Oomoo`0HOol001=oo`03001oogoo03Ioo`8001aoo`A^6@Ioo`8nX@03>X0n
XGoo00Moo`03001oogoo031oo`8003Qoo`03001oogoo01Qoo`004goo00<007ooOol0=Goo00<007oo
Ool06goo00A^6FhJJOU^6PMoo`03?Z4jP3jQ00Uoo`03001oogoo039oo`8003Moo`03001oogoo01Mo
o`004goo00<007ooOol0<goo0P007Woo0fhI1goo00@nXCZ0?Z4nX@Uoo`03001oogoo03Aoo`8003Eo
o`03001oogoo01Moo`004goo00<007ooOol0<Goo0P007goo00A^6VWiKQY^6@Moo`03>X0nXCZ000Yo
o`03001oogoo03Ioo`03001oogoo035oo`8001Uoo`004Woo00<007ooOol0<7oo0P008Goo16hI1Woo
00@jP3jQ?Z4nX@Yoo`03001oogoo03Moo`80039oo`03001oogoo01Moo`004Woo00<007ooOol0;goo
00<007ooOol08Goo00A^6VhIKQYYn@Eoo`04>X0nXCZ0?Z4;Ool00`00Oomoo`0iOol2000aOol00`00
Oomoo`0FOol0019oo`03001oogoo02eoo`8002=oo`A^6@Moo`8nX@03>X1oogoo00Uoo`03001oogoo
03]oo`8002moo`03001oogoo01Ioo`004Goo00<007ooOol0;7oo0P0097oo00A^6VhIKQYYn@Moo`04
>X0nXCZ0?Z4;Ool00`00Oomoo`0mOol00`00Oomoo`0/Ool00`00Oomoo`0FOol0015oo`03001oogoo
02]oo`03001oogoo02Aoo`=^6@Moo`8nX@03>X0nXCjQ00]oo`03001oogoo03ioo`8002eoo`03001o
ogoo01Eoo`004Goo00<007ooOol0:Goo0P009Woo00A^6FhJJOU^6PMoo`03?Z4jP3jQ00eoo`03001o
ogoo041oo`8002]oo`03001oogoo01Eoo`004Goo00<007ooOol09goo0P00:7oo0fhI1goo00@nXCZ0
?Z4nX@eoo`03001oogoo049oo`8002Uoo`03001oogoo01Eoo`0047oo00<007ooOol09Woo0P00:Goo
00A^6VWiKQY^6@Moo`03>X0nXCZ000ioo`03001oogoo04Aoo`03001oogoo02Ioo`03001oogoo01Eo
o`0047oo00<007ooOol09Goo00<007ooOol0:Goo16hI1Woo00@jP3jQ?Z4nX@ioo`03001oogoo04Eo
o`8002Ioo`8001Ioo`0047oo00<007ooOol08goo0P00;7oo00A^6VhIKQYYn@Eoo`04>X0nXCZ0?Z4?
Ool00`00Oomoo`17Ool2000UOol00`00Oomoo`0DOol000moo`03001oogoo029oo`8002eoo`A^6@Io
o`<nXA1oo`03001oogoo04Uoo`03001oogoo029oo`03001oogoo01Aoo`003goo00<007ooOol08Goo
00<007ooOol0;7oo00A^6VhIKQYYn@Ioo`04?Z4jP3jQ>X0@Ool00`00Oomoo`1:Ool2000SOol00`00
Oomoo`0COol000moo`03001oogoo01moo`8002moo`=^6@Moo`8nX@03>X0nXGoo00moo`03001oogoo
04aoo`80025oo`03001oogoo01=oo`003goo00<007ooOol07Goo0P00<7oo00A^6FhJJOU^6PMoo`04
?Z4jP3jQ>X0@Ool00`00Oomoo`1>Ool2000OOol00`00Oomoo`0COol000ioo`03001oogoo01aoo`80
035oo`A^6@Moo`03?Z4jP3jQ008nXA1oo`03001oogoo051oo`03001oogoo01eoo`03001oogoo019o
o`003Woo00<007ooOol06goo00<007ooOol0<Woo00=YnFhJKQT01goo00<jP3jQ>X004Woo00<007oo
Ool0DGoo0P007Goo00<007ooOol04Woo000>Ool00`00Oomoo`0IOol2000dOol4KQT6Ool013Z0?Z4n
XCjQ4Woo00<007ooOol0Dgoo0P006goo00<007ooOol04Woo000=Ool00`00Oomoo`0HOol2000eOol0
1FWiKQY^6FhJJOT01Woo00<nXCZ0?Z404goo00<007ooOol0EGoo0P006Goo00<007ooOol04Woo000=
Ool00`00Oomoo`0GOol00`00Oomoo`0eOol3KQT7Ool3?Z400cZ0Oomoo`0AOol00`00Oomoo`1GOol0
0`00Oomoo`0EOol3000COol000eoo`03001oogoo01Eoo`8003Moo`04KQY^6FhJJOT6Ool013jQ>X0n
XCZ057oo00<007ooOol0F7oo0P005goo00<007ooOol04Goo000=Ool00`00Oomoo`0COol2000iOol3
KQT7Ool2?Z400cZ0Oomoo`0COol00`00Oomoo`1JOol2000EOol00`00Oomoo`0AOol000aoo`03001o
ogoo019oo`8003Yoo`04KQU^6VWiKQX6Ool013Z0?Z4jP3jQ5Goo00<007ooOol0G7oo00<007ooOol0
4goo00<007ooOol047oo000<Ool00`00Oomoo`0AOol00`00Oomoo`0iOol4KQT7Ool00cjQ>X0nX@0F
Ool00`00Oomoo`1MOol2000COol00`00Oomoo`0@Ool000aoo`03001oogoo00moo`8003aoo`03KQYY
nFhJ00Moo`04?Z4jP3jQ>X0FOol00`00Oomoo`1OOol2000AOol00`00Oomoo`0@Ool000]oo`03001o
ogoo00ioo`8003eoo`A^6@Moo`04>X0nXCjQ?Z4FOol00`00Oomoo`1QOol2000?Ool00`00Oomoo`04
Ool2000:Ool000]oo`03001oogoo00eoo`03001oogoo03eoo`04JOU^6VhIKQX7Ool013jQ>X0nXCZ0
5Woo00<007ooOol0Hgoo00<007ooOol03Goo00<007ooOol00Woo00@007ooOol000Uoo`002goo00<0
07ooOol02goo0P00@7oo16hI1Woo0cjQ00<jP7ooOol05Goo00<007ooOol0I7oo0P003Goo00<007oo
Ool00Woo00@007ooOol000Uoo`002goo00<007ooOol02Goo0P00@Goo00A^6VhIKQYYn@Ioo`04?Z4j
P3jQ>X0HOol00`00Oomoo`1VOol2000;Ool00`00Oomoo`02Ool01000Oomoo`002Goo000:Ool00`00
Oomoo`08Ool20012Ool4KQT7Ool2?Z400cZ0Oomoo`0GOol00`00Oomoo`1XOol2000:Ool01@00Oomo
ogoo00000Woo00<007ooOol01goo000:Ool00`00Oomoo`07Ool00`00Oomoo`12Ool00fhIKQYYn@07
Ool013Z0?Z4jP3jQ6Goo00<007ooOol0JWoo00<007ooOol01Goo0`0017oo0P002Woo000:Ool00`00
Oomoo`05Ool20014Ool4KQT7Ool00cjQ>X0nX@0JOol00`00Oomoo`1[Ool20007Ool00`00Oomoo`0>
Ool000Uoo`03001oogoo00Aoo`8004Ioo`03KQYYnFhJ00Moo`04?Z4jP3jQ>X0JOol00`00Oomoo`1]
Ool20006Ool00`00Oomoo`0=Ool000Uoo`03001oogoo00=oo`03001oogoo04Eoo`A^6@Ioo`04?Z4j
P3jQ?Z4KOol00`00Oomoo`1_Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool000Uoo`04001oogooOol2
0018Ool016WiKQY^6FhJ1Woo00<jP3jQ>X0077oo00<007ooOol0L7oo0P000goo00<007ooOol03Goo
0009Ool01000Ool00000BWoo16hI1Goo00@jP3jQ?Z4nXAaoo`03001oogoo079oo`800003Ool007oo
00ioo`0027oo0`0000=oo`00Ool0B7oo00A^6VhIKQYYn@Ioo`04?Z4jP3jQ>X0LOol00`00Oomoo`1d
Ool3000>Ool000Qoo`80009oo`03001oogoo04Ioo`A^6@Moo`8nX@03>X0nXGoo01]oo`03001oogoo
07Aoo`<000ioo`002Woo1000Agoo00=^6FhJJOT01goo00DjP3jQ>X0nXCZ001aoo`03001oogoo071o
o`@0015oo`003Woo10000Woo00<007ooOol0?Goo16hI1goo00<nXCZ0?Z407Woo00<007ooOol0K7oo
10005Goo000BOol40005Ool00`00Oomoo`0eOol016hIKQYYnFhJ1goo00@nXCZ0?Z4jP1ioo`03001o
ogoo06Qoo`@001Uoo`005Woo100000=oo`00Ool0=Woo0fhI27oo00<jP3jQ?Z407goo00<007ooOol0
I7oo10007Goo000JOol40004Ool00`00Oomoo`0]Ool016hJJOU^6VhI1goo00@jP3jQ>X0nXAmoo`03
001oogoo061oo`@0025oo`007Woo1@00;goo16hI1goo0cjQ87oo00<007ooOol0G7oo10009Goo000R
Ool40003Ool00`00Oomoo`0VOol016hJKQU^6VWi:Woo00<007ooOol0F7oo1000:Goo0008Ool5000I
Ool40006Ool00`00Oomoo`0NOol5KQTZOol00`00Oomoo`1DOol4000]Ool000Yoo`03001oogoo01eo
o`@0009oo`03001oogoo01ioo`03KQU^6VWi02aoo`03001oogoo051oo`@0035oo`002Woo00<007oo
Ool08Goo100017oo00<007ooOol05goo16hI;7oo00<007ooOol0C7oo1000=Goo000:Ool00`00Oomo
o`0UOol5000HOol016hIKQYYnFhJ;Goo00<007ooOol0B7oo1000>Goo000:Ool00`00Oomoo`0YOol4
0003Ool00`00Oomoo`0?Ool3KQT^Ool00`00Oomoo`14Ool4000mOol000Uoo`8002moo`@000Eoo`03
001oogoo00Qoo`04KQYYnFhJKQT^Ool00`00Oomoo`10Ool40011Ool003ioo`D000]oo`=^6Bmoo`03
001oogoo03aoo`@004Eoo`00@Woo10000Woo00<007ooOol00goo00<007ooOol0;goo00<007ooOol0
>7oo1000BGoo0016Ool40004Ool00`00Oomoo`0_Ool00`00Oomoo`0dOol4001=Ool002Ioo`8000Ao
o`8000Aoo`8001Ioo`D000Eoo`03001oogoo02Uoo`03001oogoo031oo`@0055oo`009Goo00@007oo
Ool000Qoo`04001oogoo000IOol400000goo001oo`0[Ool00`00Oomoo`0/Ool4001EOol002Eoo`04
001oogoo000;Ool00`00Oomoo`0KOol40003Ool00`00Oomoo`0TOol00`00Oomoo`0XOol4001IOol0
02Eoo`04001oogoo0009Ool2000ROol40004Ool00`00Oomoo`0OOol00`00Oomoo`0TOol4001MOol0
02Eoo`04001oogoo0009Ool00`00Oomoo`0UOol50004Ool00`00Oomoo`0JOol00`00Oomoo`0POol4
001QOol002Ioo`8000Yoo`<002Uoo`@00003Ool007oo00=oo`03001oogoo01Eoo`03001oogoo01ao
o`@006Eoo`00HWoo10000Woo00<007ooOol05Goo00<007ooOol067oo1000JGoo001VOol40003Ool0
0`00Oomoo`0@Ool00`00Oomoo`0DOol4001]Ool004aoo`8001aoo`@000=oo`03001oogoo00aoo`03
001oogoo011oo`@0075oo`00Bgoo00@007ooOol001moo`@000Aoo`03001oogoo00Moo`03001oogoo
00aoo`@007Eoo`00Bgoo00@007ooOol002=oo`D000=oo`07001oogooOol007oo00002Woo1000NGoo
001;Ool01000Oomoo`009goo1@000goo00<007oo00001Woo1000OGoo001;Ool01000Oomoo`00:goo
1@0000Aoo`00Oomoo`@0085oo`00C7oo0P00<7oo1@00QGoo001SOol20004Ool20004Ool2002GOol0
069oo`04001oogoo0008Ool01000Oomoo`00UWoo001ROol01000Oomoo`002goo00<007ooOol0U7oo
001LOol40002Ool01000Oomoo`002Goo0P00Ugoo001ROol01000Oomoo`002Goo00<007ooOol0UWoo
001SOol2000:Ool3000=Ool50024Ool0085oo`03001oogoo08Aoo`00PGoo00<007ooOol0Q7oo001i
Ool40004Ool00`00Oomoo`24Ool0085oo`03001oogoo08Aoo`00P7oo0P00QWoo0000\
\>"],
  ImageRangeCache->{{{0, 263.813}, {261.125, 0}} -> {0.0373153, -0.0388469, \
0.00359608, 0.00359608}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Four spheres sedimenting in a Newtonian fluid. Initially the spheres are at \
equal distance from each others.  Due to hydrodynamic interaction, the last \
sphere lags behind after a certain time.\
\>", "Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["FU={0,0,-3,0,0,-3,0,0,-3,0,0,-3,0,0,0,0,0,0,0,0,0,0,0,0};", "Input"],

Cell["\<\
X[1]=0;Y[1]=0;Z[1]=0;X[2]=0;Y[2]=0;Z[2]=2.5;X[3]=0;Y[3]=0;Z[3]=5;X[4]=0;Y[4]=\
0;Z[4]=7.5;\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics3D[{{RGBColor[1,0,1],PointSize[0.05],Point[{X[1],Y[1],Z[1]}]},{\
RGBColor[1,0,1],PointSize[0.05],Point[{X[2],Y[2],Z[2]}]},{RGBColor[1,0,1],\
PointSize[0.05],Point[{X[3],Y[3],Z[3]}]},{RGBColor[1,0,1],PointSize[0.05],\
Point[{X[4],Y[4],Z[4]}]}}]]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.58052 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.840339 2.69471 -0.114189 2.69471 [
[ 0 0 0 0 ]
[ 1 2.58052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08242 .2111 m
0 2.27545 L
s
0 2.27545 m
.3651 2.58052 L
s
.3651 2.58052 m
.38703 .57111 L
s
.38703 .57111 m
.08242 .2111 L
s
.63691 0 m
.92173 .38064 L
s
.92173 .38064 m
1 2.41985 L
s
1 2.41985 m
.663 2.09382 L
s
.663 2.09382 m
.63691 0 L
s
.08242 .2111 m
0 2.27545 L
s
0 2.27545 m
.663 2.09382 L
s
.663 2.09382 m
.63691 0 L
s
.63691 0 m
.08242 .2111 L
s
.38703 .57111 m
.92173 .38064 L
s
.92173 .38064 m
1 2.41985 L
s
1 2.41985 m
.3651 2.58052 L
s
.3651 2.58052 m
.38703 .57111 L
s
0 0 m
1 0 L
1 2.58052 L
0 2.58052 L
closepath
clip
newpath
1 0 1 r
.05 w
.50702 .33803 Mdot
.50702 .91869 Mdot
.50702 1.56558 Mdot
.50702 2.29072 Mdot
0 g
.25 Mabswid
.63691 0 m
.92173 .38064 L
s
.92173 .38064 m
1 2.41985 L
s
1 2.41985 m
.663 2.09382 L
s
.663 2.09382 m
.63691 0 L
s
.08242 .2111 m
0 2.27545 L
s
0 2.27545 m
.663 2.09382 L
s
.663 2.09382 m
.63691 0 L
s
.63691 0 m
.08242 .2111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 743.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0002ia000`40O003h00Oogoo8Goo002eOol2
001YOol00;=oo`800003Ool0000006Qoo`00/7oo0`000goo00<007oo0000Igoo002]Ool30006Ool0
0`00Ool0001WOol00:]oo`8000Uoo`04001oogoo001VOol00:Qoo`<000]oo`05001oogooOol0001U
Ool00:Ioo`8000ioo`03001oogoo009oo`03001oogoo069oo`00Xgoo0`0047oo00<007ooOol00Woo
00<007ooOol0HWoo002POol3000COol00`00Oomoo`03Ool00`00Oomoo`1QOol009ioo`8001Ioo`03
001oogoo00Aoo`03001oogoo061oo`00Vgoo0`0067oo00<007ooOol01Goo00<007ooOol0Ggoo002I
Ool2000KOol00`00Oomoo`05Ool00`00Oomoo`1OOol009Ioo`<001eoo`03001oogoo00Ioo`03001o
ogoo05ioo`00Tgoo0`0087oo00<007ooOol01goo00<007ooOol0GGoo002AOol2000SOol00`00Oomo
o`08Ool00`00Oomoo`1LOol008ioo`<002Eoo`03001oogoo00Qoo`03001oogoo05aoo`00Rgoo0`00
:7oo00<007ooOol02Goo00<007ooOol0Fgoo0029Ool2000[Ool00`00Oomoo`0:Ool00`00Oomoo`1J
Ool008Ioo`<002eoo`03001oogoo00]oo`03001oogoo05Uoo`00Q7oo0P00<7oo00<007ooOol02goo
00<007ooOol0FGoo0021Ool3000bOol00`00Oomoo`0<Ool00`00Oomoo`1HOol007ioo`<003Eoo`03
001oogoo00eoo`03001oogoo05Moo`00O7oo0P00>7oo00<007ooOol03Woo00<007ooOol0EWoo001i
Ool3000jOol00`00Oomoo`0>Ool00`00Oomoo`1FOol007Moo`8003eoo`03001oogoo00moo`03001o
ogoo05Eoo`00M7oo0`00?goo00<007ooOol047oo00<007ooOol0E7oo001aOol30012Ool00`00Oomo
o`0AOol00`00Oomoo`1COol006moo`8004Eoo`03001oogoo015oo`03001oogoo05=oo`00K7oo0`00
Agoo00<007ooOol04Woo00<007ooOol0DWoo001ZOol2001:Ool00`00Oomoo`0COol00`00Oomoo`1A
Ool006Moo`<004aoo`03001oogoo01Aoo`03001oogoo051oo`00I7oo0`00Cgoo00<007ooOol057oo
00<007ooOol0D7oo001ROol2001BOol00`00Oomoo`0EOol00`00Oomoo`1?Ool005moo`<005Aoo`03
001oogoo01Ioo`03001oogoo04ioo`00GGoo0P00Egoo00<007ooOol05goo00<007ooOol0CGoo001J
Ool3001IOol00`00Oomoo`0GOol00`00Oomoo`1=Ool005Moo`<005aoo`03001oogoo01Qoo`03001o
ogoo04aoo`00EGoo0P00Ggoo00<007ooOol06Goo00<007ooOol0Bgoo001BOol3001ROol00`00Oomo
o`0IOol00`00Oomoo`1:Ool0051oo`8006Eoo`03001oogoo01Uoo`03001oogoo04Yoo`00CGoo0`00
Igoo00<007ooOol06Woo00<007ooOol0BGoo001:Ool3001ZOol00`00Oomoo`0KOol00`00Oomoo`18
Ool004Qoo`8006eoo`03001oogoo01aoo`03001oogoo04Moo`00AGoo0`00Kgoo00<007ooOol077oo
00<007ooOol0Agoo0013Ool2001bOol00`00Oomoo`0MOol00`00Oomoo`16Ool0041oo`<007Aoo`03
001oogoo01ioo`03001oogoo04Eoo`00?Goo0`00Mgoo00<007ooOol07goo00<007ooOol0A7oo000k
Ool2001jOol00`00Oomoo`0OOol00`00Oomoo`14Ool003Qoo`<007aoo`03001oogoo021oo`03001o
ogoo04=oo`00=Goo0`00Ogoo00<007ooOol08Goo00<007ooOol0@Woo000cOol20022Ool00`00Oomo
o`0ROol00`00Oomoo`11Ool0031oo`<008Aoo`03001oogoo029oo`03001oogoo045oo`00;Woo0P00
Qgoo00<007ooOol08goo00<007ooOol0@7oo000[Ool30029Ool00`00Oomoo`0TOol00`00Oomoo`0o
Ool002Qoo`<008aoo`03001oogoo02Eoo`03001oogoo03ioo`009Woo0P00Sgoo00<007ooOol09Goo
00<007ooOol0?Woo000SOol3002AOol00`00Oomoo`0VOol00`00Oomoo`0mOol0025oo`8009Aoo`03
001oogoo02Moo`03001oogoo03aoo`007Woo0`00UWoo00<007ooOol0:7oo00<007ooOol0>goo000K
Ool3002IOol00`00Oomoo`0XOol00`00Oomoo`0kOol001Uoo`8009aoo`03001oogoo02Uoo`03001o
ogoo03Yoo`005goo0P00WWoo00<007ooOol0:Woo00<007ooOol0>Goo000GOol2002NOol00`00Oomo
o`0[Ool00`00Oomoo`0hOol001Moo`03001oo`0009eoo`03001oogoo02]oo`03001oogoo03Qoo`00
5goo00@007ooOol009aoo`03001oogoo02aoo`03001oogoo03Moo`005goo00@007ooOol009aoo`03
001oogoo02eoo`03001oogoo03Ioo`005goo00D007ooOomoo`0009]oo`03001oogoo02ioo`03001o
ogoo03Eoo`005goo00<007ooOol00Woo00<007ooOol0V7oo00<007ooOol0;Woo00<007ooOol0=Goo
000GOol00`00Oomoo`03Ool00`00Oomoo`2GOol00`00Oomoo`0_Ool00`00Oomoo`0dOol001Moo`03
001oogoo00Aoo`03001oogoo09Ioo`03001oogoo031oo`03001oogoo03=oo`005goo00<007ooOol0
1Goo00<007ooOol0UGoo00<007ooOol0<Goo00<007ooOol0<Woo000GOol00`00Oomoo`06Ool00`00
Oomoo`2DOol00`00Oomoo`0aOol00`00Oomoo`0bOol001Moo`03001oogoo00Ioo`03001oogoo09Ao
o`03001oogoo039oo`03001oogoo035oo`005goo00<007ooOol01goo00<007ooOol0Tgoo00<007oo
Ool0<goo00<007ooOol0<7oo000FOol00`00Oomoo`09Ool00`00Oomoo`2BOol00`00Oomoo`0dOol0
0`00Oomoo`0_Ool001Ioo`03001oogoo00Yoo`03001oogoo095oo`03001oogoo03Aoo`03001oogoo
02moo`005Woo00<007ooOol02goo00<007ooOol0T7oo00<007ooOol0=Goo00<007ooOol0;Woo000F
Ool00`00Oomoo`0<Ool00`00Oomoo`2?Ool00`00Oomoo`0fOol00`00Oomoo`0]Ool001Ioo`03001o
ogoo00eoo`03001oogoo08ioo`03001oogoo03Moo`03001oogoo02aoo`005Woo00<007ooOol03Goo
00<007ooOol0SWoo00<007ooOol0=goo00<007ooOol0;7oo000FOol00`00Oomoo`0>Ool00`00Oomo
o`2=Ool00`00Oomoo`0hOol00`00Oomoo`0[Ool001Ioo`03001oogoo00moo`03001oogoo08aoo`03
001oogoo03Uoo`03001oogoo02Yoo`005Woo00<007ooOol047oo00<007ooOol0Rgoo00<007ooOol0
>Woo00<007ooOol0:Goo000FOol00`00Oomoo`0AOol00`00Oomoo`2:Ool00`00Oomoo`0jOol00`00
Oomoo`0YOol001Ioo`03001oogoo019oo`03001oogoo08Uoo`03001oogoo03]oo`03001oogoo02Qo
o`005Woo00<007ooOol04goo00<007ooOol0R7oo00<007ooOol0?7oo00<007ooOol09goo000FOol0
0`00Oomoo`0COol00`00Oomoo`28Ool00`00Oomoo`0mOol00`00Oomoo`0VOol001Ioo`03001oogoo
01Aoo`03001oogoo08Moo`03001oogoo03eoo`03001oogoo02Ioo`005Woo00<007ooOol05Goo00<0
07ooOol0QWoo00<007ooOol0?Woo00<007ooOol09Goo000FOol00`00Oomoo`0FOol00`00Oomoo`25
Ool00`00Oomoo`0oOol00`00Oomoo`0TOol001Ioo`03001oogoo01Moo`03001oogoo08Aoo`03001o
ogoo041oo`03001oogoo02=oo`005Woo00<007ooOol067oo00<007ooOol0FWoo1W`O8goo00<007oo
Ool0@7oo00<007ooOol08goo000FOol00`00Oomoo`0HOol00`00Oomoo`1IOol8O1lROol00`00Oomo
o`11Ool00`00Oomoo`0ROol001Ioo`03001oogoo01Uoo`03001oogoo05Moo`Yl7b5oo`03001oogoo
049oo`03001oogoo025oo`005Woo00<007ooOol06Woo00<007ooOol0EGoo37`O87oo00<007ooOol0
@goo00<007ooOol087oo000FOol00`00Oomoo`0KOol00`00Oomoo`1COol>O1lOOol00`00Oomoo`13
Ool00`00Oomoo`0POol001Ioo`03001oogoo01aoo`03001oogoo059oo`il7amoo`03001oogoo04Ao
o`03001oogoo01moo`005Woo00<007ooOol07Goo00<007ooOol0DGoo3W`O7goo00<007ooOol0AGoo
00<007ooOol07Woo000FOol00`00Oomoo`0NOol00`00Oomoo`1@Ool>O1lOOol00`00Oomoo`16Ool0
0`00Oomoo`0MOol001Ioo`03001oogoo01ioo`03001oogoo051oo`il7amoo`03001oogoo04Ioo`03
001oogoo01eoo`005Goo00<007ooOol087oo00<007ooOol0Cgoo3W`O7goo00<007ooOol0Agoo00<0
07ooOol077oo000EOol00`00Oomoo`0QOol00`00Oomoo`1?Ool<O1lPOol00`00Oomoo`18Ool00`00
Oomoo`0KOol001Eoo`03001oogoo029oo`03001oogoo04moo`Yl7b5oo`03001oogoo04Uoo`03001o
ogoo01Yoo`005Goo00<007ooOol08goo00<007ooOol0Cgoo27`O8Woo00<007ooOol0BGoo00<007oo
Ool06Woo000EOol00`00Oomoo`0TOol00`00Oomoo`1?Ool6O1lSOol00`00Oomoo`1:Ool00`00Oomo
o`0IOol001Eoo`03001oogoo02Eoo`03001oogoo07Moo`03001oogoo04]oo`03001oogoo01Qoo`00
5Goo00<007ooOol09Goo00<007ooOol0Mgoo00<007ooOol0C7oo00<007ooOol05goo000EOol00`00
Oomoo`0VOol00`00Oomoo`1fOol00`00Oomoo`1<Ool00`00Oomoo`0GOol001Eoo`03001oogoo02Mo
o`03001oogoo07Eoo`03001oogoo04eoo`03001oogoo01Ioo`005Goo00<007ooOol0:7oo00<007oo
Ool0M7oo00<007ooOol0CGoo0P005goo000EOol00`00Oomoo`0YOol00`00Oomoo`1cOol00`00Oomo
o`1:Ool300000goo001oo`0FOol001Eoo`03001oogoo02Yoo`03001oogoo079oo`03001oogoo04Qo
o`8000Aoo`03001oogoo01Eoo`005Goo00<007ooOol0:goo00<007ooOol0LGoo00<007ooOol0AGoo
0`001Woo00<007ooOol05Goo000EOol00`00Oomoo`0[Ool00`00Oomoo`1bOol00`00Oomoo`11Ool3
0009Ool00`00Oomoo`0EOol001Eoo`03001oogoo02aoo`03001oogoo075oo`03001oogoo03ioo`<0
00aoo`03001oogoo01Eoo`005Goo00<007ooOol0;Goo00<007ooOol0L7oo00<007ooOol0>goo0`00
3goo00<007ooOol05Goo000EOol00`00Oomoo`0^Ool00`00Oomoo`1_Ool00`00Oomoo`0iOol2000B
Ool00`00Oomoo`0EOol001Eoo`03001oogoo02moo`03001oogoo06ioo`03001oogoo03Ioo`<001Ao
o`03001oogoo01Eoo`005Goo00<007ooOol0<7oo00<007ooOol0KGoo00<007ooOol0<goo0`005goo
00<007ooOol05Goo000EOol00`00Oomoo`0aOol00`00Oomoo`1/Ool00`00Oomoo`0`Ool3000JOol0
0`00Oomoo`0EOol001Eoo`03001oogoo035oo`03001oogoo06aoo`03001oogoo02ioo`8001eoo`03
001oogoo01Eoo`005Goo00<007ooOol0<Woo00<007ooOol0Jgoo00<007ooOol0:goo0`007goo00<0
07ooOol05Goo000EOol00`00Oomoo`0cOol00`00Oomoo`1ZOol00`00Oomoo`0XOol3000SOol00`00
Oomoo`0DOol001Eoo`03001oogoo03Aoo`03001oogoo06Uoo`03001oogoo02Eoo`<002Ioo`03001o
ogoo01Aoo`005Goo00<007ooOol0=Goo00<007ooOol0J7oo00<007ooOol08Woo0`00:Goo00<007oo
Ool057oo000EOol00`00Oomoo`0fOol00`00Oomoo`1WOol00`00Oomoo`0POol2000/Ool00`00Oomo
o`0DOol001Aoo`03001oogoo03Qoo`03001oogoo06Ioo`03001oogoo01eoo`<002ioo`03001oogoo
01Aoo`0057oo00<007ooOol0>7oo00<007ooOol0IWoo00<007ooOol06Woo0`00<Goo00<007ooOol0
57oo000DOol00`00Oomoo`0iOol00`00Oomoo`1UOol00`00Oomoo`0GOol3000dOol00`00Oomoo`0D
Ool001Aoo`03001oogoo03Yoo`03001oogoo06Aoo`03001oogoo01Aoo`<003Moo`03001oogoo01Ao
o`0057oo00<007ooOol0>goo00<007ooOol0Hgoo00<007ooOol04Woo0P00>Woo00<007ooOol057oo
000DOol00`00Oomoo`0lOol00`00Oomoo`1ROol00`00Oomoo`0?Ool3000lOol00`00Oomoo`0DOol0
01Aoo`03001oogoo03eoo`03001oogoo065oo`03001oogoo00aoo`<003moo`03001oogoo01Aoo`00
57oo00<007ooOol0?Woo00<007ooOol0H7oo00<007ooOol02Goo0`00@Woo00<007ooOol057oo000D
Ool00`00Oomoo`0nOol00`00Oomoo`1POol00`00Oomoo`07Ool20015Ool00`00Oomoo`0DOol001Ao
o`03001oogoo03moo`03001oogoo05moo`03001oogoo00Aoo`<004Moo`03001oogoo01Aoo`0057oo
00<007ooOol0@7oo00<007ooOol0GWoo00@007ooOomoo`<004Yoo`03001oogoo01Aoo`0057oo00<0
07ooOol0@Goo00<007ooOol0GGoo1000CGoo00<007ooOol057oo000DOol00`00Oomoo`12Ool00`00
Oomoo`1JOol3001@Ool00`00Oomoo`0DOol001Aoo`03001oogoo04=oo`03001oogoo05Moo`80009o
o`03001oogoo04ioo`03001oogoo01Aoo`0057oo00<007ooOol0@goo00<007ooOol0E7oo0`0017oo
00<007ooOol0CWoo00<007ooOol057oo000DOol00`00Oomoo`14Ool00`00Oomoo`1@Ool30007Ool0
0`00Oomoo`1>Ool00`00Oomoo`0DOol001Aoo`03001oogoo04Eoo`03001oogoo04aoo`<000Yoo`03
001oogoo04ioo`03001oogoo01Aoo`0057oo00<007ooOol0AWoo00<007ooOol0BGoo0P003Goo00<0
07ooOol0CWoo00<007ooOol057oo000DOol00`00Oomoo`17Ool00`00Oomoo`15Ool3000?Ool00`00
Oomoo`1>Ool00`00Oomoo`0DOol001Aoo`03001oogoo04Qoo`03001oogoo045oo`<0019oo`03001o
ogoo04ioo`03001oogoo01Aoo`0057oo00<007ooOol0BGoo00<007ooOol0?Goo0`005Goo00<007oo
Ool0CWoo00<007ooOol057oo000DOol00`00Oomoo`19Ool00`00Oomoo`0jOol3000HOol00`00Oomo
o`1>Ool00`00Oomoo`0DOol001Aoo`03001oogoo04Yoo`03001oogoo03Moo`8001]oo`03001oogoo
04moo`03001oogoo01=oo`0057oo00<007ooOol0Bgoo00<007ooOol0<goo0`007Goo00<007ooOol0
Cgoo00<007ooOol04goo000DOol00`00Oomoo`1<Ool00`00Oomoo`0_Ool3000POol00`00Oomoo`1?
Ool00`00Oomoo`0COol001Aoo`03001oogoo04eoo`03001oogoo02]oo`<002=oo`03001oogoo04mo
o`03001oogoo01=oo`004goo00<007ooOol0Cgoo00<007ooOol09goo0`009Woo00<007ooOol0Cgoo
00<007ooOol04goo000COol00`00Oomoo`1@Ool00`00Oomoo`0TOol2000YOol00`00Oomoo`1?Ool0
0`00Oomoo`0COol001=oo`03001oogoo051oo`03001oogoo025oo`<002]oo`03001oogoo04moo`03
001oogoo01=oo`004goo00<007ooOol0DGoo00<007ooOol07Goo0`00;Woo00<007ooOol0Cgoo00<0
07ooOol04goo000COol00`00Oomoo`1BOol00`00Oomoo`0IOol3000aOol00`00Oomoo`1?Ool00`00
Oomoo`0COol001=oo`03001oogoo05=oo`03001oogoo01Ioo`8003Aoo`03001oogoo04moo`03001o
ogoo01=oo`004goo00<007ooOol0E7oo00<007ooOol04Woo0`00=Woo00<007ooOol0Cgoo00<007oo
Ool04goo000COol00`00Oomoo`1EOol00`00Oomoo`0>Ool3000iOol00`00Oomoo`1?Ool00`00Oomo
o`0COol001=oo`03001oogoo05Ioo`03001oogoo00Yoo`<003aoo`03001oogoo04moo`03001oogoo
01=oo`004goo00<007ooOol0EWoo00<007ooOol01goo0`00?goo00<007ooOol0Cgoo00<007ooOol0
4goo000COol00`00Oomoo`1GOol00`00Oomoo`04Ool20012Ool00`00Oomoo`1?Ool00`00Oomoo`0C
Ool001=oo`03001oogoo05Qoo`03001oogoo00<004Aoo`03001oogoo04moo`03001oogoo01=oo`00
4goo00<007ooOol0FGoo0P00Agoo00<007ooOol0Cgoo00<007ooOol04goo000COol00`00Oomoo`1I
Ool00`00Oomoo`16Ool00`00Oomoo`1?Ool00`00Oomoo`0COol001=oo`03001oogoo05Uoo`03001o
ogoo04Ioo`03001oogoo04moo`03001oogoo01=oo`004goo00<007ooOol0FGoo00<007ooOol0AWoo
00<007ooOol0Cgoo00<007ooOol04goo000COol00`00Oomoo`1IOol00`00Oomoo`16Ool00`00Oomo
o`1?Ool00`00Oomoo`0COol001=oo`03001oogoo05Uoo`03001oogoo04Ioo`03001oogoo04moo`03
001oogoo01=oo`004goo00<007ooOol0FGoo00<007ooOol0AWoo00<007ooOol0Cgoo00<007ooOol0
4goo000COol00`00Oomoo`1IOol00`00Oomoo`16Ool00`00Oomoo`1?Ool00`00Oomoo`0COol001=o
o`03001oogoo05Uoo`03001oogoo04Ioo`03001oogoo04moo`03001oogoo01=oo`004goo00<007oo
Ool0FGoo00<007ooOol0AWoo00<007ooOol0D7oo00<007ooOol04Woo000COol00`00Oomoo`1IOol0
0`00Oomoo`16Ool00`00Oomoo`1@Ool00`00Oomoo`0BOol001=oo`03001oogoo05Uoo`03001oogoo
04Ioo`03001oogoo051oo`03001oogoo019oo`004goo00<007ooOol0FGoo00<007ooOol0AWoo00<0
07ooOol0D7oo00<007ooOol04Woo000BOol00`00Oomoo`1JOol00`00Oomoo`16Ool00`00Oomoo`1@
Ool00`00Oomoo`0BOol0019oo`03001oogoo05Yoo`03001oogoo04Ioo`03001oogoo051oo`03001o
ogoo019oo`004Woo00<007ooOol0FWoo00<007ooOol0AWoo00<007ooOol0D7oo00<007ooOol04Woo
000BOol00`00Oomoo`1JOol00`00Oomoo`16Ool00`00Oomoo`1@Ool00`00Oomoo`0BOol0019oo`03
001oogoo05Yoo`03001oogoo04Ioo`03001oogoo051oo`03001oogoo019oo`004Woo00<007ooOol0
FWoo00<007ooOol0AWoo00<007ooOol0D7oo00<007ooOol04Woo000BOol00`00Oomoo`1JOol00`00
Oomoo`16Ool00`00Oomoo`1@Ool00`00Oomoo`0BOol0019oo`03001oogoo05Yoo`03001oogoo04Io
o`03001oogoo051oo`03001oogoo019oo`004Woo00<007ooOol0FWoo00<007ooOol0AWoo00<007oo
Ool0D7oo00<007ooOol04Woo000BOol00`00Oomoo`1JOol00`00Oomoo`16Ool00`00Oomoo`1@Ool0
0`00Oomoo`0BOol0019oo`03001oogoo05Yoo`03001oogoo04Ioo`03001oogoo051oo`03001oogoo
019oo`004Woo00<007ooOol0FWoo00<007ooOol0Agoo00<007ooOol0Cgoo00<007ooOol04Woo000B
Ool00`00Oomoo`1JOol00`00Oomoo`17Ool00`00Oomoo`1?Ool00`00Oomoo`0BOol0019oo`03001o
ogoo05Yoo`03001oogoo04Moo`03001oogoo04moo`03001oogoo019oo`004Woo00<007ooOol0FWoo
00<007ooOol0Agoo00<007ooOol0Cgoo00<007ooOol04Woo000BOol00`00Oomoo`1JOol00`00Oomo
o`17Ool00`00Oomoo`1?Ool00`00Oomoo`0BOol0019oo`03001oogoo05Yoo`03001oogoo04Moo`03
001oogoo04moo`03001oogoo019oo`004Woo00<007ooOol0FWoo00<007ooOol0Agoo00<007ooOol0
Cgoo00<007ooOol04Woo000BOol00`00Oomoo`1JOol00`00Oomoo`17Ool00`00Oomoo`1?Ool00`00
Oomoo`0BOol0019oo`03001oogoo05Yoo`03001oogoo04Moo`03001oogoo04moo`03001oogoo019o
o`004Woo00<007ooOol0FWoo00<007ooOol0Agoo00<007ooOol0Cgoo00<007ooOol04Woo000BOol0
0`00Oomoo`1JOol00`00Oomoo`17Ool00`00Oomoo`1?Ool00`00Oomoo`0BOol0019oo`03001oogoo
05Yoo`03001oogoo04Moo`03001oogoo051oo`03001oogoo015oo`004Woo00<007ooOol0FWoo00<0
07ooOol0Agoo00<007ooOol0D7oo00<007ooOol04Goo000BOol00`00Oomoo`1JOol00`00Oomoo`17
Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol0019oo`03001oogoo05Yoo`03001oogoo04Moo`03001o
ogoo051oo`03001oogoo015oo`004Goo00<007ooOol0Fgoo00<007ooOol0Agoo00<007ooOol0D7oo
00<007ooOol04Goo000AOol00`00Oomoo`1KOol00`00Oomoo`17Ool00`00Oomoo`1@Ool00`00Oomo
o`0AOol0015oo`03001oogoo05]oo`03001oogoo04Moo`03001oogoo051oo`03001oogoo015oo`00
4Goo00<007ooOol0FWoo00<007ooOol0B7oo00<007ooOol0D7oo00<007ooOol04Goo000AOol00`00
Oomoo`1JOol00`00Oomoo`18Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol0015oo`03001oogoo05Yo
o`03001oogoo04Qoo`03001oogoo051oo`03001oogoo015oo`004Goo00<007ooOol0FWoo00<007oo
Ool0B7oo00<007ooOol0D7oo00<007ooOol04Goo000AOol00`00Oomoo`1JOol00`00Oomoo`18Ool0
0`00Oomoo`1@Ool00`00Oomoo`0AOol0015oo`03001oogoo05Yoo`03001oogoo04Qoo`03001oogoo
051oo`03001oogoo015oo`004Goo00<007ooOol0FWoo00<007ooOol0B7oo00<007ooOol0D7oo00<0
07ooOol04Goo000AOol00`00Oomoo`1JOol00`00Oomoo`18Ool00`00Oomoo`1@Ool00`00Oomoo`0A
Ool0015oo`03001oogoo05Yoo`03001oogoo04Qoo`03001oogoo051oo`03001oogoo015oo`004Goo
00<007ooOol0FWoo00<007ooOol0B7oo00<007ooOol0D7oo00<007ooOol04Goo000AOol00`00Oomo
o`1JOol00`00Oomoo`18Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol0015oo`03001oogoo05Yoo`03
001oogoo04Qoo`03001oogoo051oo`03001oogoo015oo`004Goo00<007ooOol0FWoo00<007ooOol0
B7oo00<007ooOol0D7oo00<007ooOol04Goo000AOol00`00Oomoo`1JOol00`00Oomoo`18Ool00`00
Oomoo`1@Ool00`00Oomoo`0AOol0015oo`03001oogoo05Yoo`03001oogoo04Qoo`03001oogoo051o
o`03001oogoo015oo`004Goo00<007ooOol0FWoo00<007ooOol0B7oo00<007ooOol0D7oo00<007oo
Ool04Goo000AOol00`00Oomoo`1JOol00`00Oomoo`18Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol0
015oo`03001oogoo05Yoo`03001oogoo04Qoo`03001oogoo051oo`03001oogoo015oo`004Goo00<0
07ooOol0FWoo00<007ooOol0B7oo00<007ooOol0DGoo00<007ooOol047oo000AOol00`00Oomoo`1J
Ool00`00Oomoo`18Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool0015oo`03001oogoo05Yoo`03001o
ogoo04Qoo`03001oogoo055oo`03001oogoo011oo`004Goo00<007ooOol0FWoo00<007ooOol0B7oo
00<007ooOol0DGoo00<007ooOol047oo000AOol00`00Oomoo`1JOol00`00Oomoo`18Ool00`00Oomo
o`1AOol00`00Oomoo`0@Ool0011oo`03001oogoo05]oo`03001oogoo04Qoo`03001oogoo055oo`03
001oogoo011oo`0047oo00<007ooOol0Fgoo00<007ooOol0B7oo00<007ooOol0DGoo00<007ooOol0
47oo000@Ool00`00Oomoo`1KOol00`00Oomoo`18Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool0011o
o`03001oogoo05]oo`03001oogoo04Qoo`03001oogoo055oo`03001oogoo011oo`0047oo00<007oo
Ool0Fgoo00<007ooOol0B7oo00<007ooOol0DGoo00<007ooOol047oo000@Ool00`00Oomoo`1KOol0
0`00Oomoo`18Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool0011oo`03001oogoo05]oo`03001oogoo
04Qoo`03001oogoo055oo`03001oogoo011oo`0047oo00<007ooOol0Fgoo00<007ooOol0B7oo00<0
07ooOol0DGoo00<007ooOol047oo000@Ool00`00Oomoo`1KOol00`00Oomoo`18Ool00`00Oomoo`1A
Ool00`00Oomoo`0@Ool0011oo`03001oogoo05]oo`03001oogoo04Qoo`03001oogoo055oo`03001o
ogoo011oo`0047oo00<007ooOol0Fgoo00<007ooOol0B7oo00<007ooOol0DGoo00<007ooOol047oo
000@Ool00`00Oomoo`1KOol00`00Oomoo`18Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool0011oo`03
001oogoo05]oo`03001oogoo04Qoo`03001oogoo055oo`03001oogoo011oo`0047oo00<007ooOol0
Fgoo00<007ooOol0B7oo00<007ooOol0DGoo00<007ooOol047oo000@Ool00`00Oomoo`1KOol00`00
Oomoo`18Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool0011oo`03001oogoo05]oo`03001oogoo04Qo
o`03001oogoo055oo`03001oogoo011oo`0047oo00<007ooOol0Fgoo00<007ooOol0B7oo00<007oo
Ool0DGoo00<007ooOol047oo000@Ool00`00Oomoo`1KOol00`00Oomoo`18Ool00`00Oomoo`1AOol0
0`00Oomoo`0@Ool0011oo`03001oogoo05]oo`03001oogoo04Qoo`03001oogoo055oo`03001oogoo
011oo`0047oo00<007ooOol0Fgoo00<007ooOol0B7oo00<007ooOol0DGoo00<007ooOol047oo000@
Ool00`00Oomoo`1KOol00`00Oomoo`18Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool0011oo`03001o
ogoo05]oo`03001oogoo04Qoo`03001oogoo059oo`03001oogoo00moo`0047oo00<007ooOol0Fgoo
00<007ooOol0B7oo00<007ooOol0DWoo00<007ooOol03goo000@Ool00`00Oomoo`1KOol00`00Oomo
o`18Ool00`00Oomoo`1BOol00`00Oomoo`0?Ool0011oo`03001oogoo05]oo`03001oogoo04Qoo`03
001oogoo059oo`03001oogoo00moo`0047oo00<007ooOol0Fgoo00<007ooOol0B7oo00<007ooOol0
DWoo00<007ooOol03goo000?Ool00`00Oomoo`1LOol00`00Oomoo`18Ool00`00Oomoo`1BOol00`00
Oomoo`0?Ool000moo`03001oogoo05aoo`03001oogoo04Qoo`03001oogoo059oo`03001oogoo00mo
o`003goo00<007ooOol0G7oo00<007ooOol07Goo1W`O9Goo00<007ooOol0DWoo00<007ooOol03goo
000?Ool00`00Oomoo`1LOol00`00Oomoo`0LOol8O1lTOol00`00Oomoo`1BOol00`00Oomoo`0?Ool0
00moo`03001oogoo05aoo`03001oogoo01]oo`Yl7b=oo`03001oogoo059oo`03001oogoo00moo`00
3goo00<007ooOol0G7oo00<007ooOol06Woo37`O8Woo00<007ooOol0DWoo00<007ooOol03goo000?
Ool00`00Oomoo`1LOol00`00Oomoo`0IOol>O1lQOol00`00Oomoo`1BOol00`00Oomoo`0?Ool000mo
o`03001oogoo05aoo`03001oogoo01Uoo`il7b5oo`03001oogoo059oo`03001oogoo00moo`003goo
00<007ooOol0G7oo00<007ooOol06Goo3W`O8Woo00<007ooOol0DGoo00<007ooOol03goo000?Ool0
0`00Oomoo`1LOol00`00Oomoo`0IOol>O1lROol00`00Oomoo`1AOol00`00Oomoo`0?Ool000moo`03
001oogoo05aoo`03001oogoo01Uoo`il7b9oo`03001oogoo055oo`03001oogoo00moo`003goo00<0
07ooOol0G7oo00<007ooOol06Goo3W`O8Woo00<007ooOol0DGoo00<007ooOol03goo000?Ool00`00
Oomoo`1LOol00`00Oomoo`0JOol<O1lSOol00`00Oomoo`1AOol00`00Oomoo`0?Ool000moo`03001o
ogoo05aoo`03001oogoo01]oo`Yl7bAoo`03001oogoo055oo`03001oogoo00moo`003goo00<007oo
Ool0G7oo00<007ooOol077oo27`O9Goo00<007ooOol0DGoo00<007ooOol03goo000?Ool00`00Oomo
o`1LOol00`00Oomoo`0MOol6O1lVOol00`00Oomoo`1AOol00`00Oomoo`0?Ool000moo`03001oogoo
05aoo`03001oogoo04Uoo`03001oogoo055oo`03001oogoo00moo`003goo00<007ooOol0G7oo00<0
07ooOol0BGoo00<007ooOol0DGoo00<007ooOol03goo000?Ool00`00Oomoo`1LOol00`00Oomoo`19
Ool00`00Oomoo`1AOol00`00Oomoo`0?Ool000moo`03001oogoo05aoo`03001oogoo04Uoo`03001o
ogoo055oo`03001oogoo00moo`003goo00<007ooOol0G7oo00<007ooOol0BGoo00<007ooOol0DWoo
00<007ooOol03Woo000?Ool00`00Oomoo`1LOol00`00Oomoo`19Ool00`00Oomoo`1BOol00`00Oomo
o`0>Ool000moo`03001oogoo05aoo`03001oogoo04Uoo`03001oogoo059oo`03001oogoo00ioo`00
3goo00<007ooOol0G7oo00<007ooOol0BGoo00<007ooOol0DWoo00<007ooOol03Woo000?Ool00`00
Oomoo`1LOol00`00Oomoo`19Ool00`00Oomoo`1BOol00`00Oomoo`0>Ool000ioo`03001oogoo05eo
o`03001oogoo04Uoo`03001oogoo059oo`03001oogoo00ioo`003Woo00<007ooOol0GGoo00<007oo
Ool0BGoo00<007ooOol0DWoo00<007ooOol03Woo000>Ool00`00Oomoo`1MOol00`00Oomoo`19Ool0
0`00Oomoo`1BOol00`00Oomoo`0>Ool000ioo`03001oogoo05eoo`03001oogoo04Uoo`03001oogoo
059oo`03001oogoo00ioo`003Woo00<007ooOol0GGoo00<007ooOol0BGoo00<007ooOol0DWoo00<0
07ooOol03Woo000>Ool00`00Oomoo`1MOol00`00Oomoo`19Ool00`00Oomoo`1BOol00`00Oomoo`0>
Ool000ioo`03001oogoo05eoo`03001oogoo04Uoo`03001oogoo059oo`03001oogoo00ioo`003Woo
00<007ooOol0GGoo00<007ooOol0BGoo00<007ooOol0DWoo00<007ooOol03Woo000>Ool00`00Oomo
o`1LOol00`00Oomoo`1:Ool00`00Oomoo`1BOol00`00Oomoo`0>Ool000ioo`03001oogoo05aoo`03
001oogoo04Yoo`03001oogoo059oo`03001oogoo00ioo`003Woo00<007ooOol0G7oo00<007ooOol0
BWoo00<007ooOol0DWoo00<007ooOol03Woo000>Ool00`00Oomoo`1LOol00`00Oomoo`1:Ool00`00
Oomoo`1BOol00`00Oomoo`0>Ool000ioo`03001oogoo05aoo`03001oogoo04Yoo`03001oogoo059o
o`03001oogoo00ioo`003Woo00<007ooOol0G7oo00<007ooOol0BWoo00<007ooOol0DWoo00<007oo
Ool03Woo000>Ool00`00Oomoo`1LOol00`00Oomoo`1:Ool00`00Oomoo`1BOol00`00Oomoo`0>Ool0
00ioo`03001oogoo05aoo`03001oogoo04Yoo`03001oogoo059oo`03001oogoo00ioo`003Woo00<0
07ooOol0G7oo00<007ooOol0BWoo00<007ooOol0DWoo00<007ooOol03Woo000>Ool00`00Oomoo`1L
Ool00`00Oomoo`1:Ool00`00Oomoo`1BOol00`00Oomoo`0>Ool000ioo`03001oogoo05aoo`03001o
ogoo04Yoo`03001oogoo059oo`03001oogoo00ioo`003Woo00<007ooOol0G7oo00<007ooOol0BWoo
00<007ooOol0DWoo00<007ooOol03Woo000>Ool00`00Oomoo`1LOol00`00Oomoo`1:Ool00`00Oomo
o`1BOol00`00Oomoo`0>Ool000ioo`03001oogoo05aoo`03001oogoo04Yoo`03001oogoo05=oo`03
001oogoo00eoo`003Woo00<007ooOol0G7oo00<007ooOol0BWoo00<007ooOol0Dgoo00<007ooOol0
3Goo000>Ool00`00Oomoo`1LOol00`00Oomoo`1:Ool00`00Oomoo`1COol00`00Oomoo`0=Ool000io
o`03001oogoo05aoo`03001oogoo04Yoo`03001oogoo05=oo`03001oogoo00eoo`003Woo00<007oo
Ool0G7oo00<007ooOol0BWoo00<007ooOol0Dgoo00<007ooOol03Goo000=Ool00`00Oomoo`1MOol0
0`00Oomoo`1:Ool00`00Oomoo`1COol00`00Oomoo`0=Ool000eoo`03001oogoo05eoo`03001oogoo
04Yoo`03001oogoo05=oo`03001oogoo00eoo`003Goo00<007ooOol0GGoo00<007ooOol0BWoo00<0
07ooOol0Dgoo00<007ooOol03Goo000=Ool00`00Oomoo`1MOol00`00Oomoo`1:Ool00`00Oomoo`1C
Ool00`00Oomoo`0=Ool000eoo`03001oogoo05eoo`03001oogoo04Yoo`03001oogoo05=oo`03001o
ogoo00eoo`003Goo00<007ooOol0GGoo00<007ooOol0BWoo00<007ooOol0Dgoo00<007ooOol03Goo
000=Ool00`00Oomoo`1MOol00`00Oomoo`1:Ool00`00Oomoo`1COol00`00Oomoo`0=Ool000eoo`03
001oogoo05eoo`03001oogoo04Yoo`03001oogoo05=oo`03001oogoo00eoo`003Goo00<007ooOol0
GGoo00<007ooOol0BWoo00<007ooOol0Dgoo00<007ooOol03Goo000=Ool00`00Oomoo`1MOol00`00
Oomoo`1:Ool00`00Oomoo`1COol00`00Oomoo`0=Ool000eoo`03001oogoo05eoo`03001oogoo04Yo
o`03001oogoo05=oo`03001oogoo00eoo`003Goo00<007ooOol0GGoo00<007ooOol0BWoo00<007oo
Ool0Dgoo00<007ooOol03Goo000=Ool00`00Oomoo`1MOol00`00Oomoo`1:Ool00`00Oomoo`1COol0
0`00Oomoo`0=Ool000eoo`03001oogoo05eoo`03001oogoo04Yoo`03001oogoo05=oo`03001oogoo
00eoo`003Goo00<007ooOol0GGoo00<007ooOol0BWoo00<007ooOol0Dgoo00<007ooOol03Goo000=
Ool00`00Oomoo`1MOol00`00Oomoo`1:Ool00`00Oomoo`1COol00`00Oomoo`0=Ool000eoo`03001o
ogoo05eoo`03001oogoo04Yoo`03001oogoo05=oo`03001oogoo00eoo`003Goo00<007ooOol0GGoo
00<007ooOol0BWoo00<007ooOol0Dgoo00<007ooOol03Goo000=Ool00`00Oomoo`1MOol00`00Oomo
o`1:Ool00`00Oomoo`1COol00`00Oomoo`0=Ool000eoo`03001oogoo05eoo`03001oogoo04Yoo`03
001oogoo05=oo`03001oogoo00eoo`003Goo00<007ooOol0GGoo00<007ooOol0BWoo00<007ooOol0
E7oo00<007ooOol037oo000=Ool00`00Oomoo`1MOol00`00Oomoo`1:Ool00`00Oomoo`1DOol00`00
Oomoo`0<Ool000eoo`03001oogoo05eoo`03001oogoo04Yoo`03001oogoo05Aoo`03001oogoo00ao
o`003Goo00<007ooOol0GGoo00<007ooOol0BWoo00<007ooOol0E7oo00<007ooOol037oo000=Ool0
0`00Oomoo`1MOol00`00Oomoo`1:Ool00`00Oomoo`1DOol00`00Oomoo`0<Ool000eoo`03001oogoo
05eoo`03001oogoo04Yoo`03001oogoo05Aoo`03001oogoo00aoo`0037oo00<007ooOol0GWoo00<0
07ooOol0BWoo00<007ooOol0E7oo00<007ooOol037oo000<Ool00`00Oomoo`1NOol00`00Oomoo`1:
Ool00`00Oomoo`1DOol00`00Oomoo`0<Ool000aoo`03001oogoo05ioo`03001oogoo04Yoo`03001o
ogoo05Aoo`03001oogoo00aoo`0037oo00<007ooOol0GWoo00<007ooOol0BWoo00<007ooOol0E7oo
00<007ooOol037oo000<Ool00`00Oomoo`1NOol00`00Oomoo`1:Ool00`00Oomoo`1DOol00`00Oomo
o`0<Ool000aoo`03001oogoo05ioo`03001oogoo04Yoo`03001oogoo05Aoo`03001oogoo00aoo`00
37oo00<007ooOol0GWoo00<007ooOol0BWoo00<007ooOol0E7oo00<007ooOol037oo000<Ool00`00
Oomoo`1NOol00`00Oomoo`1;Ool00`00Oomoo`1COol00`00Oomoo`0<Ool000aoo`03001oogoo05io
o`03001oogoo04]oo`03001oogoo05=oo`03001oogoo00aoo`0037oo00<007ooOol0GWoo00<007oo
Ool0Bgoo00<007ooOol0Dgoo00<007ooOol037oo000<Ool00`00Oomoo`1NOol00`00Oomoo`1;Ool0
0`00Oomoo`1COol00`00Oomoo`0<Ool000aoo`03001oogoo05ioo`03001oogoo04]oo`03001oogoo
05=oo`03001oogoo00aoo`0037oo00<007ooOol0GWoo00<007ooOol0Bgoo00<007ooOol0Dgoo00<0
07ooOol037oo000<Ool00`00Oomoo`1NOol00`00Oomoo`1;Ool00`00Oomoo`1COol00`00Oomoo`0<
Ool000aoo`03001oogoo05ioo`03001oogoo04]oo`03001oogoo05=oo`03001oogoo00aoo`0037oo
00<007ooOol0GWoo00<007ooOol0Bgoo00<007ooOol0Dgoo00<007ooOol037oo000<Ool00`00Oomo
o`1NOol00`00Oomoo`1;Ool00`00Oomoo`1COol00`00Oomoo`0<Ool000aoo`03001oogoo05ioo`03
001oogoo04]oo`03001oogoo05=oo`03001oogoo00aoo`0037oo00<007ooOol0GWoo00<007ooOol0
Bgoo00<007ooOol0Dgoo00<007ooOol037oo000<Ool00`00Oomoo`1NOol00`00Oomoo`1;Ool00`00
Oomoo`1COol00`00Oomoo`0<Ool000aoo`03001oogoo05ioo`03001oogoo04]oo`03001oogoo05Ao
o`03001oogoo00]oo`0037oo00<007ooOol0GWoo00<007ooOol0Bgoo00<007ooOol0E7oo00<007oo
Ool02goo000<Ool00`00Oomoo`1NOol00`00Oomoo`1;Ool00`00Oomoo`1DOol00`00Oomoo`0;Ool0
00aoo`03001oogoo05ioo`03001oogoo04]oo`03001oogoo05Aoo`03001oogoo00]oo`0037oo00<0
07ooOol0GWoo00<007ooOol0Bgoo00<007ooOol0E7oo00<007ooOol02goo000;Ool00`00Oomoo`1O
Ool00`00Oomoo`1;Ool00`00Oomoo`1DOol00`00Oomoo`0;Ool000]oo`03001oogoo05moo`03001o
ogoo04]oo`03001oogoo05Aoo`03001oogoo00]oo`002goo00<007ooOol0Ggoo00<007ooOol0Bgoo
00<007ooOol0E7oo00<007ooOol02goo000;Ool00`00Oomoo`1OOol00`00Oomoo`1;Ool00`00Oomo
o`1DOol00`00Oomoo`0;Ool000]oo`03001oogoo05moo`03001oogoo04]oo`03001oogoo05Aoo`03
001oogoo00]oo`002goo00<007ooOol0Ggoo00<007ooOol0Bgoo00<007ooOol0E7oo00<007ooOol0
2goo000;Ool00`00Oomoo`1OOol00`00Oomoo`1;Ool00`00Oomoo`1DOol00`00Oomoo`0;Ool000]o
o`03001oogoo05moo`03001oogoo04]oo`03001oogoo05Aoo`03001oogoo00]oo`002goo00<007oo
Ool0Ggoo00<007ooOol0Bgoo00<007ooOol0E7oo00<007ooOol02goo000;Ool00`00Oomoo`1OOol0
0`00Oomoo`1;Ool00`00Oomoo`1DOol00`00Oomoo`0;Ool000]oo`03001oogoo05moo`03001oogoo
04]oo`03001oogoo05Aoo`03001oogoo00]oo`002goo00<007ooOol0Ggoo00<007ooOol0Bgoo00<0
07ooOol0E7oo00<007ooOol02goo000;Ool00`00Oomoo`1OOol00`00Oomoo`1;Ool00`00Oomoo`1D
Ool00`00Oomoo`0;Ool000]oo`03001oogoo05moo`03001oogoo04]oo`03001oogoo05Aoo`03001o
ogoo00]oo`002goo00<007ooOol0GWoo00<007ooOol0C7oo00<007ooOol0E7oo00<007ooOol02goo
000;Ool00`00Oomoo`1NOol00`00Oomoo`1<Ool00`00Oomoo`1DOol00`00Oomoo`0;Ool000]oo`03
001oogoo05ioo`03001oogoo04aoo`03001oogoo05Aoo`03001oogoo00]oo`002goo00<007ooOol0
GWoo00<007ooOol0C7oo00<007ooOol0E7oo00<007ooOol02goo000;Ool00`00Oomoo`1NOol00`00
Oomoo`1<Ool00`00Oomoo`1DOol00`00Oomoo`0;Ool000]oo`03001oogoo05ioo`03001oogoo04ao
o`03001oogoo05Aoo`03001oogoo00]oo`002goo00<007ooOol0GWoo00<007ooOol0C7oo00<007oo
Ool0EGoo00<007ooOol02Woo000;Ool00`00Oomoo`1NOol00`00Oomoo`1<Ool00`00Oomoo`1EOol0
0`00Oomoo`0:Ool000]oo`03001oogoo05ioo`03001oogoo04aoo`03001oogoo05Eoo`03001oogoo
00Yoo`002goo00<007ooOol0GWoo00<007ooOol0C7oo00<007ooOol0EGoo00<007ooOol02Woo000;
Ool00`00Oomoo`1NOol00`00Oomoo`1<Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool000]oo`03001o
ogoo05ioo`03001oogoo04aoo`03001oogoo05Eoo`03001oogoo00Yoo`002Woo00<007ooOol0Ggoo
00<007ooOol0C7oo00<007ooOol0EGoo00<007ooOol02Woo000:Ool00`00Oomoo`1OOol00`00Oomo
o`1<Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool000Yoo`03001oogoo05moo`03001oogoo04aoo`03
001oogoo05Eoo`03001oogoo00Yoo`002Woo00<007ooOol0Ggoo00<007ooOol0C7oo00<007ooOol0
EGoo00<007ooOol02Woo000:Ool00`00Oomoo`1OOol00`00Oomoo`1<Ool00`00Oomoo`1EOol00`00
Oomoo`0:Ool000Yoo`03001oogoo05moo`03001oogoo04aoo`03001oogoo05Eoo`03001oogoo00Yo
o`002Woo00<007ooOol0Ggoo00<007ooOol0C7oo00<007ooOol0EGoo00<007ooOol02Woo000:Ool0
0`00Oomoo`1OOol00`00Oomoo`1<Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool000Yoo`03001oogoo
05moo`03001oogoo04aoo`03001oogoo05Eoo`03001oogoo00Yoo`002Woo00<007ooOol0Ggoo00<0
07ooOol0C7oo00<007ooOol0EGoo00<007ooOol02Woo000:Ool00`00Oomoo`1OOol00`00Oomoo`1<
Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool000Yoo`03001oogoo05moo`03001oogoo04aoo`03001o
ogoo05Eoo`03001oogoo00Yoo`002Woo00<007ooOol0Ggoo00<007ooOol0C7oo00<007ooOol0EGoo
00<007ooOol02Woo000:Ool00`00Oomoo`1OOol00`00Oomoo`1<Ool00`00Oomoo`1EOol00`00Oomo
o`0:Ool000Yoo`03001oogoo05moo`03001oogoo04aoo`03001oogoo05Eoo`03001oogoo00Yoo`00
2Woo00<007ooOol0Ggoo00<007ooOol0C7oo00<007ooOol0EGoo00<007ooOol02Woo000:Ool00`00
Oomoo`1OOol00`00Oomoo`1<Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool000Yoo`03001oogoo05mo
o`03001oogoo04aoo`03001oogoo05Eoo`03001oogoo00Yoo`002Woo00<007ooOol0Ggoo00<007oo
Ool0C7oo00<007ooOol0EGoo00<007ooOol02Woo000:Ool00`00Oomoo`1OOol00`00Oomoo`1<Ool0
0`00Oomoo`1FOol00`00Oomoo`09Ool000Yoo`03001oogoo05moo`03001oogoo04aoo`03001oogoo
05Ioo`03001oogoo00Uoo`002Woo00<007ooOol0Ggoo00<007ooOol0C7oo00<007ooOol0EWoo00<0
07ooOol02Goo000:Ool00`00Oomoo`1OOol00`00Oomoo`1<Ool00`00Oomoo`1FOol00`00Oomoo`09
Ool000Yoo`03001oogoo05moo`03001oogoo04aoo`03001oogoo05Ioo`03001oogoo00Uoo`002Woo
00<007ooOol0Ggoo00<007ooOol0C7oo00<007ooOol0EWoo00<007ooOol02Goo000:Ool00`00Oomo
o`1OOol00`00Oomoo`1<Ool00`00Oomoo`1FOol00`00Oomoo`09Ool000Uoo`03001oogoo061oo`03
001oogoo04aoo`03001oogoo05Ioo`03001oogoo00Uoo`002Goo00<007ooOol0H7oo00<007ooOol0
C7oo00<007ooOol0EWoo00<007ooOol02Goo0009Ool00`00Oomoo`1POol00`00Oomoo`1<Ool00`00
Oomoo`1FOol00`00Oomoo`09Ool000Uoo`03001oogoo061oo`03001oogoo04aoo`03001oogoo05Io
o`03001oogoo00Uoo`002Goo00<007ooOol0H7oo00<007ooOol0C7oo00<007ooOol0EWoo00<007oo
Ool02Goo0009Ool00`00Oomoo`1POol00`00Oomoo`1=Ool00`00Oomoo`1EOol00`00Oomoo`09Ool0
00Uoo`03001oogoo061oo`03001oogoo04eoo`03001oogoo05Eoo`03001oogoo00Uoo`002Goo00<0
07ooOol0H7oo00<007ooOol0CGoo00<007ooOol0EGoo00<007ooOol02Goo0009Ool00`00Oomoo`1P
Ool00`00Oomoo`1=Ool00`00Oomoo`1EOol00`00Oomoo`09Ool000Uoo`03001oogoo061oo`03001o
ogoo04eoo`03001oogoo05Eoo`03001oogoo00Uoo`002Goo00<007ooOol0H7oo00<007ooOol0CGoo
00<007ooOol0EGoo00<007ooOol02Goo0009Ool00`00Oomoo`1POol00`00Oomoo`1=Ool00`00Oomo
o`1EOol00`00Oomoo`09Ool000Uoo`03001oogoo061oo`03001oogoo04eoo`03001oogoo05Eoo`03
001oogoo00Uoo`002Goo00<007ooOol0H7oo00<007ooOol0CGoo00<007ooOol0EGoo00<007ooOol0
2Goo0009Ool00`00Oomoo`1POol00`00Oomoo`1=Ool00`00Oomoo`1EOol00`00Oomoo`09Ool000Uo
o`03001oogoo061oo`03001oogoo04eoo`03001oogoo05Eoo`03001oogoo00Uoo`002Goo00<007oo
Ool0H7oo00<007ooOol0CGoo00<007ooOol0EGoo00<007ooOol02Goo0009Ool00`00Oomoo`1POol0
0`00Oomoo`1=Ool00`00Oomoo`1EOol00`00Oomoo`09Ool000Uoo`03001oogoo061oo`03001oogoo
04eoo`03001oogoo05Eoo`03001oogoo00Uoo`002Goo00<007ooOol0H7oo00<007ooOol0CGoo00<0
07ooOol0EWoo00<007ooOol027oo0009Ool00`00Oomoo`1POol00`00Oomoo`1=Ool00`00Oomoo`1F
Ool00`00Oomoo`08Ool000Uoo`03001oogoo061oo`03001oogoo04eoo`03001oogoo05Ioo`03001o
ogoo00Qoo`002Goo00<007ooOol0H7oo00<007ooOol0CGoo00<007ooOol0EWoo00<007ooOol027oo
0009Ool00`00Oomoo`1POol00`00Oomoo`1=Ool00`00Oomoo`1FOol00`00Oomoo`08Ool000Uoo`03
001oogoo061oo`03001oogoo04eoo`03001oogoo05Ioo`03001oogoo00Qoo`002Goo00<007ooOol0
H7oo00<007ooOol0CGoo00<007ooOol0EWoo00<007ooOol027oo0008Ool00`00Oomoo`1QOol00`00
Oomoo`1=Ool00`00Oomoo`1FOol00`00Oomoo`08Ool000Qoo`03001oogoo065oo`03001oogoo04eo
o`03001oogoo05Ioo`03001oogoo00Qoo`0027oo00<007ooOol0HGoo00<007ooOol0CGoo00<007oo
Ool0EWoo00<007ooOol027oo0008Ool00`00Oomoo`1QOol00`00Oomoo`1=Ool00`00Oomoo`1FOol0
0`00Oomoo`08Ool000Qoo`03001oogoo065oo`03001oogoo04eoo`03001oogoo05Ioo`03001oogoo
00Qoo`0027oo00<007ooOol0HGoo00<007ooOol0CGoo00<007ooOol0EWoo00<007ooOol027oo0008
Ool00`00Oomoo`1QOol00`00Oomoo`1=Ool00`00Oomoo`1FOol00`00Oomoo`08Ool000Qoo`03001o
ogoo065oo`03001oogoo04eoo`03001oogoo05Ioo`03001oogoo00Qoo`0027oo00<007ooOol0HGoo
00<007ooOol07goo1W`O:7oo00<007ooOol0EWoo00<007ooOol027oo0008Ool00`00Oomoo`1QOol0
0`00Oomoo`0NOol8O1lWOol00`00Oomoo`1FOol00`00Oomoo`08Ool000Qoo`03001oogoo065oo`03
001oogoo01eoo`Yl7bIoo`03001oogoo05Ioo`03001oogoo00Qoo`0027oo00<007ooOol0HGoo00<0
07ooOol077oo37`O9Goo00<007ooOol0EWoo00<007ooOol027oo0008Ool00`00Oomoo`1QOol00`00
Oomoo`0KOol>O1lTOol00`00Oomoo`1FOol00`00Oomoo`08Ool000Qoo`03001oogoo065oo`03001o
ogoo01]oo`il7bAoo`03001oogoo05Ioo`03001oogoo00Qoo`0027oo00<007ooOol0HGoo00<007oo
Ool06goo3W`O97oo00<007ooOol0EWoo00<007ooOol027oo0008Ool00`00Oomoo`1QOol00`00Oomo
o`0KOol>O1lTOol00`00Oomoo`1FOol00`00Oomoo`08Ool000Qoo`03001oogoo065oo`03001oogoo
01]oo`il7bAoo`03001oogoo05Ioo`03001oogoo00Qoo`0027oo00<007ooOol0HGoo00<007ooOol0
6goo3W`O97oo00<007ooOol0EWoo00<007ooOol027oo0008Ool00`00Oomoo`1POol00`00Oomoo`0M
Ool<O1lUOol00`00Oomoo`1GOol00`00Oomoo`07Ool000Qoo`03001oogoo061oo`03001oogoo01io
o`Yl7bIoo`03001oogoo05Moo`03001oogoo00Moo`0027oo00<007ooOol0H7oo00<007ooOol07goo
27`O9goo00<007ooOol0Egoo00<007ooOol01goo0008Ool00`00Oomoo`1POol00`00Oomoo`0POol6
O1lXOol00`00Oomoo`1GOol00`00Oomoo`07Ool000Qoo`03001oogoo061oo`03001oogoo04ioo`03
001oogoo05Moo`03001oogoo00Moo`0027oo00<007ooOol0H7oo00<007ooOol0CWoo00<007ooOol0
Egoo00<007ooOol01goo0008Ool00`00Oomoo`1POol00`00Oomoo`1>Ool00`00Oomoo`1GOol00`00
Oomoo`07Ool000Moo`03001oogoo065oo`03001oogoo04ioo`03001oogoo05Moo`03001oogoo00Mo
o`001goo00<007ooOol0HGoo00<007ooOol0CWoo00<007ooOol0Egoo00<007ooOol01goo0007Ool0
0`00Oomoo`1QOol00`00Oomoo`1>Ool00`00Oomoo`1GOol00`00Oomoo`07Ool000Moo`03001oogoo
065oo`03001oogoo04ioo`03001oogoo05Moo`03001oogoo00Moo`001goo00<007ooOol0HGoo00<0
07ooOol0CWoo00<007ooOol0Egoo00<007ooOol01goo0007Ool00`00Oomoo`1QOol00`00Oomoo`1>
Ool00`00Oomoo`1GOol00`00Oomoo`07Ool000Moo`03001oogoo065oo`03001oogoo04ioo`03001o
ogoo05Moo`03001oogoo00Moo`001goo00<007ooOol0HGoo00<007ooOol0CWoo00<007ooOol0Egoo
00<007ooOol01goo0007Ool00`00Oomoo`1QOol00`00Oomoo`1>Ool00`00Oomoo`1GOol00`00Oomo
o`07Ool000Moo`03001oogoo065oo`03001oogoo04ioo`03001oogoo05Moo`03001oogoo00Moo`00
1goo00<007ooOol0HGoo00<007ooOol0CWoo00<007ooOol0Egoo00<007ooOol01goo0007Ool00`00
Oomoo`1QOol00`00Oomoo`1>Ool00`00Oomoo`1GOol00`00Oomoo`07Ool000Moo`03001oogoo065o
o`03001oogoo04ioo`03001oogoo05Moo`03001oogoo00Moo`001goo00<007ooOol0HGoo00<007oo
Ool0CWoo00<007ooOol0Egoo00<007ooOol01goo0007Ool00`00Oomoo`1QOol00`00Oomoo`1>Ool0
0`00Oomoo`1GOol00`00Oomoo`07Ool000Moo`03001oogoo065oo`03001oogoo04ioo`03001oogoo
05Moo`03001oogoo00Moo`001goo00<007ooOol0HGoo00<007ooOol0CWoo00<007ooOol0Egoo00<0
07ooOol01goo0007Ool00`00Oomoo`1QOol00`00Oomoo`1>Ool00`00Oomoo`1GOol00`00Oomoo`07
Ool000Moo`03001oogoo065oo`03001oogoo04ioo`03001oogoo05Moo`03001oogoo00Moo`001goo
00<007ooOol0HGoo00<007ooOol0CWoo00<007ooOol0F7oo00<007ooOol01Woo0007Ool00`00Oomo
o`1QOol00`00Oomoo`1>Ool00`00Oomoo`1HOol00`00Oomoo`06Ool000Moo`03001oogoo065oo`03
001oogoo04ioo`03001oogoo05Qoo`03001oogoo00Ioo`001goo00<007ooOol0HGoo00<007ooOol0
CWoo00<007ooOol0F7oo00<007ooOol01Woo0007Ool00`00Oomoo`1QOol00`00Oomoo`1>Ool00`00
Oomoo`1HOol00`00Oomoo`06Ool000Moo`03001oogoo065oo`03001oogoo04ioo`03001oogoo05Qo
o`03001oogoo00Ioo`001goo00<007ooOol0HGoo00<007ooOol0CWoo00<007ooOol0F7oo00<007oo
Ool01Woo0006Ool00`00Oomoo`1ROol00`00Oomoo`1>Ool00`00Oomoo`1HOol00`00Oomoo`06Ool0
00Ioo`03001oogoo069oo`03001oogoo04ioo`03001oogoo05Qoo`03001oogoo00Ioo`001Woo00<0
07ooOol0HWoo00<007ooOol0CWoo00<007ooOol0F7oo00<007ooOol01Woo0006Ool00`00Oomoo`1R
Ool00`00Oomoo`1?Ool00`00Oomoo`1GOol00`00Oomoo`06Ool000Ioo`03001oogoo069oo`03001o
ogoo04moo`03001oogoo05Moo`03001oogoo00Ioo`001Woo00<007ooOol0HWoo00<007ooOol0Cgoo
00<007ooOol0Egoo00<007ooOol01Woo0006Ool00`00Oomoo`1ROol00`00Oomoo`1?Ool00`00Oomo
o`1GOol00`00Oomoo`06Ool000Ioo`03001oogoo069oo`03001oogoo04moo`03001oogoo05Moo`03
001oogoo00Ioo`001Woo00<007ooOol0HWoo00<007ooOol0Cgoo00<007ooOol0Egoo00<007ooOol0
1Woo0006Ool00`00Oomoo`1ROol00`00Oomoo`1?Ool00`00Oomoo`1GOol00`00Oomoo`06Ool000Io
o`03001oogoo069oo`03001oogoo04moo`03001oogoo05Moo`03001oogoo00Ioo`001Woo00<007oo
Ool0HWoo00<007ooOol0Cgoo00<007ooOol0Egoo00<007ooOol01Woo0006Ool00`00Oomoo`1ROol0
0`00Oomoo`1?Ool00`00Oomoo`1GOol00`00Oomoo`06Ool000Ioo`03001oogoo069oo`03001oogoo
04moo`03001oogoo05Moo`03001oogoo00Ioo`001Woo00<007ooOol0HWoo00<007ooOol0Cgoo00<0
07ooOol0Egoo00<007ooOol01Woo0006Ool00`00Oomoo`1ROol00`00Oomoo`1?Ool00`00Oomoo`1G
Ool00`00Oomoo`06Ool000Ioo`03001oogoo069oo`03001oogoo04moo`03001oogoo05Moo`03001o
ogoo00Ioo`001Woo00<007ooOol0HWoo00<007ooOol0Cgoo00<007ooOol0Egoo00<007ooOol01Woo
0006Ool00`00Oomoo`1ROol00`00Oomoo`1?Ool00`00Oomoo`1HOol00`00Oomoo`05Ool000Ioo`03
001oogoo069oo`03001oogoo04moo`03001oogoo05Qoo`03001oogoo00Eoo`001Woo00<007ooOol0
HWoo00<007ooOol0Cgoo00<007ooOol0F7oo00<007ooOol01Goo0006Ool00`00Oomoo`1ROol00`00
Oomoo`1?Ool00`00Oomoo`1HOol00`00Oomoo`05Ool000Ioo`03001oogoo069oo`03001oogoo04mo
o`03001oogoo05Qoo`03001oogoo00Eoo`001Woo00<007ooOol0HWoo00<007ooOol0Cgoo00<007oo
Ool0F7oo00<007ooOol01Goo0006Ool00`00Oomoo`1ROol00`00Oomoo`1?Ool00`00Oomoo`1HOol0
0`00Oomoo`05Ool000Ioo`03001oogoo069oo`03001oogoo04moo`03001oogoo05Qoo`03001oogoo
00Eoo`001Goo00<007ooOol0Hgoo00<007ooOol0Cgoo00<007ooOol0F7oo00<007ooOol01Goo0005
Ool00`00Oomoo`1SOol00`00Oomoo`1?Ool00`00Oomoo`1HOol00`00Oomoo`05Ool000Eoo`03001o
ogoo06=oo`03001oogoo04moo`03001oogoo05Qoo`03001oogoo00Eoo`001Goo00<007ooOol0Hgoo
00<007ooOol0Cgoo00<007ooOol0F7oo00<007ooOol01Goo0005Ool00`00Oomoo`1SOol00`00Oomo
o`1?Ool00`00Oomoo`1HOol00`00Oomoo`05Ool000Eoo`03001oogoo06=oo`03001oogoo04moo`03
001oogoo05Qoo`03001oogoo00Eoo`001Goo00<007ooOol0Hgoo00<007ooOol0Cgoo00<007ooOol0
F7oo00<007ooOol01Goo0005Ool00`00Oomoo`1SOol00`00Oomoo`1?Ool00`00Oomoo`1HOol00`00
Oomoo`05Ool000Eoo`03001oogoo06=oo`03001oogoo04moo`03001oogoo05Qoo`03001oogoo00Eo
o`001Goo00<007ooOol0Hgoo00<007ooOol0Cgoo00<007ooOol0F7oo00<007ooOol01Goo0005Ool0
0`00Oomoo`1SOol00`00Oomoo`1?Ool00`00Oomoo`1HOol00`00Oomoo`05Ool000Eoo`03001oogoo
06=oo`03001oogoo04moo`03001oogoo05Qoo`03001oogoo00Eoo`001Goo00<007ooOol0Hgoo00<0
07ooOol0Cgoo00<007ooOol0F7oo00<007ooOol01Goo0005Ool00`00Oomoo`1SOol00`00Oomoo`1?
Ool00`00Oomoo`1HOol00`00Oomoo`05Ool000Eoo`03001oogoo06=oo`03001oogoo04moo`03001o
ogoo05Qoo`03001oogoo00Eoo`001Goo00<007ooOol0Hgoo00<007ooOol0Cgoo00<007ooOol0F7oo
00<007ooOol01Goo0005Ool00`00Oomoo`1SOol00`00Oomoo`1?Ool00`00Oomoo`1HOol00`00Oomo
o`05Ool000Eoo`03001oogoo06=oo`03001oogoo04moo`03001oogoo05Qoo`03001oogoo00Eoo`00
1Goo00<007ooOol0Hgoo00<007ooOol0Cgoo00<007ooOol0FGoo00<007ooOol017oo0005Ool00`00
Oomoo`1SOol00`00Oomoo`1?Ool00`00Oomoo`1IOol00`00Oomoo`04Ool000Eoo`03001oogoo06=o
o`03001oogoo04moo`03001oogoo05Uoo`03001oogoo00Aoo`001Goo00<007ooOol0Hgoo00<007oo
Ool0Cgoo00<007ooOol0FGoo00<007ooOol017oo0005Ool00`00Oomoo`1SOol00`00Oomoo`1?Ool0
0`00Oomoo`1IOol00`00Oomoo`04Ool000Eoo`03001oogoo069oo`03001oogoo051oo`03001oogoo
05Uoo`03001oogoo00Aoo`001Goo00<007ooOol0HWoo00<007ooOol0D7oo00<007ooOol0FGoo00<0
07ooOol017oo0005Ool00`00Oomoo`1ROol00`00Oomoo`1@Ool00`00Oomoo`1IOol00`00Oomoo`04
Ool000Aoo`03001oogoo06=oo`03001oogoo051oo`03001oogoo05Uoo`03001oogoo00Aoo`0017oo
00<007ooOol0Hgoo00<007ooOol0D7oo00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomo
o`1SOol00`00Oomoo`1@Ool00`00Oomoo`1IOol00`00Oomoo`04Ool000Aoo`03001oogoo06=oo`03
001oogoo051oo`03001oogoo05Uoo`03001oogoo00Aoo`0017oo00<007ooOol0Hgoo00<007ooOol0
D7oo00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomoo`1SOol00`00Oomoo`1@Ool00`00
Oomoo`1IOol00`00Oomoo`04Ool000Aoo`03001oogoo06=oo`03001oogoo051oo`03001oogoo05Uo
o`03001oogoo00Aoo`0017oo00<007ooOol0Hgoo00<007ooOol0D7oo00<007ooOol0FGoo00<007oo
Ool017oo0004Ool00`00Oomoo`1SOol00`00Oomoo`1@Ool00`00Oomoo`1IOol00`00Oomoo`04Ool0
00Aoo`03001oogoo06=oo`03001oogoo051oo`03001oogoo05Uoo`03001oogoo00Aoo`0017oo00<0
07ooOol0Hgoo00<007ooOol0D7oo00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomoo`1S
Ool00`00Oomoo`1@Ool00`00Oomoo`1IOol00`00Oomoo`04Ool000Aoo`03001oogoo06=oo`03001o
ogoo051oo`03001oogoo05Uoo`03001oogoo00Aoo`0017oo00<007ooOol0Hgoo00<007ooOol0D7oo
00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomoo`1SOol00`00Oomoo`1@Ool00`00Oomo
o`1IOol00`00Oomoo`04Ool000Aoo`03001oogoo06=oo`03001oogoo051oo`03001oogoo05Uoo`03
001oogoo00Aoo`0017oo00<007ooOol0Hgoo00<007ooOol0D7oo00<007ooOol0FGoo00<007ooOol0
17oo0004Ool00`00Oomoo`1SOol00`00Oomoo`1@Ool00`00Oomoo`1JOol00`00Oomoo`03Ool000Ao
o`03001oogoo06=oo`03001oogoo051oo`03001oogoo05Yoo`03001oogoo00=oo`0017oo00<007oo
Ool0Hgoo00<007ooOol0D7oo00<007ooOol0FWoo00<007ooOol00goo0004Ool00`00Oomoo`1SOol0
0`00Oomoo`1@Ool00`00Oomoo`1JOol00`00Oomoo`03Ool000Aoo`03001oogoo06=oo`03001oogoo
051oo`03001oogoo05Yoo`03001oogoo00=oo`0017oo00<007ooOol0Hgoo00<007ooOol0D7oo00<0
07ooOol0FWoo00<007ooOol00goo0004Ool00`00Oomoo`1SOol00`00Oomoo`1@Ool00`00Oomoo`1J
Ool00`00Oomoo`03Ool000Aoo`03001oogoo06=oo`03001oogoo051oo`03001oogoo05Yoo`03001o
ogoo00=oo`000goo00<007ooOol0I7oo00<007ooOol0D7oo00<007ooOol0FWoo00<007ooOol00goo
0003Ool00`00Oomoo`1TOol00`00Oomoo`1AOol00`00Oomoo`1IOol00`00Oomoo`03Ool000=oo`03
001oogoo06Aoo`03001oogoo055oo`03001oogoo05Uoo`03001oogoo00=oo`000goo00<007ooOol0
I7oo00<007ooOol0DGoo00<007ooOol0FGoo00<007ooOol00goo0003Ool00`00Oomoo`1TOol00`00
Oomoo`1AOol00`00Oomoo`1IOol00`00Oomoo`03Ool000=oo`03001oogoo06Aoo`03001oogoo055o
o`03001oogoo05Uoo`03001oogoo00=oo`000goo00<007ooOol0I7oo00<007ooOol0DGoo00<007oo
Ool0FGoo00<007ooOol00goo0003Ool00`00Oomoo`1TOol00`00Oomoo`1AOol00`00Oomoo`1IOol0
0`00Oomoo`03Ool000=oo`03001oogoo06Aoo`03001oogoo055oo`03001oogoo05Uoo`03001oogoo
00=oo`000goo00<007ooOol0I7oo00<007ooOol0DGoo00<007ooOol0FGoo00<007ooOol00goo0003
Ool00`00Oomoo`1TOol00`00Oomoo`1AOol00`00Oomoo`1IOol00`00Oomoo`03Ool000=oo`03001o
ogoo06Aoo`03001oogoo055oo`03001oogoo05Uoo`03001oogoo00=oo`000goo00<007ooOol0I7oo
00<007ooOol0DGoo00<007ooOol0FGoo00<007ooOol00goo0003Ool00`00Oomoo`1TOol00`00Oomo
o`1AOol00`00Oomoo`1IOol00`00Oomoo`03Ool000=oo`03001oogoo06Aoo`03001oogoo055oo`03
001oogoo05Uoo`03001oogoo00=oo`000goo00<007ooOol0I7oo00<007ooOol0DGoo00<007ooOol0
FGoo00<007ooOol00goo0003Ool00`00Oomoo`1TOol00`00Oomoo`1AOol00`00Oomoo`1IOol00`00
Oomoo`03Ool000=oo`03001oogoo06Aoo`03001oogoo055oo`03001oogoo05Uoo`03001oogoo00=o
o`000goo00<007ooOol0I7oo00<007ooOol0DGoo00<007ooOol0FWoo00<007ooOol00Woo0003Ool0
0`00Oomoo`1TOol00`00Oomoo`1AOol00`00Oomoo`1JOol00`00Oomoo`02Ool000=oo`03001oogoo
06Aoo`03001oogoo055oo`03001oogoo05Yoo`03001oogoo009oo`000goo00<007ooOol0I7oo00<0
07ooOol0DGoo00<007ooOol0FWoo00<007ooOol00Woo0003Ool00`00Oomoo`1TOol00`00Oomoo`1A
Ool00`00Oomoo`1JOol00`00Oomoo`02Ool000=oo`03001oogoo06Aoo`03001oogoo055oo`03001o
ogoo05Yoo`03001oogoo009oo`000goo00<007ooOol0I7oo00<007ooOol0DGoo00<007ooOol0FWoo
00<007ooOol00Woo0003Ool00`00Oomoo`1TOol00`00Oomoo`1AOol00`00Oomoo`1JOol00`00Oomo
o`02Ool0009oo`03001oogoo06Eoo`03001oogoo055oo`03001oogoo05Yoo`03001oogoo009oo`00
0Woo00<007ooOol0IGoo00<007ooOol0DGoo00<007ooOol0FWoo00<007ooOol00Woo0002Ool00`00
Oomoo`1UOol00`00Oomoo`1AOol00`00Oomoo`1JOol00`00Oomoo`02Ool0009oo`03001oogoo06Eo
o`03001oogoo055oo`03001oogoo05Yoo`03001oogoo009oo`000Woo00<007ooOol0IGoo00<007oo
Ool0DGoo00<007ooOol0FWoo00<007ooOol00Woo0002Ool00`00Oomoo`1UOol00`00Oomoo`1AOol0
0`00Oomoo`1JOol00`00Oomoo`02Ool0009oo`03001oogoo06Eoo`03001oogoo055oo`03001oogoo
05Yoo`03001oogoo009oo`000Woo00<007ooOol0IGoo00<007ooOol0DGoo00<007ooOol0FWoo00<0
07ooOol00Woo0002Ool00`00Oomoo`1UOol00`00Oomoo`1AOol00`00Oomoo`1JOol00`00Oomoo`02
Ool0009oo`03001oogoo06Eoo`03001oogoo055oo`03001oogoo05Yoo`03001oogoo009oo`000Woo
00<007ooOol0IGoo00<007ooOol0DGoo00<007ooOol0FWoo00<007ooOol00Woo0002Ool00`00Oomo
o`1UOol00`00Oomoo`1AOol00`00Oomoo`1JOol00`00Oomoo`02Ool0009oo`03001oogoo06Eoo`03
001oogoo051oo`8005aoo`03001oogoo009oo`000Woo00<007ooOol0IGoo00<007ooOol0C7oo1000
0Woo00<007ooOol0FGoo00<007ooOol00Woo0002Ool00`00Oomoo`1UOol00`00Oomoo`18Ool40007
Ool00`00Oomoo`1HOol00`00Oomoo`02Ool0009oo`03001oogoo06Eoo`03001oogoo04Eoo`<000ao
o`03001oogoo05Moo`03001oogoo009oo`000Woo00<007ooOol0IGoo00<007ooOol0@Goo100047oo
00<007ooOol0EWoo00<007ooOol00Woo0002Ool00`00Oomoo`1UOol00`00Oomoo`0mOol4000EOol0
0`00Oomoo`1FOol00`00Oomoo`01Ool0009oo`03001oogoo06Eoo`03001oogoo03Yoo`<001Yoo`03
001oogoo05Eoo`03001oogoo005oo`000Woo00<007ooOol0IGoo00<007ooOol0=Woo10007Woo00<0
07ooOol0E7oo00<007ooOol00Goo0002Ool00`00Oomoo`1UOol00`00Oomoo`0bOol4000SOol00`00
Oomoo`1COol00`00Oomoo`01Ool0009oo`03001oogoo06Eoo`03001oogoo02moo`<002Qoo`03001o
ogoo059oo`03001oogoo005oo`000Woo00<007ooOol0IGoo00<007ooOol0:goo1000;7oo00<007oo
Ool0DGoo00<007ooOol00Goo0002Ool00`00Oomoo`1UOol00`00Oomoo`0WOol4000aOol00`00Oomo
o`1@Ool00`00Oomoo`01Ool0009oo`03001oogoo06Eoo`03001oogoo02Aoo`<003Ioo`03001oogoo
04moo`03001oogoo005oo`000Woo00<007ooOol0IGoo00<007ooOol087oo1000>Woo00<007ooOol0
CWoo00<007ooOol00Goo00000goo001oo`1WOol00`00Oomoo`0MOol3000oOol00`00Oomoo`1=Ool0
0`00Oomoo`01Ool00003Ool007oo06Moo`03001oogoo01Uoo`@004=oo`03001oogoo04aoo`03001o
ogoo005oo`0000=oo`00Ool0Igoo00<007ooOol05Goo1000B7oo0P00C7oo00<007ooOol00Goo0000
0goo001oo`1VOol00`00Oomoo`0COol3001>Ool00`00Oomoo`19Ool00`00Oomoo`01Ool00003Ool0
07oo06Ioo`03001oogoo00moo`@0059oo`03001oogoo04Qoo`03001oogoo005oo`0000=oo`00Ool0
IWoo00<007ooOol02goo1000Egoo00<007ooOol0Agoo00<007ooOol00Goo00000goo001oo`1VOol0
0`00Oomoo`08Ool3001LOol00`00Oomoo`16Ool00`00Oomoo`01Ool00003Ool007oo06Ioo`03001o
ogoo00Aoo`@0061oo`03001oogoo04Eoo`03001oogoo005oo`0000=oo`00Ool0IWoo00<007ooOol0
1000IGoo00<007ooOol0A7oo00<007ooOol00Goo00000goo001oo`1VOol3001ZOol00`00Oomoo`13
Ool00`00Oomoo`01Ool00003Ool007oo069oo`D006eoo`03001oogoo049oo`03001oogoo005oo`00
00=oo`00Ool0GWoo100017oo00<007ooOol0K7oo00<007ooOol0@Goo00<007ooOol00Goo00000goo
001oo`1KOol30008Ool00`00Oomoo`1]Ool00`00Oomoo`10Ool00`00Oomoo`01Ool00003Ool007oo
05Moo`@000]oo`03001oogoo06ioo`03001oogoo03moo`03001oogoo005oo`0000=oo`00Ool0Dgoo
10003goo00<007ooOol0Kgoo00<007ooOol0?Woo00<007ooOol00Goo00000goo001oo`1@Ool3000C
Ool00`00Oomoo`1`Ool00`00Oomoo`0mOol00`00Oomoo`01Ool00003Ool007oo04aoo`@001Ioo`03
001oogoo075oo`03001oogoo03aoo`03001oogoo005oo`0000=oo`00Ool0B7oo10006Woo00<007oo
Ool0LWoo00<007ooOol0?7oo0@000Goo0Goo00000goo001oo`15Ool3000NOol00`00Oomoo`1cOol0
0`00Oomoo`0kOol10001Ool1Ool00003Ool007oo045oo`@0025oo`03001oogoo07Aoo`03001oogoo
03Yoo`40005oo`5oo`0000=oo`00Ool0?Goo10009Goo00<007ooOol0MGoo00<007ooOol0>Goo0@00
0Goo0Goo00000goo001oo`0jOol3000YOol00`00Oomoo`1fOol00`00Oomoo`0hOol10001Ool1Ool0
0003Ool007oo03Ioo`@002aoo`03001oogoo07Moo`03001oogoo03Moo`40005oo`5oo`0000=oo`00
Ool0<Woo1000<7oo00<007ooOol0N7oo00<007ooOol0=Woo0@000Goo0Goo00000goo001oo`0_Ool3
000dOol00`00Oomoo`1iOol00`00Oomoo`0eOol10001Ool1Ool00003Ool007oo02]oo`@003Moo`03
001oogoo07Yoo`03001oogoo03Aoo`40005oo`5oo`0000<007ooOol0:7oo0`00>goo00<007ooOol0
Ngoo00<007ooOol0<goo0@000Goo0Goo00000`00Oomoo`0TOol4000nOol00`00Oomoo`1lOol00`00
Oomoo`0bOol10001Ool1Ool00003001oogoo021oo`@0049oo`03001oogoo07eoo`03001oogoo035o
o`40005oo`5oo`0000<007ooOol07Goo0`00AWoo00<007ooOol0OWoo00<007ooOol0<7oo0@000Goo
0Goo00000`00Oomoo`0IOol40019Ool00`00Oomoo`1oOol00`00Oomoo`0_Ool10001Ool1Ool00003
001oogoo01Eoo`@004eoo`03001oogoo081oo`03001oogoo02ioo`40005oo`5oo`0000<007ooOol0
4Woo0`00DGoo00<007ooOol0PGoo00<007ooOol0;Goo0@000Goo0Goo00000`00Oomoo`0>Ool4001D
Ool00`00Oomoo`22Ool2000]Ool10001Ool1Ool00003001oogoo00Yoo`@005Qoo`03001oogoo08Ao
o`03001oogoo02Yoo`40005oo`5oo`0000<007ooOol01goo0`00G7oo00<007ooOol0QGoo00<007oo
Ool0:Goo0@000Goo0Goo00000`00Oomoo`03Ool4001OOol00`00Oomoo`0ROol6O1mNOol00`00Oomo
o`0XOol10001Ool1Ool00003001oo`0000<006=oo`03001oogoo025oo`Ql7eioo`03001oogoo02Mo
o`40005oo`5oo`000P00Igoo00<007ooOol087oo2W`OGWoo00<007ooOol09Woo0@000Goo0Goo0000
0goo001oo`1VOol00`00Oomoo`0OOol<O1mNOol00`00Oomoo`0UOol10001Ool1Ool0009oo`03001o
ogoo06Aoo`03001oogoo01ioo`il7eioo`03001oogoo02Aoo`40005oo`5oo`000goo0P00I7oo00<0
07ooOol07Woo3W`OGgoo00<007ooOol08goo0@000Goo0Goo0005Ool00`00Oomoo`1QOol00`00Oomo
o`0NOol>O1mPOol00`00Oomoo`0SOol10001Ool000Ioo`03001oogoo061oo`03001oogoo01ioo`il
7f5oo`03001oogoo029oo`40005oo`001goo00<007ooOol0Ggoo00<007ooOol07Woo3W`OHWoo00<0
07ooOol08Goo0@000Goo0008Ool00`00Oomoo`1NOol00`00Oomoo`0NOol>O1mSOol00`00Oomoo`0P
Ool10001Ool000Uoo`8005ioo`03001oogoo01moo`al7fEoo`03001oogoo01moo`40005oo`002goo
00<007ooOol0Fgoo00<007ooOol087oo2W`OIgoo00<007ooOol07Woo0@000Goo000<Ool00`00Oomo
o`1JOol00`00Oomoo`0QOol8O1mYOol00`00Oomoo`0MOol10001Ool000eoo`03001oogoo05Uoo`03
001oogoo029oo`Il7f]oo`03001oogoo01aoo`40005oo`003Woo00<007ooOol0F7oo00<007ooOol0
U7oo00<007ooOol06goo0@000Goo000?Ool00`00Oomoo`1GOol00`00Oomoo`2EOol00`00Oomoo`0J
Ool10001Ool0011oo`8005Moo`03001oogoo09Ioo`03001oogoo01Uoo`40005oo`004Woo00<007oo
Ool0E7oo00<007ooOol0Ugoo00<007ooOol067oo0@000Goo000COol00`00Oomoo`1COol00`00Oomo
o`2HOol00`00Oomoo`0GOol10001Ool001Aoo`03001oogoo059oo`03001oogoo09Uoo`03001oogoo
01Ioo`40005oo`005Goo00<007ooOol0DGoo00<007ooOol0VWoo00<007ooOol05Goo0@000Goo000F
Ool2001AOol00`00Oomoo`2KOol00`00Oomoo`0DOol10001Ool001Qoo`03001oogoo04ioo`03001o
ogoo09aoo`03001oogoo01=oo`40005oo`006Goo00<007ooOol0CGoo00<007ooOol0WGoo00<007oo
Ool04Woo0@000Goo000JOol00`00Oomoo`1<Ool00`00Oomoo`2NOol00`00Oomoo`0AOol10001Ool0
01]oo`03001oogoo04]oo`03001oogoo09moo`03001oogoo011oo`40005oo`0077oo00<007ooOol0
BWoo00<007ooOol0X7oo00<007ooOol03goo0@000Goo000MOol2001:Ool00`00Oomoo`2QOol00`00
Oomoo`0>Ool10001Ool001moo`03001oogoo04Moo`03001oogoo0:9oo`8000ioo`40005oo`0087oo
00<007ooOol0AWoo00<007ooOol0Y7oo00<007ooOol02goo0@000Goo000QOol00`00Oomoo`15Ool0
0`00Oomoo`2UOol00`00Oomoo`0:Ool10001Ool0029oo`03001oogoo04Aoo`03001oogoo0:Ioo`03
001oogoo00Uoo`40005oo`008goo0P00A7oo00<007ooOol0Ygoo00<007ooOol02Goo0@00000UOol0
0`00Oomoo`11Ool00`00Oomoo`2XOol00`00Oomoo`08Ool1000002Ioo`03001oogoo041oo`03001o
ogoo0:Uoo`03001oogoo00Moo`4000009goo00<007ooOol0?goo00<007ooOol0ZWoo00<007ooOol0
1Woo0@00000XOol00`00Oomoo`0nOol00`00Oomoo`2[Ool00`00Oomoo`05Ool1000002Uoo`03001o
ogoo03eoo`03001oogoo0:aoo`03001oogoo00Aoo`400000:Woo0P00?Goo00<007ooOol0[Goo00<0
07ooOol00goo0@00000/Ool00`00Oomoo`0jOol00`00Oomoo`2^Ool00`00Oomoo`02Ool1000002eo
o`03001oogoo03Uoo`03001oogoo0:moo`04001oogooOol1000002ioo`03001oogoo03Qoo`03001o
ogoo0;1oo`03001oogoo00400000;goo00<007ooOol0=goo00<007ooOol0/Goo0@000Goo0@00000`
Ool2000gOol00`00Oomoo`2bOol20000039oo`03001oogoo03Aoo`03001oogoo0;9oo`800000<goo
00<007ooOol0<goo00<007ooOol0[Woo10000Woo000dOol00`00Oomoo`0bOol00`00Oomoo`2ZOol4
0006Ool003Eoo`03001oogoo035oo`03001oogoo0:Ioo`@000Yoo`00=Woo00<007ooOol0<7oo00<0
07ooOol0XWoo10003Woo000gOol2000_Ool00`00Oomoo`2OOol4000BOol003Uoo`03001oogoo02ao
o`03001oogoo09]oo`@001Ioo`00>Woo00<007ooOol0:goo00<007ooOol0Ugoo10006Woo000kOol0
0`00Oomoo`0ZOol00`00Oomoo`2COol4000NOol003aoo`03001oogoo02Uoo`03001oogoo08moo`@0
029oo`00?Goo0P00:Goo00<007ooOol0Rgoo10009Woo000oOol00`00Oomoo`0VOol00`00Oomoo`27
Ool4000ZOol0041oo`03001oogoo02Eoo`03001oogoo08=oo`@002ioo`00@Goo00<007ooOol097oo
00<007ooOol0Ogoo1000<Woo0012Ool00`00Oomoo`0SOol00`00Oomoo`1kOol4000fOol004=oo`03
001oogoo029oo`03001oogoo07Moo`@003Yoo`00A7oo0P008Woo00<007ooOol0Lgoo1000?Woo0016
Ool00`00Oomoo`0OOol00`00Oomoo`1_Ool40012Ool004Moo`03001oogoo01ioo`03001oogoo06]o
o`@004Ioo`00B7oo00<007ooOol07Goo00<007ooOol0Igoo1000BWoo0019Ool00`00Oomoo`0LOol0
0`00Oomoo`1SOol4001>Ool004Yoo`8001aoo`03001oogoo05moo`@0059oo`00C7oo00<007ooOol0
6Goo00<007ooOol0Fgoo1000EWoo001=Ool00`00Oomoo`0HOol00`00Oomoo`1GOol4001JOol004io
o`03001oogoo01Moo`03001oogoo05=oo`@005ioo`00Cgoo00<007ooOol05Woo00<007ooOol0Cgoo
1000HWoo001@Ool00`00Oomoo`0EOol00`00Oomoo`1;Ool4001VOol0055oo`8001Eoo`03001oogoo
04Moo`@006Yoo`00Dgoo00<007ooOol04Woo00<007ooOol0@goo1000KWoo001DOol00`00Oomoo`0A
Ool00`00Oomoo`0oOol4001bOol005Eoo`03001oogoo011oo`03001oogoo03]oo`@007Ioo`00EWoo
00<007ooOol03goo00<007ooOol0=goo1000NWoo001GOol2000?Ool00`00Oomoo`0cOol4001nOol0
05Uoo`03001oogoo00aoo`03001oogoo02moo`@0089oo`00FWoo00<007ooOol02goo00<007ooOol0
:goo1000QWoo001KOol00`00Oomoo`0:Ool00`00Oomoo`0WOol4002:Ool005aoo`03001oogoo00Uo
o`03001oogoo02=oo`@008ioo`00GGoo00<007ooOol027oo00<007ooOol07goo1000TWoo001NOol2
0008Ool00`00Oomoo`0KOol4002FOol0061oo`03001oogoo00Eoo`03001oogoo01Moo`@009Yoo`00
HGoo00<007ooOol017oo00<007ooOol04goo1000WWoo001ROol00`00Oomoo`03Ool00`00Oomoo`0?
Ool4002ROol006=oo`03001oogoo009oo`03001oogoo00]oo`@00:Ioo`00I7oo0P000Woo00<007oo
Ool01goo1000ZWoo001VOol00`00Ool00005Ool4002^Ool006Moo`800003Ool0000000800;9oo`00
J7oo0P00]Woo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {742.188, 0}} -> {0.311846, 0.0413501, \
0.00129304, 0.00129304}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["dt=0.01;", "Input"],

Cell["NSPHR=4;NDIM=6 NSPHR;Ng=3 NSPHR; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\StokesianDynamics\\\\data.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\StokesianDynamics\\data.m", 7]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];
X[3,0]=X[3];Y[3,0]=Y[3];Z[3,0]=Z[3];
X[4,0]=X[4];Y[4,0]=Y[4];Z[4,0]=Z[4];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<500,{<<\"C:\\\\StokesianDynamics\\\\NEWTON2.m\";
X[1,t]=X[1,t-1]+UNEW[1]*dt;Y[1,t]=Y[1,t-1]+UNEW[2]*dt;Z[1,t]=Z[1,t-1]+UNEW[3]*\
dt;X[2,t]=X[2,t-1]+UNEW[4]*dt;Y[2,t]=Y[2,t-1]+UNEW[5]*dt;Z[2,t]=Z[2,t-1]+UNEW[\
6]*dt;X[3,t]=X[3,t-1]+UNEW[7]*dt;Y[3,t]=Y[3,t-1]+UNEW[8]*dt;Z[3,t]=Z[3,t-1]+\
UNEW[9]*dt;X[4,t]=X[4,t-1]+UNEW[10]*dt;Y[4,t]=Y[4,t-1]+UNEW[11]*dt;Z[4,t]=Z[4,\
t-1]+UNEW[12]*dt;Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"],

Cell[BoxData[
    \(100\)], "Print"],

Cell[BoxData[
    \(101\)], "Print"],

Cell[BoxData[
    \(102\)], "Print"],

Cell[BoxData[
    \(103\)], "Print"],

Cell[BoxData[
    \(104\)], "Print"],

Cell[BoxData[
    \(105\)], "Print"],

Cell[BoxData[
    \(106\)], "Print"],

Cell[BoxData[
    \(107\)], "Print"],

Cell[BoxData[
    \(108\)], "Print"],

Cell[BoxData[
    \(109\)], "Print"],

Cell[BoxData[
    \(110\)], "Print"],

Cell[BoxData[
    \(111\)], "Print"],

Cell[BoxData[
    \(112\)], "Print"],

Cell[BoxData[
    \(113\)], "Print"],

Cell[BoxData[
    \(114\)], "Print"],

Cell[BoxData[
    \(115\)], "Print"],

Cell[BoxData[
    \(116\)], "Print"],

Cell[BoxData[
    \(117\)], "Print"],

Cell[BoxData[
    \(118\)], "Print"],

Cell[BoxData[
    \(119\)], "Print"],

Cell[BoxData[
    \(120\)], "Print"],

Cell[BoxData[
    \(121\)], "Print"],

Cell[BoxData[
    \(122\)], "Print"],

Cell[BoxData[
    \(123\)], "Print"],

Cell[BoxData[
    \(124\)], "Print"],

Cell[BoxData[
    \(125\)], "Print"],

Cell[BoxData[
    \(126\)], "Print"],

Cell[BoxData[
    \(127\)], "Print"],

Cell[BoxData[
    \(128\)], "Print"],

Cell[BoxData[
    \(129\)], "Print"],

Cell[BoxData[
    \(130\)], "Print"],

Cell[BoxData[
    \(131\)], "Print"],

Cell[BoxData[
    \(132\)], "Print"],

Cell[BoxData[
    \(133\)], "Print"],

Cell[BoxData[
    \(134\)], "Print"],

Cell[BoxData[
    \(135\)], "Print"],

Cell[BoxData[
    \(136\)], "Print"],

Cell[BoxData[
    \(137\)], "Print"],

Cell[BoxData[
    \(138\)], "Print"],

Cell[BoxData[
    \(139\)], "Print"],

Cell[BoxData[
    \(140\)], "Print"],

Cell[BoxData[
    \(141\)], "Print"],

Cell[BoxData[
    \(142\)], "Print"],

Cell[BoxData[
    \(143\)], "Print"],

Cell[BoxData[
    \(144\)], "Print"],

Cell[BoxData[
    \(145\)], "Print"],

Cell[BoxData[
    \(146\)], "Print"],

Cell[BoxData[
    \(147\)], "Print"],

Cell[BoxData[
    \(148\)], "Print"],

Cell[BoxData[
    \(149\)], "Print"],

Cell[BoxData[
    \(150\)], "Print"],

Cell[BoxData[
    \(151\)], "Print"],

Cell[BoxData[
    \(152\)], "Print"],

Cell[BoxData[
    \(153\)], "Print"],

Cell[BoxData[
    \(154\)], "Print"],

Cell[BoxData[
    \(155\)], "Print"],

Cell[BoxData[
    \(156\)], "Print"],

Cell[BoxData[
    \(157\)], "Print"],

Cell[BoxData[
    \(158\)], "Print"],

Cell[BoxData[
    \(159\)], "Print"],

Cell[BoxData[
    \(160\)], "Print"],

Cell[BoxData[
    \(161\)], "Print"],

Cell[BoxData[
    \(162\)], "Print"],

Cell[BoxData[
    \(163\)], "Print"],

Cell[BoxData[
    \(164\)], "Print"],

Cell[BoxData[
    \(165\)], "Print"],

Cell[BoxData[
    \(166\)], "Print"],

Cell[BoxData[
    \(167\)], "Print"],

Cell[BoxData[
    \(168\)], "Print"],

Cell[BoxData[
    \(169\)], "Print"],

Cell[BoxData[
    \(170\)], "Print"],

Cell[BoxData[
    \(171\)], "Print"],

Cell[BoxData[
    \(172\)], "Print"],

Cell[BoxData[
    \(173\)], "Print"],

Cell[BoxData[
    \(174\)], "Print"],

Cell[BoxData[
    \(175\)], "Print"],

Cell[BoxData[
    \(176\)], "Print"],

Cell[BoxData[
    \(177\)], "Print"],

Cell[BoxData[
    \(178\)], "Print"],

Cell[BoxData[
    \(179\)], "Print"],

Cell[BoxData[
    \(180\)], "Print"],

Cell[BoxData[
    \(181\)], "Print"],

Cell[BoxData[
    \(182\)], "Print"],

Cell[BoxData[
    \(183\)], "Print"],

Cell[BoxData[
    \(184\)], "Print"],

Cell[BoxData[
    \(185\)], "Print"],

Cell[BoxData[
    \(186\)], "Print"],

Cell[BoxData[
    \(187\)], "Print"],

Cell[BoxData[
    \(188\)], "Print"],

Cell[BoxData[
    \(189\)], "Print"],

Cell[BoxData[
    \(190\)], "Print"],

Cell[BoxData[
    \(191\)], "Print"],

Cell[BoxData[
    \(192\)], "Print"],

Cell[BoxData[
    \(193\)], "Print"],

Cell[BoxData[
    \(194\)], "Print"],

Cell[BoxData[
    \(195\)], "Print"],

Cell[BoxData[
    \(196\)], "Print"],

Cell[BoxData[
    \(197\)], "Print"],

Cell[BoxData[
    \(198\)], "Print"],

Cell[BoxData[
    \(199\)], "Print"],

Cell[BoxData[
    \(200\)], "Print"],

Cell[BoxData[
    \(201\)], "Print"],

Cell[BoxData[
    \(202\)], "Print"],

Cell[BoxData[
    \(203\)], "Print"],

Cell[BoxData[
    \(204\)], "Print"],

Cell[BoxData[
    \(205\)], "Print"],

Cell[BoxData[
    \(206\)], "Print"],

Cell[BoxData[
    \(207\)], "Print"],

Cell[BoxData[
    \(208\)], "Print"],

Cell[BoxData[
    \(209\)], "Print"],

Cell[BoxData[
    \(210\)], "Print"],

Cell[BoxData[
    \(211\)], "Print"],

Cell[BoxData[
    \(212\)], "Print"],

Cell[BoxData[
    \(213\)], "Print"],

Cell[BoxData[
    \(214\)], "Print"],

Cell[BoxData[
    \(215\)], "Print"],

Cell[BoxData[
    \(216\)], "Print"],

Cell[BoxData[
    \(217\)], "Print"],

Cell[BoxData[
    \(218\)], "Print"],

Cell[BoxData[
    \(219\)], "Print"],

Cell[BoxData[
    \(220\)], "Print"],

Cell[BoxData[
    \(221\)], "Print"],

Cell[BoxData[
    \(222\)], "Print"],

Cell[BoxData[
    \(223\)], "Print"],

Cell[BoxData[
    \(224\)], "Print"],

Cell[BoxData[
    \(225\)], "Print"],

Cell[BoxData[
    \(226\)], "Print"],

Cell[BoxData[
    \(227\)], "Print"],

Cell[BoxData[
    \(228\)], "Print"],

Cell[BoxData[
    \(229\)], "Print"],

Cell[BoxData[
    \(230\)], "Print"],

Cell[BoxData[
    \(231\)], "Print"],

Cell[BoxData[
    \(232\)], "Print"],

Cell[BoxData[
    \(233\)], "Print"],

Cell[BoxData[
    \(234\)], "Print"],

Cell[BoxData[
    \(235\)], "Print"],

Cell[BoxData[
    \(236\)], "Print"],

Cell[BoxData[
    \(237\)], "Print"],

Cell[BoxData[
    \(238\)], "Print"],

Cell[BoxData[
    \(239\)], "Print"],

Cell[BoxData[
    \(240\)], "Print"],

Cell[BoxData[
    \(241\)], "Print"],

Cell[BoxData[
    \(242\)], "Print"],

Cell[BoxData[
    \(243\)], "Print"],

Cell[BoxData[
    \(244\)], "Print"],

Cell[BoxData[
    \(245\)], "Print"],

Cell[BoxData[
    \(246\)], "Print"],

Cell[BoxData[
    \(247\)], "Print"],

Cell[BoxData[
    \(248\)], "Print"],

Cell[BoxData[
    \(249\)], "Print"],

Cell[BoxData[
    \(250\)], "Print"],

Cell[BoxData[
    \(251\)], "Print"],

Cell[BoxData[
    \(252\)], "Print"],

Cell[BoxData[
    \(253\)], "Print"],

Cell[BoxData[
    \(254\)], "Print"],

Cell[BoxData[
    \(255\)], "Print"],

Cell[BoxData[
    \(256\)], "Print"],

Cell[BoxData[
    \(257\)], "Print"],

Cell[BoxData[
    \(258\)], "Print"],

Cell[BoxData[
    \(259\)], "Print"],

Cell[BoxData[
    \(260\)], "Print"],

Cell[BoxData[
    \(261\)], "Print"],

Cell[BoxData[
    \(262\)], "Print"],

Cell[BoxData[
    \(263\)], "Print"],

Cell[BoxData[
    \(264\)], "Print"],

Cell[BoxData[
    \(265\)], "Print"],

Cell[BoxData[
    \(266\)], "Print"],

Cell[BoxData[
    \(267\)], "Print"],

Cell[BoxData[
    \(268\)], "Print"],

Cell[BoxData[
    \(269\)], "Print"],

Cell[BoxData[
    \(270\)], "Print"],

Cell[BoxData[
    \(271\)], "Print"],

Cell[BoxData[
    \(272\)], "Print"],

Cell[BoxData[
    \(273\)], "Print"],

Cell[BoxData[
    \(274\)], "Print"],

Cell[BoxData[
    \(275\)], "Print"],

Cell[BoxData[
    \(276\)], "Print"],

Cell[BoxData[
    \(277\)], "Print"],

Cell[BoxData[
    \(278\)], "Print"],

Cell[BoxData[
    \(279\)], "Print"],

Cell[BoxData[
    \(280\)], "Print"],

Cell[BoxData[
    \(281\)], "Print"],

Cell[BoxData[
    \(282\)], "Print"],

Cell[BoxData[
    \(283\)], "Print"],

Cell[BoxData[
    \(284\)], "Print"],

Cell[BoxData[
    \(285\)], "Print"],

Cell[BoxData[
    \(286\)], "Print"],

Cell[BoxData[
    \(287\)], "Print"],

Cell[BoxData[
    \(288\)], "Print"],

Cell[BoxData[
    \(289\)], "Print"],

Cell[BoxData[
    \(290\)], "Print"],

Cell[BoxData[
    \(291\)], "Print"],

Cell[BoxData[
    \(292\)], "Print"],

Cell[BoxData[
    \(293\)], "Print"],

Cell[BoxData[
    \(294\)], "Print"],

Cell[BoxData[
    \(295\)], "Print"],

Cell[BoxData[
    \(296\)], "Print"],

Cell[BoxData[
    \(297\)], "Print"],

Cell[BoxData[
    \(298\)], "Print"],

Cell[BoxData[
    \(299\)], "Print"],

Cell[BoxData[
    \(300\)], "Print"],

Cell[BoxData[
    \(301\)], "Print"],

Cell[BoxData[
    \(302\)], "Print"],

Cell[BoxData[
    \(303\)], "Print"],

Cell[BoxData[
    \(304\)], "Print"],

Cell[BoxData[
    \(305\)], "Print"],

Cell[BoxData[
    \(306\)], "Print"],

Cell[BoxData[
    \(307\)], "Print"],

Cell[BoxData[
    \(308\)], "Print"],

Cell[BoxData[
    \(309\)], "Print"],

Cell[BoxData[
    \(310\)], "Print"],

Cell[BoxData[
    \(311\)], "Print"],

Cell[BoxData[
    \(312\)], "Print"],

Cell[BoxData[
    \(313\)], "Print"],

Cell[BoxData[
    \(314\)], "Print"],

Cell[BoxData[
    \(315\)], "Print"],

Cell[BoxData[
    \(316\)], "Print"],

Cell[BoxData[
    \(317\)], "Print"],

Cell[BoxData[
    \(318\)], "Print"],

Cell[BoxData[
    \(319\)], "Print"],

Cell[BoxData[
    \(320\)], "Print"],

Cell[BoxData[
    \(321\)], "Print"],

Cell[BoxData[
    \(322\)], "Print"],

Cell[BoxData[
    \(323\)], "Print"],

Cell[BoxData[
    \(324\)], "Print"],

Cell[BoxData[
    \(325\)], "Print"],

Cell[BoxData[
    \(326\)], "Print"],

Cell[BoxData[
    \(327\)], "Print"],

Cell[BoxData[
    \(328\)], "Print"],

Cell[BoxData[
    \(329\)], "Print"],

Cell[BoxData[
    \(330\)], "Print"],

Cell[BoxData[
    \(331\)], "Print"],

Cell[BoxData[
    \(332\)], "Print"],

Cell[BoxData[
    \(333\)], "Print"],

Cell[BoxData[
    \(334\)], "Print"],

Cell[BoxData[
    \(335\)], "Print"],

Cell[BoxData[
    \(336\)], "Print"],

Cell[BoxData[
    \(337\)], "Print"],

Cell[BoxData[
    \(338\)], "Print"],

Cell[BoxData[
    \(339\)], "Print"],

Cell[BoxData[
    \(340\)], "Print"],

Cell[BoxData[
    \(341\)], "Print"],

Cell[BoxData[
    \(342\)], "Print"],

Cell[BoxData[
    \(343\)], "Print"],

Cell[BoxData[
    \(344\)], "Print"],

Cell[BoxData[
    \(345\)], "Print"],

Cell[BoxData[
    \(346\)], "Print"],

Cell[BoxData[
    \(347\)], "Print"],

Cell[BoxData[
    \(348\)], "Print"],

Cell[BoxData[
    \(349\)], "Print"],

Cell[BoxData[
    \(350\)], "Print"],

Cell[BoxData[
    \(351\)], "Print"],

Cell[BoxData[
    \(352\)], "Print"],

Cell[BoxData[
    \(353\)], "Print"],

Cell[BoxData[
    \(354\)], "Print"],

Cell[BoxData[
    \(355\)], "Print"],

Cell[BoxData[
    \(356\)], "Print"],

Cell[BoxData[
    \(357\)], "Print"],

Cell[BoxData[
    \(358\)], "Print"],

Cell[BoxData[
    \(359\)], "Print"],

Cell[BoxData[
    \(360\)], "Print"],

Cell[BoxData[
    \(361\)], "Print"],

Cell[BoxData[
    \(362\)], "Print"],

Cell[BoxData[
    \(363\)], "Print"],

Cell[BoxData[
    \(364\)], "Print"],

Cell[BoxData[
    \(365\)], "Print"],

Cell[BoxData[
    \(366\)], "Print"],

Cell[BoxData[
    \(367\)], "Print"],

Cell[BoxData[
    \(368\)], "Print"],

Cell[BoxData[
    \(369\)], "Print"],

Cell[BoxData[
    \(370\)], "Print"],

Cell[BoxData[
    \(371\)], "Print"],

Cell[BoxData[
    \(372\)], "Print"],

Cell[BoxData[
    \(373\)], "Print"],

Cell[BoxData[
    \(374\)], "Print"],

Cell[BoxData[
    \(375\)], "Print"],

Cell[BoxData[
    \(376\)], "Print"],

Cell[BoxData[
    \(377\)], "Print"],

Cell[BoxData[
    \(378\)], "Print"],

Cell[BoxData[
    \(379\)], "Print"],

Cell[BoxData[
    \(380\)], "Print"],

Cell[BoxData[
    \(381\)], "Print"],

Cell[BoxData[
    \(382\)], "Print"],

Cell[BoxData[
    \(383\)], "Print"],

Cell[BoxData[
    \(384\)], "Print"],

Cell[BoxData[
    \(385\)], "Print"],

Cell[BoxData[
    \(386\)], "Print"],

Cell[BoxData[
    \(387\)], "Print"],

Cell[BoxData[
    \(388\)], "Print"],

Cell[BoxData[
    \(389\)], "Print"],

Cell[BoxData[
    \(390\)], "Print"],

Cell[BoxData[
    \(391\)], "Print"],

Cell[BoxData[
    \(392\)], "Print"],

Cell[BoxData[
    \(393\)], "Print"],

Cell[BoxData[
    \(394\)], "Print"],

Cell[BoxData[
    \(395\)], "Print"],

Cell[BoxData[
    \(396\)], "Print"],

Cell[BoxData[
    \(397\)], "Print"],

Cell[BoxData[
    \(398\)], "Print"],

Cell[BoxData[
    \(399\)], "Print"],

Cell[BoxData[
    \(400\)], "Print"],

Cell[BoxData[
    \(401\)], "Print"],

Cell[BoxData[
    \(402\)], "Print"],

Cell[BoxData[
    \(403\)], "Print"],

Cell[BoxData[
    \(404\)], "Print"],

Cell[BoxData[
    \(405\)], "Print"],

Cell[BoxData[
    \(406\)], "Print"],

Cell[BoxData[
    \(407\)], "Print"],

Cell[BoxData[
    \(408\)], "Print"],

Cell[BoxData[
    \(409\)], "Print"],

Cell[BoxData[
    \(410\)], "Print"],

Cell[BoxData[
    \(411\)], "Print"],

Cell[BoxData[
    \(412\)], "Print"],

Cell[BoxData[
    \(413\)], "Print"],

Cell[BoxData[
    \(414\)], "Print"],

Cell[BoxData[
    \(415\)], "Print"],

Cell[BoxData[
    \(416\)], "Print"],

Cell[BoxData[
    \(417\)], "Print"],

Cell[BoxData[
    \(418\)], "Print"],

Cell[BoxData[
    \(419\)], "Print"],

Cell[BoxData[
    \(420\)], "Print"],

Cell[BoxData[
    \(421\)], "Print"],

Cell[BoxData[
    \(422\)], "Print"],

Cell[BoxData[
    \(423\)], "Print"],

Cell[BoxData[
    \(424\)], "Print"],

Cell[BoxData[
    \(425\)], "Print"],

Cell[BoxData[
    \(426\)], "Print"],

Cell[BoxData[
    \(427\)], "Print"],

Cell[BoxData[
    \(428\)], "Print"],

Cell[BoxData[
    \(429\)], "Print"],

Cell[BoxData[
    \(430\)], "Print"],

Cell[BoxData[
    \(431\)], "Print"],

Cell[BoxData[
    \(432\)], "Print"],

Cell[BoxData[
    \(433\)], "Print"],

Cell[BoxData[
    \(434\)], "Print"],

Cell[BoxData[
    \(435\)], "Print"],

Cell[BoxData[
    \(436\)], "Print"],

Cell[BoxData[
    \(437\)], "Print"],

Cell[BoxData[
    \(438\)], "Print"],

Cell[BoxData[
    \(439\)], "Print"],

Cell[BoxData[
    \(440\)], "Print"],

Cell[BoxData[
    \(441\)], "Print"],

Cell[BoxData[
    \(442\)], "Print"],

Cell[BoxData[
    \(443\)], "Print"],

Cell[BoxData[
    \(444\)], "Print"],

Cell[BoxData[
    \(445\)], "Print"],

Cell[BoxData[
    \(446\)], "Print"],

Cell[BoxData[
    \(447\)], "Print"],

Cell[BoxData[
    \(448\)], "Print"],

Cell[BoxData[
    \(449\)], "Print"],

Cell[BoxData[
    \(450\)], "Print"],

Cell[BoxData[
    \(451\)], "Print"],

Cell[BoxData[
    \(452\)], "Print"],

Cell[BoxData[
    \(453\)], "Print"],

Cell[BoxData[
    \(454\)], "Print"],

Cell[BoxData[
    \(455\)], "Print"],

Cell[BoxData[
    \(456\)], "Print"],

Cell[BoxData[
    \(457\)], "Print"],

Cell[BoxData[
    \(458\)], "Print"],

Cell[BoxData[
    \(459\)], "Print"],

Cell[BoxData[
    \(460\)], "Print"],

Cell[BoxData[
    \(461\)], "Print"],

Cell[BoxData[
    \(462\)], "Print"],

Cell[BoxData[
    \(463\)], "Print"],

Cell[BoxData[
    \(464\)], "Print"],

Cell[BoxData[
    \(465\)], "Print"],

Cell[BoxData[
    \(466\)], "Print"],

Cell[BoxData[
    \(467\)], "Print"],

Cell[BoxData[
    \(468\)], "Print"],

Cell[BoxData[
    \(469\)], "Print"],

Cell[BoxData[
    \(470\)], "Print"],

Cell[BoxData[
    \(471\)], "Print"],

Cell[BoxData[
    \(472\)], "Print"],

Cell[BoxData[
    \(473\)], "Print"],

Cell[BoxData[
    \(474\)], "Print"],

Cell[BoxData[
    \(475\)], "Print"],

Cell[BoxData[
    \(476\)], "Print"],

Cell[BoxData[
    \(477\)], "Print"],

Cell[BoxData[
    \(478\)], "Print"],

Cell[BoxData[
    \(479\)], "Print"],

Cell[BoxData[
    \(480\)], "Print"],

Cell[BoxData[
    \(481\)], "Print"],

Cell[BoxData[
    \(482\)], "Print"],

Cell[BoxData[
    \(483\)], "Print"],

Cell[BoxData[
    \(484\)], "Print"],

Cell[BoxData[
    \(485\)], "Print"],

Cell[BoxData[
    \(486\)], "Print"],

Cell[BoxData[
    \(487\)], "Print"],

Cell[BoxData[
    \(488\)], "Print"],

Cell[BoxData[
    \(489\)], "Print"],

Cell[BoxData[
    \(490\)], "Print"],

Cell[BoxData[
    \(491\)], "Print"],

Cell[BoxData[
    \(492\)], "Print"],

Cell[BoxData[
    \(493\)], "Print"],

Cell[BoxData[
    \(494\)], "Print"],

Cell[BoxData[
    \(495\)], "Print"],

Cell[BoxData[
    \(496\)], "Print"],

Cell[BoxData[
    \(497\)], "Print"],

Cell[BoxData[
    \(498\)], "Print"],

Cell[BoxData[
    \(499\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics3D[{{RGBColor[1,0,1],PointSize[0.05],Point[{X[1,499],Y[1,499],Z[\
1,499]}]},{RGBColor[1,0,1],PointSize[0.05],Point[{X[2,499],Y[2,499],Z[2,499]}]\
},{RGBColor[1,0,1],PointSize[0.05],Point[{X[3,499],Y[3,499],Z[3,499]}]},{\
RGBColor[1,0,1],PointSize[0.05],Point[{X[4,499],Y[4,499],Z[4,499]}]}}]]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.11288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.6813 4.37064 -0.25776 4.37064 [
[ 0 0 0 0 ]
[ 1 4.11288 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08152 .20641 m
0 3.80365 L
s
0 3.80365 m
.35929 4.11288 L
s
.35929 4.11288 m
.38202 .57058 L
s
.38202 .57058 m
.08152 .20641 L
s
.63167 0 m
.92086 .37597 L
s
.92086 .37597 m
1 3.94805 L
s
1 3.94805 m
.65678 3.62684 L
s
.65678 3.62684 m
.63167 0 L
s
.08152 .20641 m
0 3.80365 L
s
0 3.80365 m
.65678 3.62684 L
s
.65678 3.62684 m
.63167 0 L
s
.63167 0 m
.08152 .20641 L
s
.38202 .57058 m
.92086 .37597 L
s
.92086 .37597 m
1 3.94805 L
s
1 3.94805 m
.35929 4.11288 L
s
.35929 4.11288 m
.38202 .57058 L
s
0 0 m
1 0 L
1 4.11288 L
0 4.11288 L
closepath
clip
newpath
1 0 1 r
.05 w
.50402 .36367 Mdot
.50402 .81506 Mdot
.50402 1.79174 Mdot
.50402 3.7752 Mdot
0 g
.25 Mabswid
.63167 0 m
.92086 .37597 L
s
.92086 .37597 m
1 3.94805 L
s
1 3.94805 m
.65678 3.62684 L
s
.65678 3.62684 m
.63167 0 L
s
.08152 .20641 m
0 3.80365 L
s
0 3.80365 m
.65678 3.62684 L
s
.65678 3.62684 m
.63167 0 L
s
.63167 0 m
.08152 .20641 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{111.563, 458.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001_0001bQ000`40O003h00OKgoo0014Ool2000Y
Ool0049oo`800003Ool0000002Qoo`00?goo0`000goo00<007oo00009goo000lOol30006Ool00`00
Ool0000WOol003Yoo`8000Uoo`04001oogoo000VOol003Moo`<000]oo`05001oogooOol0000UOol0
03Eoo`8000ioo`03001oogoo009oo`03001oogoo029oo`00<Woo0`0047oo00<007ooOol00Woo00<0
07ooOol08Woo000_Ool3000COol00`00Oomoo`03Ool00`00Oomoo`0QOol002eoo`8001Ioo`03001o
ogoo00Aoo`03001oogoo021oo`00:Woo0`0067oo00<007ooOol01Goo00<007ooOol07goo000XOol2
000KOol00`00Oomoo`05Ool00`00Oomoo`0OOol002Eoo`<001eoo`03001oogoo00Ioo`03001oogoo
01ioo`008Woo0`0087oo00<007ooOol01goo00<007ooOol07Goo000POol2000SOol00`00Oomoo`08
Ool00`00Oomoo`0LOol001eoo`<002Eoo`03001oogoo00Qoo`03001oogoo01aoo`006Woo0`00:7oo
00<007ooOol02Goo00<007ooOol06goo000HOol2000[Ool00`00Oomoo`0:Ool00`00Oomoo`0JOol0
01Eoo`<002eoo`03001oogoo00]oo`03001oogoo01Uoo`004goo0P00<7oo00<007ooOol02goo00<0
07ooOol06Goo000@Ool3000bOol00`00Oomoo`0<Ool00`00Oomoo`0HOol000eoo`<003Eoo`03001o
ogoo00eoo`03001oogoo01Moo`002goo0P00>7oo00<007ooOol03Woo00<007ooOol05Woo0009Ool2
000jOol00`00Oomoo`0?Ool00`00Oomoo`0EOol000Uoo`8003Yoo`03001oogoo00moo`03001oogoo
01Eoo`002Goo00<007oo0000>Goo00<007ooOol047oo00<007ooOol057oo0009Ool00`00Ool0000i
Ool00`00Oomoo`0AOol00`00Oomoo`0COol000Uoo`04001oogoo000hOol00`00Oomoo`0BOol00`00
Oomoo`0BOol000Uoo`05001oogooOol0000gOol00`00Oomoo`0BOol00`00Oomoo`0BOol000Uoo`03
001oogoo009oo`03001oogoo03Aoo`03001oogoo01=oo`03001oogoo015oo`002Goo00<007ooOol0
0goo00<007ooOol0<goo00<007ooOol057oo00<007ooOol047oo0009Ool00`00Oomoo`04Ool00`00
Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`0?Ool000Uoo`03001oogoo00Aoo`03001oogoo039o
o`03001oogoo01Eoo`03001oogoo00moo`002Goo00<007ooOol01Goo00<007ooOol0<Goo00<007oo
Ool05Woo00<007ooOol03Woo0009Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool00`00Oomoo`0GOol0
0`00Oomoo`0=Ool000Uoo`03001oogoo00Moo`03001oogoo02moo`03001oogoo01Qoo`03001oogoo
00aoo`002Goo00<007ooOol027oo00<007ooOol0;Woo00<007ooOol067oo00<007ooOol037oo0009
Ool00`00Oomoo`09Ool00`00Oomoo`0]Ool00`00Oomoo`0IOol00`00Oomoo`0;Ool000Uoo`03001o
ogoo00Uoo`03001oogoo02eoo`03001oogoo01Yoo`03001oogoo00Yoo`002Goo00<007ooOol02Woo
00<007ooOol07Goo0g`O37oo00<007ooOol06goo00<007ooOol02Goo0009Ool00`00Oomoo`0;Ool0
0`00Oomoo`0KOol5O1l;Ool00`00Oomoo`0KOol00`00Oomoo`09Ool000Uoo`03001oogoo00aoo`03
001oogoo01Yoo`El7`]oo`03001oogoo01aoo`03001oogoo00Qoo`002Goo00<007ooOol03Goo00<0
07ooOol06Goo1G`O2goo00<007ooOol077oo0P002Goo0009Ool00`00Oomoo`0>Ool00`00Oomoo`0I
Ool3O1l<Ool00`00Oomoo`0IOol300000goo001oo`08Ool000Uoo`03001oogoo00ioo`03001oogoo
02Qoo`03001oogoo01Ioo`<000Aoo`03001oogoo00Moo`002Goo00<007ooOol03goo00<007ooOol0
9goo00<007ooOol057oo0P001goo00<007ooOol01goo0008Ool00`00Oomoo`0AOol00`00Oomoo`0V
Ool00`00Oomoo`0AOol30009Ool00`00Oomoo`07Ool000Qoo`03001oogoo019oo`03001oogoo02Eo
o`03001oogoo00ioo`<000aoo`03001oogoo00Moo`0027oo00<007ooOol04goo00<007ooOol097oo
00<007ooOol02goo0`003goo00<007ooOol01goo0008Ool00`00Oomoo`0COol00`00Oomoo`0TOol0
0`00Oomoo`08Ool3000BOol00`00Oomoo`07Ool000Qoo`03001oogoo01Aoo`03001oogoo02=oo`03
001oogoo00Ioo`8001Eoo`03001oogoo00Moo`0027oo00<007ooOol05Goo00<007ooOol08Woo00<0
07ooOol00goo0`005goo00<007ooOol01goo0008Ool00`00Oomoo`0FOol00`00Oomoo`0QOol00`00
Oomoo`03000JOol00`00Oomoo`07Ool000Qoo`03001oogoo01Moo`03001oogoo021oo`<001eoo`03
001oogoo00Moo`0027oo00<007ooOol067oo00<007ooOol077oo10007goo00<007ooOol01goo0008
Ool00`00Oomoo`0HOol00`00Oomoo`0JOol20003Ool00`00Oomoo`0MOol00`00Oomoo`07Ool000Qo
o`03001oogoo01Uoo`03001oogoo01Ioo`<000Eoo`03001oogoo01eoo`03001oogoo00Moo`0027oo
00<007ooOol06Woo00<007ooOol04Woo0`0027oo00<007ooOol07Goo00<007ooOol01goo0008Ool0
0`00Oomoo`0KOol00`00Oomoo`0>Ool3000;Ool00`00Oomoo`0MOol00`00Oomoo`07Ool000Qoo`03
001oogoo01aoo`03001oogoo00Yoo`<000ioo`03001oogoo01eoo`03001oogoo00Moo`0027oo00<0
07ooOol07Goo00<007ooOol01goo0P004Goo00<007ooOol07Goo00<007ooOol01goo0008Ool00`00
Oomoo`0MOol00`00Oomoo`04Ool3000COol00`00Oomoo`0MOol00`00Oomoo`07Ool000Qoo`03001o
ogoo01ioo`03001oogoo00<001Ioo`03001oogoo01eoo`03001oogoo00Moo`0027oo00<007ooOol0
7goo0P006Goo00<007ooOol07Goo00<007ooOol01goo0008Ool00`00Oomoo`0OOol00`00Oomoo`0H
Ool00`00Oomoo`0NOol00`00Oomoo`06Ool000Qoo`03001oogoo01moo`03001oogoo01Qoo`03001o
ogoo01ioo`03001oogoo00Ioo`0027oo00<007ooOol07goo00<007ooOol067oo00<007ooOol07Woo
00<007ooOol01Woo0008Ool00`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomo
o`06Ool000Qoo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`00
27oo00<007ooOol07goo00<007ooOol06Goo00<007ooOol07Goo00<007ooOol01Woo0008Ool00`00
Oomoo`0OOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06Ool000Qoo`03001oogoo01mo
o`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`0027oo00<007ooOol07goo00<007oo
Ool06Goo00<007ooOol07Goo00<007ooOol01Woo0008Ool00`00Oomoo`0OOol00`00Oomoo`0IOol0
0`00Oomoo`0MOol00`00Oomoo`06Ool000Qoo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo
01eoo`03001oogoo00Ioo`0027oo00<007ooOol07goo00<007ooOol06Goo00<007ooOol07Goo00<0
07ooOol01Woo0008Ool00`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06
Ool000Qoo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`0027oo
00<007ooOol07goo00<007ooOol06Goo00<007ooOol07Goo00<007ooOol01Woo0008Ool00`00Oomo
o`0OOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06Ool000Qoo`03001oogoo01moo`03
001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`0027oo00<007ooOol07goo00<007ooOol0
6Goo00<007ooOol07Goo00<007ooOol01Woo0008Ool00`00Oomoo`0OOol00`00Oomoo`0IOol00`00
Oomoo`0MOol00`00Oomoo`06Ool000Qoo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo01eo
o`03001oogoo00Ioo`0027oo00<007ooOol07goo00<007ooOol06Goo00<007ooOol07Goo00<007oo
Ool01Woo0008Ool00`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06Ool0
00Qoo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`0027oo00<0
07ooOol07goo00<007ooOol06Goo00<007ooOol07Goo00<007ooOol01Woo0008Ool00`00Oomoo`0O
Ool00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06Ool000Qoo`03001oogoo01moo`03001o
ogoo00Uoo`=l7`eoo`03001oogoo01eoo`03001oogoo00Ioo`001goo00<007ooOol087oo00<007oo
Ool027oo1G`O37oo00<007ooOol07Goo00<007ooOol01Woo0007Ool00`00Oomoo`0POol00`00Oomo
o`08Ool5O1l<Ool00`00Oomoo`0MOol00`00Oomoo`06Ool000Moo`03001oogoo021oo`03001oogoo
00Qoo`El7`aoo`03001oogoo01eoo`03001oogoo00Ioo`001goo00<007ooOol087oo00<007ooOol0
2Goo0g`O3Goo00<007ooOol07Goo00<007ooOol01Woo0007Ool00`00Oomoo`0POol00`00Oomoo`0I
Ool00`00Oomoo`0MOol00`00Oomoo`06Ool000Moo`03001oogoo021oo`03001oogoo01Uoo`03001o
ogoo01eoo`03001oogoo00Ioo`001goo00<007ooOol087oo00<007ooOol06Goo00<007ooOol07Goo
00<007ooOol01Woo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomo
o`06Ool000Moo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`00
1goo00<007ooOol087oo00<007ooOol06Goo00<007ooOol07Goo00<007ooOol01Woo0007Ool00`00
Oomoo`0POol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06Ool000Moo`03001oogoo021o
o`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`001goo00<007ooOol087oo00<007oo
Ool06Goo00<007ooOol07Goo00<007ooOol01Woo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol0
0`00Oomoo`0MOol00`00Oomoo`06Ool000Moo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo
01eoo`03001oogoo00Ioo`001goo00<007ooOol087oo00<007ooOol06Goo00<007ooOol07Goo00<0
07ooOol01Woo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`06
Ool000Moo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo00Ioo`001goo
00<007ooOol087oo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol01Goo0007Ool00`00Oomo
o`0POol00`00Oomoo`0IOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Moo`03001oogoo021oo`03
001oogoo01Uoo`03001oogoo01ioo`03001oogoo00Eoo`001goo00<007ooOol087oo00<007ooOol0
6Goo00<007ooOol07Woo00<007ooOol01Goo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol00`00
Oomoo`0NOol00`00Oomoo`05Ool000Moo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo01io
o`03001oogoo00Eoo`001goo00<007ooOol087oo00<007ooOol06Goo00<007ooOol07Woo00<007oo
Ool01Goo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol00`00Oomoo`0NOol00`00Oomoo`05Ool0
00Moo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo01ioo`03001oogoo00Eoo`001goo00<0
07ooOol087oo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol01Goo0007Ool00`00Oomoo`0P
Ool00`00Oomoo`0IOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Moo`03001oogoo021oo`03001o
ogoo01Uoo`03001oogoo01ioo`03001oogoo00Eoo`001goo00<007ooOol087oo00<007ooOol06Goo
00<007ooOol07Woo00<007ooOol01Goo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol00`00Oomo
o`0NOol00`00Oomoo`05Ool000Moo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo01ioo`03
001oogoo00Eoo`001goo00<007ooOol087oo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol0
1Goo0007Ool00`00Oomoo`0POol00`00Oomoo`0IOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Mo
o`03001oogoo021oo`03001oogoo01Uoo`03001oogoo01ioo`03001oogoo00Eoo`001goo00<007oo
Ool087oo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol01Goo0007Ool00`00Oomoo`0POol0
0`00Oomoo`0IOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Moo`03001oogoo021oo`03001oogoo
01Uoo`03001oogoo01ioo`03001oogoo00Eoo`001goo00<007ooOol07goo00<007ooOol06Woo00<0
07ooOol07Woo00<007ooOol01Goo0007Ool00`00Oomoo`0OOol00`00Oomoo`0JOol00`00Oomoo`0N
Ool00`00Oomoo`05Ool000Moo`03001oogoo01moo`03001oogoo01Yoo`03001oogoo01ioo`03001o
ogoo00Eoo`001goo00<007ooOol07goo00<007ooOol06Woo00<007ooOol07Woo00<007ooOol01Goo
0007Ool00`00Oomoo`0OOol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Ioo`03
001oogoo021oo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo00Eoo`001Woo00<007ooOol0
87oo00<007ooOol06Woo00<007ooOol07Woo00<007ooOol01Goo0006Ool00`00Oomoo`0POol00`00
Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Ioo`03001oogoo021oo`03001oogoo01Yo
o`03001oogoo01ioo`03001oogoo00Eoo`001Woo00<007ooOol087oo00<007ooOol06Woo00<007oo
Ool07Woo00<007ooOol01Goo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0NOol0
0`00Oomoo`05Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo
00Eoo`001Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol07Woo00<007ooOol01Goo0006
Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Ioo`03001o
ogoo021oo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo00Eoo`001Woo00<007ooOol087oo
00<007ooOol06Woo00<007ooOol07Woo00<007ooOol01Goo0006Ool00`00Oomoo`0POol00`00Oomo
o`0JOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03
001oogoo01ioo`03001oogoo00Eoo`001Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol0
7Woo00<007ooOol01Goo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00
Oomoo`05Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo00Eo
o`001Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol07Woo00<007ooOol01Goo0006Ool0
0`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Ioo`03001oogoo
021oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Woo00<007ooOol087oo00<0
07ooOol06Woo00<007ooOol07goo00<007ooOol017oo0006Ool00`00Oomoo`0POol00`00Oomoo`0J
Ool00`00Oomoo`0OOol00`00Oomoo`04Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001o
ogoo01moo`03001oogoo00Aoo`001Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol07goo
00<007ooOol017oo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomo
o`04Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`00
1Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol07goo00<007ooOol017oo0006Ool00`00
Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool000Ioo`03001oogoo021o
o`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Woo00<007ooOol087oo00<007oo
Ool06Woo00<007ooOol07goo00<007ooOol017oo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol0
0`00Oomoo`0OOol00`00Oomoo`04Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo
01moo`03001oogoo00Aoo`001Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol07goo00<0
07ooOol017oo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04
Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Woo
00<007ooOol087oo00<007ooOol06Woo00<007ooOol07goo00<007ooOol017oo0006Ool00`00Oomo
o`0POol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool000Ioo`03001oogoo021oo`03
001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Woo00<007ooOol087oo00<007ooOol0
6Woo00<007ooOol07goo00<007ooOol017oo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00
Oomoo`0OOol00`00Oomoo`04Ool000Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo01mo
o`03001oogoo00Aoo`001Woo00<007ooOol087oo00<007ooOol06Woo00<007ooOol07goo00<007oo
Ool017oo0006Ool00`00Oomoo`0POol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool0
00Ioo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Woo00<0
07ooOol087oo00<007ooOol06Woo00<007ooOol07goo00<007ooOol017oo0005Ool00`00Oomoo`0Q
Ool00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool000Eoo`03001oogoo025oo`03001o
ogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Goo00<007ooOol08Goo00<007ooOol06Woo
00<007ooOol07goo00<007ooOol017oo0005Ool00`00Oomoo`0QOol00`00Oomoo`0JOol00`00Oomo
o`0OOol00`00Oomoo`04Ool000Eoo`03001oogoo025oo`03001oogoo01Yoo`03001oogoo01moo`03
001oogoo00Aoo`001Goo00<007ooOol08Goo00<007ooOol06Woo00<007ooOol07goo00<007ooOol0
17oo0005Ool00`00Oomoo`0QOol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool000Eo
o`03001oogoo025oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Goo00<007oo
Ool08Goo00<007ooOol06Woo00<007ooOol07goo00<007ooOol017oo0005Ool00`00Oomoo`0QOol0
0`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool000Eoo`03001oogoo025oo`03001oogoo
01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Goo00<007ooOol08Goo00<007ooOol06Woo00<0
07ooOol07goo00<007ooOol017oo0005Ool00`00Oomoo`0QOol00`00Oomoo`0JOol00`00Oomoo`0O
Ool00`00Oomoo`04Ool000Eoo`03001oogoo025oo`03001oogoo01Yoo`03001oogoo01moo`03001o
ogoo00Aoo`001Goo00<007ooOol08Goo00<007ooOol06Woo00<007ooOol07goo00<007ooOol017oo
0005Ool00`00Oomoo`0QOol00`00Oomoo`0JOol00`00Oomoo`0OOol00`00Oomoo`04Ool000Eoo`03
001oogoo025oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00Aoo`001Goo00<007ooOol0
8Goo00<007ooOol06Woo00<007ooOol07goo00<007ooOol017oo0005Ool00`00Oomoo`0QOol00`00
Oomoo`0JOol00`00Oomoo`0POol00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001oogoo00Yo
o`=l7`eoo`03001oogoo021oo`03001oogoo00=oo`001Goo00<007ooOol08Goo00<007ooOol02Goo
1G`O37oo00<007ooOol087oo00<007ooOol00goo0005Ool00`00Oomoo`0QOol00`00Oomoo`09Ool5
O1l<Ool00`00Oomoo`0POol00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001oogoo00Uoo`El
7`aoo`03001oogoo021oo`03001oogoo00=oo`001Goo00<007ooOol08Goo00<007ooOol02Woo0g`O
3Woo00<007ooOol07goo00<007ooOol00goo0005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol00`00
Oomoo`0OOol00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01mo
o`03001oogoo00=oo`001Goo00<007ooOol08Goo00<007ooOol06goo00<007ooOol07goo00<007oo
Ool00goo0005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool0
00Eoo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo00=oo`001Goo00<0
07ooOol08Goo00<007ooOol06goo00<007ooOol07goo00<007ooOol00goo0005Ool00`00Oomoo`0Q
Ool00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001o
ogoo01]oo`03001oogoo01moo`03001oogoo00=oo`001Goo00<007ooOol08Goo00<007ooOol06goo
00<007ooOol07goo00<007ooOol00goo0005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomo
o`0OOol00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01moo`03
001oogoo00=oo`001Goo00<007ooOol08Goo00<007ooOol06goo00<007ooOol07goo00<007ooOol0
0goo0005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Eo
o`03001oogoo025oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo00=oo`001Goo00<007oo
Ool08Goo00<007ooOol06goo00<007ooOol07goo00<007ooOol00goo0005Ool00`00Oomoo`0QOol0
0`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001oogoo
01]oo`03001oogoo01moo`03001oogoo00=oo`001Goo00<007ooOol08Goo00<007ooOol06goo00<0
07ooOol07goo00<007ooOol00goo0005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol00`00Oomoo`0O
Ool00`00Oomoo`03Ool000Eoo`03001oogoo025oo`03001oogoo01]oo`03001oogoo01moo`03001o
ogoo00=oo`0017oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol07goo00<007ooOol00goo
0004Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Aoo`03
001oogoo029oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo00=oo`0017oo00<007ooOol0
8Woo00<007ooOol06goo00<007ooOol07goo00<007ooOol00goo0004Ool00`00Oomoo`0ROol00`00
Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Aoo`03001oogoo029oo`03001oogoo01]o
o`03001oogoo01moo`03001oogoo00=oo`0017oo00<007ooOol08Woo00<007ooOol06goo00<007oo
Ool07goo00<007ooOol00goo0004Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0OOol0
0`00Oomoo`03Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo
00=oo`0017oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol07goo00<007ooOol00goo0004
Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Aoo`03001o
ogoo029oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo00=oo`0017oo00<007ooOol08Woo
00<007ooOol06goo00<007ooOol07goo00<007ooOol00goo0004Ool00`00Oomoo`0ROol00`00Oomo
o`0KOol00`00Oomoo`0OOol00`00Oomoo`03Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03
001oogoo01moo`03001oogoo00=oo`0017oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol0
7goo00<007ooOol00goo0004Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0OOol00`00
Oomoo`03Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo00=o
o`0017oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol087oo00<007ooOol00Woo0004Ool0
0`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`02Ool000Aoo`03001oogoo
029oo`03001oogoo01]oo`03001oogoo021oo`03001oogoo009oo`0017oo00<007ooOol08Woo00<0
07ooOol06goo00<007ooOol087oo00<007ooOol00Woo0004Ool00`00Oomoo`0ROol00`00Oomoo`0K
Ool00`00Oomoo`0POol00`00Oomoo`02Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03001o
ogoo021oo`03001oogoo009oo`0017oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol087oo
00<007ooOol00Woo0004Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomo
o`02Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo021oo`03001oogoo009oo`00
17oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol087oo00<007ooOol00Woo0004Ool00`00
Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`02Ool000Aoo`03001oogoo029o
o`03001oogoo01]oo`03001oogoo021oo`03001oogoo009oo`0017oo00<007ooOol08Woo00<007oo
Ool06goo00<007ooOol087oo00<007ooOol00Woo0004Ool00`00Oomoo`0ROol00`00Oomoo`0KOol0
0`00Oomoo`0POol00`00Oomoo`02Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo
021oo`03001oogoo009oo`0017oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol087oo00<0
07ooOol00Woo0004Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`02
Ool000Aoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo021oo`03001oogoo009oo`0017oo
00<007ooOol08Woo00<007ooOol06goo00<007ooOol087oo00<007ooOol00Woo0004Ool00`00Oomo
o`0QOol00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`02Ool000Aoo`03001oogoo025oo`03
001oogoo01aoo`03001oogoo021oo`03001oogoo009oo`0017oo00<007ooOol08Goo00<007ooOol0
77oo00<007ooOol087oo00<007ooOol00Woo0004Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00
Oomoo`0POol00`00Oomoo`02Ool000Aoo`03001oogoo025oo`03001oogoo01aoo`03001oogoo021o
o`03001oogoo009oo`0017oo00<007ooOol08Goo00<007ooOol077oo00<007ooOol087oo00<007oo
Ool00Woo0004Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`02Ool0
00Aoo`03001oogoo025oo`03001oogoo01aoo`03001oogoo021oo`03001oogoo009oo`000goo00<0
07ooOol08Woo00<007ooOol077oo00<007ooOol087oo00<007ooOol00Woo0003Ool00`00Oomoo`0R
Ool00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`02Ool000=oo`03001oogoo029oo`03001o
ogoo01aoo`03001oogoo021oo`03001oogoo009oo`000goo00<007ooOol08Woo00<007ooOol077oo
00<007ooOol087oo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomo
o`0POol00`00Oomoo`02Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03001oogoo021oo`03
001oogoo009oo`000goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol087oo00<007ooOol0
0Woo0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`02Ool000=o
o`03001oogoo029oo`03001oogoo01aoo`03001oogoo021oo`03001oogoo009oo`000goo00<007oo
Ool08Woo00<007ooOol077oo00<007ooOol087oo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol0
0`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`02Ool000=oo`03001oogoo029oo`03001oogoo
01aoo`03001oogoo021oo`03001oogoo009oo`000goo00<007ooOol08Woo00<007ooOol077oo00<0
07ooOol087oo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0P
Ool00`00Oomoo`02Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03001oogoo021oo`03001o
ogoo009oo`000goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol087oo00<007ooOol00Woo
0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`02Ool000=oo`03
001oogoo029oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000goo00<007ooOol0
8Woo00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0003Ool00`00Oomoo`0ROol00`00
Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool000=oo`03001oogoo029oo`03001oogoo01ao
o`03001oogoo025oo`03001oogoo005oo`000goo00<007ooOol08Woo00<007ooOol077oo00<007oo
Ool08Goo00<007ooOol00Goo0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0QOol0
0`00Oomoo`01Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo
005oo`000goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0003
Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool000=oo`03001o
ogoo029oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000goo00<007ooOol08Woo
00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0003Ool00`00Oomoo`0ROol00`00Oomo
o`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03
001oogoo025oo`03001oogoo005oo`000goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol0
8Goo00<007ooOol00Goo0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00
Oomoo`01Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005o
o`000goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0003Ool0
0`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool000=oo`03001oogoo
029oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000goo00<007ooOol08Woo00<0
07ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0003Ool00`00Oomoo`0ROol00`00Oomoo`0L
Ool00`00Oomoo`0QOol00`00Oomoo`01Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03001o
ogoo025oo`03001oogoo005oo`000goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol08Goo
00<007ooOol00Goo0003Ool00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomo
o`01Ool000=oo`03001oogoo029oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`00
0goo00<007ooOol08Woo00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0003Ool00`00
Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool0009oo`03001oogoo02=o
o`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000Woo00<007ooOol08goo00<007oo
Ool077oo00<007ooOol08Goo00<007ooOol00Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0LOol0
0`00Oomoo`0QOol00`00Oomoo`01Ool0009oo`03001oogoo02=oo`03001oogoo01aoo`03001oogoo
025oo`03001oogoo005oo`000Woo00<007ooOol08goo00<007ooOol077oo00<007ooOol08Goo00<0
07ooOol00Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01
Ool0009oo`03001oogoo02=oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000Woo
00<007ooOol08goo00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0002Ool00`00Oomo
o`0SOol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool0009oo`03001oogoo02=oo`03
001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000Woo00<007ooOol08goo00<007ooOol0
77oo00<007ooOol08Goo00<007ooOol00Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0LOol00`00
Oomoo`0QOol00`00Oomoo`01Ool0009oo`03001oogoo02=oo`03001oogoo01aoo`03001oogoo025o
o`03001oogoo005oo`000Woo00<007ooOol08goo00<007ooOol077oo00<007ooOol08Goo00<007oo
Ool00Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0LOol00`00Oomoo`0QOol00`00Oomoo`01Ool0
009oo`03001oogoo02=oo`03001oogoo01aoo`03001oogoo025oo`03001oogoo005oo`000Woo00<0
07ooOol08goo00<007ooOol077oo00<007ooOol08Goo00<007ooOol00Goo0002Ool00`00Oomoo`0S
Ool00`00Oomoo`0LOol00`00Oomoo`0ROol10001Ool1Ool0009oo`03001oogoo02=oo`03001oogoo
01aoo`03001oogoo029oo`40005oo`5oo`000Woo00<007ooOol08goo00<007ooOol077oo00<007oo
Ool08Woo0@000Goo0Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0LOol00`00Oomoo`0ROol10001
Ool1Ool0009oo`03001oogoo02=oo`03001oogoo01aoo`03001oogoo029oo`40005oo`5oo`000Woo
00<007ooOol08goo00<007ooOol077oo00<007ooOol08Woo0@000Goo0Goo0002Ool00`00Oomoo`0S
Ool00`00Oomoo`0LOol00`00Oomoo`0ROol10001Ool1Ool0009oo`03001oogoo02=oo`03001oogoo
01eoo`03001oogoo025oo`40005oo`5oo`000Woo00<007ooOol08goo00<007ooOol07Goo00<007oo
Ool08Goo0@000Goo0Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001
Ool1Ool0009oo`03001oogoo02=oo`03001oogoo01eoo`03001oogoo025oo`40005oo`5oo`000Woo
00<007ooOol08goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo0002Ool00`00Oomoo`0S
Ool00`00Oomoo`0MOol00`00Oomoo`0QOol10001Ool1Ool0009oo`03001oogoo02=oo`03001oogoo
01eoo`03001oogoo025oo`40005oo`5oo`000Woo00<007ooOol08goo00<007ooOol07Goo00<007oo
Ool08Goo0@000Goo0Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001
Ool1Ool0009oo`03001oogoo02=oo`03001oogoo01eoo`03001oogoo025oo`40005oo`5oo`000Woo
00<007ooOol08goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo0002Ool00`00Oomoo`0S
Ool00`00Oomoo`0MOol00`00Oomoo`0QOol10001Ool1Ool0009oo`03001oogoo02=oo`03001oogoo
01eoo`03001oogoo025oo`40005oo`5oo`000Woo00<007ooOol08goo00<007ooOol07Goo00<007oo
Ool08Goo0@000Goo0Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001
Ool1Ool0009oo`03001oogoo02=oo`03001oogoo01eoo`03001oogoo025oo`40005oo`5oo`000Woo
00<007ooOol08goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo0002Ool00`00Oomoo`0S
Ool00`00Oomoo`0MOol00`00Oomoo`0QOol10001Ool1Ool0009oo`03001oogoo02=oo`03001oogoo
01eoo`03001oogoo025oo`40005oo`5oo`000Woo00<007ooOol08goo00<007ooOol07Goo00<007oo
Ool08Goo0@000Goo0Goo00000goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001Ool1
Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo025oo`40005oo`5oo`0000=oo`00Ool0
9Goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo00000goo001oo`0UOol00`00Oomoo`0M
Ool00`00Oomoo`0QOol10001Ool1Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo025o
o`40005oo`5oo`0000=oo`00Ool09Goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo0000
0goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001Ool1Ool00003Ool007oo02Eoo`03
001oogoo01eoo`03001oogoo025oo`40005oo`5oo`0000=oo`00Ool09Goo00<007ooOol07Goo00<0
07ooOol08Goo0@000Goo0Goo00000goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001
Ool1Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo025oo`40005oo`5oo`0000=oo`00
Ool09Goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo00000goo001oo`0UOol00`00Oomo
o`0MOol00`00Oomoo`0QOol10001Ool1Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo
025oo`40005oo`5oo`0000=oo`00Ool09Goo00<007ooOol07Goo00<007ooOol08Goo0@000Goo0Goo
00000goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0QOol10001Ool1Ool00003Ool007oo02Eo
o`03001oogoo01eoo`03001oogoo025oo`40005oo`5oo`0000=oo`00Ool09Goo00<007ooOol07Goo
00<007ooOol08Woo0@000Goo00000goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0ROol10001
Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo029oo`40005oo`0000=oo`00Ool09Goo
00<007ooOol07Goo00<007ooOol08Woo0@000Goo00000goo001oo`0UOol00`00Oomoo`0MOol00`00
Oomoo`0ROol10001Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo029oo`40005oo`00
00=oo`00Ool09Goo00<007ooOol07Goo00<007ooOol08Woo0@000Goo00000goo001oo`0UOol00`00
Oomoo`0MOol00`00Oomoo`0ROol10001Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo
029oo`40005oo`0000=oo`00Ool09Goo00<007ooOol07Goo00<007ooOol08Woo0@000Goo00000goo
001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0ROol10001Ool00003Ool007oo02Eoo`03001oogoo
01eoo`03001oogoo029oo`40005oo`0000=oo`00Ool09Goo00<007ooOol07Goo00<007ooOol08Woo
0@000Goo00000goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0ROol10001Ool00003Ool007oo
02Eoo`03001oogoo01eoo`03001oogoo029oo`40005oo`0000=oo`00Ool09Goo00<007ooOol07Goo
00<007ooOol08Woo0@000Goo00000goo001oo`0UOol00`00Oomoo`0MOol00`00Oomoo`0ROol10001
Ool00003Ool007oo02Eoo`03001oogoo01eoo`03001oogoo029oo`40005oo`0000=oo`00Ool097oo
00<007ooOol07Woo00<007ooOol08Woo0@000Goo00000goo001oo`0TOol00`00Oomoo`0NOol00`00
Oomoo`0ROol10001Ool00003Ool007oo02Aoo`03001oogoo01ioo`03001oogoo029oo`40005oo`00
00=oo`00Ool097oo00<007ooOol07Woo00<007ooOol08Woo0@000Goo00000goo001oo`0TOol00`00
Oomoo`0NOol00`00Oomoo`0ROol10001Ool00003Ool007oo02Aoo`03001oogoo01ioo`03001oogoo
029oo`40005oo`0000=oo`00Ool097oo00<007ooOol07Woo00<007ooOol08Woo0@000Goo00000goo
001oo`0TOol00`00Oomoo`0NOol00`00Oomoo`0ROol10001Ool00003Ool007oo02Aoo`03001oogoo
01ioo`03001oogoo029oo`40005oo`0000<007ooOol097oo00<007ooOol07Woo00<007ooOol08Woo
0@000Goo00000`00Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`0ROol10001Ool00003001oogoo
02Aoo`03001oogoo01eoo`8002Aoo`40005oo`0000<007ooOol097oo00<007ooOol06Goo10000Woo
00<007ooOol08Goo0@000Goo00000`00Oomoo`0TOol00`00Oomoo`0FOol30007Ool00`00Oomoo`0P
Ool10001Ool00003001oogoo02Aoo`03001oogoo019oo`@000]oo`03001oogoo01moo`40005oo`00
00<007ooOol097oo00<007ooOol03Woo100047oo00<007ooOol07Woo0@000Goo00000`00Oomoo`0T
Ool00`00Oomoo`0;Ool3000EOol00`00Oomoo`0MOol10001Ool00003001oogoo02Aoo`03001oogoo
00Moo`@001Uoo`03001oogoo01aoo`40005oo`0000<007ooOol097oo00<007ooOol017oo0`007Woo
00<007ooOol06goo0@000Goo00000`00Oomoo`0TOol00`00Oomoo`04000ROol00`00Oomoo`0JOol1
0001Ool00003001oogoo02=oo`@002Moo`8001Yoo`40005oo`0000<007ooOol087oo0`0000=oo`00
Ool0:Woo00<007ooOol05goo0@000Goo00000`00Oomoo`0LOol40004Ool00`00Oomoo`0ZOol00`00
Oomoo`0FOol10001Ool00003001oogoo01Uoo`<000Qoo`03001oogoo02]oo`03001oogoo01Eoo`40
005oo`0000<007ooOol05Goo10002goo00<007ooOol0;7oo00<007ooOol057oo0@000Goo00000`00
Oomoo`0AOol4000?Ool00`00Oomoo`0]Ool00`00Oomoo`0COol10001Ool00003001oogoo00ioo`<0
01=oo`03001oogoo00aoo`=l7amoo`03001oogoo01=oo`40000000<007ooOol02Woo10005Woo00<0
07ooOol02goo1G`O7goo00<007ooOol04Woo0@0000000`00Oomoo`07Ool3000JOol00`00Oomoo`0;
Ool5O1lPOol00`00Oomoo`0AOol100000003001oogoo00=oo`@001eoo`03001oogoo00]oo`El7b5o
o`03001oogoo011oo`40000000<007oo00000`008Goo00<007ooOol037oo0g`O8goo00<007ooOol0
3goo0@000002000UOol00`00Oomoo`0cOol00`00Oomoo`0>Ool100000003Ool007oo02Aoo`03001o
ogoo03Aoo`03001oogoo00eoo`4000000Woo00<007ooOol08Woo00<007ooOol0=Goo00<007ooOol0
37oo0@000003Ool2000ROol00`00Oomoo`0fOol00`00Oomoo`0;Ool1000000Eoo`03001oogoo01mo
o`03001oogoo03Moo`03001oogoo00Yoo`4000001Woo00<007ooOol07Woo00<007ooOol0>7oo00<0
07ooOol02Goo0@000007Ool00`00Oomoo`0MOol00`00Oomoo`0iOol00`00Oomoo`08Ool1000000Qo
o`03001oogoo01aoo`03001oogoo03Yoo`8000Qoo`4000002Goo00<007ooOol06goo00<007ooOol0
?7oo00<007ooOol01Goo0@00000:Ool00`00Oomoo`0JOol00`00Oomoo`0mOol00`00Oomoo`04Ool1
000000]oo`8001Yoo`03001oogoo03ioo`03001oogoo00=oo`4000003Goo00<007ooOol05goo00<0
07ooOol0?goo00<007ooOol00Woo0@00000>Ool00`00Oomoo`0FOol00`00Oomoo`10Ool01000Oomo
ogoo0@00000?Ool00`00Oomoo`0EOol00`00Oomoo`11Ool00`00Oomoo`010000011oo`03001oogoo
01Aoo`03001oogoo049oo`40005oo`4000004Goo00<007ooOol04goo00<007ooOol0@goo0P00000B
Ool00`00Oomoo`0BOol00`00Oomoo`13Ool2000001=oo`80019oo`03001oogoo03moo`@0009oo`00
5Goo00<007ooOol03goo00<007ooOol0>goo10001Woo000FOol00`00Oomoo`0>Ool00`00Oomoo`0g
Ool4000:Ool001Moo`03001oogoo00eoo`03001oogoo03=oo`@000ioo`0067oo00<007ooOol037oo
00<007ooOol0;goo10004Woo000IOol00`00Oomoo`0;Ool00`00Oomoo`0[Ool4000FOol001Yoo`03
001oogoo00Yoo`03001oogoo02Moo`@001Yoo`006goo0P002Woo00<007ooOol08goo10007Woo000M
Ool00`00Oomoo`07Ool00`00Oomoo`0OOol4000ROol001ioo`03001oogoo00Ioo`03001oogoo01]o
o`@002Ioo`007goo00<007ooOol01Goo00<007ooOol05goo1000:Woo000POol00`00Oomoo`04Ool0
0`00Oomoo`0COol4000^Ool0025oo`03001oogoo00=oo`03001oogoo00moo`@0039oo`008Woo00<0
07ooOol00Woo00<007ooOol02goo1000=Woo000SOol20002Ool00`00Oomoo`07Ool4000jOol002Eo
o`03001oo`0000Eoo`@003ioo`009Woo0P0000=oo`0000000P00@Woo000WOol20016Ool006moo`00
\
\>"],
  ImageRangeCache->{{{0, 110.563}, {457.813, 0}} -> {0.384679, 0.0557814, \
0.00206943, 0.00206943}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Four spheres sedimenting in a Newtonian fluid. Depending on their initial \
arrangement, the spheres' trajectories can be very peculiar and show a \
periodic structure.\
\>", "Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["\<\
FU={0,0,-30,0,0,-30,0,0,-30,0,0,-30,0,0,0,0,0,0,0,0,0,0,0,0};\
\>", "Input"],

Cell["\<\
X[1]=1.1;Y[1]=0;Z[1]=1.5;X[2]=-1.1;Y[2]=0;Z[2]=1.5;X[3]=-1.1;Y[3]=0;Z[3]=-0.7;\
X[4]=1.1;Y[4]=0;Z[4]=-0.7;\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics3D[{{RGBColor[1,0,1],PointSize[0.05],Point[{X[1],Y[1],Z[1]}]},{\
RGBColor[1,0,1],PointSize[0.05],Point[{X[2],Y[2],Z[2]}]},{RGBColor[1,0,1],\
PointSize[0.05],Point[{X[3],Y[3],Z[3]}]},{RGBColor[1,0,1],PointSize[0.05],\
Point[{X[4],Y[4],Z[4]}]}}]]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08799 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.058102 1.1584 4.13623e-017 1.1584 [
[ 0 0 0 0 ]
[ 1 1.08799 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08678 .24904 m
0 .82368 L
s
0 .82368 m
.37559 1.08799 L
s
.37559 1.08799 m
.3961 .56445 L
s
.3961 .56445 m
.08678 .24904 L
s
.68674 0 m
.9257 .38937 L
s
.9257 .38937 m
1 .94326 L
s
1 .94326 m
.72478 .60323 L
s
.72478 .60323 m
.68674 0 L
s
.08678 .24904 m
0 .82368 L
s
0 .82368 m
.72478 .60323 L
s
.72478 .60323 m
.68674 0 L
s
.68674 0 m
.08678 .24904 L
s
.3961 .56445 m
.9257 .38937 L
s
.9257 .38937 m
1 .94326 L
s
1 .94326 m
.37559 1.08799 L
s
.37559 1.08799 m
.3961 .56445 L
s
0 0 m
1 0 L
1 1.08799 L
0 1.08799 L
closepath
clip
newpath
1 0 1 r
.05 w
.26549 .42655 Mdot
.80356 .22964 Mdot
.22169 .94972 Mdot
.85802 .78042 Mdot
0 g
.25 Mabswid
.68674 0 m
.9257 .38937 L
s
.9257 .38937 m
1 .94326 L
s
1 .94326 m
.72478 .60323 L
s
.72478 .60323 m
.68674 0 L
s
.08678 .24904 m
0 .82368 L
s
0 .82368 m
.72478 .60323 L
s
.72478 .60323 m
.68674 0 L
s
.68674 0 m
.08678 .24904 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 313.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001>A000`40O003h00Oa7oo0P00FWoo0032
Ool200000goo0000001IOol00;moo`<000=oo`8005Uoo`00_Goo0P001Woo00<007oo0000F7oo002k
Ool20008Ool00`00Ool0001HOol00;Qoo`<000Yoo`04001oogoo001GOol00;Ioo`8000eoo`05001o
ogooOol0001FOol00;=oo`<000moo`05001oogooOol0001FOol00;5oo`8001=oo`05001oogooOol0
001EOol00:moo`8001Eoo`05001oogooOol0001EOol00:aoo`<001Moo`03001oogoo009oo`03001o
ogoo059oo`00ZWoo0P006Woo00<007ooOol00goo00<007ooOol0DGoo002WOol3000LOol00`00Oomo
o`03Ool00`00Oomoo`1AOol00:Eoo`8001moo`03001oogoo00Aoo`03001oogoo051oo`00Xgoo0P00
8Goo00<007ooOol01Goo00<007ooOol0Cgoo002POol3000SOol00`00Oomoo`05Ool00`00Oomoo`1?
Ool009ioo`8002Ioo`03001oogoo00Ioo`03001oogoo04ioo`00Vgoo0`00:7oo00<007ooOol01Woo
00<007ooOol0CWoo002IOol2000[Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool009Moo`8002eoo`03
001oogoo00Qoo`03001oogoo04aoo`00U7oo0`00;goo00<007ooOol027oo00<007ooOol0C7oo002B
Ool2000bOol00`00Oomoo`09Ool00`00Oomoo`1;Ool008moo`<003Aoo`03001oogoo00Uoo`03001o
ogoo04]oo`00SGoo0P00=goo00<007ooOol02Woo00<007ooOol0BWoo002;Ool2000jOol00`00Oomo
o`0:Ool00`00Oomoo`19Ool008Qoo`<003aoo`03001oogoo00Yoo`03001oogoo04Uoo`00QWoo0P00
?goo00<007ooOol02goo00<007ooOol0B7oo0023Ool30011Ool00`00Oomoo`0;Ool00`00Oomoo`18
Ool0085oo`8004Aoo`03001oogoo00aoo`03001oogoo04Moo`00Ogoo0P00AWoo00<007ooOol03Goo
00<007ooOol0AWoo001lOol30018Ool00`00Oomoo`0=Ool00`00Oomoo`16Ool007Yoo`8004]oo`03
001oogoo00ioo`03001oogoo04Eoo`00Mgoo0`00CGoo00<007ooOol03Woo00<007ooOol0AGoo001e
Ool2001@Ool00`00Oomoo`0?Ool00`00Oomoo`14Ool007=oo`80059oo`03001oogoo011oo`03001o
ogoo04=oo`00L7oo0`00E7oo00<007ooOol047oo00<007ooOol0@goo001^Ool2001GOol00`00Oomo
o`0AOol00`00Oomoo`12Ool006]oo`<005Uoo`03001oogoo015oo`03001oogoo049oo`00JGoo0P00
G7oo00<007ooOol04Woo00<007ooOol0@Goo001WOol2001NOol00`00Oomoo`0COol00`00Oomoo`10
Ool006Aoo`<0065oo`03001oogoo019oo`03001oogoo041oo`00HWoo0P00I7oo00<007ooOol04goo
00<007ooOol0?goo001OOol3001VOol00`00Oomoo`0DOol00`00Oomoo`0nOol005eoo`8006Uoo`03
001oogoo01Aoo`03001oogoo03ioo`00Fgoo0P00Jgoo00<007ooOol05Goo00<007ooOol0?Goo001H
Ool3001]Ool00`00Oomoo`0EOol00`00Oomoo`0mOol005Ioo`80071oo`03001oogoo01Ioo`03001o
ogoo03aoo`00Dgoo0`00LWoo00<007ooOol05goo00<007ooOol0>goo001AOol2001eOol00`00Oomo
o`0GOol00`00Oomoo`0kOol004moo`8007Moo`03001oogoo01Qoo`03001oogoo03Yoo`00C7oo0`00
NGoo00<007ooOol067oo00<007ooOol0>Woo001:Ool2001lOol00`00Oomoo`0IOol00`00Oomoo`0i
Ool004Moo`<007ioo`03001oogoo01Yoo`03001oogoo03Qoo`00AGoo0P00PGoo00<007ooOol06Woo
00<007ooOol0>7oo0013Ool20023Ool00`00Oomoo`0KOol00`00Oomoo`0gOol0041oo`<008Eoo`03
001oogoo01]oo`03001oogoo03Moo`00?Woo0P00RGoo00<007ooOol06goo00<007ooOol0=Woo000k
Ool3002;Ool00`00Oomoo`0LOol00`00Oomoo`0eOol003Uoo`8008ioo`03001oogoo01aoo`03001o
ogoo03Eoo`00=goo0P00T7oo00<007ooOol07Goo00<007ooOol0=7oo000dOol3002BOol00`00Oomo
o`0GOol6O1l00`00Oomoo`0dOol0039oo`8009Eoo`03001oogoo01Ioo`Ql7`03001oogoo03=oo`00
;goo0`00Ugoo00<007ooOol05Goo2W`O00<007ooOol0<Woo000]Ool2002JOol00`00Oomoo`0DOol;
O1l00`00Oomoo`0bOol002]oo`8009aoo`03001oogoo01=oo`el7`03001oogoo035oo`00:7oo0`00
WWoo00<007ooOol04goo3G`O00<007ooOol0<Goo000VOol2002QOol00`00Oomoo`0COol>O1l00`00
Oomoo`0`Ool002=oo`<00:=oo`03001oogoo01=oo`il7`03Ool007oo031oo`008Goo0P00YWoo00<0
07ooOol04goo3W`O00=oo`00Ool0<7oo000OOol2002XOol00`00Oomoo`0COol>O1l2Ool00`00Oomo
o`0^Ool001aoo`<00:Yoo`03001oogoo01Aoo`al7`Aoo`03001oogoo02eoo`006Woo0P00[Woo00<0
07ooOol057oo2W`O1Goo00<007ooOol0;Goo000HOol2002`Ool00`00Oomoo`0EOol8O1l7Ool00`00
Oomoo`0/Ool001Qoo`800;1oo`03001oogoo01Ioo`Il7`Qoo`03001oogoo02aoo`0067oo00<007oo
0000[goo00<007ooOol09Goo00<007ooOol0:goo000HOol01000Oomoo`00[Woo00<007ooOol09Woo
00<007ooOol0:Woo000GOol00`00Oomoo`02Ool00`00Oomoo`2[Ool00`00Oomoo`0VOol00`00Oomo
o`0ZOol001Moo`03001oogoo00=oo`03001oogoo0:Yoo`03001oogoo02Moo`03001oogoo02Uoo`00
5goo00<007ooOol017oo00<007ooOol0ZGoo00<007ooOol09goo00<007ooOol0:Goo000GOol00`00
Oomoo`05Ool00`00Oomoo`2XOol00`00Oomoo`0XOol00`00Oomoo`0XOol001Moo`03001oogoo00Io
o`03001oogoo0:Moo`03001oogoo02Uoo`03001oogoo02Moo`005goo00<007ooOol01goo00<007oo
Ool0YWoo00<007ooOol0:Goo00<007ooOol09goo000GOol00`00Oomoo`08Ool00`00Oomoo`2UOol0
0`00Oomoo`0ZOol00`00Oomoo`0VOol001Ioo`03001oogoo00Yoo`03001oogoo0:Aoo`03001oogoo
02Yoo`03001oogoo02Ioo`005Woo00<007ooOol02goo00<007ooOol0Xgoo00<007ooOol0:goo00<0
07ooOol09Goo000FOol00`00Oomoo`0<Ool00`00Oomoo`2ROol00`00Oomoo`0/Ool00`00Oomoo`0T
Ool001Ioo`03001oogoo00eoo`03001oogoo0:5oo`03001oogoo02aoo`03001oogoo02Aoo`005Woo
00<007ooOol03Woo00<007ooOol0XGoo00<007ooOol0;7oo00<007ooOol08goo000FOol00`00Oomo
o`0?Ool00`00Oomoo`2POol00`00Oomoo`0/Ool00`00Oomoo`0SOol001Ioo`03001oogoo011oo`03
001oogoo09moo`03001oogoo02eoo`03001oogoo029oo`005Goo00<007ooOol04Woo00<007ooOol0
WWoo00<007ooOol0;Woo00<007ooOol08Goo000EOol00`00Oomoo`0COol00`00Oomoo`2MOol00`00
Oomoo`0^Ool00`00Oomoo`0QOol001Eoo`03001oogoo01Aoo`03001oogoo09aoo`03001oogoo02mo
o`03001oogoo021oo`005Goo00<007ooOol05Goo00<007ooOol0Vgoo00<007ooOol0;goo00<007oo
Ool087oo000EOol00`00Oomoo`0FOol00`00Oomoo`2JOol00`00Oomoo`0`Ool00`00Oomoo`0OOol0
01Eoo`03001oogoo01Moo`03001oogoo09Uoo`03001oogoo035oo`03001oogoo01ioo`005Goo00<0
07ooOol067oo00<007ooOol0V7oo00<007ooOol0<Goo00<007ooOol07Woo000DOol00`00Oomoo`0J
Ool00`00Oomoo`2GOol00`00Oomoo`0bOol00`00Oomoo`0MOol001Aoo`03001oogoo01]oo`03001o
ogoo09Ioo`03001oogoo03=oo`03001oogoo01aoo`0057oo00<007ooOol077oo00<007ooOol0UGoo
00<007ooOol0<goo00<007ooOol077oo000DOol00`00Oomoo`0MOol00`00Oomoo`2DOol00`00Oomo
o`0dOol00`00Oomoo`0KOol001Aoo`03001oogoo01ioo`03001oogoo09=oo`03001oogoo03Aoo`03
001oogoo01]oo`0057oo00<007ooOol07goo00<007ooOol0TWoo00<007ooOol0=Goo00<007ooOol0
6Woo000COol00`00Oomoo`0QOol00`00Oomoo`2BOol00`00Oomoo`0eOol00`00Oomoo`0IOol001=o
o`03001oogoo029oo`03001oogoo095oo`03001oogoo03Eoo`03001oogoo01Uoo`004goo00<007oo
Ool08goo00<007ooOol0T7oo00<007ooOol0=Woo00<007ooOol067oo000COol00`00Oomoo`0TOol0
0`00Oomoo`2?Ool00`00Oomoo`0fOol00`00Oomoo`0HOol001=oo`03001oogoo02Eoo`03001oogoo
08ioo`03001oogoo03Moo`03001oogoo01Moo`004goo00<007ooOol09Woo00<007ooOol0SGoo00<0
07ooOol0>7oo00<007ooOol05Woo000COol00`00Oomoo`0WOol00`00Oomoo`2<Ool00`00Oomoo`0h
Ool00`00Oomoo`0FOol0019oo`03001oogoo02Uoo`03001oogoo08]oo`03001oogoo03Uoo`03001o
ogoo01Eoo`004Woo00<007ooOol0:Woo00<007ooOol0RWoo00<007ooOol0>Goo00<007ooOol05Goo
000BOol00`00Oomoo`0[Ool00`00Oomoo`29Ool00`00Oomoo`0iOol2000FOol0019oo`03001oogoo
02aoo`03001oogoo08Qoo`03001oogoo03Ioo`<00003Ool007oo01Eoo`004Woo00<007ooOol0;Goo
00<007ooOol0Qgoo00<007ooOol0<goo0`0017oo00<007ooOol057oo000BOol00`00Oomoo`0^Ool0
0`00Oomoo`26Ool00`00Oomoo`0`Ool30007Ool00`00Oomoo`0DOol0019oo`03001oogoo02moo`03
001oogoo009oo`Il7geoo`03001oogoo02eoo`<000]oo`03001oogoo01=oo`004Goo00<007ooOol0
<Goo00<007ooOol027`OO7oo00<007ooOol0:Woo0`003Woo00<007ooOol04goo000AOol00`00Oomo
o`0aOol00`00Ooml7`09O1mlOol00`00Oomoo`0VOol3000AOol00`00Oomoo`0COol0015oo`03001o
ogoo039oo`al7g]oo`03001oogoo02=oo`<001Aoo`03001oogoo01=oo`004Goo00<007ooOol0<Goo
3W`ONWoo00<007ooOol087oo0`005goo00<007ooOol04goo000AOol00`00Oomoo`0aOol>O1mjOol0
0`00Oomoo`0MOol3000JOol00`00Oomoo`0COol0015oo`03001oogoo035oo`il7gYoo`03001oogoo
01Yoo`<001eoo`03001oogoo01=oo`004Goo00<007ooOol0<Goo3W`ONWoo00<007ooOol05goo0`00
8Goo00<007ooOol04Woo000@Ool00`00Oomoo`0bOol>O1mjOol00`00Oomoo`0DOol3000TOol00`00
Oomoo`0BOol0011oo`03001oogoo039oo`il7gYoo`03001oogoo011oo`@002Moo`03001oogoo019o
o`0047oo00<007ooOol0<goo37`ONgoo00<007ooOol03Goo0`00:goo00<007ooOol04Woo000@Ool0
0`00Oomoo`0dOol:O1mlOol00`00Oomoo`0:Ool3000^Ool00`00Oomoo`0BOol0011oo`03001oogoo
03Eoo`Ql7geoo`03001oogoo00Moo`<0035oo`03001oogoo019oo`0047oo00<007ooOol0=Woo1W`O
00=oo`00Ool0Ngoo00<007ooOol017oo0`00=7oo00<007ooOol04Woo000@Ool00`00Oomoo`0nOol0
0`00Oomoo`1iOol01000Oomoogoo0`00=goo00<007ooOol04Woo000?Ool00`00Oomoo`10Ool00`00
Oomoo`1hOol4000kOol00`00Oomoo`0AOol000moo`03001oogoo045oo`03001oogoo07Eoo`<003io
o`03001oogoo015oo`003goo00<007ooOol0@Woo00<007ooOol0LGoo0`000Woo00<007ooOol0?7oo
00<007ooOol04Goo000?Ool00`00Oomoo`13Ool00`00Oomoo`1]Ool30006Ool00`00Oomoo`0kOol0
0`00Oomoo`0AOol000moo`03001oogoo04Aoo`03001oogoo06Uoo`<000Uoo`03001oogoo03]oo`03
001oogoo015oo`003goo00<007ooOol0AGoo00<007ooOol0IGoo0`0037oo00<007ooOol0>goo00<0
07ooOol04Goo000?Ool00`00Oomoo`16Ool00`00Oomoo`1QOol3000?Ool00`00Oomoo`0kOol00`00
Oomoo`0AOol000ioo`03001oogoo04Qoo`03001oogoo05eoo`<0019oo`03001oogoo03aoo`03001o
ogoo011oo`003Woo00<007ooOol0BGoo00<007ooOol0FGoo0`005Goo00<007ooOol0?7oo00<007oo
Ool047oo000>Ool00`00Oomoo`1:Ool00`00Oomoo`1EOol3000HOol00`00Oomoo`0lOol00`00Oomo
o`0@Ool000ioo`03001oogoo04]oo`03001oogoo055oo`<001]oo`03001oogoo03aoo`03001oogoo
011oo`003Woo00<007ooOol0C7oo00<007ooOol0CGoo0`007Woo00<007ooOol0?7oo00<007ooOol0
47oo000>Ool00`00Oomoo`1=Ool00`00Oomoo`19Ool3000QOol00`00Oomoo`0lOol00`00Oomoo`0@
Ool000ioo`03001oogoo04ioo`03001oogoo04Eoo`<002Aoo`03001oogoo03aoo`03001oogoo011o
o`003Goo00<007ooOol0D7oo00<007ooOol0@Goo0`009goo00<007ooOol0?Goo00<007ooOol03goo
000=Ool00`00Oomoo`1AOol00`00Oomoo`0mOol3000ZOol00`00Oomoo`0mOol00`00Oomoo`0?Ool0
00eoo`03001oogoo059oo`03001oogoo03Uoo`<002eoo`03001oogoo03eoo`03001oogoo00moo`00
3Goo00<007ooOol0Dgoo00<007ooOol0=Goo0`00<7oo00<007ooOol0?Goo00<007ooOol03goo000=
Ool00`00Oomoo`1DOol00`00Oomoo`0aOol3000cOol00`00Oomoo`0mOol00`00Oomoo`0?Ool000eo
o`03001oogoo05Eoo`03001oogoo02aoo`@003Moo`03001oogoo03aoo`03001oogoo00moo`003Goo
00<007ooOol0EWoo00<007ooOol0:7oo0`00>goo00<007ooOol0?7oo00<007ooOol03goo000<Ool0
0`00Oomoo`1HOol00`00Oomoo`0TOol3000nOol00`00Oomoo`0mOol00`00Oomoo`0>Ool000aoo`03
001oogoo05Uoo`03001oogoo021oo`<0045oo`03001oogoo03eoo`03001oogoo00ioo`0037oo00<0
07ooOol0FWoo00<007ooOol077oo0`00A7oo00<007ooOol0?Goo00<007ooOol03Woo000<Ool00`00
Oomoo`1KOol00`00Oomoo`0HOol30017Ool00`00Oomoo`0mOol00`00Oomoo`0>Ool000aoo`03001o
ogoo05aoo`03001oogoo01Aoo`<004Yoo`03001oogoo03eoo`03001oogoo00ioo`0037oo00<007oo
Ool0GGoo00<007ooOol047oo0`00CGoo00<007ooOol0?Goo00<007ooOol03Woo000;Ool00`00Oomo
o`1OOol00`00Oomoo`0<Ool3001@Ool00`00Oomoo`0mOol00`00Oomoo`0>Ool000]oo`03001oogoo
061oo`03001oogoo00Qoo`<005=oo`03001oogoo03ioo`03001oogoo00eoo`002goo00<007ooOol0
HGoo00<007ooOol017oo0`00EWoo00<007ooOol0?Woo00<007ooOol03Goo000;Ool00`00Oomoo`1R
Ool00`00Oomoo`03001IOol00`00Oomoo`0nOol00`00Oomoo`0=Ool000]oo`03001oogoo06=oo`80
05aoo`03001oogoo03ioo`03001oogoo00eoo`002goo00<007ooOol0Hgoo00<007ooOol0Fgoo00<0
07ooOol0?Woo00<007ooOol03Goo000;Ool00`00Oomoo`1SOol00`00Oomoo`1KOol00`00Oomoo`0n
Ool00`00Oomoo`0=Ool000Yoo`03001oogoo06Aoo`03001oogoo05]oo`03001oogoo03ioo`03001o
ogoo00eoo`002Woo00<007ooOol0I7oo00<007ooOol0G7oo00<007ooOol0?Goo00<007ooOol03Goo
000:Ool00`00Oomoo`1TOol00`00Oomoo`1LOol00`00Oomoo`0nOol00`00Oomoo`0<Ool000Yoo`03
001oogoo06Aoo`03001oogoo05aoo`03001oogoo03ioo`03001oogoo00aoo`002Woo00<007ooOol0
I7oo00<007ooOol0G7oo00<007ooOol0?Woo00<007ooOol037oo000:Ool00`00Oomoo`1TOol00`00
Oomoo`1LOol00`00Oomoo`0nOol00`00Oomoo`0<Ool000Yoo`03001oogoo06Aoo`03001oogoo05ao
o`03001oogoo03ioo`03001oogoo00aoo`002Goo00<007ooOol0IGoo00<007ooOol0G7oo00<007oo
Ool0?Woo00<007ooOol037oo0009Ool00`00Oomoo`1UOol00`00Oomoo`1KOol20010Ool00`00Oomo
o`0<Ool000Uoo`03001oogoo06Eoo`03001oogoo05Qoo`<0009oo`03001oogoo03ioo`03001oogoo
00]oo`002Goo00<007ooOol0I7oo00<007ooOol0EGoo10001Woo00<007ooOol0?Goo00<007ooOol0
2goo0009Ool00`00Oomoo`1TOol00`00Oomoo`1BOol3000:Ool00`00Oomoo`0mOol00`00Oomoo`0;
Ool000Uoo`03001oogoo06Aoo`03001oogoo04moo`<000ioo`03001oogoo03aoo`03001oogoo00]o
o`002Goo00<007ooOol0I7oo00<007ooOol0C7oo0`004Woo00<007ooOol0>goo00<007ooOol02goo
0008Ool00`00Oomoo`1UOol00`00Oomoo`18Ool4000FOol00`00Oomoo`0jOol00`00Oomoo`0;Ool0
00Qoo`03001oogoo06Eoo`03001oogoo04Eoo`<001]oo`03001oogoo03Uoo`03001oogoo00]oo`00
27oo00<007ooOol0IGoo00<007ooOol0@Woo0`007Woo00<007ooOol0>Woo00<007ooOol02Woo0008
Ool00`00Oomoo`1UOol00`00Oomoo`0oOol3000ROol00`00Oomoo`0iOol00`00Oomoo`0:Ool000Qo
o`03001oogoo06Eoo`03001oogoo03]oo`@002Ioo`03001oogoo03Qoo`03001oogoo00Yoo`0027oo
00<007ooOol0IGoo00<007ooOol0>7oo0`00:goo00<007ooOol0=goo00<007ooOol02Woo0008Ool0
0`00Oomoo`1UOol00`00Oomoo`0eOol3000_Ool00`00Oomoo`0fOol00`00Oomoo`0:Ool000Moo`03
001oogoo06Ioo`03001oogoo039oo`<0039oo`03001oogoo03Ioo`03001oogoo00Yoo`001goo00<0
07ooOol0IWoo00<007ooOol0;Woo1000=Woo00<007ooOol0=Goo00<007ooOol02Woo0007Ool00`00
Oomoo`1VOol00`00Oomoo`0[Ool3000kOol00`00Oomoo`0eOol00`00Oomoo`09Ool000Moo`03001o
ogoo06Ioo`03001oogoo02Qoo`<003moo`03001oogoo03Aoo`03001oogoo00Uoo`001goo00<007oo
Ool0IWoo00<007ooOol09Goo0`00@goo00<007ooOol0<goo00<007ooOol02Goo0007Ool00`00Oomo
o`1VOol00`00Oomoo`0QOol40017Ool00`00Oomoo`0bOol00`00Oomoo`09Ool000Moo`03001oogoo
06Ioo`03001oogoo01ioo`<004]oo`03001oogoo039oo`03001oogoo00Uoo`001Woo00<007ooOol0
Igoo00<007ooOol06goo0`00Cgoo00<007ooOol0<Goo00<007ooOol02Goo0006Ool00`00Oomoo`1W
Ool00`00Oomoo`0HOol3001COol00`00Oomoo`0`Ool00`00Oomoo`09Ool000Ioo`03001oogoo06Mo
o`03001oogoo01Aoo`@005Moo`03001oogoo02moo`03001oogoo00Uoo`001Woo00<007ooOol0Igoo
00<007ooOol04Goo0`00G7oo00<007ooOol0;goo00<007ooOol027oo0006Ool00`00Oomoo`1WOol0
0`00Oomoo`0>Ool3001OOol00`00Oomoo`0_Ool00`00Oomoo`08Ool000Ioo`03001oogoo06Moo`03
001oogoo00]oo`<006=oo`03001oogoo02ioo`03001oogoo00Qoo`001Woo00<007ooOol0Igoo00<0
07ooOol01goo1000Igoo00<007ooOol0;Goo00<007ooOol027oo0005Ool00`00Oomoo`1WOol00`00
Oomoo`05Ool3001/Ool00`00Oomoo`0/Ool00`00Oomoo`08Ool000Eoo`03001oogoo06Moo`03001o
ogoo009oo`<0071oo`03001oogoo02]oo`03001oogoo00Qoo`001Goo00<007ooOol0Igoo00<007oo
00000P00Lgoo00<007ooOol0:goo00<007ooOol027oo0005Ool00`00Oomoo`1UOol4001gOol00`00
Oomoo`0[Ool00`00Oomoo`07Ool000Eoo`03001oogoo069oo`<0009oo`03001oogoo07Moo`03001o
ogoo02Yoo`03001oogoo00Moo`001Goo00<007ooOol0Ggoo0`001Goo00<007ooOol0N7oo00<007oo
Ool0:Goo00<007ooOol01goo0005Ool00`00Oomoo`1LOol30008Ool00`00Oomoo`1iOol00`00Oomo
o`0XOol00`00Oomoo`07Ool000Aoo`03001oogoo05Uoo`@000]oo`03001oogoo07Uoo`03001oogoo
02Qoo`03001oogoo00Moo`0017oo00<007ooOol0EWoo0`003goo00<007ooOol0NWoo00<007ooOol0
9goo00<007ooOol01goo0004Ool00`00Oomoo`1COol3000BOol00`00Oomoo`1kOol00`00Oomoo`0V
Ool00`00Oomoo`07Ool000Aoo`03001oogoo051oo`<001Eoo`03001oogoo07aoo`03001oogoo02Io
o`03001oogoo00Ioo`0017oo00<007ooOol0C7oo100067oo00<007ooOol0OGoo00<007ooOol09Goo
00<007ooOol01Woo0004Ool00`00Oomoo`19Ool3000LOol00`00Oomoo`1mOol00`00Oomoo`0UOol0
0`00Oomoo`06Ool000=oo`03001oogoo04Moo`<001moo`03001oogoo07ioo`03001oogoo02Aoo`03
001oogoo00Ioo`000goo00<007ooOol0A7oo0`008Woo00<007ooOol0Ogoo00<007ooOol08goo00<0
07ooOol01Woo0003Ool00`00Oomoo`10Ool4000UOol00`00Oomoo`20Ool00`00Oomoo`0ROol00`00
Oomoo`06Ool000=oo`03001oogoo03eoo`<002Uoo`03001oogoo085oo`03001oogoo025oo`03001o
ogoo00Ioo`000goo00<007ooOol0>Woo0`00;7oo00<007ooOol0PGoo00<007ooOol08Woo00<007oo
Ool01Goo0003Ool00`00Oomoo`0gOol3000_Ool00`00Oomoo`21Ool00g`O001l7`03O1lOOol00`00
Oomoo`05Ool000=oo`03001oogoo03=oo`@0039oo`03001oogoo081oo`=l7`03001l7g`O009l7aio
o`03001oogoo00Eoo`000Woo00<007ooOol0<Goo0`00=Woo00<007ooOol0Ogoo1G`O00<007`OO1l0
0W`O7Goo00<007ooOol01Goo0002Ool00`00Oomoo`0^Ool3000iOol00`00Oomoo`1nOol7O1l00`00
O1ml7`02O1lLOol00`00Oomoo`05Ool0009oo`03001oogoo02]oo`<003aoo`03001oogoo07eoo`Ul
7`03001l7g`O009l7a]oo`03001oogoo00Eoo`000Woo00<007ooOol09goo1000?goo00<007ooOol0
OGoo2G`O00<007`OO1l00W`O6goo00<007ooOol01Goo0002Ool00`00Oomoo`0TOol30013Ool00`00
Oomoo`1mOol:O1l01000O1ml7g`O6goo00<007ooOol01Goo0002Ool00`00Oomoo`0QOol30015Ool0
0`00Oomoo`1nOol;O1l00`00O1ml7`0LOol00`00Oomoo`04Ool0009oo`03001oogoo01ioo`<004Qo
o`03001oogoo07ioo`al7`03001l7goo01]oo`03001oogoo00Aoo`0000=oo`00Ool077oo1000Bgoo
00<007ooOol0OWoo3G`O00<007ooOol06Woo00<007ooOol017oo00000goo001oo`0IOol3001?Ool0
0`00Oomoo`1oOol<O1l00`00Oomoo`0JOol00`00Oomoo`04Ool00003Ool007oo01Ioo`<0059oo`03
001oogoo081oo`Yl7`9oo`03001oogoo01Uoo`03001oogoo00Aoo`0000=oo`00Ool04goo0`00EGoo
00<007ooOol0PGoo27`O17oo00<007ooOol067oo00<007ooOol017oo00000goo001oo`0?Ool4001H
Ool00`00Oomoo`22Ool6O1l6Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00003Ool007oo00aoo`<0
05aoo`03001oogoo08moo`03001oogoo01Moo`03001oogoo00=oo`0000=oo`00Ool02Goo0`00Ggoo
00<007ooOol0Sgoo00<007ooOol05goo00<007ooOol00goo00000`00Oomoo`06Ool3001ROol00`00
Oomoo`2@Ool00`00Oomoo`0FOol00`00Oomoo`03Ool00003001oogoo009oo`@006Eoo`03001oogoo
095oo`03001oogoo01Eoo`03001oogoo00=oo`0000<007oo00000P00JGoo00<007ooOol0TWoo00<0
07ooOol057oo00<007ooOol00goo0002001/Ool00`00Oomoo`2COol00`00Oomoo`0COol00`00Oomo
o`03Ool00003Ool0000006]oo`03001oogoo09=oo`03001oogoo01=oo`03001oogoo00=oo`000goo
00<007ooOol0J7oo00<007ooOol0U7oo00<007ooOol04goo00<007ooOol00Woo0004Ool00`00Oomo
o`1WOol00`00Oomoo`2EOol00`00Oomoo`0BOol00`00Oomoo`02Ool000Eoo`8006Moo`03001oogoo
09Ioo`03001oogoo015oo`03001oogoo009oo`001goo00<007ooOol0I7oo00<007ooOol0Ugoo00<0
07ooOol047oo00<007ooOol00Woo0008Ool2001TOol00`00Oomoo`2GOol00`00Oomoo`0@Ool00`00
Oomoo`02Ool000Yoo`03001oogoo065oo`03001oogoo09Qoo`03001oogoo00moo`03001oogoo009o
o`002goo0P00HGoo00<007ooOol0VGoo00<007ooOol03Woo00<007ooOol00Woo000=Ool00`00Oomo
o`1NOol00`00Oomoo`2JOol00`00Oomoo`0>Ool00`00Oomoo`01Ool000ioo`03001oogoo05eoo`03
001oogoo09]oo`03001oogoo00eoo`03001oogoo005oo`003goo0P00GGoo00<007ooOol0Vgoo00<0
07ooOol03Goo00<007ooOol00Goo000AOol00`00Oomoo`1JOol00`00Oomoo`2LOol00`00Oomoo`0<
Ool00`00Oomoo`01Ool0019oo`8005Uoo`03001oogoo09ioo`03001oogoo00]oo`03001oogoo005o
o`0057oo00<007ooOol0EWoo00<007ooOol0Wgoo00<007ooOol02Woo00<007ooOol00Goo000EOol2
001FOol00`00Oomoo`2POol00`00Oomoo`09Ool00`00Oomoo`01Ool001Moo`03001oogoo05=oo`03
001oogoo0:1oo`03001oogoo00Yoo`40005oo`5oo`0067oo00<007ooOol0DWoo00<007ooOol0XGoo
00<007ooOol02Goo0@000Goo0Goo000IOol2001BOol00`00Oomoo`2ROol00`00Oomoo`08Ool10001
Ool1Ool001]oo`03001oogoo04moo`03001oogoo0:=oo`03001oogoo00Moo`40005oo`5oo`0077oo
0P00Cgoo00<007ooOol0Y7oo00<007ooOol01Woo0@000Goo0Goo000NOol00`00Oomoo`1<Ool00`00
Oomoo`2UOol00`00Oomoo`05Ool10001Ool1Ool001moo`8004aoo`03001oogoo0:Eoo`03001oogoo
00Eoo`40005oo`5oo`008Goo00<007ooOol0BGoo00<007ooOol0YWoo00<007ooOol017oo0@000Goo
0Goo000ROol00`00Oomoo`18Ool00`00Oomoo`2WOol00`00Oomoo`04Ool10001Ool002=oo`8004Qo
o`03001oogoo0:Qoo`03001oogoo00=oo`40005oo`009Goo00<007ooOol0AGoo00<007ooOol0ZGoo
00<007ooOol00Woo0@000Goo000VOol20015Ool00`00Oomoo`2YOol00`00Oomoo`02Ool10001Ool0
02Qoo`03001oogoo049oo`03001oogoo0:Yoo`05001oogooOol00001Ool002Uoo`80019oo`Il7bYo
o`03001oogoo0:]oo`04001oogoo0001Ool002]oo`03001oogoo00ioo`Ql7bUoo`03001oogoo0:ao
o`03001oo`00005oo`00;7oo00<007ooOol037oo2W`O:7oo00<007ooOol0[Goo0@000Goo0@00000]
Ool2000;Ool<O1lWOol00`00Oomoo`2]Ool10001Ool1000002moo`03001oogoo00Moo`il7bIoo`03
001oogoo0:ioo`800000<7oo0P001goo3W`O9Woo00<007ooOol0[Goo0`00000bOol00`00Oomoo`04
Ool>O1lVOol00`00Oomoo`2YOol40003Ool003=oo`8000Aoo`il7bIoo`03001oogoo0:Eoo`@000Mo
o`00=Goo00@007ooOomoo`il7bIoo`03001oogoo0:1oo`D000]oo`00=Woo00<007ooOol03W`O9Goo
00<007ooOol0WGoo100047oo000gOol200000gooO1ml7`0:O1lVOol00`00Oomoo`2HOol5000DOol0
03Uoo`03001oog`O00Ul7bMoo`03001oogoo09Aoo`@001Uoo`00>Woo0P0027`O:7oo00<007ooOol0
T7oo10007Goo000lOol00`00O1ml7`04O1lYOol00`00Oomoo`2;Ool5000QOol003eoo`8002eoo`03
001oogoo08Moo`@002Ioo`00?goo00<007ooOol0:Woo00<007ooOol0PWoo1@00:Woo0010Ool00`00
Oomoo`0YOol00`00Oomoo`1nOol4000_Ool0045oo`8002Uoo`03001oogoo07Yoo`@003=oo`00@goo
00<007ooOol09Woo00<007ooOol0MGoo1@00=goo0014Ool2000VOol00`00Oomoo`1aOol4000lOol0
04Ioo`03001oogoo02=oo`03001oogoo06aoo`D0041oo`00Agoo0P008goo00<007ooOol0J7oo1000
AGoo0019Ool00`00Oomoo`0POol00`00Oomoo`1TOol40019Ool004Yoo`03001oogoo01moo`03001o
ogoo05moo`D004eoo`00Bgoo0P007goo00<007ooOol0Fgoo1000DWoo001=Ool00`00Oomoo`0LOol0
0`00Oomoo`1GOol4001FOol004ioo`8001aoo`03001oogoo059oo`D005Yoo`00D7oo00<007ooOol0
6Goo00<007ooOol0CWoo1000Ggoo001AOol2000IOol00`00Oomoo`19Ool5001SOol005=oo`03001o
ogoo01Ioo`03001oogoo04Eoo`@006Qoo`00E7oo00<007ooOol05Goo00<007ooOol0@Goo1000K7oo
001EOol2000EOol00`00Oomoo`0lOol5001`Ool005Moo`03001oogoo019oo`03001oogoo03Qoo`@0
07Eoo`00F7oo0P004Woo00<007ooOol0<goo1@00NGoo001JOol00`00Oomoo`0>Ool00`00Oomoo`0`
Ool4001nOol005]oo`8000ioo`03001oogoo02aoo`@0089oo`00GGoo00<007ooOol02goo00<007oo
Ool09goo1@00QWoo001NOol00`00Oomoo`0:Ool00`00Oomoo`0SOol4002;Ool005moo`8000Yoo`03
001oogoo01ioo`D008moo`00HGoo00<007ooOol01goo00<007ooOol06Woo1000U7oo001ROol20007
Ool00`00Oomoo`0FOol4002HOol006Aoo`03001oogoo00Aoo`03001oogoo015oo`D009aoo`00IGoo
0P0017oo00<007ooOol03Goo1000XGoo001WOol01@00Oomoogoo00002Woo1@00YGoo001XOol01000
Oomoo`001Woo1000ZWoo001YOol30002Ool4002^Ool006]oo`<00;9oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {312.313, 0}} -> {0.0501528, -9.39857*^-05, \
0.0030079, 0.0030079}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["dt=0.01;", "Input"],

Cell["NSPHR=4;NDIM=6 NSPHR;Ng=3 NSPHR; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\StokesianDynamics\\\\data.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\StokesianDynamics\\data.m", 8]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];
X[3,0]=X[3];Y[3,0]=Y[3];Z[3,0]=Z[3];
X[4,0]=X[4];Y[4,0]=Y[4];Z[4,0]=Z[4];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<641,{<<\"C:\\\\StokesianDynamics\\\\NEWTON2.m\";
X[1,t]=X[1,t-1]+UNEW[1]*dt;Y[1,t]=Y[1,t-1]+UNEW[2]*dt;Z[1,t]=Z[1,t-1]+UNEW[3]*\
dt;X[2,t]=X[2,t-1]+UNEW[4]*dt;Y[2,t]=Y[2,t-1]+UNEW[5]*dt;Z[2,t]=Z[2,t-1]+UNEW[\
6]*dt;X[3,t]=X[3,t-1]+UNEW[7]*dt;Y[3,t]=Y[3,t-1]+UNEW[8]*dt;Z[3,t]=Z[3,t-1]+\
UNEW[9]*dt;X[4,t]=X[4,t-1]+UNEW[10]*dt;Y[4,t]=Y[4,t-1]+UNEW[11]*dt;Z[4,t]=Z[4,\
t-1]+UNEW[12]*dt;Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"],

Cell[BoxData[
    \(100\)], "Print"],

Cell[BoxData[
    \(101\)], "Print"],

Cell[BoxData[
    \(102\)], "Print"],

Cell[BoxData[
    \(103\)], "Print"],

Cell[BoxData[
    \(104\)], "Print"],

Cell[BoxData[
    \(105\)], "Print"],

Cell[BoxData[
    \(106\)], "Print"],

Cell[BoxData[
    \(107\)], "Print"],

Cell[BoxData[
    \(108\)], "Print"],

Cell[BoxData[
    \(109\)], "Print"],

Cell[BoxData[
    \(110\)], "Print"],

Cell[BoxData[
    \(111\)], "Print"],

Cell[BoxData[
    \(112\)], "Print"],

Cell[BoxData[
    \(113\)], "Print"],

Cell[BoxData[
    \(114\)], "Print"],

Cell[BoxData[
    \(115\)], "Print"],

Cell[BoxData[
    \(116\)], "Print"],

Cell[BoxData[
    \(117\)], "Print"],

Cell[BoxData[
    \(118\)], "Print"],

Cell[BoxData[
    \(119\)], "Print"],

Cell[BoxData[
    \(120\)], "Print"],

Cell[BoxData[
    \(121\)], "Print"],

Cell[BoxData[
    \(122\)], "Print"],

Cell[BoxData[
    \(123\)], "Print"],

Cell[BoxData[
    \(124\)], "Print"],

Cell[BoxData[
    \(125\)], "Print"],

Cell[BoxData[
    \(126\)], "Print"],

Cell[BoxData[
    \(127\)], "Print"],

Cell[BoxData[
    \(128\)], "Print"],

Cell[BoxData[
    \(129\)], "Print"],

Cell[BoxData[
    \(130\)], "Print"],

Cell[BoxData[
    \(131\)], "Print"],

Cell[BoxData[
    \(132\)], "Print"],

Cell[BoxData[
    \(133\)], "Print"],

Cell[BoxData[
    \(134\)], "Print"],

Cell[BoxData[
    \(135\)], "Print"],

Cell[BoxData[
    \(136\)], "Print"],

Cell[BoxData[
    \(137\)], "Print"],

Cell[BoxData[
    \(138\)], "Print"],

Cell[BoxData[
    \(139\)], "Print"],

Cell[BoxData[
    \(140\)], "Print"],

Cell[BoxData[
    \(141\)], "Print"],

Cell[BoxData[
    \(142\)], "Print"],

Cell[BoxData[
    \(143\)], "Print"],

Cell[BoxData[
    \(144\)], "Print"],

Cell[BoxData[
    \(145\)], "Print"],

Cell[BoxData[
    \(146\)], "Print"],

Cell[BoxData[
    \(147\)], "Print"],

Cell[BoxData[
    \(148\)], "Print"],

Cell[BoxData[
    \(149\)], "Print"],

Cell[BoxData[
    \(150\)], "Print"],

Cell[BoxData[
    \(151\)], "Print"],

Cell[BoxData[
    \(152\)], "Print"],

Cell[BoxData[
    \(153\)], "Print"],

Cell[BoxData[
    \(154\)], "Print"],

Cell[BoxData[
    \(155\)], "Print"],

Cell[BoxData[
    \(156\)], "Print"],

Cell[BoxData[
    \(157\)], "Print"],

Cell[BoxData[
    \(158\)], "Print"],

Cell[BoxData[
    \(159\)], "Print"],

Cell[BoxData[
    \(160\)], "Print"],

Cell[BoxData[
    \(161\)], "Print"],

Cell[BoxData[
    \(162\)], "Print"],

Cell[BoxData[
    \(163\)], "Print"],

Cell[BoxData[
    \(164\)], "Print"],

Cell[BoxData[
    \(165\)], "Print"],

Cell[BoxData[
    \(166\)], "Print"],

Cell[BoxData[
    \(167\)], "Print"],

Cell[BoxData[
    \(168\)], "Print"],

Cell[BoxData[
    \(169\)], "Print"],

Cell[BoxData[
    \(170\)], "Print"],

Cell[BoxData[
    \(171\)], "Print"],

Cell[BoxData[
    \(172\)], "Print"],

Cell[BoxData[
    \(173\)], "Print"],

Cell[BoxData[
    \(174\)], "Print"],

Cell[BoxData[
    \(175\)], "Print"],

Cell[BoxData[
    \(176\)], "Print"],

Cell[BoxData[
    \(177\)], "Print"],

Cell[BoxData[
    \(178\)], "Print"],

Cell[BoxData[
    \(179\)], "Print"],

Cell[BoxData[
    \(180\)], "Print"],

Cell[BoxData[
    \(181\)], "Print"],

Cell[BoxData[
    \(182\)], "Print"],

Cell[BoxData[
    \(183\)], "Print"],

Cell[BoxData[
    \(184\)], "Print"],

Cell[BoxData[
    \(185\)], "Print"],

Cell[BoxData[
    \(186\)], "Print"],

Cell[BoxData[
    \(187\)], "Print"],

Cell[BoxData[
    \(188\)], "Print"],

Cell[BoxData[
    \(189\)], "Print"],

Cell[BoxData[
    \(190\)], "Print"],

Cell[BoxData[
    \(191\)], "Print"],

Cell[BoxData[
    \(192\)], "Print"],

Cell[BoxData[
    \(193\)], "Print"],

Cell[BoxData[
    \(194\)], "Print"],

Cell[BoxData[
    \(195\)], "Print"],

Cell[BoxData[
    \(196\)], "Print"],

Cell[BoxData[
    \(197\)], "Print"],

Cell[BoxData[
    \(198\)], "Print"],

Cell[BoxData[
    \(199\)], "Print"],

Cell[BoxData[
    \(200\)], "Print"],

Cell[BoxData[
    \(201\)], "Print"],

Cell[BoxData[
    \(202\)], "Print"],

Cell[BoxData[
    \(203\)], "Print"],

Cell[BoxData[
    \(204\)], "Print"],

Cell[BoxData[
    \(205\)], "Print"],

Cell[BoxData[
    \(206\)], "Print"],

Cell[BoxData[
    \(207\)], "Print"],

Cell[BoxData[
    \(208\)], "Print"],

Cell[BoxData[
    \(209\)], "Print"],

Cell[BoxData[
    \(210\)], "Print"],

Cell[BoxData[
    \(211\)], "Print"],

Cell[BoxData[
    \(212\)], "Print"],

Cell[BoxData[
    \(213\)], "Print"],

Cell[BoxData[
    \(214\)], "Print"],

Cell[BoxData[
    \(215\)], "Print"],

Cell[BoxData[
    \(216\)], "Print"],

Cell[BoxData[
    \(217\)], "Print"],

Cell[BoxData[
    \(218\)], "Print"],

Cell[BoxData[
    \(219\)], "Print"],

Cell[BoxData[
    \(220\)], "Print"],

Cell[BoxData[
    \(221\)], "Print"],

Cell[BoxData[
    \(222\)], "Print"],

Cell[BoxData[
    \(223\)], "Print"],

Cell[BoxData[
    \(224\)], "Print"],

Cell[BoxData[
    \(225\)], "Print"],

Cell[BoxData[
    \(226\)], "Print"],

Cell[BoxData[
    \(227\)], "Print"],

Cell[BoxData[
    \(228\)], "Print"],

Cell[BoxData[
    \(229\)], "Print"],

Cell[BoxData[
    \(230\)], "Print"],

Cell[BoxData[
    \(231\)], "Print"],

Cell[BoxData[
    \(232\)], "Print"],

Cell[BoxData[
    \(233\)], "Print"],

Cell[BoxData[
    \(234\)], "Print"],

Cell[BoxData[
    \(235\)], "Print"],

Cell[BoxData[
    \(236\)], "Print"],

Cell[BoxData[
    \(237\)], "Print"],

Cell[BoxData[
    \(238\)], "Print"],

Cell[BoxData[
    \(239\)], "Print"],

Cell[BoxData[
    \(240\)], "Print"],

Cell[BoxData[
    \(241\)], "Print"],

Cell[BoxData[
    \(242\)], "Print"],

Cell[BoxData[
    \(243\)], "Print"],

Cell[BoxData[
    \(244\)], "Print"],

Cell[BoxData[
    \(245\)], "Print"],

Cell[BoxData[
    \(246\)], "Print"],

Cell[BoxData[
    \(247\)], "Print"],

Cell[BoxData[
    \(248\)], "Print"],

Cell[BoxData[
    \(249\)], "Print"],

Cell[BoxData[
    \(250\)], "Print"],

Cell[BoxData[
    \(251\)], "Print"],

Cell[BoxData[
    \(252\)], "Print"],

Cell[BoxData[
    \(253\)], "Print"],

Cell[BoxData[
    \(254\)], "Print"],

Cell[BoxData[
    \(255\)], "Print"],

Cell[BoxData[
    \(256\)], "Print"],

Cell[BoxData[
    \(257\)], "Print"],

Cell[BoxData[
    \(258\)], "Print"],

Cell[BoxData[
    \(259\)], "Print"],

Cell[BoxData[
    \(260\)], "Print"],

Cell[BoxData[
    \(261\)], "Print"],

Cell[BoxData[
    \(262\)], "Print"],

Cell[BoxData[
    \(263\)], "Print"],

Cell[BoxData[
    \(264\)], "Print"],

Cell[BoxData[
    \(265\)], "Print"],

Cell[BoxData[
    \(266\)], "Print"],

Cell[BoxData[
    \(267\)], "Print"],

Cell[BoxData[
    \(268\)], "Print"],

Cell[BoxData[
    \(269\)], "Print"],

Cell[BoxData[
    \(270\)], "Print"],

Cell[BoxData[
    \(271\)], "Print"],

Cell[BoxData[
    \(272\)], "Print"],

Cell[BoxData[
    \(273\)], "Print"],

Cell[BoxData[
    \(274\)], "Print"],

Cell[BoxData[
    \(275\)], "Print"],

Cell[BoxData[
    \(276\)], "Print"],

Cell[BoxData[
    \(277\)], "Print"],

Cell[BoxData[
    \(278\)], "Print"],

Cell[BoxData[
    \(279\)], "Print"],

Cell[BoxData[
    \(280\)], "Print"],

Cell[BoxData[
    \(281\)], "Print"],

Cell[BoxData[
    \(282\)], "Print"],

Cell[BoxData[
    \(283\)], "Print"],

Cell[BoxData[
    \(284\)], "Print"],

Cell[BoxData[
    \(285\)], "Print"],

Cell[BoxData[
    \(286\)], "Print"],

Cell[BoxData[
    \(287\)], "Print"],

Cell[BoxData[
    \(288\)], "Print"],

Cell[BoxData[
    \(289\)], "Print"],

Cell[BoxData[
    \(290\)], "Print"],

Cell[BoxData[
    \(291\)], "Print"],

Cell[BoxData[
    \(292\)], "Print"],

Cell[BoxData[
    \(293\)], "Print"],

Cell[BoxData[
    \(294\)], "Print"],

Cell[BoxData[
    \(295\)], "Print"],

Cell[BoxData[
    \(296\)], "Print"],

Cell[BoxData[
    \(297\)], "Print"],

Cell[BoxData[
    \(298\)], "Print"],

Cell[BoxData[
    \(299\)], "Print"],

Cell[BoxData[
    \(300\)], "Print"],

Cell[BoxData[
    \(301\)], "Print"],

Cell[BoxData[
    \(302\)], "Print"],

Cell[BoxData[
    \(303\)], "Print"],

Cell[BoxData[
    \(304\)], "Print"],

Cell[BoxData[
    \(305\)], "Print"],

Cell[BoxData[
    \(306\)], "Print"],

Cell[BoxData[
    \(307\)], "Print"],

Cell[BoxData[
    \(308\)], "Print"],

Cell[BoxData[
    \(309\)], "Print"],

Cell[BoxData[
    \(310\)], "Print"],

Cell[BoxData[
    \(311\)], "Print"],

Cell[BoxData[
    \(312\)], "Print"],

Cell[BoxData[
    \(313\)], "Print"],

Cell[BoxData[
    \(314\)], "Print"],

Cell[BoxData[
    \(315\)], "Print"],

Cell[BoxData[
    \(316\)], "Print"],

Cell[BoxData[
    \(317\)], "Print"],

Cell[BoxData[
    \(318\)], "Print"],

Cell[BoxData[
    \(319\)], "Print"],

Cell[BoxData[
    \(320\)], "Print"],

Cell[BoxData[
    \(321\)], "Print"],

Cell[BoxData[
    \(322\)], "Print"],

Cell[BoxData[
    \(323\)], "Print"],

Cell[BoxData[
    \(324\)], "Print"],

Cell[BoxData[
    \(325\)], "Print"],

Cell[BoxData[
    \(326\)], "Print"],

Cell[BoxData[
    \(327\)], "Print"],

Cell[BoxData[
    \(328\)], "Print"],

Cell[BoxData[
    \(329\)], "Print"],

Cell[BoxData[
    \(330\)], "Print"],

Cell[BoxData[
    \(331\)], "Print"],

Cell[BoxData[
    \(332\)], "Print"],

Cell[BoxData[
    \(333\)], "Print"],

Cell[BoxData[
    \(334\)], "Print"],

Cell[BoxData[
    \(335\)], "Print"],

Cell[BoxData[
    \(336\)], "Print"],

Cell[BoxData[
    \(337\)], "Print"],

Cell[BoxData[
    \(338\)], "Print"],

Cell[BoxData[
    \(339\)], "Print"],

Cell[BoxData[
    \(340\)], "Print"],

Cell[BoxData[
    \(341\)], "Print"],

Cell[BoxData[
    \(342\)], "Print"],

Cell[BoxData[
    \(343\)], "Print"],

Cell[BoxData[
    \(344\)], "Print"],

Cell[BoxData[
    \(345\)], "Print"],

Cell[BoxData[
    \(346\)], "Print"],

Cell[BoxData[
    \(347\)], "Print"],

Cell[BoxData[
    \(348\)], "Print"],

Cell[BoxData[
    \(349\)], "Print"],

Cell[BoxData[
    \(350\)], "Print"],

Cell[BoxData[
    \(351\)], "Print"],

Cell[BoxData[
    \(352\)], "Print"],

Cell[BoxData[
    \(353\)], "Print"],

Cell[BoxData[
    \(354\)], "Print"],

Cell[BoxData[
    \(355\)], "Print"],

Cell[BoxData[
    \(356\)], "Print"],

Cell[BoxData[
    \(357\)], "Print"],

Cell[BoxData[
    \(358\)], "Print"],

Cell[BoxData[
    \(359\)], "Print"],

Cell[BoxData[
    \(360\)], "Print"],

Cell[BoxData[
    \(361\)], "Print"],

Cell[BoxData[
    \(362\)], "Print"],

Cell[BoxData[
    \(363\)], "Print"],

Cell[BoxData[
    \(364\)], "Print"],

Cell[BoxData[
    \(365\)], "Print"],

Cell[BoxData[
    \(366\)], "Print"],

Cell[BoxData[
    \(367\)], "Print"],

Cell[BoxData[
    \(368\)], "Print"],

Cell[BoxData[
    \(369\)], "Print"],

Cell[BoxData[
    \(370\)], "Print"],

Cell[BoxData[
    \(371\)], "Print"],

Cell[BoxData[
    \(372\)], "Print"],

Cell[BoxData[
    \(373\)], "Print"],

Cell[BoxData[
    \(374\)], "Print"],

Cell[BoxData[
    \(375\)], "Print"],

Cell[BoxData[
    \(376\)], "Print"],

Cell[BoxData[
    \(377\)], "Print"],

Cell[BoxData[
    \(378\)], "Print"],

Cell[BoxData[
    \(379\)], "Print"],

Cell[BoxData[
    \(380\)], "Print"],

Cell[BoxData[
    \(381\)], "Print"],

Cell[BoxData[
    \(382\)], "Print"],

Cell[BoxData[
    \(383\)], "Print"],

Cell[BoxData[
    \(384\)], "Print"],

Cell[BoxData[
    \(385\)], "Print"],

Cell[BoxData[
    \(386\)], "Print"],

Cell[BoxData[
    \(387\)], "Print"],

Cell[BoxData[
    \(388\)], "Print"],

Cell[BoxData[
    \(389\)], "Print"],

Cell[BoxData[
    \(390\)], "Print"],

Cell[BoxData[
    \(391\)], "Print"],

Cell[BoxData[
    \(392\)], "Print"],

Cell[BoxData[
    \(393\)], "Print"],

Cell[BoxData[
    \(394\)], "Print"],

Cell[BoxData[
    \(395\)], "Print"],

Cell[BoxData[
    \(396\)], "Print"],

Cell[BoxData[
    \(397\)], "Print"],

Cell[BoxData[
    \(398\)], "Print"],

Cell[BoxData[
    \(399\)], "Print"],

Cell[BoxData[
    \(400\)], "Print"],

Cell[BoxData[
    \(401\)], "Print"],

Cell[BoxData[
    \(402\)], "Print"],

Cell[BoxData[
    \(403\)], "Print"],

Cell[BoxData[
    \(404\)], "Print"],

Cell[BoxData[
    \(405\)], "Print"],

Cell[BoxData[
    \(406\)], "Print"],

Cell[BoxData[
    \(407\)], "Print"],

Cell[BoxData[
    \(408\)], "Print"],

Cell[BoxData[
    \(409\)], "Print"],

Cell[BoxData[
    \(410\)], "Print"],

Cell[BoxData[
    \(411\)], "Print"],

Cell[BoxData[
    \(412\)], "Print"],

Cell[BoxData[
    \(413\)], "Print"],

Cell[BoxData[
    \(414\)], "Print"],

Cell[BoxData[
    \(415\)], "Print"],

Cell[BoxData[
    \(416\)], "Print"],

Cell[BoxData[
    \(417\)], "Print"],

Cell[BoxData[
    \(418\)], "Print"],

Cell[BoxData[
    \(419\)], "Print"],

Cell[BoxData[
    \(420\)], "Print"],

Cell[BoxData[
    \(421\)], "Print"],

Cell[BoxData[
    \(422\)], "Print"],

Cell[BoxData[
    \(423\)], "Print"],

Cell[BoxData[
    \(424\)], "Print"],

Cell[BoxData[
    \(425\)], "Print"],

Cell[BoxData[
    \(426\)], "Print"],

Cell[BoxData[
    \(427\)], "Print"],

Cell[BoxData[
    \(428\)], "Print"],

Cell[BoxData[
    \(429\)], "Print"],

Cell[BoxData[
    \(430\)], "Print"],

Cell[BoxData[
    \(431\)], "Print"],

Cell[BoxData[
    \(432\)], "Print"],

Cell[BoxData[
    \(433\)], "Print"],

Cell[BoxData[
    \(434\)], "Print"],

Cell[BoxData[
    \(435\)], "Print"],

Cell[BoxData[
    \(436\)], "Print"],

Cell[BoxData[
    \(437\)], "Print"],

Cell[BoxData[
    \(438\)], "Print"],

Cell[BoxData[
    \(439\)], "Print"],

Cell[BoxData[
    \(440\)], "Print"],

Cell[BoxData[
    \(441\)], "Print"],

Cell[BoxData[
    \(442\)], "Print"],

Cell[BoxData[
    \(443\)], "Print"],

Cell[BoxData[
    \(444\)], "Print"],

Cell[BoxData[
    \(445\)], "Print"],

Cell[BoxData[
    \(446\)], "Print"],

Cell[BoxData[
    \(447\)], "Print"],

Cell[BoxData[
    \(448\)], "Print"],

Cell[BoxData[
    \(449\)], "Print"],

Cell[BoxData[
    \(450\)], "Print"],

Cell[BoxData[
    \(451\)], "Print"],

Cell[BoxData[
    \(452\)], "Print"],

Cell[BoxData[
    \(453\)], "Print"],

Cell[BoxData[
    \(454\)], "Print"],

Cell[BoxData[
    \(455\)], "Print"],

Cell[BoxData[
    \(456\)], "Print"],

Cell[BoxData[
    \(457\)], "Print"],

Cell[BoxData[
    \(458\)], "Print"],

Cell[BoxData[
    \(459\)], "Print"],

Cell[BoxData[
    \(460\)], "Print"],

Cell[BoxData[
    \(461\)], "Print"],

Cell[BoxData[
    \(462\)], "Print"],

Cell[BoxData[
    \(463\)], "Print"],

Cell[BoxData[
    \(464\)], "Print"],

Cell[BoxData[
    \(465\)], "Print"],

Cell[BoxData[
    \(466\)], "Print"],

Cell[BoxData[
    \(467\)], "Print"],

Cell[BoxData[
    \(468\)], "Print"],

Cell[BoxData[
    \(469\)], "Print"],

Cell[BoxData[
    \(470\)], "Print"],

Cell[BoxData[
    \(471\)], "Print"],

Cell[BoxData[
    \(472\)], "Print"],

Cell[BoxData[
    \(473\)], "Print"],

Cell[BoxData[
    \(474\)], "Print"],

Cell[BoxData[
    \(475\)], "Print"],

Cell[BoxData[
    \(476\)], "Print"],

Cell[BoxData[
    \(477\)], "Print"],

Cell[BoxData[
    \(478\)], "Print"],

Cell[BoxData[
    \(479\)], "Print"],

Cell[BoxData[
    \(480\)], "Print"],

Cell[BoxData[
    \(481\)], "Print"],

Cell[BoxData[
    \(482\)], "Print"],

Cell[BoxData[
    \(483\)], "Print"],

Cell[BoxData[
    \(484\)], "Print"],

Cell[BoxData[
    \(485\)], "Print"],

Cell[BoxData[
    \(486\)], "Print"],

Cell[BoxData[
    \(487\)], "Print"],

Cell[BoxData[
    \(488\)], "Print"],

Cell[BoxData[
    \(489\)], "Print"],

Cell[BoxData[
    \(490\)], "Print"],

Cell[BoxData[
    \(491\)], "Print"],

Cell[BoxData[
    \(492\)], "Print"],

Cell[BoxData[
    \(493\)], "Print"],

Cell[BoxData[
    \(494\)], "Print"],

Cell[BoxData[
    \(495\)], "Print"],

Cell[BoxData[
    \(496\)], "Print"],

Cell[BoxData[
    \(497\)], "Print"],

Cell[BoxData[
    \(498\)], "Print"],

Cell[BoxData[
    \(499\)], "Print"],

Cell[BoxData[
    \(500\)], "Print"],

Cell[BoxData[
    \(501\)], "Print"],

Cell[BoxData[
    \(502\)], "Print"],

Cell[BoxData[
    \(503\)], "Print"],

Cell[BoxData[
    \(504\)], "Print"],

Cell[BoxData[
    \(505\)], "Print"],

Cell[BoxData[
    \(506\)], "Print"],

Cell[BoxData[
    \(507\)], "Print"],

Cell[BoxData[
    \(508\)], "Print"],

Cell[BoxData[
    \(509\)], "Print"],

Cell[BoxData[
    \(510\)], "Print"],

Cell[BoxData[
    \(511\)], "Print"],

Cell[BoxData[
    \(512\)], "Print"],

Cell[BoxData[
    \(513\)], "Print"],

Cell[BoxData[
    \(514\)], "Print"],

Cell[BoxData[
    \(515\)], "Print"],

Cell[BoxData[
    \(516\)], "Print"],

Cell[BoxData[
    \(517\)], "Print"],

Cell[BoxData[
    \(518\)], "Print"],

Cell[BoxData[
    \(519\)], "Print"],

Cell[BoxData[
    \(520\)], "Print"],

Cell[BoxData[
    \(521\)], "Print"],

Cell[BoxData[
    \(522\)], "Print"],

Cell[BoxData[
    \(523\)], "Print"],

Cell[BoxData[
    \(524\)], "Print"],

Cell[BoxData[
    \(525\)], "Print"],

Cell[BoxData[
    \(526\)], "Print"],

Cell[BoxData[
    \(527\)], "Print"],

Cell[BoxData[
    \(528\)], "Print"],

Cell[BoxData[
    \(529\)], "Print"],

Cell[BoxData[
    \(530\)], "Print"],

Cell[BoxData[
    \(531\)], "Print"],

Cell[BoxData[
    \(532\)], "Print"],

Cell[BoxData[
    \(533\)], "Print"],

Cell[BoxData[
    \(534\)], "Print"],

Cell[BoxData[
    \(535\)], "Print"],

Cell[BoxData[
    \(536\)], "Print"],

Cell[BoxData[
    \(537\)], "Print"],

Cell[BoxData[
    \(538\)], "Print"],

Cell[BoxData[
    \(539\)], "Print"],

Cell[BoxData[
    \(540\)], "Print"],

Cell[BoxData[
    \(541\)], "Print"],

Cell[BoxData[
    \(542\)], "Print"],

Cell[BoxData[
    \(543\)], "Print"],

Cell[BoxData[
    \(544\)], "Print"],

Cell[BoxData[
    \(545\)], "Print"],

Cell[BoxData[
    \(546\)], "Print"],

Cell[BoxData[
    \(547\)], "Print"],

Cell[BoxData[
    \(548\)], "Print"],

Cell[BoxData[
    \(549\)], "Print"],

Cell[BoxData[
    \(550\)], "Print"],

Cell[BoxData[
    \(551\)], "Print"],

Cell[BoxData[
    \(552\)], "Print"],

Cell[BoxData[
    \(553\)], "Print"],

Cell[BoxData[
    \(554\)], "Print"],

Cell[BoxData[
    \(555\)], "Print"],

Cell[BoxData[
    \(556\)], "Print"],

Cell[BoxData[
    \(557\)], "Print"],

Cell[BoxData[
    \(558\)], "Print"],

Cell[BoxData[
    \(559\)], "Print"],

Cell[BoxData[
    \(560\)], "Print"],

Cell[BoxData[
    \(561\)], "Print"],

Cell[BoxData[
    \(562\)], "Print"],

Cell[BoxData[
    \(563\)], "Print"],

Cell[BoxData[
    \(564\)], "Print"],

Cell[BoxData[
    \(565\)], "Print"],

Cell[BoxData[
    \(566\)], "Print"],

Cell[BoxData[
    \(567\)], "Print"],

Cell[BoxData[
    \(568\)], "Print"],

Cell[BoxData[
    \(569\)], "Print"],

Cell[BoxData[
    \(570\)], "Print"],

Cell[BoxData[
    \(571\)], "Print"],

Cell[BoxData[
    \(572\)], "Print"],

Cell[BoxData[
    \(573\)], "Print"],

Cell[BoxData[
    \(574\)], "Print"],

Cell[BoxData[
    \(575\)], "Print"],

Cell[BoxData[
    \(576\)], "Print"],

Cell[BoxData[
    \(577\)], "Print"],

Cell[BoxData[
    \(578\)], "Print"],

Cell[BoxData[
    \(579\)], "Print"],

Cell[BoxData[
    \(580\)], "Print"],

Cell[BoxData[
    \(581\)], "Print"],

Cell[BoxData[
    \(582\)], "Print"],

Cell[BoxData[
    \(583\)], "Print"],

Cell[BoxData[
    \(584\)], "Print"],

Cell[BoxData[
    \(585\)], "Print"],

Cell[BoxData[
    \(586\)], "Print"],

Cell[BoxData[
    \(587\)], "Print"],

Cell[BoxData[
    \(588\)], "Print"],

Cell[BoxData[
    \(589\)], "Print"],

Cell[BoxData[
    \(590\)], "Print"],

Cell[BoxData[
    \(591\)], "Print"],

Cell[BoxData[
    \(592\)], "Print"],

Cell[BoxData[
    \(593\)], "Print"],

Cell[BoxData[
    \(594\)], "Print"],

Cell[BoxData[
    \(595\)], "Print"],

Cell[BoxData[
    \(596\)], "Print"],

Cell[BoxData[
    \(597\)], "Print"],

Cell[BoxData[
    \(598\)], "Print"],

Cell[BoxData[
    \(599\)], "Print"],

Cell[BoxData[
    \(600\)], "Print"],

Cell[BoxData[
    \(601\)], "Print"],

Cell[BoxData[
    \(602\)], "Print"],

Cell[BoxData[
    \(603\)], "Print"],

Cell[BoxData[
    \(604\)], "Print"],

Cell[BoxData[
    \(605\)], "Print"],

Cell[BoxData[
    \(606\)], "Print"],

Cell[BoxData[
    \(607\)], "Print"],

Cell[BoxData[
    \(608\)], "Print"],

Cell[BoxData[
    \(609\)], "Print"],

Cell[BoxData[
    \(610\)], "Print"],

Cell[BoxData[
    \(611\)], "Print"],

Cell[BoxData[
    \(612\)], "Print"],

Cell[BoxData[
    \(613\)], "Print"],

Cell[BoxData[
    \(614\)], "Print"],

Cell[BoxData[
    \(615\)], "Print"],

Cell[BoxData[
    \(616\)], "Print"],

Cell[BoxData[
    \(617\)], "Print"],

Cell[BoxData[
    \(618\)], "Print"],

Cell[BoxData[
    \(619\)], "Print"],

Cell[BoxData[
    \(620\)], "Print"],

Cell[BoxData[
    \(621\)], "Print"],

Cell[BoxData[
    \(622\)], "Print"],

Cell[BoxData[
    \(623\)], "Print"],

Cell[BoxData[
    \(624\)], "Print"],

Cell[BoxData[
    \(625\)], "Print"],

Cell[BoxData[
    \(626\)], "Print"],

Cell[BoxData[
    \(627\)], "Print"],

Cell[BoxData[
    \(628\)], "Print"],

Cell[BoxData[
    \(629\)], "Print"],

Cell[BoxData[
    \(630\)], "Print"],

Cell[BoxData[
    \(631\)], "Print"],

Cell[BoxData[
    \(632\)], "Print"],

Cell[BoxData[
    \(633\)], "Print"],

Cell[BoxData[
    \(634\)], "Print"],

Cell[BoxData[
    \(635\)], "Print"],

Cell[BoxData[
    \(636\)], "Print"],

Cell[BoxData[
    \(637\)], "Print"],

Cell[BoxData[
    \(638\)], "Print"],

Cell[BoxData[
    \(639\)], "Print"],

Cell[BoxData[
    \(640\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "c1=ScatterPlot3D[Table[{X[1,t],Y[1,t],Z[1,t]},{t,0,640}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined->True,PlotStyle->{RGBColor[Random[],Random[],Random[]],\
Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "c2=ScatterPlot3D[Table[{X[2,t],Y[2,t],Z[2,t]},{t,0,640}],",
  StyleBox["BoxRatios-", "MR",
    FontWeight->"Bold"],
  StyleBox[">", "MR"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "c3=ScatterPlot3D[Table[{X[3,t],Y[3,t],Z[3,t]},{t,0,640}],",
  StyleBox["BoxRatios-", "MR",
    FontWeight->"Bold"],
  StyleBox[">", "MR"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "c4=ScatterPlot3D[Table[{X[4,t],Y[4,t],Z[4,t]},{t,0,640}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[c1,c2,c3,c4,DisplayFunction\[Rule]$DisplayFunction]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 7.7412e-017 1.16608 [
[.18373 .19058 -11.4488 -9 ]
[.18373 .19058 .55117 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.53771 .04117 -5.05869 -9 ]
[.53771 .04117 .94131 0 ]
[.00955 .82643 -6.92724 0 ]
[.00955 .82643 5.07276 9 ]
[.12079 .90442 -13.4221 0 ]
[.12079 .90442 10.5779 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31055 1.03745 -9.54626 0 ]
[.31055 1.03745 8.45374 9 ]
[.39213 1.09464 -3.11145 0 ]
[.39213 1.09464 2.88855 9 ]
[.05842 .35512 -24 -2.70009 ]
[.05842 .35512 0 6.29991 ]
[.0374 .48666 -24 -2.81772 ]
[.0374 .48666 0 6.18228 ]
[.01437 .63087 -24 -2.94789 ]
[.01437 .63087 0 6.05211 ]
[-0.01099 .78968 -6 -3.09272 ]
[-0.01099 .78968 0 5.90728 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.19353 .20137 m
.19843 .20677 L
s
[(-2)] .18373 .19058 .90814 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.54595 .05319 m
.55008 .0592 L
s
[(2)] .53771 .04117 .68623 1 Mshowa
.125 Mabswid
.23496 .18395 m
.23785 .18723 L
s
.2771 .16623 m
.27993 .16956 L
s
.31997 .14821 m
.32275 .15158 L
s
.40797 .11121 m
.41064 .11467 L
s
.45315 .09221 m
.45575 .09572 L
s
.49913 .07288 m
.50167 .07643 L
s
.1528 .2185 m
.15578 .22169 L
s
.11274 .23534 m
.11577 .23849 L
s
.59363 .03314 m
.59603 .0368 L
s
.64218 .01273 m
.64451 .01643 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(-1)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(-0.5)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(0.5)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(1)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.07195 .3497 m
.07872 .347 L
s
[(-300)] .05842 .35512 1 -0.39998 Mshowa
.05106 .48156 m
.05788 .47901 L
s
[(-200)] .0374 .48666 1 -0.37384 Mshowa
.02815 .62612 m
.03504 .62375 L
s
[(-100)] .01437 .63087 1 -0.34491 Mshowa
.00292 .78533 m
.00987 .78315 L
s
[(0)] -0.01099 .78968 1 -0.31273 Mshowa
.125 Mabswid
.06792 .37514 m
.07199 .37353 L
s
.06382 .40103 m
.06789 .39944 L
s
.05964 .42739 m
.06372 .42582 L
s
.05539 .45423 m
.05948 .45268 L
s
.04664 .5094 m
.05075 .50789 L
s
.04215 .53776 m
.04626 .53627 L
s
.03757 .56666 m
.04169 .56519 L
s
.0329 .5961 m
.03703 .59466 L
s
.0233 .65672 m
.02744 .65532 L
s
.01835 .68793 m
.0225 .68655 L
s
.01331 .71975 m
.01747 .71839 L
s
.00817 .75221 m
.01233 .75088 L
s
.07591 .32471 m
.07996 .32307 L
s
.0798 .30015 m
.08385 .2985 L
s
.08363 .27602 m
.08767 .27434 L
s
.08739 .25229 m
.09142 .2506 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.943 .561 .298 r
.015 w
.278 .48388 m
.27921 .48287 L
s
.27696 .48483 m
.278 .48388 L
s
.27611 .48572 m
.27696 .48483 L
s
.27921 .48287 m
.28061 .48178 L
s
.27546 .48653 m
.27611 .48572 L
s
.28061 .48178 m
.28217 .48064 L
s
.275 .48728 m
.27546 .48653 L
s
.28217 .48064 m
.2839 .47944 L
s
.27473 .48795 m
.275 .48728 L
s
.2839 .47944 m
.28578 .47818 L
s
.27467 .48856 m
.27473 .48795 L
s
.28578 .47818 m
.28781 .47687 L
s
.2748 .48909 m
.27467 .48856 L
s
.28781 .47687 m
.28999 .4755 L
s
.27514 .48955 m
.2748 .48909 L
s
.28999 .4755 m
.2923 .47408 L
s
.27567 .48995 m
.27514 .48955 L
s
.2923 .47408 m
.29473 .47262 L
s
.2764 .49028 m
.27567 .48995 L
s
.29473 .47262 m
.29728 .47111 L
s
.29728 .47111 m
.29995 .46956 L
s
.27731 .49054 m
.2764 .49028 L
s
.29995 .46956 m
.30271 .46797 L
s
.27842 .49073 m
.27731 .49054 L
s
.30271 .46797 m
.30556 .46635 L
s
.27971 .49086 m
.27842 .49073 L
s
.30556 .46635 m
.30849 .46469 L
s
.28118 .49093 m
.27971 .49086 L
s
.30849 .46469 m
.3115 .46301 L
s
.3115 .46301 m
.31457 .4613 L
s
.28281 .49094 m
.28118 .49093 L
s
.31457 .4613 m
.31769 .45958 L
s
.28461 .4909 m
.28281 .49094 L
s
.31769 .45958 m
.32086 .45783 L
s
.28657 .49081 m
.28461 .4909 L
s
.32086 .45783 m
.32405 .45607 L
s
.32405 .45607 m
.32728 .45429 L
s
.28867 .49066 m
.28657 .49081 L
s
.32728 .45429 m
.33052 .45251 L
s
.2909 .49047 m
.28867 .49066 L
s
.33052 .45251 m
.33376 .45073 L
s
.33376 .45073 m
.33701 .44894 L
s
.29327 .49024 m
.2909 .49047 L
s
.33701 .44894 m
.34024 .44715 L
s
.34024 .44715 m
.34346 .44537 L
s
.29576 .48997 m
.29327 .49024 L
s
.34346 .44537 m
.34666 .4436 L
s
.29836 .48966 m
.29576 .48997 L
s
.34666 .4436 m
.34982 .44183 L
s
.34982 .44183 m
.35295 .44007 L
s
.30106 .48932 m
.29836 .48966 L
s
.35295 .44007 m
.35604 .43833 L
s
.35604 .43833 m
.35908 .4366 L
s
.30385 .48894 m
.30106 .48932 L
s
.35908 .4366 m
.36207 .43489 L
s
.36207 .43489 m
.36501 .4332 L
s
.30673 .48855 m
.30385 .48894 L
s
.36501 .4332 m
.3679 .43152 L
s
.3679 .43152 m
.37072 .42987 L
s
.37072 .42987 m
.37349 .42823 L
s
.30967 .48813 m
.30673 .48855 L
s
.37349 .42823 m
.3762 .42661 L
s
.3762 .42661 m
.37884 .42502 L
s
.31268 .48769 m
.30967 .48813 L
s
.37884 .42502 m
.38143 .42345 L
s
.38143 .42345 m
.38395 .42189 L
s
.38395 .42189 m
.38641 .42036 L
s
.31574 .48724 m
.31268 .48769 L
s
.38641 .42036 m
.3888 .41886 L
s
.3888 .41886 m
.39114 .41737 L
s
.39114 .41737 m
.39341 .4159 L
s
.39341 .4159 m
.39562 .41446 L
s
.31885 .48677 m
.31574 .48724 L
s
.39562 .41446 m
.39778 .41303 L
s
.39778 .41303 m
.39987 .41163 L
s
.39987 .41163 m
.40191 .41024 L
s
.40191 .41024 m
.40388 .40888 L
s
.32199 .48629 m
.31885 .48677 L
s
.40388 .40888 m
.40581 .40753 L
s
.40581 .40753 m
.40767 .40621 L
s
.40767 .40621 m
.40948 .4049 L
s
.40948 .4049 m
.41124 .40361 L
s
.41124 .40361 m
.41295 .40234 L
s
.41295 .40234 m
.4146 .40109 L
s
.4146 .40109 m
.41621 .39985 L
s
.41621 .39985 m
.41776 .39863 L
s
.32515 .48581 m
.32199 .48629 L
s
.41776 .39863 m
.41926 .39743 L
s
.43367 .38427 m
.43457 .38327 L
s
.41926 .39743 m
.42072 .39625 L
s
.43271 .38528 m
.43367 .38427 L
s
.42072 .39625 m
.42213 .39508 L
s
.43172 .38631 m
.43271 .38528 L
s
.42213 .39508 m
.42349 .39393 L
s
.43068 .38735 m
.43172 .38631 L
s
.42349 .39393 m
.4248 .39279 L
s
.42959 .38841 m
.43068 .38735 L
s
.4248 .39279 m
.42607 .39167 L
s
.42846 .38948 m
.42959 .38841 L
s
.42607 .39167 m
.42729 .39057 L
s
.42729 .39057 m
.42846 .38948 L
s
.801 .162 .719 r
.44518 .37532 m
.4452 .37464 L
s
.44516 .37601 m
.44518 .37532 L
s
.943 .561 .298 r
.32834 .48533 m
.32515 .48581 L
s
.801 .162 .719 r
.44514 .3767 m
.44516 .37601 L
s
.44512 .37739 m
.44514 .3767 L
s
.4451 .37809 m
.44512 .37739 L
s
.44508 .37878 m
.4451 .37809 L
s
.943 .561 .298 r
.33153 .48484 m
.32834 .48533 L
s
.801 .162 .719 r
.44506 .37947 m
.44508 .37878 L
s
.44504 .38017 m
.44506 .37947 L
s
.44503 .38086 m
.44504 .38017 L
s
.943 .561 .298 r
.33472 .48436 m
.33153 .48484 L
s
.801 .162 .719 r
.44501 .38156 m
.44503 .38086 L
s
.44499 .38225 m
.44501 .38156 L
s
.44497 .38295 m
.44499 .38225 L
s
.44495 .38365 m
.44497 .38295 L
s
.943 .561 .298 r
.33791 .48389 m
.33472 .48436 L
s
.801 .162 .719 r
.44493 .38435 m
.44495 .38365 L
s
.44491 .38505 m
.44493 .38435 L
s
.44489 .38575 m
.44491 .38505 L
s
.44487 .38645 m
.44489 .38575 L
s
.943 .561 .298 r
.34108 .48342 m
.33791 .48389 L
s
.801 .162 .719 r
.44485 .38715 m
.44487 .38645 L
s
.44483 .38786 m
.44485 .38715 L
s
.44481 .38856 m
.44483 .38786 L
s
.943 .561 .298 r
.34423 .48296 m
.34108 .48342 L
s
.801 .162 .719 r
.44479 .38927 m
.44481 .38856 L
s
.44477 .38998 m
.44479 .38927 L
s
.44475 .39068 m
.44477 .38998 L
s
.44473 .39139 m
.44475 .39068 L
s
.943 .561 .298 r
.34735 .48251 m
.34423 .48296 L
s
.801 .162 .719 r
.44471 .3921 m
.44473 .39139 L
s
.44469 .39281 m
.44471 .3921 L
s
.44467 .39352 m
.44469 .39281 L
s
.943 .561 .298 r
.35044 .48208 m
.34735 .48251 L
s
.801 .162 .719 r
.44465 .39423 m
.44467 .39352 L
s
.44463 .39495 m
.44465 .39423 L
s
.44461 .39566 m
.44463 .39495 L
s
.44459 .39637 m
.44461 .39566 L
s
.943 .561 .298 r
.35349 .48167 m
.35044 .48208 L
s
.801 .162 .719 r
.44457 .39709 m
.44459 .39637 L
s
.44455 .3978 m
.44457 .39709 L
s
.44453 .39852 m
.44455 .3978 L
s
.943 .561 .298 r
.3565 .48127 m
.35349 .48167 L
s
.801 .162 .719 r
.44451 .39924 m
.44453 .39852 L
s
.44449 .39995 m
.44451 .39924 L
s
.44447 .40067 m
.44449 .39995 L
s
.943 .561 .298 r
.35947 .48089 m
.3565 .48127 L
s
.801 .162 .719 r
.44445 .40139 m
.44447 .40067 L
s
.44443 .40211 m
.44445 .40139 L
s
.44441 .40282 m
.44443 .40211 L
s
.44439 .40354 m
.44441 .40282 L
s
.943 .561 .298 r
.36238 .48052 m
.35947 .48089 L
s
.801 .162 .719 r
.44437 .40426 m
.44439 .40354 L
s
.44435 .40498 m
.44437 .40426 L
s
.44433 .40569 m
.44435 .40498 L
s
.943 .561 .298 r
.36525 .48018 m
.36238 .48052 L
s
.801 .162 .719 r
.44431 .40641 m
.44433 .40569 L
s
.44429 .40713 m
.44431 .40641 L
s
.44427 .40785 m
.44429 .40713 L
s
.943 .561 .298 r
.36805 .47986 m
.36525 .48018 L
s
.801 .162 .719 r
.44425 .40856 m
.44427 .40785 L
s
.44423 .40928 m
.44425 .40856 L
s
.44421 .40999 m
.44423 .40928 L
s
.44419 .41071 m
.44421 .40999 L
s
.943 .561 .298 r
.37081 .47956 m
.36805 .47986 L
s
.801 .162 .719 r
.44417 .41142 m
.44419 .41071 L
s
.44415 .41214 m
.44417 .41142 L
s
.44413 .41285 m
.44415 .41214 L
s
.943 .561 .298 r
.3735 .47929 m
.37081 .47956 L
s
.801 .162 .719 r
.44411 .41356 m
.44413 .41285 L
s
.44409 .41427 m
.44411 .41356 L
s
.44407 .41498 m
.44409 .41427 L
s
.943 .561 .298 r
.37614 .47903 m
.3735 .47929 L
s
.801 .162 .719 r
.44405 .4157 m
.44407 .41498 L
s
.44403 .41641 m
.44405 .4157 L
s
.44401 .41712 m
.44403 .41641 L
s
.943 .561 .298 r
.37872 .4788 m
.37614 .47903 L
s
.801 .162 .719 r
.44399 .41783 m
.44401 .41712 L
s
.44397 .41853 m
.44399 .41783 L
s
.44395 .41924 m
.44397 .41853 L
s
.943 .561 .298 r
.38124 .47859 m
.37872 .4788 L
s
.801 .162 .719 r
.44393 .41995 m
.44395 .41924 L
s
.44391 .42066 m
.44393 .41995 L
s
.44389 .42137 m
.44391 .42066 L
s
.943 .561 .298 r
.3837 .47841 m
.38124 .47859 L
s
.801 .162 .719 r
.44387 .42208 m
.44389 .42137 L
s
.44385 .42279 m
.44387 .42208 L
s
.44383 .42349 m
.44385 .42279 L
s
.943 .561 .298 r
.3861 .47824 m
.3837 .47841 L
s
.801 .162 .719 r
.44381 .4242 m
.44383 .42349 L
s
.44379 .42491 m
.44381 .4242 L
s
.44377 .42562 m
.44379 .42491 L
s
.943 .561 .298 r
.38843 .4781 m
.3861 .47824 L
s
.801 .162 .719 r
.44375 .42633 m
.44377 .42562 L
s
.44373 .42704 m
.44375 .42633 L
s
.44371 .42775 m
.44373 .42704 L
s
.943 .561 .298 r
.39071 .47799 m
.38843 .4781 L
s
.801 .162 .719 r
.44369 .42846 m
.44371 .42775 L
s
.44367 .42917 m
.44369 .42846 L
s
.44365 .42988 m
.44367 .42917 L
s
.943 .561 .298 r
.39293 .47789 m
.39071 .47799 L
s
.801 .162 .719 r
.44363 .43059 m
.44365 .42988 L
s
.44361 .4313 m
.44363 .43059 L
s
.44359 .43202 m
.44361 .4313 L
s
.943 .561 .298 r
.39509 .47782 m
.39293 .47789 L
s
.801 .162 .719 r
.44357 .43273 m
.44359 .43202 L
s
.44355 .43344 m
.44357 .43273 L
s
.943 .561 .298 r
.39719 .47777 m
.39509 .47782 L
s
.801 .162 .719 r
.44353 .43416 m
.44355 .43344 L
s
.44351 .43487 m
.44353 .43416 L
s
.44349 .43559 m
.44351 .43487 L
s
.943 .561 .298 r
.39923 .47774 m
.39719 .47777 L
s
.801 .162 .719 r
.44347 .43631 m
.44349 .43559 L
s
.44345 .43703 m
.44347 .43631 L
s
.44343 .43775 m
.44345 .43703 L
s
.943 .561 .298 r
.40122 .47773 m
.39923 .47774 L
s
.801 .162 .719 r
.44341 .43847 m
.44343 .43775 L
s
.44339 .43919 m
.44341 .43847 L
s
.943 .561 .298 r
.40315 .47775 m
.40122 .47773 L
s
.801 .162 .719 r
.44337 .43991 m
.44339 .43919 L
s
.44335 .44064 m
.44337 .43991 L
s
.44333 .44136 m
.44335 .44064 L
s
.943 .561 .298 r
.40503 .47778 m
.40315 .47775 L
s
.801 .162 .719 r
.44331 .44209 m
.44333 .44136 L
s
.44329 .44282 m
.44331 .44209 L
s
.943 .561 .298 r
.40685 .47784 m
.40503 .47778 L
s
.801 .162 .719 r
.44327 .44355 m
.44329 .44282 L
s
.44325 .44428 m
.44327 .44355 L
s
.44323 .44501 m
.44325 .44428 L
s
.943 .561 .298 r
.40861 .47791 m
.40685 .47784 L
s
.801 .162 .719 r
.44321 .44575 m
.44323 .44501 L
s
.44319 .44648 m
.44321 .44575 L
s
.943 .561 .298 r
.41033 .47801 m
.40861 .47791 L
s
.801 .162 .719 r
.44317 .44722 m
.44319 .44648 L
s
.44314 .44795 m
.44317 .44722 L
s
.943 .561 .298 r
.41199 .47813 m
.41033 .47801 L
s
.801 .162 .719 r
.44312 .44869 m
.44314 .44795 L
s
.4431 .44943 m
.44312 .44869 L
s
.44308 .45017 m
.4431 .44943 L
s
.943 .561 .298 r
.4136 .47826 m
.41199 .47813 L
s
.801 .162 .719 r
.44306 .45092 m
.44308 .45017 L
s
.44304 .45166 m
.44306 .45092 L
s
.943 .561 .298 r
.41515 .47842 m
.4136 .47826 L
s
.801 .162 .719 r
.44302 .4524 m
.44304 .45166 L
s
.443 .45315 m
.44302 .4524 L
s
.943 .561 .298 r
.41666 .4786 m
.41515 .47842 L
s
.801 .162 .719 r
.44298 .45389 m
.443 .45315 L
s
.44296 .45464 m
.44298 .45389 L
s
.943 .561 .298 r
.41812 .47879 m
.41666 .4786 L
s
.801 .162 .719 r
.44294 .45539 m
.44296 .45464 L
s
.44291 .45614 m
.44294 .45539 L
s
.943 .561 .298 r
.41952 .479 m
.41812 .47879 L
s
.801 .162 .719 r
.44289 .45689 m
.44291 .45614 L
s
.44287 .45763 m
.44289 .45689 L
s
.943 .561 .298 r
.42088 .47924 m
.41952 .479 L
s
.801 .162 .719 r
.44285 .45838 m
.44287 .45763 L
s
.44283 .45913 m
.44285 .45838 L
s
.943 .561 .298 r
.42219 .47949 m
.42088 .47924 L
s
.801 .162 .719 r
.44281 .45988 m
.44283 .45913 L
s
.44279 .46063 m
.44281 .45988 L
s
.27008 .61853 m
.27134 .61747 L
s
.26902 .61952 m
.27008 .61853 L
s
.26817 .62044 m
.26902 .61952 L
s
.27134 .61747 m
.2728 .61634 L
s
.26754 .62129 m
.26817 .62044 L
s
.2728 .61634 m
.27445 .61515 L
s
.943 .561 .298 r
.42345 .47976 m
.42219 .47949 L
s
.801 .162 .719 r
.44277 .46138 m
.44279 .46063 L
s
.26713 .62207 m
.26754 .62129 L
s
.27445 .61515 m
.27628 .6139 L
s
.26693 .62277 m
.26713 .62207 L
s
.27628 .6139 m
.27827 .6126 L
s
.44275 .46213 m
.44277 .46138 L
s
.26696 .6234 m
.26693 .62277 L
s
.27827 .6126 m
.28042 .61124 L
s
.943 .561 .298 r
.42466 .48005 m
.42345 .47976 L
s
.801 .162 .719 r
.44273 .46289 m
.44275 .46213 L
s
.26722 .62396 m
.26696 .6234 L
s
.28042 .61124 m
.28273 .60982 L
s
.4427 .46364 m
.44273 .46289 L
s
.26769 .62445 m
.26722 .62396 L
s
.28273 .60982 m
.28518 .60836 L
s
.943 .561 .298 r
.42583 .48035 m
.42466 .48005 L
s
.801 .162 .719 r
.44268 .46439 m
.4427 .46364 L
s
.28518 .60836 m
.28777 .60684 L
s
.26839 .62486 m
.26769 .62445 L
s
.44266 .46514 m
.44268 .46439 L
s
.28777 .60684 m
.29047 .60529 L
s
.943 .561 .298 r
.42694 .48068 m
.42583 .48035 L
s
.801 .162 .719 r
.44264 .46589 m
.44266 .46514 L
s
.2693 .62521 m
.26839 .62486 L
s
.29047 .60529 m
.29329 .6037 L
s
.44262 .46664 m
.44264 .46589 L
s
.943 .561 .298 r
.42801 .48102 m
.42694 .48068 L
s
.801 .162 .719 r
.27042 .62549 m
.2693 .62521 L
s
.4426 .46739 m
.44262 .46664 L
s
.29329 .6037 m
.29622 .60206 L
s
.44258 .46814 m
.4426 .46739 L
s
.943 .561 .298 r
.42903 .48138 m
.42801 .48102 L
s
.801 .162 .719 r
.27175 .6257 m
.27042 .62549 L
s
.76 .35 .299 r
.61007 .31501 m
.61005 .31431 L
s
.801 .162 .719 r
.29622 .60206 m
.29924 .6004 L
s
.44256 .46889 m
.44258 .46814 L
s
.76 .35 .299 r
.61009 .3157 m
.61007 .31501 L
s
.801 .162 .719 r
.44254 .46964 m
.44256 .46889 L
s
.943 .561 .298 r
.43 .48176 m
.42903 .48138 L
s
.801 .162 .719 r
.29924 .6004 m
.30234 .5987 L
s
.27328 .62585 m
.27175 .6257 L
s
.76 .35 .299 r
.61011 .3164 m
.61009 .3157 L
s
.801 .162 .719 r
.44251 .47039 m
.44254 .46964 L
s
.76 .35 .299 r
.61013 .3171 m
.61011 .3164 L
s
.801 .162 .719 r
.30234 .5987 m
.30551 .59698 L
s
.943 .561 .298 r
.43093 .48216 m
.43 .48176 L
s
.801 .162 .719 r
.44249 .47114 m
.44251 .47039 L
s
.76 .35 .299 r
.61015 .3178 m
.61013 .3171 L
s
.801 .162 .719 r
.275 .62594 m
.27328 .62585 L
s
.44247 .47189 m
.44249 .47114 L
s
.30551 .59698 m
.30875 .59524 L
s
.76 .35 .299 r
.61017 .3185 m
.61015 .3178 L
s
.943 .561 .298 r
.43181 .48258 m
.43093 .48216 L
s
.801 .162 .719 r
.44245 .47264 m
.44247 .47189 L
s
.76 .35 .299 r
.61019 .3192 m
.61017 .3185 L
s
.801 .162 .719 r
.2769 .62598 m
.275 .62594 L
s
.44243 .47339 m
.44245 .47264 L
s
.30875 .59524 m
.31203 .59347 L
s
.943 .561 .298 r
.43264 .48301 m
.43181 .48258 L
s
.76 .35 .299 r
.61021 .3199 m
.61019 .3192 L
s
.801 .162 .719 r
.44241 .47413 m
.44243 .47339 L
s
.76 .35 .299 r
.61023 .3206 m
.61021 .3199 L
s
.801 .162 .719 r
.31203 .59347 m
.31537 .59169 L
s
.943 .561 .298 r
.43342 .48346 m
.43264 .48301 L
s
.801 .162 .719 r
.44239 .47488 m
.44241 .47413 L
s
.27897 .62596 m
.2769 .62598 L
s
.76 .35 .299 r
.61025 .32131 m
.61023 .3206 L
s
.801 .162 .719 r
.44237 .47563 m
.44239 .47488 L
s
.76 .35 .299 r
.61027 .32201 m
.61025 .32131 L
s
.943 .561 .298 r
.43416 .48393 m
.43342 .48346 L
s
.801 .162 .719 r
.31537 .59169 m
.31873 .58989 L
s
.44234 .47638 m
.44237 .47563 L
s
.76 .35 .299 r
.61029 .32272 m
.61027 .32201 L
s
.801 .162 .719 r
.28121 .62589 m
.27897 .62596 L
s
.44232 .47713 m
.44234 .47638 L
s
.943 .561 .298 r
.43485 .48442 m
.43416 .48393 L
s
.801 .162 .719 r
.31873 .58989 m
.32212 .58808 L
s
.76 .35 .299 r
.61031 .32342 m
.61029 .32272 L
s
.801 .162 .719 r
.4423 .47788 m
.44232 .47713 L
s
.76 .35 .299 r
.61033 .32413 m
.61031 .32342 L
s
.943 .561 .298 r
.4355 .48492 m
.43485 .48442 L
s
.801 .162 .719 r
.44228 .47863 m
.4423 .47788 L
s
.32212 .58808 m
.32553 .58627 L
s
.76 .35 .299 r
.61035 .32484 m
.61033 .32413 L
s
.801 .162 .719 r
.28359 .62577 m
.28121 .62589 L
s
.44226 .47938 m
.44228 .47863 L
s
.943 .561 .298 r
.43611 .48544 m
.4355 .48492 L
s
.76 .35 .299 r
.61038 .32555 m
.61035 .32484 L
s
.526 .271 .006 r
.62239 .31541 m
.62142 .31507 L
s
.801 .162 .719 r
.32553 .58627 m
.32893 .58445 L
s
.44224 .48012 m
.44226 .47938 L
s
.76 .35 .299 r
.6104 .32626 m
.61038 .32555 L
s
.943 .561 .298 r
.43666 .48597 m
.43611 .48544 L
s
.801 .162 .719 r
.44221 .48087 m
.44224 .48012 L
s
.76 .35 .299 r
.61042 .32697 m
.6104 .32626 L
s
.801 .162 .719 r
.2861 .62562 m
.28359 .62577 L
s
.526 .271 .006 r
.62341 .31572 m
.62239 .31541 L
s
.801 .162 .719 r
.32893 .58445 m
.33234 .58262 L
s
.44219 .48162 m
.44221 .48087 L
s
.943 .561 .298 r
.43718 .48653 m
.43666 .48597 L
s
.76 .35 .299 r
.61044 .32768 m
.61042 .32697 L
s
.801 .162 .719 r
.44217 .48237 m
.44219 .48162 L
s
.526 .271 .006 r
.62448 .31602 m
.62341 .31572 L
s
.76 .35 .299 r
.61046 .32839 m
.61044 .32768 L
s
.943 .561 .298 r
.43766 .48709 m
.43718 .48653 L
s
.801 .162 .719 r
.33234 .58262 m
.33573 .5808 L
s
.44214 .48312 m
.44217 .48237 L
s
.28875 .62543 m
.2861 .62562 L
s
.76 .35 .299 r
.61048 .3291 m
.61046 .32839 L
s
.943 .561 .298 r
.4381 .48767 m
.43766 .48709 L
s
.801 .162 .719 r
.44212 .48387 m
.44214 .48312 L
s
.526 .271 .006 r
.62561 .3163 m
.62448 .31602 L
s
.801 .162 .719 r
.33573 .5808 m
.33911 .57899 L
s
.76 .35 .299 r
.6105 .32982 m
.61048 .3291 L
s
.801 .162 .719 r
.44209 .48462 m
.44212 .48387 L
s
.943 .561 .298 r
.43851 .48826 m
.4381 .48767 L
s
.76 .35 .299 r
.61052 .33053 m
.6105 .32982 L
s
.526 .271 .006 r
.62678 .31656 m
.62561 .3163 L
s
.801 .162 .719 r
.33911 .57899 m
.34246 .57718 L
s
.44207 .48537 m
.44209 .48462 L
s
.76 .35 .299 r
.61054 .33125 m
.61052 .33053 L
s
.801 .162 .719 r
.29151 .6252 m
.28875 .62543 L
s
.943 .561 .298 r
.43888 .48887 m
.43851 .48826 L
s
.801 .162 .719 r
.44204 .48612 m
.44207 .48537 L
s
.76 .35 .299 r
.61057 .33197 m
.61054 .33125 L
s
.526 .271 .006 r
.62799 .3168 m
.62678 .31656 L
s
.801 .162 .719 r
.34246 .57718 m
.34578 .57538 L
s
.943 .561 .298 r
.43922 .48949 m
.43888 .48887 L
s
.801 .162 .719 r
.44201 .48687 m
.44204 .48612 L
s
.76 .35 .299 r
.61059 .33269 m
.61057 .33197 L
s
.801 .162 .719 r
.44198 .48762 m
.44201 .48687 L
s
.943 .561 .298 r
.43952 .49012 m
.43922 .48949 L
s
.76 .35 .299 r
.61061 .33341 m
.61059 .33269 L
s
.801 .162 .719 r
.34578 .57538 m
.34906 .57359 L
s
.526 .271 .006 r
.62926 .31703 m
.62799 .3168 L
s
.801 .162 .719 r
.29438 .62494 m
.29151 .6252 L
s
.44195 .48837 m
.44198 .48762 L
s
.943 .561 .298 r
.43979 .49076 m
.43952 .49012 L
s
.76 .35 .299 r
.61063 .33413 m
.61061 .33341 L
s
.801 .162 .719 r
.44192 .48913 m
.44195 .48837 L
s
.34906 .57359 m
.35229 .57181 L
s
.526 .271 .006 r
.63058 .31723 m
.62926 .31703 L
s
.76 .35 .299 r
.61065 .33485 m
.61063 .33413 L
s
.943 .561 .298 r
.44003 .49141 m
.43979 .49076 L
s
.801 .162 .719 r
.44188 .48988 m
.44192 .48913 L
s
.76 .35 .299 r
.61067 .33557 m
.61065 .33485 L
s
.801 .162 .719 r
.35229 .57181 m
.35548 .57005 L
s
.943 .561 .298 r
.44025 .49208 m
.44003 .49141 L
s
.801 .162 .719 r
.29734 .62465 m
.29438 .62494 L
s
.44185 .49064 m
.44188 .48988 L
s
.526 .271 .006 r
.63196 .31742 m
.63058 .31723 L
s
.76 .35 .299 r
.61069 .33629 m
.61067 .33557 L
s
.943 .561 .298 r
.44043 .49275 m
.44025 .49208 L
s
.801 .162 .719 r
.4418 .49139 m
.44185 .49064 L
s
.35548 .57005 m
.35862 .5683 L
s
.76 .35 .299 r
.61071 .33701 m
.61069 .33629 L
s
.801 .162 .719 r
.44176 .49215 m
.4418 .49139 L
s
.943 .561 .298 r
.4406 .49343 m
.44043 .49275 L
s
.526 .271 .006 r
.63338 .31759 m
.63196 .31742 L
s
.76 .35 .299 r
.61074 .33774 m
.61071 .33701 L
s
.801 .162 .719 r
.35862 .5683 m
.3617 .56657 L
s
.44171 .49291 m
.44176 .49215 L
s
.30039 .62434 m
.29734 .62465 L
s
.943 .561 .298 r
.44074 .49412 m
.4406 .49343 L
s
.76 .35 .299 r
.61076 .33846 m
.61074 .33774 L
s
.801 .162 .719 r
.44165 .49367 m
.44171 .49291 L
s
.943 .561 .298 r
.44086 .49481 m
.44074 .49412 L
s
.526 .271 .006 r
.63485 .31774 m
.63338 .31759 L
s
.801 .162 .719 r
.3617 .56657 m
.36472 .56485 L
s
.76 .35 .299 r
.61078 .33918 m
.61076 .33846 L
s
.801 .162 .719 r
.44159 .49444 m
.44165 .49367 L
s
.943 .561 .298 r
.44097 .49552 m
.44086 .49481 L
s
.76 .35 .299 r
.6108 .33991 m
.61078 .33918 L
s
.801 .162 .719 r
.36472 .56485 m
.36768 .56316 L
s
.44151 .49521 m
.44159 .49444 L
s
.526 .271 .006 r
.63638 .31786 m
.63485 .31774 L
s
.801 .162 .719 r
.30351 .62401 m
.30039 .62434 L
s
.943 .561 .298 r
.44107 .49623 m
.44097 .49552 L
s
.76 .35 .299 r
.61082 .34063 m
.6108 .33991 L
s
.801 .162 .719 r
.44143 .49598 m
.44151 .49521 L
s
.36768 .56316 m
.37057 .56148 L
s
.76 .35 .299 r
.61084 .34136 m
.61082 .34063 L
s
.943 .561 .298 r
.44115 .49694 m
.44107 .49623 L
s
.801 .162 .719 r
.44134 .49676 m
.44143 .49598 L
s
.526 .271 .006 r
.63796 .31797 m
.63638 .31786 L
s
.801 .162 .719 r
.37057 .56148 m
.37341 .55983 L
s
.76 .35 .299 r
.61086 .34209 m
.61084 .34136 L
s
.801 .162 .719 r
.44123 .49754 m
.44134 .49676 L
s
.943 .561 .298 r
.44121 .49766 m
.44115 .49694 L
s
.801 .162 .719 r
.44111 .49832 m
.44123 .49754 L
s
.76 .35 .299 r
.61089 .34281 m
.61086 .34209 L
s
.943 .561 .298 r
.44127 .49839 m
.44121 .49766 L
s
.801 .162 .719 r
.37341 .55983 m
.37618 .55819 L
s
.3067 .62366 m
.30351 .62401 L
s
.44097 .49911 m
.44111 .49832 L
s
.526 .271 .006 r
.6396 .31806 m
.63796 .31797 L
s
.76 .35 .299 r
.61091 .34354 m
.61089 .34281 L
s
.943 .561 .298 r
.44131 .49912 m
.44127 .49839 L
s
.801 .162 .719 r
.37618 .55819 m
.37888 .55658 L
s
.44082 .49991 m
.44097 .49911 L
s
.76 .35 .299 r
.61093 .34426 m
.61091 .34354 L
s
.943 .561 .298 r
.44135 .49986 m
.44131 .49912 L
s
.801 .162 .719 r
.37888 .55658 m
.38152 .55499 L
s
.44065 .50071 m
.44082 .49991 L
s
.76 .35 .299 r
.61095 .34499 m
.61093 .34426 L
s
.526 .271 .006 r
.64129 .31813 m
.6396 .31806 L
s
.943 .561 .298 r
.44138 .50059 m
.44135 .49986 L
s
.801 .162 .719 r
.44045 .50152 m
.44065 .50071 L
s
.38152 .55499 m
.38409 .55341 L
s
.30993 .6233 m
.3067 .62366 L
s
.76 .35 .299 r
.61097 .34571 m
.61095 .34499 L
s
.943 .561 .298 r
.4414 .50133 m
.44138 .50059 L
s
.801 .162 .719 r
.44023 .50234 m
.44045 .50152 L
s
.38409 .55341 m
.3866 .55186 L
s
.76 .35 .299 r
.61099 .34644 m
.61097 .34571 L
s
.801 .162 .719 r
.43997 .50316 m
.44023 .50234 L
s
.526 .271 .006 r
.64304 .31818 m
.64129 .31813 L
s
.943 .561 .298 r
.44141 .50208 m
.4414 .50133 L
s
.801 .162 .719 r
.3866 .55186 m
.38903 .55033 L
s
.43969 .504 m
.43997 .50316 L
s
.76 .35 .299 r
.61101 .34716 m
.61099 .34644 L
s
.943 .561 .298 r
.44142 .50282 m
.44141 .50208 L
s
.801 .162 .719 r
.38903 .55033 m
.39141 .54882 L
s
.43937 .50485 m
.43969 .504 L
s
.76 .35 .299 r
.61104 .34789 m
.61101 .34716 L
s
.801 .162 .719 r
.31321 .62293 m
.30993 .6233 L
s
.943 .561 .298 r
.44143 .50357 m
.44142 .50282 L
s
.526 .271 .006 r
.64485 .3182 m
.64304 .31818 L
s
.801 .162 .719 r
.43902 .50572 m
.43937 .50485 L
s
.39141 .54882 m
.39371 .54733 L
s
.76 .35 .299 r
.61106 .34861 m
.61104 .34789 L
s
.801 .162 .719 r
.43863 .50659 m
.43902 .50572 L
s
.943 .561 .298 r
.44143 .50432 m
.44143 .50357 L
s
.801 .162 .719 r
.39371 .54733 m
.39595 .54586 L
s
.4382 .50748 m
.43863 .50659 L
s
.76 .35 .299 r
.61108 .34934 m
.61106 .34861 L
s
.801 .162 .719 r
.39595 .54586 m
.39813 .54441 L
s
.943 .561 .298 r
.44143 .50507 m
.44143 .50432 L
s
.801 .162 .719 r
.43772 .50838 m
.4382 .50748 L
s
.526 .271 .006 r
.64672 .31821 m
.64485 .3182 L
s
.801 .162 .719 r
.39813 .54441 m
.40025 .54299 L
s
.76 .35 .299 r
.6111 .35006 m
.61108 .34934 L
s
.801 .162 .719 r
.43721 .5093 m
.43772 .50838 L
s
.943 .561 .298 r
.44142 .50582 m
.44143 .50507 L
s
.801 .162 .719 r
.40025 .54299 m
.4023 .54158 L
s
.31653 .62255 m
.31321 .62293 L
s
.43666 .51023 m
.43721 .5093 L
s
.76 .35 .299 r
.61112 .35078 m
.6111 .35006 L
s
.801 .162 .719 r
.4023 .54158 m
.40429 .54019 L
s
.943 .561 .298 r
.44142 .50657 m
.44142 .50582 L
s
.801 .162 .719 r
.43607 .51117 m
.43666 .51023 L
s
.40429 .54019 m
.40623 .53882 L
s
.43542 .51213 m
.43607 .51117 L
s
.76 .35 .299 r
.61114 .35151 m
.61112 .35078 L
s
.526 .271 .006 r
.64864 .31819 m
.64672 .31821 L
s
.801 .162 .719 r
.40623 .53882 m
.4081 .53747 L
s
.943 .561 .298 r
.44141 .50733 m
.44142 .50657 L
s
.801 .162 .719 r
.43473 .51311 m
.43542 .51213 L
s
.4081 .53747 m
.40991 .53613 L
s
.43398 .5141 m
.43473 .51311 L
s
.76 .35 .299 r
.61116 .35223 m
.61114 .35151 L
s
.801 .162 .719 r
.40991 .53613 m
.41167 .53482 L
s
.43319 .51511 m
.43398 .5141 L
s
.943 .561 .298 r
.4414 .50809 m
.44141 .50733 L
s
.801 .162 .719 r
.41167 .53482 m
.41337 .53352 L
s
.43234 .51614 m
.43319 .51511 L
s
.76 .35 .299 r
.61119 .35295 m
.61116 .35223 L
s
.801 .162 .719 r
.41337 .53352 m
.41501 .53224 L
s
.43144 .51718 m
.43234 .51614 L
s
.43049 .51824 m
.43144 .51718 L
s
.41501 .53224 m
.41659 .53098 L
s
.943 .561 .298 r
.44138 .50884 m
.4414 .50809 L
s
.801 .162 .719 r
.31986 .62217 m
.31653 .62255 L
s
.526 .271 .006 r
.65063 .31815 m
.64864 .31819 L
s
.801 .162 .719 r
.4295 .51931 m
.43049 .51824 L
s
.41659 .53098 m
.41813 .52974 L
s
.42844 .5204 m
.4295 .51931 L
s
.41813 .52974 m
.4196 .52851 L
s
.42734 .52151 m
.42844 .5204 L
s
.4196 .52851 m
.42102 .5273 L
s
.76 .35 .299 r
.61121 .35367 m
.61119 .35295 L
s
.801 .162 .719 r
.42618 .52264 m
.42734 .52151 L
s
.42102 .5273 m
.42239 .52611 L
s
.42497 .52378 m
.42618 .52264 L
s
.42239 .52611 m
.42371 .52494 L
s
.42371 .52494 m
.42497 .52378 L
s
.943 .561 .298 r
.44137 .5096 m
.44138 .50884 L
s
.76 .35 .299 r
.61123 .35439 m
.61121 .35367 L
s
.943 .561 .298 r
.44136 .51036 m
.44137 .5096 L
s
.526 .271 .006 r
.65268 .31809 m
.65063 .31815 L
s
.76 .35 .299 r
.61125 .35511 m
.61123 .35439 L
s
.943 .561 .298 r
.44134 .51113 m
.44136 .51036 L
s
.76 .35 .299 r
.61127 .35583 m
.61125 .35511 L
s
.801 .162 .719 r
.32322 .62178 m
.31986 .62217 L
s
.943 .561 .298 r
.44132 .51189 m
.44134 .51113 L
s
.76 .35 .299 r
.61129 .35655 m
.61127 .35583 L
s
.526 .271 .006 r
.6548 .318 m
.65268 .31809 L
s
.943 .561 .298 r
.44131 .51265 m
.44132 .51189 L
s
.76 .35 .299 r
.61131 .35727 m
.61129 .35655 L
s
.943 .561 .298 r
.44129 .51342 m
.44131 .51265 L
s
.76 .35 .299 r
.61133 .35798 m
.61131 .35727 L
s
.943 .561 .298 r
.44127 .51418 m
.44129 .51342 L
s
.801 .162 .719 r
.32658 .6214 m
.32322 .62178 L
s
.526 .271 .006 r
.65698 .31789 m
.6548 .318 L
s
.76 .35 .299 r
.61136 .3587 m
.61133 .35798 L
s
.943 .561 .298 r
.44125 .51495 m
.44127 .51418 L
s
.76 .35 .299 r
.61138 .35942 m
.61136 .3587 L
s
.943 .561 .298 r
.44123 .51572 m
.44125 .51495 L
s
.76 .35 .299 r
.6114 .36014 m
.61138 .35942 L
s
.526 .271 .006 r
.65923 .31776 m
.65698 .31789 L
s
.943 .561 .298 r
.44121 .51649 m
.44123 .51572 L
s
.76 .35 .299 r
.61142 .36085 m
.6114 .36014 L
s
.801 .162 .719 r
.32993 .62102 m
.32658 .6214 L
s
.943 .561 .298 r
.44119 .51726 m
.44121 .51649 L
s
.76 .35 .299 r
.61144 .36157 m
.61142 .36085 L
s
.943 .561 .298 r
.44117 .51803 m
.44119 .51726 L
s
.526 .271 .006 r
.66154 .3176 m
.65923 .31776 L
s
.76 .35 .299 r
.61146 .36229 m
.61144 .36157 L
s
.943 .561 .298 r
.44115 .5188 m
.44117 .51803 L
s
.76 .35 .299 r
.61148 .363 m
.61146 .36229 L
s
.943 .561 .298 r
.44113 .51957 m
.44115 .5188 L
s
.801 .162 .719 r
.33328 .62065 m
.32993 .62102 L
s
.76 .35 .299 r
.6115 .36372 m
.61148 .363 L
s
.943 .561 .298 r
.44111 .52035 m
.44113 .51957 L
s
.526 .271 .006 r
.66393 .31742 m
.66154 .3176 L
s
.76 .35 .299 r
.61153 .36444 m
.6115 .36372 L
s
.943 .561 .298 r
.44109 .52112 m
.44111 .52035 L
s
.76 .35 .299 r
.61155 .36515 m
.61153 .36444 L
s
.943 .561 .298 r
.44107 .5219 m
.44109 .52112 L
s
.76 .35 .299 r
.61157 .36587 m
.61155 .36515 L
s
.526 .271 .006 r
.66638 .31721 m
.66393 .31742 L
s
.801 .162 .719 r
.33662 .62028 m
.33328 .62065 L
s
.943 .561 .298 r
.44105 .52267 m
.44107 .5219 L
s
.76 .35 .299 r
.61159 .36659 m
.61157 .36587 L
s
.943 .561 .298 r
.44102 .52345 m
.44105 .52267 L
s
.76 .35 .299 r
.61161 .3673 m
.61159 .36659 L
s
.943 .561 .298 r
.441 .52423 m
.44102 .52345 L
s
.76 .35 .299 r
.61163 .36802 m
.61161 .3673 L
s
.526 .271 .006 r
.66891 .31698 m
.66638 .31721 L
s
.943 .561 .298 r
.44098 .52501 m
.441 .52423 L
s
.76 .35 .299 r
.61165 .36874 m
.61163 .36802 L
s
.801 .162 .719 r
.33993 .61993 m
.33662 .62028 L
s
.943 .561 .298 r
.44096 .52579 m
.44098 .52501 L
s
.76 .35 .299 r
.61167 .36946 m
.61165 .36874 L
s
.943 .561 .298 r
.44094 .52657 m
.44096 .52579 L
s
.526 .271 .006 r
.67151 .31672 m
.66891 .31698 L
s
.76 .35 .299 r
.6117 .37018 m
.61167 .36946 L
s
.943 .561 .298 r
.44092 .52736 m
.44094 .52657 L
s
.76 .35 .299 r
.61172 .3709 m
.6117 .37018 L
s
.943 .561 .298 r
.44089 .52814 m
.44092 .52736 L
s
.801 .162 .719 r
.34321 .61958 m
.33993 .61993 L
s
.76 .35 .299 r
.61174 .37162 m
.61172 .3709 L
s
.526 .271 .006 r
.67418 .31643 m
.67151 .31672 L
s
.943 .561 .298 r
.44087 .52893 m
.44089 .52814 L
s
.76 .35 .299 r
.61176 .37234 m
.61174 .37162 L
s
.943 .561 .298 r
.44085 .52971 m
.44087 .52893 L
s
.76 .35 .299 r
.61178 .37306 m
.61176 .37234 L
s
.6118 .37379 m
.61178 .37306 L
s
.943 .561 .298 r
.44083 .5305 m
.44085 .52971 L
s
.801 .162 .719 r
.34645 .61926 m
.34321 .61958 L
s
.526 .271 .006 r
.67693 .31612 m
.67418 .31643 L
s
.76 .35 .299 r
.61182 .37451 m
.6118 .37379 L
s
.943 .561 .298 r
.44081 .53129 m
.44083 .5305 L
s
.76 .35 .299 r
.61184 .37523 m
.61182 .37451 L
s
.943 .561 .298 r
.44078 .53207 m
.44081 .53129 L
s
.76 .35 .299 r
.61187 .37596 m
.61184 .37523 L
s
.943 .561 .298 r
.44076 .53286 m
.44078 .53207 L
s
.526 .271 .006 r
.67976 .31578 m
.67693 .31612 L
s
.76 .35 .299 r
.61189 .37669 m
.61187 .37596 L
s
.801 .162 .719 r
.34966 .61894 m
.34645 .61926 L
s
.943 .561 .298 r
.44074 .53365 m
.44076 .53286 L
s
.76 .35 .299 r
.61191 .37741 m
.61189 .37669 L
s
.943 .561 .298 r
.44072 .53444 m
.44074 .53365 L
s
.76 .35 .299 r
.61193 .37814 m
.61191 .37741 L
s
.943 .561 .298 r
.4407 .53523 m
.44072 .53444 L
s
.526 .271 .006 r
.68266 .31541 m
.67976 .31578 L
s
.76 .35 .299 r
.61195 .37887 m
.61193 .37814 L
s
.943 .561 .298 r
.44067 .53602 m
.4407 .53523 L
s
.801 .162 .719 r
.35282 .61865 m
.34966 .61894 L
s
.76 .35 .299 r
.61197 .3796 m
.61195 .37887 L
s
.943 .561 .298 r
.44065 .53681 m
.44067 .53602 L
s
.76 .35 .299 r
.612 .38034 m
.61197 .3796 L
s
.943 .561 .298 r
.44063 .5376 m
.44065 .53681 L
s
.526 .271 .006 r
.68563 .31502 m
.68266 .31541 L
s
.76 .35 .299 r
.61202 .38107 m
.612 .38034 L
s
.943 .561 .298 r
.44061 .53839 m
.44063 .5376 L
s
.76 .35 .299 r
.61204 .3818 m
.61202 .38107 L
s
.801 .162 .719 r
.35593 .61837 m
.35282 .61865 L
s
.943 .561 .298 r
.44059 .53918 m
.44061 .53839 L
s
.76 .35 .299 r
.61206 .38254 m
.61204 .3818 L
s
.943 .561 .298 r
.44056 .53997 m
.44059 .53918 L
s
.526 .271 .006 r
.68869 .31459 m
.68563 .31502 L
s
.76 .35 .299 r
.61208 .38328 m
.61206 .38254 L
s
.943 .561 .298 r
.44054 .54076 m
.44056 .53997 L
s
.76 .35 .299 r
.6121 .38402 m
.61208 .38328 L
s
.943 .561 .298 r
.44052 .54155 m
.44054 .54076 L
s
.801 .162 .719 r
.359 .61811 m
.35593 .61837 L
s
.76 .35 .299 r
.61213 .38476 m
.6121 .38402 L
s
.943 .561 .298 r
.4405 .54234 m
.44052 .54155 L
s
.76 .35 .299 r
.61215 .3855 m
.61213 .38476 L
s
.526 .271 .006 r
.69181 .31415 m
.68869 .31459 L
s
.943 .561 .298 r
.44047 .54313 m
.4405 .54234 L
s
.76 .35 .299 r
.61217 .38624 m
.61215 .3855 L
s
.943 .561 .298 r
.44045 .54392 m
.44047 .54313 L
s
.801 .162 .719 r
.362 .61788 m
.359 .61811 L
s
.76 .35 .299 r
.61219 .38698 m
.61217 .38624 L
s
.943 .561 .298 r
.44043 .5447 m
.44045 .54392 L
s
.76 .35 .299 r
.61221 .38773 m
.61219 .38698 L
s
.526 .271 .006 r
.69501 .31367 m
.69181 .31415 L
s
.943 .561 .298 r
.44041 .54549 m
.44043 .5447 L
s
.76 .35 .299 r
.61224 .38848 m
.61221 .38773 L
s
.943 .561 .298 r
.44039 .54628 m
.44041 .54549 L
s
.76 .35 .299 r
.61226 .38922 m
.61224 .38848 L
s
.801 .162 .719 r
.36495 .61766 m
.362 .61788 L
s
.943 .561 .298 r
.44036 .54707 m
.44039 .54628 L
s
.76 .35 .299 r
.61228 .38997 m
.61226 .38922 L
s
.526 .271 .006 r
.69829 .31317 m
.69501 .31367 L
s
.943 .561 .298 r
.44034 .54785 m
.44036 .54707 L
s
.76 .35 .299 r
.6123 .39072 m
.61228 .38997 L
s
.943 .561 .298 r
.44032 .54864 m
.44034 .54785 L
s
.76 .35 .299 r
.61232 .39147 m
.6123 .39072 L
s
.801 .162 .719 r
.36784 .61747 m
.36495 .61766 L
s
.943 .561 .298 r
.4403 .54942 m
.44032 .54864 L
s
.76 .35 .299 r
.61235 .39223 m
.61232 .39147 L
s
.943 .561 .298 r
.44028 .55021 m
.4403 .54942 L
s
.526 .271 .006 r
.70164 .31264 m
.69829 .31317 L
s
.76 .35 .299 r
.61237 .39298 m
.61235 .39223 L
s
.943 .561 .298 r
.44025 .55099 m
.44028 .55021 L
s
.76 .35 .299 r
.61239 .39373 m
.61237 .39298 L
s
.943 .561 .298 r
.44023 .55177 m
.44025 .55099 L
s
.801 .162 .719 r
.37067 .61729 m
.36784 .61747 L
s
.76 .35 .299 r
.61241 .39449 m
.61239 .39373 L
s
.943 .561 .298 r
.44021 .55256 m
.44023 .55177 L
s
.526 .271 .006 r
.70505 .31209 m
.70164 .31264 L
s
.76 .35 .299 r
.61244 .39524 m
.61241 .39449 L
s
.943 .561 .298 r
.44019 .55334 m
.44021 .55256 L
s
.76 .35 .299 r
.61246 .396 m
.61244 .39524 L
s
.943 .561 .298 r
.44017 .55412 m
.44019 .55334 L
s
.801 .162 .719 r
.37344 .61714 m
.37067 .61729 L
s
.76 .35 .299 r
.61248 .39676 m
.61246 .396 L
s
.943 .561 .298 r
.44014 .5549 m
.44017 .55412 L
s
.76 .35 .299 r
.6125 .39752 m
.61248 .39676 L
s
.526 .271 .006 r
.70853 .31152 m
.70505 .31209 L
s
.943 .561 .298 r
.44012 .55568 m
.44014 .5549 L
s
.76 .35 .299 r
.61253 .39827 m
.6125 .39752 L
s
.943 .561 .298 r
.4401 .55646 m
.44012 .55568 L
s
.801 .162 .719 r
.37614 .61702 m
.37344 .61714 L
s
.76 .35 .299 r
.61255 .39903 m
.61253 .39827 L
s
.943 .561 .298 r
.44008 .55724 m
.4401 .55646 L
s
.76 .35 .299 r
.61257 .39979 m
.61255 .39903 L
s
.943 .561 .298 r
.44006 .55802 m
.44008 .55724 L
s
.526 .271 .006 r
.71207 .31092 m
.70853 .31152 L
s
.76 .35 .299 r
.61259 .40055 m
.61257 .39979 L
s
.943 .561 .298 r
.44003 .5588 m
.44006 .55802 L
s
.801 .162 .719 r
.37878 .61691 m
.37614 .61702 L
s
.76 .35 .299 r
.61262 .40131 m
.61259 .40055 L
s
.943 .561 .298 r
.44001 .55958 m
.44003 .5588 L
s
.76 .35 .299 r
.61264 .40207 m
.61262 .40131 L
s
.943 .561 .298 r
.43999 .56036 m
.44001 .55958 L
s
.526 .271 .006 r
.71566 .3103 m
.71207 .31092 L
s
.76 .35 .299 r
.61266 .40283 m
.61264 .40207 L
s
.943 .561 .298 r
.43997 .56114 m
.43999 .56036 L
s
.801 .162 .719 r
.38135 .61683 m
.37878 .61691 L
s
.76 .35 .299 r
.61268 .40359 m
.61266 .40283 L
s
.943 .561 .298 r
.43995 .56192 m
.43997 .56114 L
s
.76 .35 .299 r
.61271 .40435 m
.61268 .40359 L
s
.943 .561 .298 r
.43992 .5627 m
.43995 .56192 L
s
.76 .35 .299 r
.61273 .40511 m
.61271 .40435 L
s
.943 .561 .298 r
.4399 .56349 m
.43992 .5627 L
s
.526 .271 .006 r
.71931 .30967 m
.71566 .3103 L
s
.801 .162 .719 r
.38386 .61677 m
.38135 .61683 L
s
.943 .561 .298 r
.43988 .56427 m
.4399 .56349 L
s
.76 .35 .299 r
.61275 .40587 m
.61273 .40511 L
s
.943 .561 .298 r
.43986 .56505 m
.43988 .56427 L
s
.76 .35 .299 r
.61277 .40663 m
.61275 .40587 L
s
.943 .561 .298 r
.43984 .56583 m
.43986 .56505 L
s
.76 .35 .299 r
.6128 .40739 m
.61277 .40663 L
s
.801 .162 .719 r
.38631 .61674 m
.38386 .61677 L
s
.526 .271 .006 r
.723 .30902 m
.71931 .30967 L
s
.943 .561 .298 r
.43981 .56661 m
.43984 .56583 L
s
.76 .35 .299 r
.61282 .40815 m
.6128 .40739 L
s
.943 .561 .298 r
.43979 .5674 m
.43981 .56661 L
s
.76 .35 .299 r
.61284 .40891 m
.61282 .40815 L
s
.943 .561 .298 r
.43977 .56818 m
.43979 .5674 L
s
.76 .35 .299 r
.61286 .40967 m
.61284 .40891 L
s
.801 .162 .719 r
.38869 .61672 m
.38631 .61674 L
s
.943 .561 .298 r
.43975 .56896 m
.43977 .56818 L
s
.76 .35 .299 r
.61289 .41043 m
.61286 .40967 L
s
.526 .271 .006 r
.72673 .30835 m
.723 .30902 L
s
.943 .561 .298 r
.43973 .56975 m
.43975 .56896 L
s
.76 .35 .299 r
.61291 .41119 m
.61289 .41043 L
s
.943 .561 .298 r
.4397 .57054 m
.43973 .56975 L
s
.76 .35 .299 r
.61293 .41195 m
.61291 .41119 L
s
.801 .162 .719 r
.39101 .61673 m
.38869 .61672 L
s
.943 .561 .298 r
.43968 .57132 m
.4397 .57054 L
s
.76 .35 .299 r
.61295 .41271 m
.61293 .41195 L
s
.943 .561 .298 r
.43966 .57211 m
.43968 .57132 L
s
.526 .271 .006 r
.73049 .30767 m
.72673 .30835 L
s
.76 .35 .299 r
.61298 .41347 m
.61295 .41271 L
s
.943 .561 .298 r
.43964 .5729 m
.43966 .57211 L
s
.801 .162 .719 r
.39326 .61677 m
.39101 .61673 L
s
.76 .35 .299 r
.613 .41423 m
.61298 .41347 L
s
.943 .561 .298 r
.43962 .57369 m
.43964 .5729 L
s
.76 .35 .299 r
.61302 .41498 m
.613 .41423 L
s
.943 .561 .298 r
.43959 .57448 m
.43962 .57369 L
s
.76 .35 .299 r
.61304 .41574 m
.61302 .41498 L
s
.526 .271 .006 r
.73427 .30699 m
.73049 .30767 L
s
.801 .162 .719 r
.39545 .61682 m
.39326 .61677 L
s
.943 .561 .298 r
.43957 .57527 m
.43959 .57448 L
s
.76 .35 .299 r
.61307 .4165 m
.61304 .41574 L
s
.943 .561 .298 r
.43955 .57606 m
.43957 .57527 L
s
.76 .35 .299 r
.61309 .41726 m
.61307 .4165 L
s
.943 .561 .298 r
.43953 .57686 m
.43955 .57606 L
s
.76 .35 .299 r
.61311 .41802 m
.61309 .41726 L
s
.801 .162 .719 r
.39759 .6169 m
.39545 .61682 L
s
.943 .561 .298 r
.43951 .57765 m
.43953 .57686 L
s
.76 .35 .299 r
.61314 .41877 m
.61311 .41802 L
s
.526 .271 .006 r
.73806 .3063 m
.73427 .30699 L
s
.943 .561 .298 r
.43948 .57845 m
.43951 .57765 L
s
.76 .35 .299 r
.61316 .41953 m
.61314 .41877 L
s
.943 .561 .298 r
.43946 .57924 m
.43948 .57845 L
s
.801 .162 .719 r
.39965 .61699 m
.39759 .6169 L
s
.76 .35 .299 r
.61318 .42029 m
.61316 .41953 L
s
.943 .561 .298 r
.43944 .58004 m
.43946 .57924 L
s
.76 .35 .299 r
.61321 .42105 m
.61318 .42029 L
s
.526 .271 .006 r
.74185 .30561 m
.73806 .3063 L
s
.943 .561 .298 r
.43942 .58084 m
.43944 .58004 L
s
.76 .35 .299 r
.61323 .4218 m
.61321 .42105 L
s
.801 .162 .719 r
.40166 .61712 m
.39965 .61699 L
s
.943 .561 .298 r
.43939 .58165 m
.43942 .58084 L
s
.76 .35 .299 r
.61326 .42256 m
.61323 .4218 L
s
.943 .561 .298 r
.43937 .58245 m
.43939 .58165 L
s
.76 .35 .299 r
.61328 .42332 m
.61326 .42256 L
s
.943 .561 .298 r
.43935 .58326 m
.43937 .58245 L
s
.801 .162 .719 r
.40361 .61726 m
.40166 .61712 L
s
.76 .35 .299 r
.61331 .42408 m
.61328 .42332 L
s
.526 .271 .006 r
.74564 .30492 m
.74185 .30561 L
s
.943 .561 .298 r
.43933 .58406 m
.43935 .58326 L
s
.76 .35 .299 r
.61333 .42483 m
.61331 .42408 L
s
.943 .561 .298 r
.4393 .58487 m
.43933 .58406 L
s
.76 .35 .299 r
.61336 .42559 m
.61333 .42483 L
s
.801 .162 .719 r
.40549 .61742 m
.40361 .61726 L
s
.526 .271 .006 r
.63211 .40812 m
.63342 .40692 L
s
.63085 .40929 m
.63211 .40812 L
s
.63342 .40692 m
.63478 .40571 L
s
.62964 .41045 m
.63085 .40929 L
s
.63478 .40571 m
.63621 .40449 L
s
.943 .561 .298 r
.43928 .58568 m
.4393 .58487 L
s
.526 .271 .006 r
.62848 .41159 m
.62964 .41045 L
s
.63621 .40449 m
.63768 .40324 L
s
.62738 .41272 m
.62848 .41159 L
s
.63768 .40324 m
.63921 .40197 L
s
.62633 .41383 m
.62738 .41272 L
s
.76 .35 .299 r
.61338 .42635 m
.61336 .42559 L
s
.526 .271 .006 r
.63921 .40197 m
.6408 .40069 L
s
.62534 .41492 m
.62633 .41383 L
s
.6408 .40069 m
.64244 .39939 L
s
.62439 .41599 m
.62534 .41492 L
s
.64244 .39939 m
.64414 .39807 L
s
.62349 .41705 m
.62439 .41599 L
s
.943 .561 .298 r
.43926 .58649 m
.43928 .58568 L
s
.526 .271 .006 r
.74941 .30424 m
.74564 .30492 L
s
.64414 .39807 m
.6459 .39673 L
s
.62265 .41809 m
.62349 .41705 L
s
.76 .35 .299 r
.61341 .4271 m
.61338 .42635 L
s
.526 .271 .006 r
.6459 .39673 m
.64772 .39537 L
s
.62185 .41911 m
.62265 .41809 L
s
.64772 .39537 m
.6496 .39399 L
s
.62111 .42012 m
.62185 .41911 L
s
.801 .162 .719 r
.40731 .61761 m
.40549 .61742 L
s
.943 .561 .298 r
.43924 .5873 m
.43926 .58649 L
s
.76 .35 .299 r
.61344 .42786 m
.61341 .4271 L
s
.526 .271 .006 r
.6496 .39399 m
.65154 .39259 L
s
.62042 .42111 m
.62111 .42012 L
s
.65154 .39259 m
.65354 .39117 L
s
.61976 .42209 m
.62042 .42111 L
s
.943 .561 .298 r
.43921 .58812 m
.43924 .5873 L
s
.76 .35 .299 r
.61347 .42861 m
.61344 .42786 L
s
.526 .271 .006 r
.61917 .42305 m
.61976 .42209 L
s
.65354 .39117 m
.65561 .38972 L
s
.943 .561 .298 r
.26239 .74991 m
.26366 .74882 L
s
.26134 .75093 m
.26239 .74991 L
s
.26054 .75188 m
.26134 .75093 L
s
.26366 .74882 m
.26515 .74766 L
s
.526 .271 .006 r
.61862 .424 m
.61917 .42305 L
s
.65561 .38972 m
.65773 .38826 L
s
.943 .561 .298 r
.43919 .58893 m
.43921 .58812 L
s
.25997 .75275 m
.26054 .75188 L
s
.26515 .74766 m
.26686 .74644 L
s
.76 .35 .299 r
.61351 .42937 m
.61347 .42861 L
s
.801 .162 .719 r
.40908 .61781 m
.40731 .61761 L
s
.526 .271 .006 r
.6181 .42493 m
.61862 .424 L
s
.943 .561 .298 r
.26686 .74644 m
.26877 .74515 L
s
.25966 .75355 m
.25997 .75275 L
s
.526 .271 .006 r
.75314 .30356 m
.74941 .30424 L
s
.65773 .38826 m
.65993 .38677 L
s
.61763 .42585 m
.6181 .42493 L
s
.943 .561 .298 r
.43917 .58975 m
.43919 .58893 L
s
.26877 .74515 m
.27086 .7438 L
s
.2596 .75428 m
.25966 .75355 L
s
.526 .271 .006 r
.65993 .38677 m
.66219 .38526 L
s
.76 .35 .299 r
.61354 .43012 m
.61351 .42937 L
s
.526 .271 .006 r
.61719 .42676 m
.61763 .42585 L
s
.943 .561 .298 r
.27086 .7438 m
.27314 .74239 L
s
.526 .271 .006 r
.66219 .38526 m
.66452 .38373 L
s
.943 .561 .298 r
.25979 .75492 m
.2596 .75428 L
s
.43914 .59057 m
.43917 .58975 L
s
.526 .271 .006 r
.61679 .42766 m
.61719 .42676 L
s
.76 .35 .299 r
.61358 .43088 m
.61354 .43012 L
s
.943 .561 .298 r
.27314 .74239 m
.27559 .74093 L
s
.801 .162 .719 r
.41079 .61804 m
.40908 .61781 L
s
.526 .271 .006 r
.66452 .38373 m
.66692 .38218 L
s
.61643 .42854 m
.61679 .42766 L
s
.943 .561 .298 r
.26023 .75549 m
.25979 .75492 L
s
.43912 .59139 m
.43914 .59057 L
s
.76 .35 .299 r
.61362 .43163 m
.61358 .43088 L
s
.526 .271 .006 r
.66692 .38218 m
.66938 .3806 L
s
.61611 .42941 m
.61643 .42854 L
s
.943 .561 .298 r
.27559 .74093 m
.27819 .73942 L
s
.526 .271 .006 r
.75684 .3029 m
.75314 .30356 L
s
.943 .561 .298 r
.4391 .59221 m
.43912 .59139 L
s
.26092 .75599 m
.26023 .75549 L
s
.76 .35 .299 r
.61367 .43238 m
.61362 .43163 L
s
.526 .271 .006 r
.61582 .43027 m
.61611 .42941 L
s
.66938 .3806 m
.67192 .37899 L
s
.943 .561 .298 r
.27819 .73942 m
.28094 .73786 L
s
.801 .162 .719 r
.41244 .61829 m
.41079 .61804 L
s
.943 .561 .298 r
.43908 .59303 m
.4391 .59221 L
s
.526 .271 .006 r
.61556 .43112 m
.61582 .43027 L
s
.67192 .37899 m
.67453 .37737 L
s
.76 .35 .299 r
.61372 .43313 m
.61367 .43238 L
s
.943 .561 .298 r
.26186 .75642 m
.26092 .75599 L
s
.526 .271 .006 r
.61533 .43196 m
.61556 .43112 L
s
.943 .561 .298 r
.28094 .73786 m
.28382 .73626 L
s
.43905 .59385 m
.43908 .59303 L
s
.526 .271 .006 r
.67453 .37737 m
.67721 .37571 L
s
.76 .35 .299 r
.61377 .43388 m
.61372 .43313 L
s
.526 .271 .006 r
.61513 .43279 m
.61533 .43196 L
s
.943 .561 .298 r
.43903 .59468 m
.43905 .59385 L
s
.801 .162 .719 r
.41403 .61856 m
.41244 .61829 L
s
.526 .271 .006 r
.67721 .37571 m
.67997 .37404 L
s
.76 .35 .299 r
.61383 .43463 m
.61377 .43388 L
s
.943 .561 .298 r
.28382 .73626 m
.28681 .73463 L
s
.26303 .75677 m
.26186 .75642 L
s
.526 .271 .006 r
.76048 .30226 m
.75684 .3029 L
s
.61495 .43362 m
.61513 .43279 L
s
.943 .561 .298 r
.43901 .5955 m
.43903 .59468 L
s
.76 .35 .299 r
.6139 .43537 m
.61383 .43463 L
s
.526 .271 .006 r
.67997 .37404 m
.68279 .37233 L
s
.6148 .43443 m
.61495 .43362 L
s
.943 .561 .298 r
.28681 .73463 m
.28991 .73295 L
s
.26444 .75706 m
.26303 .75677 L
s
.43898 .59633 m
.43901 .5955 L
s
.526 .271 .006 r
.61467 .43524 m
.6148 .43443 L
s
.76 .35 .299 r
.61398 .43612 m
.6139 .43537 L
s
.801 .162 .719 r
.41556 .61885 m
.41403 .61856 L
s
.526 .271 .006 r
.68279 .37233 m
.6857 .3706 L
s
.61456 .43604 m
.61467 .43524 L
s
.943 .561 .298 r
.43896 .59715 m
.43898 .59633 L
s
.28991 .73295 m
.29311 .73124 L
s
.76 .35 .299 r
.61406 .43686 m
.61398 .43612 L
s
.526 .271 .006 r
.6857 .3706 m
.68867 .36885 L
s
.76406 .30165 m
.76048 .30226 L
s
.61445 .43685 m
.61456 .43604 L
s
.943 .561 .298 r
.26608 .75728 m
.26444 .75706 L
s
.43894 .59798 m
.43896 .59715 L
s
.76 .35 .299 r
.61416 .43759 m
.61406 .43686 L
s
.801 .162 .719 r
.41703 .61916 m
.41556 .61885 L
s
.943 .561 .298 r
.29311 .73124 m
.2964 .72951 L
s
.526 .271 .006 r
.61437 .43765 m
.61445 .43685 L
s
.68867 .36885 m
.69172 .36707 L
s
.943 .561 .298 r
.43891 .59881 m
.43894 .59798 L
s
.76 .35 .299 r
.61428 .43832 m
.61416 .43759 L
s
.526 .271 .006 r
.6143 .43844 m
.61437 .43765 L
s
.69172 .36707 m
.69484 .36527 L
s
.943 .561 .298 r
.43889 .59964 m
.43891 .59881 L
s
.26793 .75744 m
.26608 .75728 L
s
.2964 .72951 m
.29975 .72774 L
s
.76 .35 .299 r
.61441 .43905 m
.61428 .43832 L
s
.801 .162 .719 r
.41845 .61949 m
.41703 .61916 L
s
.526 .271 .006 r
.61424 .43923 m
.6143 .43844 L
s
.943 .561 .298 r
.43887 .60046 m
.43889 .59964 L
s
.526 .271 .006 r
.76756 .30105 m
.76406 .30165 L
s
.69484 .36527 m
.69802 .36344 L
s
.76 .35 .299 r
.61456 .43977 m
.61441 .43905 L
s
.526 .271 .006 r
.61419 .44002 m
.61424 .43923 L
s
.943 .561 .298 r
.29975 .72774 m
.30317 .72596 L
s
.43884 .60129 m
.43887 .60046 L
s
.526 .271 .006 r
.61415 .4408 m
.61419 .44002 L
s
.76 .35 .299 r
.61472 .44047 m
.61456 .43977 L
s
.801 .162 .719 r
.41981 .61984 m
.41845 .61949 L
s
.943 .561 .298 r
.26998 .75754 m
.26793 .75744 L
s
.526 .271 .006 r
.69802 .36344 m
.70128 .36159 L
s
.943 .561 .298 r
.43882 .60212 m
.43884 .60129 L
s
.526 .271 .006 r
.61412 .44158 m
.61415 .4408 L
s
.943 .561 .298 r
.30317 .72596 m
.30664 .72415 L
s
.76 .35 .299 r
.6149 .44118 m
.61472 .44047 L
s
.943 .561 .298 r
.4388 .60295 m
.43882 .60212 L
s
.526 .271 .006 r
.70128 .36159 m
.7046 .35972 L
s
.6141 .44236 m
.61412 .44158 L
s
.77097 .30049 m
.76756 .30105 L
s
.801 .162 .719 r
.42112 .62021 m
.41981 .61984 L
s
.76 .35 .299 r
.61512 .44187 m
.6149 .44118 L
s
.943 .561 .298 r
.27222 .75759 m
.26998 .75754 L
s
.43877 .60378 m
.4388 .60295 L
s
.526 .271 .006 r
.61409 .44314 m
.6141 .44236 L
s
.943 .561 .298 r
.30664 .72415 m
.31015 .72233 L
s
.526 .271 .006 r
.7046 .35972 m
.70799 .35782 L
s
.76 .35 .299 r
.61535 .44256 m
.61512 .44187 L
s
.943 .561 .298 r
.43875 .60461 m
.43877 .60378 L
s
.526 .271 .006 r
.61407 .44392 m
.61409 .44314 L
s
.801 .162 .719 r
.42236 .6206 m
.42112 .62021 L
s
.76 .35 .299 r
.61562 .44324 m
.61535 .44256 L
s
.943 .561 .298 r
.31015 .72233 m
.3137 .7205 L
s
.526 .271 .006 r
.70799 .35782 m
.71144 .35591 L
s
.61407 .4447 m
.61407 .44392 L
s
.943 .561 .298 r
.43873 .60544 m
.43875 .60461 L
s
.526 .271 .006 r
.77428 .29997 m
.77097 .30049 L
s
.943 .561 .298 r
.27464 .75758 m
.27222 .75759 L
s
.76 .35 .299 r
.61593 .4439 m
.61562 .44324 L
s
.526 .271 .006 r
.61407 .44547 m
.61407 .4447 L
s
.943 .561 .298 r
.4387 .60627 m
.43873 .60544 L
s
.801 .162 .719 r
.42355 .62101 m
.42236 .6206 L
s
.526 .271 .006 r
.71144 .35591 m
.71495 .35397 L
s
.943 .561 .298 r
.3137 .7205 m
.31726 .71866 L
s
.526 .271 .006 r
.61407 .44625 m
.61407 .44547 L
s
.943 .561 .298 r
.43868 .6071 m
.4387 .60627 L
s
.76 .35 .299 r
.61626 .44455 m
.61593 .4439 L
s
.526 .271 .006 r
.61407 .44702 m
.61407 .44625 L
s
.943 .561 .298 r
.43865 .60793 m
.43868 .6071 L
s
.801 .162 .719 r
.42469 .62144 m
.42355 .62101 L
s
.526 .271 .006 r
.71495 .35397 m
.71851 .35202 L
s
.943 .561 .298 r
.27722 .75754 m
.27464 .75758 L
s
.76 .35 .299 r
.61664 .44519 m
.61626 .44455 L
s
.943 .561 .298 r
.31726 .71866 m
.32084 .71681 L
s
.526 .271 .006 r
.77747 .29948 m
.77428 .29997 L
s
.61408 .4478 m
.61407 .44702 L
s
.943 .561 .298 r
.43863 .60876 m
.43865 .60793 L
s
.76 .35 .299 r
.61706 .44582 m
.61664 .44519 L
s
.526 .271 .006 r
.71851 .35202 m
.72212 .35005 L
s
.61409 .44857 m
.61408 .4478 L
s
.801 .162 .719 r
.42576 .6219 m
.42469 .62144 L
s
.943 .561 .298 r
.43861 .60959 m
.43863 .60876 L
s
.32084 .71681 m
.32442 .71495 L
s
.76 .35 .299 r
.61752 .44643 m
.61706 .44582 L
s
.526 .271 .006 r
.6141 .44935 m
.61409 .44857 L
s
.943 .561 .298 r
.43858 .61042 m
.43861 .60959 L
s
.27996 .75745 m
.27722 .75754 L
s
.526 .271 .006 r
.72212 .35005 m
.72576 .34807 L
s
.78055 .29903 m
.77747 .29948 L
s
.801 .162 .719 r
.42678 .62237 m
.42576 .6219 L
s
.526 .271 .006 r
.61412 .45012 m
.6141 .44935 L
s
.943 .561 .298 r
.32442 .71495 m
.328 .7131 L
s
.76 .35 .299 r
.61803 .44702 m
.61752 .44643 L
s
.943 .561 .298 r
.43856 .61125 m
.43858 .61042 L
s
.526 .271 .006 r
.61413 .4509 m
.61412 .45012 L
s
.943 .561 .298 r
.43853 .61208 m
.43856 .61125 L
s
.526 .271 .006 r
.72576 .34807 m
.72944 .34608 L
s
.76 .35 .299 r
.61858 .4476 m
.61803 .44702 L
s
.801 .162 .719 r
.42775 .62286 m
.42678 .62237 L
s
.943 .561 .298 r
.328 .7131 m
.33156 .71125 L
s
.526 .271 .006 r
.61415 .45167 m
.61413 .4509 L
s
.943 .561 .298 r
.43851 .61292 m
.43853 .61208 L
s
.28284 .75732 m
.27996 .75745 L
s
.526 .271 .006 r
.78348 .29864 m
.78055 .29903 L
s
.61416 .45245 m
.61415 .45167 L
s
.76 .35 .299 r
.61917 .44817 m
.61858 .4476 L
s
.526 .271 .006 r
.72944 .34608 m
.73315 .34407 L
s
.943 .561 .298 r
.43848 .61375 m
.43851 .61292 L
s
.801 .162 .719 r
.42866 .62337 m
.42775 .62286 L
s
.943 .561 .298 r
.33156 .71125 m
.33511 .7094 L
s
.526 .271 .006 r
.61418 .45322 m
.61416 .45245 L
s
.943 .561 .298 r
.43845 .61458 m
.43848 .61375 L
s
.76 .35 .299 r
.61981 .44872 m
.61917 .44817 L
s
.526 .271 .006 r
.73315 .34407 m
.73688 .34207 L
s
.6142 .454 m
.61418 .45322 L
s
.801 .162 .719 r
.42951 .6239 m
.42866 .62337 L
s
.943 .561 .298 r
.43843 .61541 m
.43845 .61458 L
s
.33511 .7094 m
.33862 .70755 L
s
.28583 .75716 m
.28284 .75732 L
s
.526 .271 .006 r
.78627 .29829 m
.78348 .29864 L
s
.76 .35 .299 r
.6205 .44926 m
.61981 .44872 L
s
.526 .271 .006 r
.61422 .45478 m
.6142 .454 L
s
.943 .561 .298 r
.4384 .61624 m
.43843 .61541 L
s
.526 .271 .006 r
.73688 .34207 m
.74061 .34006 L
s
.801 .162 .719 r
.43031 .62445 m
.42951 .6239 L
s
.526 .271 .006 r
.61424 .45556 m
.61422 .45478 L
s
.943 .561 .298 r
.33862 .70755 m
.3421 .70572 L
s
.76 .35 .299 r
.62125 .44977 m
.6205 .44926 L
s
.943 .561 .298 r
.43837 .61707 m
.4384 .61624 L
s
.526 .271 .006 r
.61426 .45634 m
.61424 .45556 L
s
.74061 .34006 m
.74435 .33805 L
s
.801 .162 .719 r
.43105 .62501 m
.43031 .62445 L
s
.943 .561 .298 r
.43834 .6179 m
.43837 .61707 L
s
.526 .271 .006 r
.78891 .298 m
.78627 .29829 L
s
.76 .35 .299 r
.62205 .45026 m
.62125 .44977 L
s
.943 .561 .298 r
.28894 .75698 m
.28583 .75716 L
s
.3421 .70572 m
.34554 .70389 L
s
.526 .271 .006 r
.61428 .45712 m
.61426 .45634 L
s
.943 .561 .298 r
.43831 .61873 m
.43834 .6179 L
s
.801 .162 .719 r
.43175 .6256 m
.43105 .62501 L
s
.526 .271 .006 r
.6143 .4579 m
.61428 .45712 L
s
.74435 .33805 m
.74807 .33605 L
s
.76 .35 .299 r
.62291 .45074 m
.62205 .45026 L
s
.943 .561 .298 r
.43828 .61957 m
.43831 .61873 L
s
.34554 .70389 m
.34894 .70208 L
s
.526 .271 .006 r
.61432 .45868 m
.6143 .4579 L
s
.79137 .29777 m
.78891 .298 L
s
.943 .561 .298 r
.43824 .6204 m
.43828 .61957 L
s
.801 .162 .719 r
.43238 .62621 m
.43175 .6256 L
s
.76 .35 .299 r
.62382 .4512 m
.62291 .45074 L
s
.526 .271 .006 r
.74807 .33605 m
.75178 .33406 L
s
.61434 .45946 m
.61432 .45868 L
s
.943 .561 .298 r
.29216 .75676 m
.28894 .75698 L
s
.34894 .70208 m
.35228 .70027 L
s
.4382 .62123 m
.43824 .6204 L
s
.801 .162 .719 r
.43296 .62683 m
.43238 .62621 L
s
.526 .271 .006 r
.61437 .46024 m
.61434 .45946 L
s
.943 .561 .298 r
.43816 .62207 m
.4382 .62123 L
s
.76 .35 .299 r
.62478 .45164 m
.62382 .4512 L
s
.526 .271 .006 r
.75178 .33406 m
.75545 .33208 L
s
.79366 .2976 m
.79137 .29777 L
s
.943 .561 .298 r
.35228 .70027 m
.35557 .69849 L
s
.526 .271 .006 r
.61439 .46103 m
.61437 .46024 L
s
.801 .162 .719 r
.4335 .62747 m
.43296 .62683 L
s
.943 .561 .298 r
.43812 .62291 m
.43816 .62207 L
s
.526 .271 .006 r
.61441 .46181 m
.61439 .46103 L
s
.76 .35 .299 r
.6258 .45205 m
.62478 .45164 L
s
.943 .561 .298 r
.35557 .69849 m
.3588 .69672 L
s
.526 .271 .006 r
.75545 .33208 m
.75908 .33011 L
s
.943 .561 .298 r
.43807 .62374 m
.43812 .62291 L
s
.29546 .75652 m
.29216 .75676 L
s
.801 .162 .719 r
.43399 .62812 m
.4335 .62747 L
s
.526 .271 .006 r
.61443 .4626 m
.61441 .46181 L
s
.79576 .2975 m
.79366 .2976 L
s
.943 .561 .298 r
.43801 .62458 m
.43807 .62374 L
s
.3588 .69672 m
.36197 .69497 L
s
.76 .35 .299 r
.62688 .45245 m
.6258 .45205 L
s
.526 .271 .006 r
.61445 .46339 m
.61443 .4626 L
s
.75908 .33011 m
.76266 .32817 L
s
.801 .162 .719 r
.43444 .62879 m
.43399 .62812 L
s
.943 .561 .298 r
.43795 .62543 m
.43801 .62458 L
s
.526 .271 .006 r
.61448 .46418 m
.61445 .46339 L
s
.943 .561 .298 r
.36197 .69497 m
.36507 .69323 L
s
.526 .271 .006 r
.79767 .29747 m
.79576 .2975 L
s
.943 .561 .298 r
.43788 .62627 m
.43795 .62543 L
s
.801 .162 .719 r
.43485 .62948 m
.43444 .62879 L
s
.76 .35 .299 r
.62802 .45283 m
.62688 .45245 L
s
.526 .271 .006 r
.76266 .32817 m
.76616 .32625 L
s
.943 .561 .298 r
.29883 .75627 m
.29546 .75652 L
s
.526 .271 .006 r
.6145 .46497 m
.61448 .46418 L
s
.943 .561 .298 r
.4378 .62712 m
.43788 .62627 L
s
.36507 .69323 m
.36811 .69152 L
s
.801 .162 .719 r
.43521 .63017 m
.43485 .62948 L
s
.526 .271 .006 r
.61452 .46576 m
.6145 .46497 L
s
.943 .561 .298 r
.4377 .62797 m
.4378 .62712 L
s
.76 .35 .299 r
.62921 .45319 m
.62802 .45283 L
s
.526 .271 .006 r
.76616 .32625 m
.7696 .32436 L
s
.79937 .29751 m
.79767 .29747 L
s
.943 .561 .298 r
.36811 .69152 m
.37108 .68982 L
s
.526 .271 .006 r
.61455 .46655 m
.61452 .46576 L
s
.801 .162 .719 r
.43554 .63089 m
.43521 .63017 L
s
.943 .561 .298 r
.4376 .62883 m
.4377 .62797 L
s
.526 .271 .006 r
.7696 .32436 m
.77294 .32251 L
s
.61457 .46734 m
.61455 .46655 L
s
.76 .35 .299 r
.63046 .45353 m
.62921 .45319 L
s
.943 .561 .298 r
.43747 .62969 m
.4376 .62883 L
s
.37108 .68982 m
.37398 .68814 L
s
.801 .162 .719 r
.43583 .63161 m
.43554 .63089 L
s
.526 .271 .006 r
.80086 .29762 m
.79937 .29751 L
s
.943 .561 .298 r
.30225 .75601 m
.29883 .75627 L
s
.526 .271 .006 r
.61459 .46813 m
.61457 .46734 L
s
.943 .561 .298 r
.43733 .63056 m
.43747 .62969 L
s
.526 .271 .006 r
.77294 .32251 m
.77618 .32069 L
s
.943 .561 .298 r
.37398 .68814 m
.37681 .68649 L
s
.801 .162 .719 r
.43608 .63235 m
.43583 .63161 L
s
.76 .35 .299 r
.63177 .45385 m
.63046 .45353 L
s
.943 .561 .298 r
.43716 .63143 m
.43733 .63056 L
s
.526 .271 .006 r
.61462 .46893 m
.61459 .46813 L
s
.80212 .29781 m
.80086 .29762 L
s
.943 .561 .298 r
.37681 .68649 m
.37957 .68485 L
s
.801 .162 .719 r
.43631 .63309 m
.43608 .63235 L
s
.526 .271 .006 r
.77618 .32069 m
.77931 .31892 L
s
.943 .561 .298 r
.43698 .63231 m
.43716 .63143 L
s
.526 .271 .006 r
.61464 .46972 m
.61462 .46893 L
s
.943 .561 .298 r
.37957 .68485 m
.38225 .68323 L
s
.43677 .63319 m
.43698 .63231 L
s
.76 .35 .299 r
.63314 .45415 m
.63177 .45385 L
s
.526 .271 .006 r
.80316 .29809 m
.80212 .29781 L
s
.801 .162 .719 r
.43651 .63385 m
.43631 .63309 L
s
.526 .271 .006 r
.61466 .47052 m
.61464 .46972 L
s
.943 .561 .298 r
.30572 .75573 m
.30225 .75601 L
s
.526 .271 .006 r
.77931 .31892 m
.78231 .31719 L
s
.943 .561 .298 r
.43653 .63409 m
.43677 .63319 L
s
.38225 .68323 m
.38487 .68164 L
s
.526 .271 .006 r
.61469 .47132 m
.61466 .47052 L
s
.801 .162 .719 r
.43668 .63462 m
.43651 .63385 L
s
.526 .271 .006 r
.78231 .31719 m
.78517 .31551 L
s
.80396 .29845 m
.80316 .29809 L
s
.943 .561 .298 r
.43626 .63499 m
.43653 .63409 L
s
.38487 .68164 m
.38742 .68006 L
s
.76 .35 .299 r
.63457 .45443 m
.63314 .45415 L
s
.526 .271 .006 r
.61471 .47211 m
.61469 .47132 L
s
.943 .561 .298 r
.43596 .63591 m
.43626 .63499 L
s
.801 .162 .719 r
.43682 .63539 m
.43668 .63462 L
s
.526 .271 .006 r
.78517 .31551 m
.78787 .31389 L
s
.943 .561 .298 r
.38742 .68006 m
.38989 .67851 L
s
.526 .271 .006 r
.80453 .29889 m
.80396 .29845 L
s
.943 .561 .298 r
.43561 .63684 m
.43596 .63591 L
s
.526 .271 .006 r
.61473 .47291 m
.61471 .47211 L
s
.801 .162 .719 r
.43695 .63617 m
.43682 .63539 L
s
.943 .561 .298 r
.38989 .67851 m
.39229 .67698 L
s
.30923 .75545 m
.30572 .75573 L
s
.526 .271 .006 r
.78787 .31389 m
.79042 .31233 L
s
.76 .35 .299 r
.63605 .45469 m
.63457 .45443 L
s
.943 .561 .298 r
.43522 .63778 m
.43561 .63684 L
s
.526 .271 .006 r
.80485 .29942 m
.80453 .29889 L
s
.61476 .47371 m
.61473 .47291 L
s
.943 .561 .298 r
.39229 .67698 m
.39463 .67546 L
s
.801 .162 .719 r
.43706 .63696 m
.43695 .63617 L
s
.943 .561 .298 r
.43479 .63873 m
.43522 .63778 L
s
.526 .271 .006 r
.79042 .31233 m
.79279 .31083 L
s
.80493 .30003 m
.80485 .29942 L
s
.61478 .47451 m
.61476 .47371 L
s
.943 .561 .298 r
.39463 .67546 m
.3969 .67397 L
s
.4343 .6397 m
.43479 .63873 L
s
.526 .271 .006 r
.79279 .31083 m
.79498 .3094 L
s
.801 .162 .719 r
.43715 .63776 m
.43706 .63696 L
s
.76 .35 .299 r
.6376 .45492 m
.63605 .45469 L
s
.943 .561 .298 r
.3969 .67397 m
.3991 .67249 L
s
.526 .271 .006 r
.80476 .30074 m
.80493 .30003 L
s
.943 .561 .298 r
.43377 .64069 m
.4343 .6397 L
s
.526 .271 .006 r
.6148 .47531 m
.61478 .47451 L
s
.79498 .3094 m
.79697 .30804 L
s
.943 .561 .298 r
.4332 .64168 m
.43377 .64069 L
s
.3991 .67249 m
.40123 .67104 L
s
.526 .271 .006 r
.80435 .30153 m
.80476 .30074 L
s
.801 .162 .719 r
.43723 .63857 m
.43715 .63776 L
s
.526 .271 .006 r
.79697 .30804 m
.79876 .30675 L
s
.8037 .3024 m
.80435 .30153 L
s
.943 .561 .298 r
.43258 .6427 m
.4332 .64168 L
s
.40123 .67104 m
.40329 .6696 L
s
.526 .271 .006 r
.61483 .47611 m
.6148 .47531 L
s
.79876 .30675 m
.80034 .30554 L
s
.943 .561 .298 r
.31277 .75517 m
.30923 .75545 L
s
.526 .271 .006 r
.80281 .30337 m
.8037 .3024 L
s
.80034 .30554 m
.80169 .30441 L
s
.80169 .30441 m
.80281 .30337 L
s
.943 .561 .298 r
.4319 .64373 m
.43258 .6427 L
s
.40329 .6696 m
.40529 .66818 L
s
.76 .35 .299 r
.6392 .45514 m
.6376 .45492 L
s
.801 .162 .719 r
.43729 .63937 m
.43723 .63857 L
s
.943 .561 .298 r
.43115 .64478 m
.4319 .64373 L
s
.526 .271 .006 r
.61485 .47691 m
.61483 .47611 L
s
.943 .561 .298 r
.40529 .66818 m
.40722 .66679 L
s
.43034 .64585 m
.43115 .64478 L
s
.40722 .66679 m
.40908 .66541 L
s
.801 .162 .719 r
.43734 .64019 m
.43729 .63937 L
s
.943 .561 .298 r
.42948 .64693 m
.43034 .64585 L
s
.40908 .66541 m
.41088 .66405 L
s
.526 .271 .006 r
.61487 .47771 m
.61485 .47691 L
s
.943 .561 .298 r
.42855 .64804 m
.42948 .64693 L
s
.41088 .66405 m
.41262 .66271 L
s
.42757 .64916 m
.42855 .64804 L
s
.41262 .66271 m
.41429 .66138 L
s
.76 .35 .299 r
.64087 .45534 m
.6392 .45514 L
s
.801 .162 .719 r
.43738 .64101 m
.43734 .64019 L
s
.943 .561 .298 r
.42652 .6503 m
.42757 .64916 L
s
.41429 .66138 m
.4159 .66008 L
s
.42541 .65146 m
.42652 .6503 L
s
.526 .271 .006 r
.6149 .47851 m
.61487 .47771 L
s
.943 .561 .298 r
.4159 .66008 m
.41744 .65879 L
s
.42423 .65264 m
.42541 .65146 L
s
.41744 .65879 m
.41893 .65753 L
s
.423 .65383 m
.42423 .65264 L
s
.41893 .65753 m
.42035 .65628 L
s
.4217 .65504 m
.423 .65383 L
s
.42035 .65628 m
.4217 .65504 L
s
.31631 .75489 m
.31277 .75517 L
s
.801 .162 .719 r
.43741 .64183 m
.43738 .64101 L
s
.526 .271 .006 r
.61492 .47931 m
.6149 .47851 L
s
.76 .35 .299 r
.6426 .45551 m
.64087 .45534 L
s
.801 .162 .719 r
.43743 .64266 m
.43741 .64183 L
s
.526 .271 .006 r
.61495 .48012 m
.61492 .47931 L
s
.801 .162 .719 r
.43745 .64348 m
.43743 .64266 L
s
.526 .271 .006 r
.61497 .48092 m
.61495 .48012 L
s
.801 .162 .719 r
.43745 .64432 m
.43745 .64348 L
s
.76 .35 .299 r
.6444 .45567 m
.6426 .45551 L
s
.526 .271 .006 r
.61499 .48172 m
.61497 .48092 L
s
.943 .561 .298 r
.31987 .7546 m
.31631 .75489 L
s
.801 .162 .719 r
.43746 .64515 m
.43745 .64432 L
s
.526 .271 .006 r
.61502 .48252 m
.61499 .48172 L
s
.801 .162 .719 r
.43746 .64599 m
.43746 .64515 L
s
.526 .271 .006 r
.61504 .48332 m
.61502 .48252 L
s
.76 .35 .299 r
.64625 .4558 m
.6444 .45567 L
s
.801 .162 .719 r
.43746 .64683 m
.43746 .64599 L
s
.526 .271 .006 r
.61506 .48412 m
.61504 .48332 L
s
.801 .162 .719 r
.43745 .64767 m
.43746 .64683 L
s
.943 .561 .298 r
.32342 .75433 m
.31987 .7546 L
s
.526 .271 .006 r
.61509 .48492 m
.61506 .48412 L
s
.76 .35 .299 r
.64818 .45591 m
.64625 .4558 L
s
.801 .162 .719 r
.43744 .64851 m
.43745 .64767 L
s
.526 .271 .006 r
.61511 .48572 m
.61509 .48492 L
s
.801 .162 .719 r
.43743 .64935 m
.43744 .64851 L
s
.526 .271 .006 r
.61514 .48652 m
.61511 .48572 L
s
.76 .35 .299 r
.65017 .45599 m
.64818 .45591 L
s
.801 .162 .719 r
.43741 .6502 m
.43743 .64935 L
s
.526 .271 .006 r
.61516 .48732 m
.61514 .48652 L
s
.943 .561 .298 r
.32697 .75406 m
.32342 .75433 L
s
.801 .162 .719 r
.4374 .65105 m
.43741 .6502 L
s
.526 .271 .006 r
.61518 .48812 m
.61516 .48732 L
s
.76 .35 .299 r
.65222 .45606 m
.65017 .45599 L
s
.801 .162 .719 r
.43738 .6519 m
.4374 .65105 L
s
.526 .271 .006 r
.61521 .48892 m
.61518 .48812 L
s
.61523 .48972 m
.61521 .48892 L
s
.801 .162 .719 r
.43736 .65275 m
.43738 .6519 L
s
.526 .271 .006 r
.61525 .49051 m
.61523 .48972 L
s
.801 .162 .719 r
.43735 .6536 m
.43736 .65275 L
s
.943 .561 .298 r
.3305 .75379 m
.32697 .75406 L
s
.76 .35 .299 r
.65435 .4561 m
.65222 .45606 L
s
.526 .271 .006 r
.61528 .49131 m
.61525 .49051 L
s
.801 .162 .719 r
.43733 .65445 m
.43735 .6536 L
s
.526 .271 .006 r
.6153 .49211 m
.61528 .49131 L
s
.801 .162 .719 r
.43731 .65531 m
.43733 .65445 L
s
.76 .35 .299 r
.65654 .45612 m
.65435 .4561 L
s
.526 .271 .006 r
.61532 .4929 m
.6153 .49211 L
s
.801 .162 .719 r
.43729 .65616 m
.43731 .65531 L
s
.943 .561 .298 r
.334 .75354 m
.3305 .75379 L
s
.526 .271 .006 r
.61535 .4937 m
.61532 .4929 L
s
.801 .162 .719 r
.43726 .65702 m
.43729 .65616 L
s
.526 .271 .006 r
.61537 .49449 m
.61535 .4937 L
s
.801 .162 .719 r
.43724 .65787 m
.43726 .65702 L
s
.76 .35 .299 r
.65881 .45611 m
.65654 .45612 L
s
.526 .271 .006 r
.61539 .49528 m
.61537 .49449 L
s
.801 .162 .719 r
.43722 .65873 m
.43724 .65787 L
s
.526 .271 .006 r
.61542 .49608 m
.61539 .49528 L
s
.801 .162 .719 r
.4372 .65959 m
.43722 .65873 L
s
.943 .561 .298 r
.33748 .7533 m
.334 .75354 L
s
.76 .35 .299 r
.66115 .45608 m
.65881 .45611 L
s
.526 .271 .006 r
.61544 .49687 m
.61542 .49608 L
s
.801 .162 .719 r
.43717 .66045 m
.4372 .65959 L
s
.526 .271 .006 r
.61547 .49766 m
.61544 .49687 L
s
.801 .162 .719 r
.43715 .66131 m
.43717 .66045 L
s
.526 .271 .006 r
.61549 .49845 m
.61547 .49766 L
s
.801 .162 .719 r
.43713 .66218 m
.43715 .66131 L
s
.76 .35 .299 r
.66356 .45602 m
.66115 .45608 L
s
.526 .271 .006 r
.61551 .49924 m
.61549 .49845 L
s
.943 .561 .298 r
.34092 .75308 m
.33748 .7533 L
s
.801 .162 .719 r
.43711 .66304 m
.43713 .66218 L
s
.526 .271 .006 r
.61554 .50004 m
.61551 .49924 L
s
.801 .162 .719 r
.43708 .6639 m
.43711 .66304 L
s
.76 .35 .299 r
.66605 .45594 m
.66356 .45602 L
s
.526 .271 .006 r
.61556 .50083 m
.61554 .50004 L
s
.801 .162 .719 r
.43706 .66477 m
.43708 .6639 L
s
.526 .271 .006 r
.61558 .50162 m
.61556 .50083 L
s
.801 .162 .719 r
.43703 .66563 m
.43706 .66477 L
s
.943 .561 .298 r
.34432 .75286 m
.34092 .75308 L
s
.526 .271 .006 r
.61561 .50241 m
.61558 .50162 L
s
.801 .162 .719 r
.43701 .66649 m
.43703 .66563 L
s
.76 .35 .299 r
.66861 .45584 m
.66605 .45594 L
s
.526 .271 .006 r
.61563 .5032 m
.61561 .50241 L
s
.801 .162 .719 r
.43699 .66736 m
.43701 .66649 L
s
.526 .271 .006 r
.61565 .50399 m
.61563 .5032 L
s
.801 .162 .719 r
.43696 .66822 m
.43699 .66736 L
s
.526 .271 .006 r
.61568 .50479 m
.61565 .50399 L
s
.943 .561 .298 r
.34768 .75267 m
.34432 .75286 L
s
.76 .35 .299 r
.67125 .4557 m
.66861 .45584 L
s
.801 .162 .719 r
.43694 .66909 m
.43696 .66822 L
s
.526 .271 .006 r
.6157 .50558 m
.61568 .50479 L
s
.801 .162 .719 r
.43691 .66996 m
.43694 .66909 L
s
.526 .271 .006 r
.61572 .50637 m
.6157 .50558 L
s
.801 .162 .719 r
.43689 .67082 m
.43691 .66996 L
s
.526 .271 .006 r
.61575 .50717 m
.61572 .50637 L
s
.76 .35 .299 r
.67397 .45554 m
.67125 .4557 L
s
.801 .162 .719 r
.43687 .67169 m
.43689 .67082 L
s
.943 .561 .298 r
.35099 .75249 m
.34768 .75267 L
s
.526 .271 .006 r
.61577 .50796 m
.61575 .50717 L
s
.801 .162 .719 r
.43684 .67255 m
.43687 .67169 L
s
.526 .271 .006 r
.61579 .50875 m
.61577 .50796 L
s
.801 .162 .719 r
.43682 .67342 m
.43684 .67255 L
s
.526 .271 .006 r
.61582 .50955 m
.61579 .50875 L
s
.76 .35 .299 r
.67677 .45536 m
.67397 .45554 L
s
.801 .162 .719 r
.43679 .67428 m
.43682 .67342 L
s
.526 .271 .006 r
.61584 .51034 m
.61582 .50955 L
s
.943 .561 .298 r
.35425 .75234 m
.35099 .75249 L
s
.801 .162 .719 r
.43677 .67514 m
.43679 .67428 L
s
.526 .271 .006 r
.61586 .51114 m
.61584 .51034 L
s
.801 .162 .719 r
.43675 .67601 m
.43677 .67514 L
s
.526 .271 .006 r
.61589 .51194 m
.61586 .51114 L
s
.76 .35 .299 r
.67965 .45515 m
.67677 .45536 L
s
.801 .162 .719 r
.43672 .67687 m
.43675 .67601 L
s
.526 .271 .006 r
.61591 .51274 m
.61589 .51194 L
s
.943 .561 .298 r
.35745 .7522 m
.35425 .75234 L
s
.801 .162 .719 r
.4367 .67773 m
.43672 .67687 L
s
.526 .271 .006 r
.61594 .51353 m
.61591 .51274 L
s
.801 .162 .719 r
.43667 .6786 m
.4367 .67773 L
s
.526 .271 .006 r
.61596 .51433 m
.61594 .51353 L
s
.76 .35 .299 r
.68261 .45491 m
.67965 .45515 L
s
.801 .162 .719 r
.43665 .67946 m
.43667 .6786 L
s
.526 .271 .006 r
.61598 .51513 m
.61596 .51433 L
s
.801 .162 .719 r
.43662 .68032 m
.43665 .67946 L
s
.526 .271 .006 r
.61601 .51594 m
.61598 .51513 L
s
.943 .561 .298 r
.36059 .75208 m
.35745 .7522 L
s
.801 .162 .719 r
.4366 .68118 m
.43662 .68032 L
s
.526 .271 .006 r
.61603 .51674 m
.61601 .51594 L
s
.76 .35 .299 r
.68566 .45464 m
.68261 .45491 L
s
.526 .271 .006 r
.61605 .51754 m
.61603 .51674 L
s
.801 .162 .719 r
.43658 .68204 m
.4366 .68118 L
s
.526 .271 .006 r
.61608 .51835 m
.61605 .51754 L
s
.801 .162 .719 r
.43655 .6829 m
.43658 .68204 L
s
.943 .561 .298 r
.36367 .75198 m
.36059 .75208 L
s
.526 .271 .006 r
.6161 .51915 m
.61608 .51835 L
s
.801 .162 .719 r
.43653 .68375 m
.43655 .6829 L
s
.76 .35 .299 r
.68878 .45435 m
.68566 .45464 L
s
.526 .271 .006 r
.61612 .51996 m
.6161 .51915 L
s
.801 .162 .719 r
.4365 .68461 m
.43653 .68375 L
s
.526 .271 .006 r
.61615 .52077 m
.61612 .51996 L
s
.801 .162 .719 r
.43648 .68547 m
.4365 .68461 L
s
.943 .561 .298 r
.36669 .75191 m
.36367 .75198 L
s
.526 .271 .006 r
.61617 .52158 m
.61615 .52077 L
s
.801 .162 .719 r
.43645 .68632 m
.43648 .68547 L
s
.76 .35 .299 r
.69198 .45403 m
.68878 .45435 L
s
.526 .271 .006 r
.6162 .52239 m
.61617 .52158 L
s
.801 .162 .719 r
.43643 .68718 m
.43645 .68632 L
s
.526 .271 .006 r
.61622 .5232 m
.6162 .52239 L
s
.801 .162 .719 r
.43641 .68803 m
.43643 .68718 L
s
.526 .271 .006 r
.61624 .52402 m
.61622 .5232 L
s
.943 .561 .298 r
.36965 .75185 m
.36669 .75191 L
s
.801 .162 .719 r
.43638 .68889 m
.43641 .68803 L
s
.76 .35 .299 r
.69526 .45369 m
.69198 .45403 L
s
.526 .271 .006 r
.61627 .52483 m
.61624 .52402 L
s
.801 .162 .719 r
.43636 .68974 m
.43638 .68889 L
s
.526 .271 .006 r
.61629 .52565 m
.61627 .52483 L
s
.801 .162 .719 r
.43633 .6906 m
.43636 .68974 L
s
.526 .271 .006 r
.61632 .52647 m
.61629 .52565 L
s
.801 .162 .719 r
.43631 .69145 m
.43633 .6906 L
s
.943 .561 .298 r
.37253 .75182 m
.36965 .75185 L
s
.76 .35 .299 r
.69862 .45332 m
.69526 .45369 L
s
.526 .271 .006 r
.61634 .52729 m
.61632 .52647 L
s
.801 .162 .719 r
.43628 .69231 m
.43631 .69145 L
s
.526 .271 .006 r
.61636 .52811 m
.61634 .52729 L
s
.801 .162 .719 r
.43626 .69316 m
.43628 .69231 L
s
.43623 .69401 m
.43626 .69316 L
s
.526 .271 .006 r
.61639 .52894 m
.61636 .52811 L
s
.943 .561 .298 r
.37535 .75181 m
.37253 .75182 L
s
.76 .35 .299 r
.70206 .45292 m
.69862 .45332 L
s
.801 .162 .719 r
.43621 .69487 m
.43623 .69401 L
s
.526 .271 .006 r
.61641 .52976 m
.61639 .52894 L
s
.801 .162 .719 r
.43618 .69572 m
.43621 .69487 L
s
.526 .271 .006 r
.61644 .53059 m
.61641 .52976 L
s
.801 .162 .719 r
.43616 .69658 m
.43618 .69572 L
s
.526 .271 .006 r
.61646 .53142 m
.61644 .53059 L
s
.943 .561 .298 r
.37811 .75183 m
.37535 .75181 L
s
.801 .162 .719 r
.43614 .69743 m
.43616 .69658 L
s
.76 .35 .299 r
.70558 .4525 m
.70206 .45292 L
s
.526 .271 .006 r
.61649 .53225 m
.61646 .53142 L
s
.801 .162 .719 r
.43611 .69829 m
.43614 .69743 L
s
.526 .271 .006 r
.61651 .53308 m
.61649 .53225 L
s
.801 .162 .719 r
.43609 .69914 m
.43611 .69829 L
s
.526 .271 .006 r
.61654 .53391 m
.61651 .53308 L
s
.943 .561 .298 r
.38079 .75186 m
.37811 .75183 L
s
.801 .162 .719 r
.43606 .7 m
.43609 .69914 L
s
.526 .271 .006 r
.61656 .53474 m
.61654 .53391 L
s
.76 .35 .299 r
.70916 .45205 m
.70558 .4525 L
s
.801 .162 .719 r
.43604 .70085 m
.43606 .7 L
s
.526 .271 .006 r
.61659 .53558 m
.61656 .53474 L
s
.801 .162 .719 r
.43601 .70171 m
.43604 .70085 L
s
.526 .271 .006 r
.61661 .53641 m
.61659 .53558 L
s
.943 .561 .298 r
.3834 .75192 m
.38079 .75186 L
s
.801 .162 .719 r
.43599 .70257 m
.43601 .70171 L
s
.526 .271 .006 r
.61664 .53725 m
.61661 .53641 L
s
.76 .35 .299 r
.71282 .45158 m
.70916 .45205 L
s
.801 .162 .719 r
.43597 .70343 m
.43599 .70257 L
s
.526 .271 .006 r
.61666 .53809 m
.61664 .53725 L
s
.801 .162 .719 r
.43594 .70429 m
.43597 .70343 L
s
.526 .271 .006 r
.61668 .53892 m
.61666 .53809 L
s
.943 .561 .298 r
.38595 .75201 m
.3834 .75192 L
s
.801 .162 .719 r
.43592 .70515 m
.43594 .70429 L
s
.526 .271 .006 r
.61671 .53976 m
.61668 .53892 L
s
.801 .162 .719 r
.4359 .70601 m
.43592 .70515 L
s
.76 .35 .299 r
.71654 .45109 m
.71282 .45158 L
s
.526 .271 .006 r
.61673 .5406 m
.61671 .53976 L
s
.801 .162 .719 r
.43587 .70687 m
.4359 .70601 L
s
.943 .561 .298 r
.38842 .75211 m
.38595 .75201 L
s
.526 .271 .006 r
.61676 .54144 m
.61673 .5406 L
s
.801 .162 .719 r
.43585 .70773 m
.43587 .70687 L
s
.526 .271 .006 r
.61678 .54228 m
.61676 .54144 L
s
.801 .162 .719 r
.43583 .7086 m
.43585 .70773 L
s
.526 .271 .006 r
.61681 .54313 m
.61678 .54228 L
s
.76 .35 .299 r
.72033 .45058 m
.71654 .45109 L
s
.801 .162 .719 r
.4358 .70946 m
.43583 .7086 L
s
.943 .561 .298 r
.39083 .75224 m
.38842 .75211 L
s
.526 .271 .006 r
.61683 .54397 m
.61681 .54313 L
s
.801 .162 .719 r
.43578 .71033 m
.4358 .70946 L
s
.526 .271 .006 r
.61686 .54481 m
.61683 .54397 L
s
.801 .162 .719 r
.43575 .7112 m
.43578 .71033 L
s
.526 .271 .006 r
.61688 .54565 m
.61686 .54481 L
s
.943 .561 .298 r
.39316 .7524 m
.39083 .75224 L
s
.801 .162 .719 r
.43573 .71206 m
.43575 .7112 L
s
.76 .35 .299 r
.72416 .45005 m
.72033 .45058 L
s
.801 .162 .719 r
.25486 .87727 m
.25611 .87615 L
s
.25388 .87831 m
.25486 .87727 L
s
.25611 .87615 m
.25762 .87496 L
s
.25316 .87927 m
.25388 .87831 L
s
.526 .271 .006 r
.61691 .5465 m
.61688 .54565 L
s
.801 .162 .719 r
.25762 .87496 m
.25938 .8737 L
s
.25274 .88015 m
.25316 .87927 L
s
.43571 .71293 m
.43573 .71206 L
s
.25938 .8737 m
.26137 .87238 L
s
.2526 .88096 m
.25274 .88015 L
s
.526 .271 .006 r
.61694 .54734 m
.61691 .5465 L
s
.801 .162 .719 r
.26137 .87238 m
.26357 .87099 L
s
.43568 .71381 m
.43571 .71293 L
s
.25275 .88168 m
.2526 .88096 L
s
.26357 .87099 m
.26599 .86954 L
s
.943 .561 .298 r
.39543 .75257 m
.39316 .7524 L
s
.526 .271 .006 r
.61696 .54818 m
.61694 .54734 L
s
.801 .162 .719 r
.43566 .71468 m
.43568 .71381 L
s
.26599 .86954 m
.26859 .86803 L
s
.2532 .88233 m
.25275 .88168 L
s
.526 .271 .006 r
.61699 .54902 m
.61696 .54818 L
s
.76 .35 .299 r
.72805 .4495 m
.72416 .45005 L
s
.801 .162 .719 r
.43563 .71555 m
.43566 .71468 L
s
.26859 .86803 m
.27136 .86647 L
s
.25395 .88289 m
.2532 .88233 L
s
.526 .271 .006 r
.61701 .54987 m
.61699 .54902 L
s
.801 .162 .719 r
.43561 .71643 m
.43563 .71555 L
s
.943 .561 .298 r
.39762 .75277 m
.39543 .75257 L
s
.801 .162 .719 r
.27136 .86647 m
.2743 .86487 L
s
.526 .271 .006 r
.61704 .55071 m
.61701 .54987 L
s
.801 .162 .719 r
.25499 .88337 m
.25395 .88289 L
s
.43559 .71731 m
.43561 .71643 L
s
.526 .271 .006 r
.61706 .55155 m
.61704 .55071 L
s
.801 .162 .719 r
.2743 .86487 m
.27738 .86322 L
s
.43556 .71819 m
.43559 .71731 L
s
.76 .35 .299 r
.73197 .44894 m
.72805 .4495 L
s
.801 .162 .719 r
.25631 .88378 m
.25499 .88337 L
s
.526 .271 .006 r
.61709 .5524 m
.61706 .55155 L
s
.943 .561 .298 r
.39975 .75299 m
.39762 .75277 L
s
.801 .162 .719 r
.43554 .71907 m
.43556 .71819 L
s
.27738 .86322 m
.28058 .86153 L
s
.526 .271 .006 r
.61711 .55324 m
.61709 .5524 L
s
.801 .162 .719 r
.43551 .71995 m
.43554 .71907 L
s
.28058 .86153 m
.28391 .8598 L
s
.25791 .88412 m
.25631 .88378 L
s
.526 .271 .006 r
.61714 .55408 m
.61711 .55324 L
s
.801 .162 .719 r
.43549 .72084 m
.43551 .71995 L
s
.943 .561 .298 r
.40181 .75324 m
.39975 .75299 L
s
.526 .271 .006 r
.61717 .55493 m
.61714 .55408 L
s
.76 .35 .299 r
.73593 .44837 m
.73197 .44894 L
s
.801 .162 .719 r
.43546 .72172 m
.43549 .72084 L
s
.28391 .8598 m
.28733 .85804 L
s
.25978 .88438 m
.25791 .88412 L
s
.526 .271 .006 r
.61719 .55577 m
.61717 .55493 L
s
.801 .162 .719 r
.43544 .72261 m
.43546 .72172 L
s
.28733 .85804 m
.29085 .85625 L
s
.526 .271 .006 r
.61722 .55661 m
.61719 .55577 L
s
.943 .561 .298 r
.4038 .75351 m
.40181 .75324 L
s
.801 .162 .719 r
.43541 .7235 m
.43544 .72261 L
s
.526 .271 .006 r
.61725 .55745 m
.61722 .55661 L
s
.801 .162 .719 r
.2619 .88458 m
.25978 .88438 L
s
.43539 .72439 m
.43541 .7235 L
s
.29085 .85625 m
.29445 .85444 L
s
.76 .35 .299 r
.73991 .44779 m
.73593 .44837 L
s
.526 .271 .006 r
.61728 .5583 m
.61725 .55745 L
s
.801 .162 .719 r
.43536 .72529 m
.43539 .72439 L
s
.943 .561 .298 r
.40572 .7538 m
.4038 .75351 L
s
.526 .271 .006 r
.61731 .55914 m
.61728 .5583 L
s
.801 .162 .719 r
.43534 .72618 m
.43536 .72529 L
s
.29445 .85444 m
.29811 .8526 L
s
.26426 .88472 m
.2619 .88458 L
s
.526 .271 .006 r
.61734 .55998 m
.61731 .55914 L
s
.801 .162 .719 r
.43531 .72708 m
.43534 .72618 L
s
.943 .561 .298 r
.40757 .75411 m
.40572 .7538 L
s
.526 .271 .006 r
.61737 .56082 m
.61734 .55998 L
s
.801 .162 .719 r
.29811 .8526 m
.30181 .85075 L
s
.76 .35 .299 r
.74391 .44721 m
.73991 .44779 L
s
.801 .162 .719 r
.43529 .72798 m
.43531 .72708 L
s
.526 .271 .006 r
.6174 .56166 m
.61737 .56082 L
s
.801 .162 .719 r
.26684 .8848 m
.26426 .88472 L
s
.43526 .72888 m
.43529 .72798 L
s
.30181 .85075 m
.30554 .84888 L
s
.526 .271 .006 r
.61744 .5625 m
.6174 .56166 L
s
.943 .561 .298 r
.40935 .75444 m
.40757 .75411 L
s
.801 .162 .719 r
.43524 .72978 m
.43526 .72888 L
s
.526 .271 .006 r
.61748 .56334 m
.61744 .5625 L
s
.801 .162 .719 r
.43521 .73069 m
.43524 .72978 L
s
.30554 .84888 m
.30931 .84701 L
s
.76 .35 .299 r
.74791 .44662 m
.74391 .44721 L
s
.526 .271 .006 r
.61752 .56418 m
.61748 .56334 L
s
.801 .162 .719 r
.26964 .88482 m
.26684 .8848 L
s
.43518 .73159 m
.43521 .73069 L
s
.943 .561 .298 r
.41107 .7548 m
.40935 .75444 L
s
.526 .271 .006 r
.61756 .56501 m
.61752 .56418 L
s
.801 .162 .719 r
.43516 .7325 m
.43518 .73159 L
s
.30931 .84701 m
.31309 .84512 L
s
.526 .271 .006 r
.61761 .56585 m
.61756 .56501 L
s
.801 .162 .719 r
.43513 .7334 m
.43516 .7325 L
s
.943 .561 .298 r
.41272 .75518 m
.41107 .7548 L
s
.526 .271 .006 r
.61766 .56668 m
.61761 .56585 L
s
.801 .162 .719 r
.27264 .8848 m
.26964 .88482 L
s
.76 .35 .299 r
.75191 .44603 m
.74791 .44662 L
s
.801 .162 .719 r
.31309 .84512 m
.31688 .84323 L
s
.43511 .73431 m
.43513 .7334 L
s
.526 .271 .006 r
.61772 .56752 m
.61766 .56668 L
s
.801 .162 .719 r
.43508 .73522 m
.43511 .73431 L
s
.943 .561 .298 r
.4143 .75559 m
.41272 .75518 L
s
.526 .271 .006 r
.61779 .56835 m
.61772 .56752 L
s
.801 .162 .719 r
.31688 .84323 m
.32066 .84133 L
s
.43505 .73613 m
.43508 .73522 L
s
.76 .35 .299 r
.63595 .55158 m
.63737 .5503 L
s
.6346 .55283 m
.63595 .55158 L
s
.63331 .55407 m
.6346 .55283 L
s
.63737 .5503 m
.63885 .54901 L
s
.63208 .55528 m
.63331 .55407 L
s
.63885 .54901 m
.64039 .5477 L
s
.526 .271 .006 r
.61787 .56917 m
.61779 .56835 L
s
.76 .35 .299 r
.63091 .55648 m
.63208 .55528 L
s
.64039 .5477 m
.642 .54637 L
s
.801 .162 .719 r
.27581 .88473 m
.27264 .8848 L
s
.76 .35 .299 r
.62981 .55766 m
.63091 .55648 L
s
.642 .54637 m
.64367 .54502 L
s
.801 .162 .719 r
.43503 .73704 m
.43505 .73613 L
s
.76 .35 .299 r
.62877 .55883 m
.62981 .55766 L
s
.64367 .54502 m
.64541 .54364 L
s
.62779 .55997 m
.62877 .55883 L
s
.75589 .44545 m
.75191 .44603 L
s
.64541 .54364 m
.64722 .54225 L
s
.801 .162 .719 r
.32066 .84133 m
.32443 .83944 L
s
.943 .561 .298 r
.41581 .75601 m
.4143 .75559 L
s
.76 .35 .299 r
.62686 .5611 m
.62779 .55997 L
s
.64722 .54225 m
.64909 .54084 L
s
.526 .271 .006 r
.61795 .57 m
.61787 .56917 L
s
.76 .35 .299 r
.626 .5622 m
.62686 .5611 L
s
.64909 .54084 m
.65102 .53941 L
s
.801 .162 .719 r
.435 .73795 m
.43503 .73704 L
s
.76 .35 .299 r
.6252 .56329 m
.626 .5622 L
s
.65102 .53941 m
.65303 .53796 L
s
.62445 .56437 m
.6252 .56329 L
s
.526 .271 .006 r
.61805 .57082 m
.61795 .57 L
s
.76 .35 .299 r
.65303 .53796 m
.6551 .53649 L
s
.801 .162 .719 r
.43497 .73886 m
.435 .73795 L
s
.76 .35 .299 r
.62377 .56542 m
.62445 .56437 L
s
.801 .162 .719 r
.32443 .83944 m
.32819 .83755 L
s
.76 .35 .299 r
.6551 .53649 m
.65725 .53499 L
s
.62315 .56646 m
.62377 .56542 L
s
.943 .561 .298 r
.41725 .75646 m
.41581 .75601 L
s
.526 .271 .006 r
.61817 .57163 m
.61805 .57082 L
s
.76 .35 .299 r
.65725 .53499 m
.65946 .53348 L
s
.801 .162 .719 r
.43495 .73978 m
.43497 .73886 L
s
.27915 .88463 m
.27581 .88473 L
s
.76 .35 .299 r
.62257 .56748 m
.62315 .56646 L
s
.65946 .53348 m
.66175 .53194 L
s
.62204 .56849 m
.62257 .56748 L
s
.526 .271 .006 r
.6183 .57244 m
.61817 .57163 L
s
.76 .35 .299 r
.75984 .44488 m
.75589 .44545 L
s
.801 .162 .719 r
.32819 .83755 m
.33192 .83566 L
s
.43492 .74069 m
.43495 .73978 L
s
.76 .35 .299 r
.66175 .53194 m
.66411 .53038 L
s
.62156 .56949 m
.62204 .56849 L
s
.943 .561 .298 r
.41863 .75693 m
.41725 .75646 L
s
.76 .35 .299 r
.66411 .53038 m
.66655 .52879 L
s
.526 .271 .006 r
.61846 .57324 m
.6183 .57244 L
s
.76 .35 .299 r
.62112 .57047 m
.62156 .56949 L
s
.801 .162 .719 r
.43489 .7416 m
.43492 .74069 L
s
.76 .35 .299 r
.66655 .52879 m
.66905 .52719 L
s
.62073 .57143 m
.62112 .57047 L
s
.801 .162 .719 r
.33192 .83566 m
.33561 .83378 L
s
.526 .271 .006 r
.61863 .57404 m
.61846 .57324 L
s
.801 .162 .719 r
.43486 .74252 m
.43489 .7416 L
s
.76 .35 .299 r
.62038 .57239 m
.62073 .57143 L
s
.66905 .52719 m
.67163 .52556 L
s
.801 .162 .719 r
.28263 .88449 m
.27915 .88463 L
s
.943 .561 .298 r
.41993 .75743 m
.41863 .75693 L
s
.76 .35 .299 r
.62007 .57333 m
.62038 .57239 L
s
.526 .271 .006 r
.61883 .57482 m
.61863 .57404 L
s
.801 .162 .719 r
.43483 .74343 m
.43486 .74252 L
s
.76 .35 .299 r
.67163 .52556 m
.67429 .5239 L
s
.76376 .44431 m
.75984 .44488 L
s
.801 .162 .719 r
.33561 .83378 m
.33927 .8319 L
s
.76 .35 .299 r
.61979 .57427 m
.62007 .57333 L
s
.67429 .5239 m
.67703 .52223 L
s
.801 .162 .719 r
.4348 .74435 m
.43483 .74343 L
s
.526 .271 .006 r
.61905 .5756 m
.61883 .57482 L
s
.76 .35 .299 r
.61955 .57519 m
.61979 .57427 L
s
.943 .561 .298 r
.42117 .75794 m
.41993 .75743 L
s
.76 .35 .299 r
.67703 .52223 m
.67984 .52052 L
s
.801 .162 .719 r
.43477 .74527 m
.4348 .74435 L
s
.33927 .8319 m
.34289 .83004 L
s
.526 .271 .006 r
.61931 .57637 m
.61905 .5756 L
s
.76 .35 .299 r
.61934 .5761 m
.61955 .57519 L
s
.801 .162 .719 r
.28624 .88432 m
.28263 .88449 L
s
.76 .35 .299 r
.67984 .52052 m
.68273 .5188 L
s
.61916 .57701 m
.61934 .5761 L
s
.801 .162 .719 r
.43474 .74618 m
.43477 .74527 L
s
.943 .561 .298 r
.42234 .75848 m
.42117 .75794 L
s
.526 .271 .006 r
.6196 .57713 m
.61931 .57637 L
s
.76 .35 .299 r
.76761 .44377 m
.76376 .44431 L
s
.801 .162 .719 r
.34289 .83004 m
.34645 .82819 L
s
.76 .35 .299 r
.619 .57791 m
.61916 .57701 L
s
.68273 .5188 m
.6857 .51705 L
s
.801 .162 .719 r
.4347 .7471 m
.43474 .74618 L
s
.526 .271 .006 r
.61993 .57787 m
.6196 .57713 L
s
.76 .35 .299 r
.61886 .5788 m
.619 .57791 L
s
.6857 .51705 m
.68875 .51527 L
s
.801 .162 .719 r
.43466 .74802 m
.4347 .7471 L
s
.943 .561 .298 r
.42342 .75905 m
.42234 .75848 L
s
.801 .162 .719 r
.34645 .82819 m
.34996 .82635 L
s
.76 .35 .299 r
.61875 .5797 m
.61886 .5788 L
s
.526 .271 .006 r
.6203 .5786 m
.61993 .57787 L
s
.801 .162 .719 r
.43463 .74894 m
.43466 .74802 L
s
.76 .35 .299 r
.68875 .51527 m
.69187 .51347 L
s
.801 .162 .719 r
.28997 .88413 m
.28624 .88432 L
s
.76 .35 .299 r
.61865 .58058 m
.61875 .5797 L
s
.801 .162 .719 r
.34996 .82635 m
.35341 .82452 L
s
.526 .271 .006 r
.62072 .57932 m
.6203 .5786 L
s
.943 .561 .298 r
.42443 .75964 m
.42342 .75905 L
s
.76 .35 .299 r
.77141 .44325 m
.76761 .44377 L
s
.801 .162 .719 r
.43458 .74986 m
.43463 .74894 L
s
.76 .35 .299 r
.69187 .51347 m
.69508 .51164 L
s
.61856 .58147 m
.61865 .58058 L
s
.801 .162 .719 r
.43454 .75078 m
.43458 .74986 L
s
.526 .271 .006 r
.62119 .58002 m
.62072 .57932 L
s
.76 .35 .299 r
.6185 .58235 m
.61856 .58147 L
s
.801 .162 .719 r
.35341 .82452 m
.3568 .82271 L
s
.943 .561 .298 r
.42538 .76025 m
.42443 .75964 L
s
.76 .35 .299 r
.69508 .51164 m
.69836 .50979 L
s
.801 .162 .719 r
.43448 .75171 m
.43454 .75078 L
s
.76 .35 .299 r
.61844 .58322 m
.6185 .58235 L
s
.526 .271 .006 r
.6217 .5807 m
.62119 .58002 L
s
.801 .162 .719 r
.3568 .82271 m
.36013 .82091 L
s
.76 .35 .299 r
.69836 .50979 m
.70172 .50792 L
s
.801 .162 .719 r
.29379 .88391 m
.28997 .88413 L
s
.43443 .75263 m
.43448 .75171 L
s
.76 .35 .299 r
.6184 .5841 m
.61844 .58322 L
s
.943 .561 .298 r
.42626 .76088 m
.42538 .76025 L
s
.76 .35 .299 r
.77513 .44275 m
.77141 .44325 L
s
.526 .271 .006 r
.62227 .58137 m
.6217 .5807 L
s
.801 .162 .719 r
.43436 .75356 m
.43443 .75263 L
s
.76 .35 .299 r
.61837 .58497 m
.6184 .5841 L
s
.801 .162 .719 r
.36013 .82091 m
.36339 .81913 L
s
.76 .35 .299 r
.70172 .50792 m
.70515 .50602 L
s
.943 .561 .298 r
.42708 .76153 m
.42626 .76088 L
s
.801 .162 .719 r
.43429 .75449 m
.43436 .75356 L
s
.526 .271 .006 r
.62289 .58202 m
.62227 .58137 L
s
.76 .35 .299 r
.61835 .58584 m
.61837 .58497 L
s
.801 .162 .719 r
.36339 .81913 m
.36658 .81737 L
s
.76 .35 .299 r
.70515 .50602 m
.70865 .5041 L
s
.801 .162 .719 r
.4342 .75542 m
.43429 .75449 L
s
.76 .35 .299 r
.61833 .58671 m
.61835 .58584 L
s
.526 .271 .006 r
.62356 .58266 m
.62289 .58202 L
s
.943 .561 .298 r
.42784 .7622 m
.42708 .76153 L
s
.76 .35 .299 r
.77875 .44227 m
.77513 .44275 L
s
.801 .162 .719 r
.29769 .88368 m
.29379 .88391 L
s
.36658 .81737 m
.36969 .81563 L
s
.4341 .75636 m
.4342 .75542 L
s
.76 .35 .299 r
.61832 .58757 m
.61833 .58671 L
s
.70865 .5041 m
.71222 .50216 L
s
.526 .271 .006 r
.62429 .58328 m
.62356 .58266 L
s
.801 .162 .719 r
.43398 .7573 m
.4341 .75636 L
s
.76 .35 .299 r
.61832 .58844 m
.61832 .58757 L
s
.943 .561 .298 r
.42853 .76289 m
.42784 .7622 L
s
.801 .162 .719 r
.36969 .81563 m
.37274 .81391 L
s
.76 .35 .299 r
.71222 .50216 m
.71585 .5002 L
s
.801 .162 .719 r
.43385 .75825 m
.43398 .7573 L
s
.76 .35 .299 r
.61832 .58931 m
.61832 .58844 L
s
.526 .271 .006 r
.6251 .58387 m
.62429 .58328 L
s
.801 .162 .719 r
.37274 .81391 m
.37571 .8122 L
s
.943 .561 .298 r
.42916 .76361 m
.42853 .76289 L
s
.801 .162 .719 r
.43368 .7592 m
.43385 .75825 L
s
.76 .35 .299 r
.78228 .44183 m
.77875 .44227 L
s
.61832 .59017 m
.61832 .58931 L
s
.71585 .5002 m
.71955 .49822 L
s
.801 .162 .719 r
.30165 .88345 m
.29769 .88368 L
s
.37571 .8122 m
.3786 .81052 L
s
.4335 .76017 m
.43368 .7592 L
s
.526 .271 .006 r
.62597 .58445 m
.6251 .58387 L
s
.76 .35 .299 r
.61833 .59104 m
.61832 .59017 L
s
.943 .561 .298 r
.42974 .76433 m
.42916 .76361 L
s
.801 .162 .719 r
.43329 .76113 m
.4335 .76017 L
s
.3786 .81052 m
.38141 .80886 L
s
.76 .35 .299 r
.71955 .49822 m
.7233 .49622 L
s
.61834 .5919 m
.61833 .59104 L
s
.526 .271 .006 r
.6269 .585 m
.62597 .58445 L
s
.943 .561 .298 r
.43027 .76508 m
.42974 .76433 L
s
.801 .162 .719 r
.43304 .7621 m
.43329 .76113 L
s
.38141 .80886 m
.38416 .80721 L
s
.76 .35 .299 r
.61835 .59277 m
.61834 .5919 L
s
.78569 .44143 m
.78228 .44183 L
s
.801 .162 .719 r
.43276 .76309 m
.43304 .7621 L
s
.76 .35 .299 r
.7233 .49622 m
.7271 .49421 L
s
.801 .162 .719 r
.38416 .80721 m
.38682 .80559 L
s
.943 .561 .298 r
.43075 .76584 m
.43027 .76508 L
s
.76 .35 .299 r
.61837 .59364 m
.61835 .59277 L
s
.526 .271 .006 r
.6279 .58553 m
.6269 .585 L
s
.801 .162 .719 r
.43244 .76409 m
.43276 .76309 L
s
.30566 .8832 m
.30165 .88345 L
s
.38682 .80559 m
.3894 .80398 L
s
.76 .35 .299 r
.61838 .59451 m
.61837 .59364 L
s
.801 .162 .719 r
.43206 .7651 m
.43244 .76409 L
s
.76 .35 .299 r
.7271 .49421 m
.73095 .49218 L
s
.943 .561 .298 r
.43118 .76662 m
.43075 .76584 L
s
.801 .162 .719 r
.3894 .80398 m
.39191 .8024 L
s
.526 .271 .006 r
.62896 .58604 m
.6279 .58553 L
s
.801 .162 .719 r
.43164 .76612 m
.43206 .7651 L
s
.76 .35 .299 r
.6184 .59537 m
.61838 .59451 L
s
.78896 .44107 m
.78569 .44143 L
s
.801 .162 .719 r
.39191 .8024 m
.39435 .80083 L
s
.43117 .76716 m
.43164 .76612 L
s
.943 .561 .298 r
.43155 .76741 m
.43118 .76662 L
s
.76 .35 .299 r
.73095 .49218 m
.73483 .49015 L
s
.61842 .59624 m
.6184 .59537 L
s
.801 .162 .719 r
.39435 .80083 m
.3967 .79929 L
s
.43063 .76822 m
.43117 .76716 L
s
.526 .271 .006 r
.6301 .58653 m
.62896 .58604 L
s
.801 .162 .719 r
.3967 .79929 m
.39898 .79777 L
s
.43003 .7693 m
.43063 .76822 L
s
.943 .561 .298 r
.43188 .76822 m
.43155 .76741 L
s
.76 .35 .299 r
.61844 .59711 m
.61842 .59624 L
s
.801 .162 .719 r
.3097 .88296 m
.30566 .8832 L
s
.42938 .77039 m
.43003 .7693 L
s
.39898 .79777 m
.40118 .79626 L
s
.76 .35 .299 r
.73483 .49015 m
.73874 .4881 L
s
.61846 .59798 m
.61844 .59711 L
s
.801 .162 .719 r
.42867 .77149 m
.42938 .77039 L
s
.40118 .79626 m
.40331 .79478 L
s
.526 .271 .006 r
.6313 .587 m
.6301 .58653 L
s
.943 .561 .298 r
.43217 .76904 m
.43188 .76822 L
s
.76 .35 .299 r
.7921 .44076 m
.78896 .44107 L
s
.801 .162 .719 r
.42789 .77261 m
.42867 .77149 L
s
.40331 .79478 m
.40536 .79331 L
s
.42704 .77376 m
.42789 .77261 L
s
.76 .35 .299 r
.61848 .59885 m
.61846 .59798 L
s
.801 .162 .719 r
.40536 .79331 m
.40734 .79187 L
s
.943 .561 .298 r
.43242 .76988 m
.43217 .76904 L
s
.801 .162 .719 r
.42612 .77492 m
.42704 .77376 L
s
.76 .35 .299 r
.73874 .4881 m
.74268 .48605 L
s
.801 .162 .719 r
.40734 .79187 m
.40924 .79044 L
s
.42512 .7761 m
.42612 .77492 L
s
.40924 .79044 m
.41107 .78904 L
s
.526 .271 .006 r
.63257 .58745 m
.6313 .587 L
s
.76 .35 .299 r
.6185 .59973 m
.61848 .59885 L
s
.801 .162 .719 r
.42406 .77731 m
.42512 .7761 L
s
.41107 .78904 m
.41283 .78765 L
s
.42292 .77853 m
.42406 .77731 L
s
.41283 .78765 m
.4145 .78628 L
s
.42172 .77977 m
.42292 .77853 L
s
.4145 .78628 m
.41611 .78494 L
s
.943 .561 .298 r
.43264 .77072 m
.43242 .76988 L
s
.801 .162 .719 r
.42044 .78103 m
.42172 .77977 L
s
.41611 .78494 m
.41763 .78361 L
s
.41909 .7823 m
.42044 .78103 L
s
.41763 .78361 m
.41909 .7823 L
s
.76 .35 .299 r
.61853 .6006 m
.6185 .59973 L
s
.79508 .44049 m
.7921 .44076 L
s
.74268 .48605 m
.74663 .484 L
s
.801 .162 .719 r
.31377 .88271 m
.3097 .88296 L
s
.526 .271 .006 r
.63391 .58787 m
.63257 .58745 L
s
.943 .561 .298 r
.43282 .77158 m
.43264 .77072 L
s
.76 .35 .299 r
.61855 .60147 m
.61853 .6006 L
s
.943 .561 .298 r
.43298 .77245 m
.43282 .77158 L
s
.76 .35 .299 r
.74663 .484 m
.75058 .48194 L
s
.61857 .60235 m
.61855 .60147 L
s
.526 .271 .006 r
.63531 .58827 m
.63391 .58787 L
s
.76 .35 .299 r
.7979 .44028 m
.79508 .44049 L
s
.6186 .60322 m
.61857 .60235 L
s
.943 .561 .298 r
.43311 .77332 m
.43298 .77245 L
s
.76 .35 .299 r
.75058 .48194 m
.75452 .4799 L
s
.61862 .6041 m
.6186 .60322 L
s
.943 .561 .298 r
.43323 .77421 m
.43311 .77332 L
s
.801 .162 .719 r
.31783 .88247 m
.31377 .88271 L
s
.526 .271 .006 r
.63679 .58865 m
.63531 .58827 L
s
.76 .35 .299 r
.61865 .60497 m
.61862 .6041 L
s
.943 .561 .298 r
.43332 .7751 m
.43323 .77421 L
s
.76 .35 .299 r
.75452 .4799 m
.75845 .47785 L
s
.80053 .44013 m
.7979 .44028 L
s
.61867 .60585 m
.61865 .60497 L
s
.943 .561 .298 r
.43339 .776 m
.43332 .7751 L
s
.526 .271 .006 r
.63833 .58901 m
.63679 .58865 L
s
.76 .35 .299 r
.6187 .60673 m
.61867 .60585 L
s
.75845 .47785 m
.76235 .47582 L
s
.943 .561 .298 r
.43345 .7769 m
.43339 .776 L
s
.76 .35 .299 r
.61872 .60761 m
.6187 .60673 L
s
.801 .162 .719 r
.32189 .88224 m
.31783 .88247 L
s
.76 .35 .299 r
.80296 .44005 m
.80053 .44013 L
s
.526 .271 .006 r
.63995 .58935 m
.63833 .58901 L
s
.943 .561 .298 r
.4335 .77781 m
.43345 .7769 L
s
.76 .35 .299 r
.76235 .47582 m
.7662 .47381 L
s
.61875 .60849 m
.61872 .60761 L
s
.943 .561 .298 r
.43353 .77872 m
.4335 .77781 L
s
.76 .35 .299 r
.61877 .60937 m
.61875 .60849 L
s
.526 .271 .006 r
.64163 .58966 m
.63995 .58935 L
s
.76 .35 .299 r
.8052 .44003 m
.80296 .44005 L
s
.7662 .47381 m
.77001 .47181 L
s
.943 .561 .298 r
.43356 .77964 m
.43353 .77872 L
s
.76 .35 .299 r
.6188 .61025 m
.61877 .60937 L
s
.943 .561 .298 r
.43358 .78056 m
.43356 .77964 L
s
.801 .162 .719 r
.32592 .88202 m
.32189 .88224 L
s
.76 .35 .299 r
.61882 .61113 m
.6188 .61025 L
s
.77001 .47181 m
.77374 .46984 L
s
.526 .271 .006 r
.64339 .58995 m
.64163 .58966 L
s
.943 .561 .298 r
.43359 .78148 m
.43358 .78056 L
s
.76 .35 .299 r
.80722 .44007 m
.8052 .44003 L
s
.61885 .61201 m
.61882 .61113 L
s
.943 .561 .298 r
.43359 .78241 m
.43359 .78148 L
s
.76 .35 .299 r
.77374 .46984 m
.7774 .4679 L
s
.61887 .61289 m
.61885 .61201 L
s
.526 .271 .006 r
.64521 .59022 m
.64339 .58995 L
s
.943 .561 .298 r
.43359 .78334 m
.43359 .78241 L
s
.76 .35 .299 r
.80901 .4402 m
.80722 .44007 L
s
.6189 .61377 m
.61887 .61289 L
s
.7774 .4679 m
.78097 .46598 L
s
.943 .561 .298 r
.43358 .78427 m
.43359 .78334 L
s
.801 .162 .719 r
.32992 .88182 m
.32592 .88202 L
s
.76 .35 .299 r
.61893 .61465 m
.6189 .61377 L
s
.526 .271 .006 r
.64711 .59046 m
.64521 .59022 L
s
.76 .35 .299 r
.81056 .4404 m
.80901 .4402 L
s
.943 .561 .298 r
.43358 .7852 m
.43358 .78427 L
s
.76 .35 .299 r
.78097 .46598 m
.78443 .46411 L
s
.61895 .61553 m
.61893 .61465 L
s
.943 .561 .298 r
.43357 .78614 m
.43358 .7852 L
s
.76 .35 .299 r
.61898 .61641 m
.61895 .61553 L
s
.78443 .46411 m
.78778 .46227 L
s
.81187 .44068 m
.81056 .4404 L
s
.943 .561 .298 r
.43355 .78707 m
.43357 .78614 L
s
.526 .271 .006 r
.64909 .59069 m
.64711 .59046 L
s
.76 .35 .299 r
.619 .61729 m
.61898 .61641 L
s
.801 .162 .719 r
.33387 .88164 m
.32992 .88182 L
s
.76 .35 .299 r
.78778 .46227 m
.79098 .46049 L
s
.943 .561 .298 r
.43354 .78801 m
.43355 .78707 L
s
.76 .35 .299 r
.61903 .61817 m
.619 .61729 L
s
.81291 .44105 m
.81187 .44068 L
s
.943 .561 .298 r
.43352 .78895 m
.43354 .78801 L
s
.76 .35 .299 r
.79098 .46049 m
.79404 .45875 L
s
.61906 .61905 m
.61903 .61817 L
s
.526 .271 .006 r
.65113 .59088 m
.64909 .59069 L
s
.76 .35 .299 r
.81369 .44151 m
.81291 .44105 L
s
.943 .561 .298 r
.4335 .78989 m
.43352 .78895 L
s
.76 .35 .299 r
.61908 .61993 m
.61906 .61905 L
s
.79404 .45875 m
.79694 .45707 L
s
.943 .561 .298 r
.43348 .79083 m
.4335 .78989 L
s
.76 .35 .299 r
.81421 .44205 m
.81369 .44151 L
s
.61911 .62081 m
.61908 .61993 L
s
.79694 .45707 m
.79966 .45544 L
s
.526 .271 .006 r
.65326 .59106 m
.65113 .59088 L
s
.801 .162 .719 r
.33777 .88148 m
.33387 .88164 L
s
.943 .561 .298 r
.43346 .79177 m
.43348 .79083 L
s
.76 .35 .299 r
.61913 .62168 m
.61911 .62081 L
s
.81444 .44268 m
.81421 .44205 L
s
.79966 .45544 m
.8022 .45388 L
s
.943 .561 .298 r
.43344 .79271 m
.43346 .79177 L
s
.76 .35 .299 r
.8022 .45388 m
.80452 .4524 L
s
.81441 .44341 m
.81444 .44268 L
s
.61916 .62256 m
.61913 .62168 L
s
.80452 .4524 m
.80663 .45098 L
s
.526 .271 .006 r
.65545 .59121 m
.65326 .59106 L
s
.76 .35 .299 r
.81409 .44422 m
.81441 .44341 L
s
.943 .561 .298 r
.43342 .79365 m
.43344 .79271 L
s
.76 .35 .299 r
.61919 .62344 m
.61916 .62256 L
s
.80663 .45098 m
.80851 .44964 L
s
.81351 .44513 m
.81409 .44422 L
s
.80851 .44964 m
.81014 .44839 L
s
.81265 .44613 m
.81351 .44513 L
s
.81014 .44839 m
.81153 .44721 L
s
.943 .561 .298 r
.43339 .79459 m
.43342 .79365 L
s
.76 .35 .299 r
.81153 .44721 m
.81265 .44613 L
s
.61921 .62431 m
.61919 .62344 L
s
.801 .162 .719 r
.34161 .88134 m
.33777 .88148 L
s
.943 .561 .298 r
.43337 .79554 m
.43339 .79459 L
s
.76 .35 .299 r
.61924 .62519 m
.61921 .62431 L
s
.526 .271 .006 r
.65773 .59134 m
.65545 .59121 L
s
.76 .35 .299 r
.61926 .62606 m
.61924 .62519 L
s
.943 .561 .298 r
.43334 .79648 m
.43337 .79554 L
s
.76 .35 .299 r
.61929 .62693 m
.61926 .62606 L
s
.943 .561 .298 r
.43332 .79742 m
.43334 .79648 L
s
.526 .271 .006 r
.66008 .59144 m
.65773 .59134 L
s
.801 .162 .719 r
.34537 .88123 m
.34161 .88134 L
s
.76 .35 .299 r
.61932 .62781 m
.61929 .62693 L
s
.943 .561 .298 r
.43329 .79837 m
.43332 .79742 L
s
.76 .35 .299 r
.61934 .62868 m
.61932 .62781 L
s
.943 .561 .298 r
.43327 .79931 m
.43329 .79837 L
s
.76 .35 .299 r
.61937 .62955 m
.61934 .62868 L
s
.526 .271 .006 r
.66251 .59152 m
.66008 .59144 L
s
.943 .561 .298 r
.43324 .80025 m
.43327 .79931 L
s
.76 .35 .299 r
.61939 .63042 m
.61937 .62955 L
s
.943 .561 .298 r
.43322 .80119 m
.43324 .80025 L
s
.801 .162 .719 r
.34906 .88114 m
.34537 .88123 L
s
.76 .35 .299 r
.61942 .63129 m
.61939 .63042 L
s
.943 .561 .298 r
.43319 .80213 m
.43322 .80119 L
s
.526 .271 .006 r
.66503 .59157 m
.66251 .59152 L
s
.76 .35 .299 r
.61945 .63216 m
.61942 .63129 L
s
.943 .561 .298 r
.43317 .80308 m
.43319 .80213 L
s
.76 .35 .299 r
.61947 .63303 m
.61945 .63216 L
s
.943 .561 .298 r
.43314 .80402 m
.43317 .80308 L
s
.76 .35 .299 r
.6195 .6339 m
.61947 .63303 L
s
.943 .561 .298 r
.43311 .80496 m
.43314 .80402 L
s
.526 .271 .006 r
.66762 .5916 m
.66503 .59157 L
s
.801 .162 .719 r
.35266 .88109 m
.34906 .88114 L
s
.76 .35 .299 r
.61953 .63477 m
.6195 .6339 L
s
.943 .561 .298 r
.43309 .8059 m
.43311 .80496 L
s
.76 .35 .299 r
.61955 .63564 m
.61953 .63477 L
s
.943 .561 .298 r
.43306 .80683 m
.43309 .8059 L
s
.76 .35 .299 r
.61958 .63651 m
.61955 .63564 L
s
.526 .271 .006 r
.6703 .5916 m
.66762 .5916 L
s
.943 .561 .298 r
.43304 .80777 m
.43306 .80683 L
s
.801 .162 .719 r
.35647 .88098 m
.35266 .88109 L
s
.76 .35 .299 r
.61961 .63738 m
.61958 .63651 L
s
.943 .561 .298 r
.43301 .80871 m
.43304 .80777 L
s
.76 .35 .299 r
.61963 .63825 m
.61961 .63738 L
s
.943 .561 .298 r
.43298 .80964 m
.43301 .80871 L
s
.526 .271 .006 r
.67306 .59158 m
.6703 .5916 L
s
.76 .35 .299 r
.61966 .63911 m
.61963 .63825 L
s
.943 .561 .298 r
.43296 .81058 m
.43298 .80964 L
s
.76 .35 .299 r
.61968 .63998 m
.61966 .63911 L
s
.943 .561 .298 r
.43293 .81151 m
.43296 .81058 L
s
.801 .162 .719 r
.36019 .88089 m
.35647 .88098 L
s
.76 .35 .299 r
.61971 .64085 m
.61968 .63998 L
s
.943 .561 .298 r
.4329 .81245 m
.43293 .81151 L
s
.526 .271 .006 r
.6759 .59153 m
.67306 .59158 L
s
.76 .35 .299 r
.61974 .64172 m
.61971 .64085 L
s
.943 .561 .298 r
.43287 .81338 m
.4329 .81245 L
s
.76 .35 .299 r
.61976 .64259 m
.61974 .64172 L
s
.943 .561 .298 r
.43285 .81431 m
.43287 .81338 L
s
.76 .35 .299 r
.61979 .64346 m
.61976 .64259 L
s
.526 .271 .006 r
.67883 .59146 m
.6759 .59153 L
s
.801 .162 .719 r
.36382 .88084 m
.36019 .88089 L
s
.943 .561 .298 r
.43282 .81524 m
.43285 .81431 L
s
.76 .35 .299 r
.61981 .64434 m
.61979 .64346 L
s
.943 .561 .298 r
.43279 .81617 m
.43282 .81524 L
s
.76 .35 .299 r
.61984 .64521 m
.61981 .64434 L
s
.943 .561 .298 r
.43276 .8171 m
.43279 .81617 L
s
.76 .35 .299 r
.61987 .64608 m
.61984 .64521 L
s
.526 .271 .006 r
.68184 .59135 m
.67883 .59146 L
s
.943 .561 .298 r
.43273 .81803 m
.43276 .8171 L
s
.76 .35 .299 r
.61989 .64695 m
.61987 .64608 L
s
.801 .162 .719 r
.36737 .88082 m
.36382 .88084 L
s
.943 .561 .298 r
.4327 .81896 m
.43273 .81803 L
s
.76 .35 .299 r
.61992 .64783 m
.61989 .64695 L
s
.943 .561 .298 r
.43268 .81989 m
.4327 .81896 L
s
.76 .35 .299 r
.61994 .6487 m
.61992 .64783 L
s
.526 .271 .006 r
.68495 .59123 m
.68184 .59135 L
s
.943 .561 .298 r
.43265 .82082 m
.43268 .81989 L
s
.76 .35 .299 r
.61997 .64958 m
.61994 .6487 L
s
.943 .561 .298 r
.43262 .82175 m
.43265 .82082 L
s
.801 .162 .719 r
.37082 .88082 m
.36737 .88082 L
s
.76 .35 .299 r
.61999 .65046 m
.61997 .64958 L
s
.943 .561 .298 r
.43259 .82268 m
.43262 .82175 L
s
.76 .35 .299 r
.62002 .65134 m
.61999 .65046 L
s
.526 .271 .006 r
.68813 .59107 m
.68495 .59123 L
s
.943 .561 .298 r
.43256 .82361 m
.43259 .82268 L
s
.76 .35 .299 r
.62004 .65221 m
.62002 .65134 L
s
.943 .561 .298 r
.43253 .82454 m
.43256 .82361 L
s
.76 .35 .299 r
.62007 .65309 m
.62004 .65221 L
s
.801 .162 .719 r
.37418 .88086 m
.37082 .88082 L
s
.943 .561 .298 r
.4325 .82547 m
.43253 .82454 L
s
.76 .35 .299 r
.6201 .65398 m
.62007 .65309 L
s
.526 .271 .006 r
.69141 .59089 m
.68813 .59107 L
s
.943 .561 .298 r
.43248 .8264 m
.4325 .82547 L
s
.76 .35 .299 r
.62012 .65486 m
.6201 .65398 L
s
.943 .561 .298 r
.43245 .82733 m
.43248 .8264 L
s
.76 .35 .299 r
.62015 .65574 m
.62012 .65486 L
s
.943 .561 .298 r
.43242 .82826 m
.43245 .82733 L
s
.801 .162 .719 r
.37745 .88092 m
.37418 .88086 L
s
.76 .35 .299 r
.62017 .65663 m
.62015 .65574 L
s
.526 .271 .006 r
.69477 .59068 m
.69141 .59089 L
s
.943 .561 .298 r
.43239 .82919 m
.43242 .82826 L
s
.76 .35 .299 r
.6202 .65751 m
.62017 .65663 L
s
.943 .561 .298 r
.43237 .83012 m
.43239 .82919 L
s
.76 .35 .299 r
.62022 .6584 m
.6202 .65751 L
s
.943 .561 .298 r
.43234 .83105 m
.43237 .83012 L
s
.76 .35 .299 r
.62025 .65929 m
.62022 .6584 L
s
.801 .162 .719 r
.38062 .88102 m
.37745 .88092 L
s
.943 .561 .298 r
.43231 .83199 m
.43234 .83105 L
s
.526 .271 .006 r
.69822 .59045 m
.69477 .59068 L
s
.76 .35 .299 r
.62027 .66018 m
.62025 .65929 L
s
.943 .561 .298 r
.43229 .83292 m
.43231 .83199 L
s
.76 .35 .299 r
.6203 .66107 m
.62027 .66018 L
s
.943 .561 .298 r
.43226 .83386 m
.43229 .83292 L
s
.76 .35 .299 r
.62033 .66197 m
.6203 .66107 L
s
.801 .162 .719 r
.3837 .88114 m
.38062 .88102 L
s
.943 .561 .298 r
.43224 .83479 m
.43226 .83386 L
s
.526 .271 .006 r
.70175 .59019 m
.69822 .59045 L
s
.76 .35 .299 r
.62035 .66286 m
.62033 .66197 L
s
.943 .561 .298 r
.43221 .83573 m
.43224 .83479 L
s
.76 .35 .299 r
.62038 .66376 m
.62035 .66286 L
s
.943 .561 .298 r
.43219 .83667 m
.43221 .83573 L
s
.76 .35 .299 r
.62041 .66466 m
.62038 .66376 L
s
.943 .561 .298 r
.43217 .83761 m
.43219 .83667 L
s
.801 .162 .719 r
.38669 .8813 m
.3837 .88114 L
s
.76 .35 .299 r
.62043 .66556 m
.62041 .66466 L
s
.526 .271 .006 r
.70537 .5899 m
.70175 .59019 L
s
.943 .561 .298 r
.43214 .83855 m
.43217 .83761 L
s
.76 .35 .299 r
.62046 .66646 m
.62043 .66556 L
s
.943 .561 .298 r
.43212 .83949 m
.43214 .83855 L
s
.76 .35 .299 r
.62049 .66737 m
.62046 .66646 L
s
.943 .561 .298 r
.43209 .84043 m
.43212 .83949 L
s
.801 .162 .719 r
.38958 .88148 m
.38669 .8813 L
s
.76 .35 .299 r
.62051 .66828 m
.62049 .66737 L
s
.526 .271 .006 r
.70906 .58959 m
.70537 .5899 L
s
.943 .561 .298 r
.43207 .84137 m
.43209 .84043 L
s
.76 .35 .299 r
.62054 .66919 m
.62051 .66828 L
s
.943 .561 .298 r
.43204 .84231 m
.43207 .84137 L
s
.76 .35 .299 r
.62057 .6701 m
.62054 .66919 L
s
.943 .561 .298 r
.43202 .84326 m
.43204 .84231 L
s
.801 .162 .719 r
.39239 .88169 m
.38958 .88148 L
s
.76 .35 .299 r
.62059 .67101 m
.62057 .6701 L
s
.943 .561 .298 r
.432 .8442 m
.43202 .84326 L
s
.526 .271 .006 r
.71283 .58926 m
.70906 .58959 L
s
.76 .35 .299 r
.62062 .67192 m
.62059 .67101 L
s
.943 .561 .298 r
.43197 .84515 m
.432 .8442 L
s
.76 .35 .299 r
.62065 .67284 m
.62062 .67192 L
s
.943 .561 .298 r
.43195 .8461 m
.43197 .84515 L
s
.801 .162 .719 r
.3951 .88193 m
.39239 .88169 L
s
.76 .35 .299 r
.62067 .67375 m
.62065 .67284 L
s
.943 .561 .298 r
.43192 .84705 m
.43195 .8461 L
s
.526 .271 .006 r
.71668 .5889 m
.71283 .58926 L
s
.76 .35 .299 r
.6207 .67467 m
.62067 .67375 L
s
.943 .561 .298 r
.43189 .848 m
.43192 .84705 L
s
.76 .35 .299 r
.62073 .67559 m
.6207 .67467 L
s
.943 .561 .298 r
.43187 .84896 m
.43189 .848 L
s
.801 .162 .719 r
.39771 .8822 m
.3951 .88193 L
s
.76 .35 .299 r
.62076 .67651 m
.62073 .67559 L
s
.943 .561 .298 r
.43184 .84991 m
.43187 .84896 L
s
.76 .35 .299 r
.62079 .67744 m
.62076 .67651 L
s
.943 .561 .298 r
.43182 .85087 m
.43184 .84991 L
s
.526 .271 .006 r
.7206 .58852 m
.71668 .5889 L
s
.76 .35 .299 r
.62081 .67836 m
.62079 .67744 L
s
.943 .561 .298 r
.43179 .85183 m
.43182 .85087 L
s
.801 .162 .719 r
.40011 .88253 m
.39771 .8822 L
s
.76 .35 .299 r
.62084 .67929 m
.62081 .67836 L
s
.943 .561 .298 r
.43176 .85279 m
.43179 .85183 L
s
.76 .35 .299 r
.62087 .68021 m
.62084 .67929 L
s
.943 .561 .298 r
.43173 .85375 m
.43176 .85279 L
s
.526 .271 .006 r
.72457 .58812 m
.7206 .58852 L
s
.801 .162 .719 r
.40241 .88289 m
.40011 .88253 L
s
.76 .35 .299 r
.6209 .68114 m
.62087 .68021 L
s
.943 .561 .298 r
.43171 .85472 m
.43173 .85375 L
s
.76 .35 .299 r
.62093 .68206 m
.6209 .68114 L
s
.943 .561 .298 r
.43168 .85568 m
.43171 .85472 L
s
.76 .35 .299 r
.62095 .68299 m
.62093 .68206 L
s
.943 .561 .298 r
.43165 .85665 m
.43168 .85568 L
s
.801 .162 .719 r
.40463 .88327 m
.40241 .88289 L
s
.76 .35 .299 r
.62098 .68392 m
.62095 .68299 L
s
.526 .271 .006 r
.72861 .58771 m
.72457 .58812 L
s
.943 .561 .298 r
.43162 .85762 m
.43165 .85665 L
s
.76 .35 .299 r
.62101 .68485 m
.62098 .68392 L
s
.943 .561 .298 r
.43159 .8586 m
.43162 .85762 L
s
.76 .35 .299 r
.62104 .68578 m
.62101 .68485 L
s
.801 .162 .719 r
.40675 .88368 m
.40463 .88327 L
s
.943 .561 .298 r
.43156 .85957 m
.43159 .8586 L
s
.76 .35 .299 r
.62107 .68671 m
.62104 .68578 L
s
.943 .561 .298 r
.43153 .86055 m
.43156 .85957 L
s
.526 .271 .006 r
.7327 .58728 m
.72861 .58771 L
s
.76 .35 .299 r
.6211 .68764 m
.62107 .68671 L
s
.943 .561 .298 r
.43149 .86153 m
.43153 .86055 L
s
.801 .162 .719 r
.40879 .88412 m
.40675 .88368 L
s
.76 .35 .299 r
.62114 .68857 m
.6211 .68764 L
s
.943 .561 .298 r
.43146 .86252 m
.43149 .86153 L
s
.76 .35 .299 r
.62117 .6895 m
.62114 .68857 L
s
.943 .561 .298 r
.43142 .8635 m
.43146 .86252 L
s
.526 .271 .006 r
.73684 .58683 m
.7327 .58728 L
s
.801 .162 .719 r
.41073 .88459 m
.40879 .88412 L
s
.76 .35 .299 r
.6212 .69043 m
.62117 .6895 L
s
.943 .561 .298 r
.43139 .86449 m
.43142 .8635 L
s
.76 .35 .299 r
.62124 .69136 m
.6212 .69043 L
s
.943 .561 .298 r
.43135 .86548 m
.43139 .86449 L
s
.76 .35 .299 r
.62128 .69229 m
.62124 .69136 L
s
.943 .561 .298 r
.4313 .86648 m
.43135 .86548 L
s
.801 .162 .719 r
.41258 .88509 m
.41073 .88459 L
s
.76 .35 .299 r
.62132 .69322 m
.62128 .69229 L
s
.943 .561 .298 r
.43125 .86748 m
.4313 .86648 L
s
.526 .271 .006 r
.74101 .58637 m
.73684 .58683 L
s
.76 .35 .299 r
.62136 .69415 m
.62132 .69322 L
s
.943 .561 .298 r
.4312 .86848 m
.43125 .86748 L
s
.801 .162 .719 r
.41433 .88562 m
.41258 .88509 L
s
.76 .35 .299 r
.6214 .69508 m
.62136 .69415 L
s
.943 .561 .298 r
.43114 .86949 m
.4312 .86848 L
s
.76 .35 .299 r
.62145 .696 m
.6214 .69508 L
s
.943 .561 .298 r
.43107 .8705 m
.43114 .86949 L
s
.801 .162 .719 r
.41597 .88618 m
.41433 .88562 L
s
.526 .271 .006 r
.74521 .5859 m
.74101 .58637 L
s
.76 .35 .299 r
.62151 .69693 m
.62145 .696 L
s
.943 .561 .298 r
.43099 .87152 m
.43107 .8705 L
s
.4309 .87254 m
.43099 .87152 L
s
.76 .35 .299 r
.62157 .69785 m
.62151 .69693 L
s
.801 .162 .719 r
.41751 .88677 m
.41597 .88618 L
s
.943 .561 .298 r
.43078 .87358 m
.4309 .87254 L
s
.76 .35 .299 r
.62164 .69877 m
.62157 .69785 L
s
.943 .561 .298 r
.43065 .87462 m
.43078 .87358 L
s
.76 .35 .299 r
.62172 .69969 m
.62164 .69877 L
s
.526 .271 .006 r
.74942 .58543 m
.74521 .5859 L
s
.943 .561 .298 r
.43048 .87567 m
.43065 .87462 L
s
.801 .162 .719 r
.41895 .88739 m
.41751 .88677 L
s
.76 .35 .299 r
.62182 .7006 m
.62172 .69969 L
s
.943 .561 .298 r
.43028 .87673 m
.43048 .87567 L
s
.76 .35 .299 r
.62192 .70151 m
.62182 .7006 L
s
.943 .561 .298 r
.43005 .8778 m
.43028 .87673 L
s
.801 .162 .719 r
.42027 .88804 m
.41895 .88739 L
s
.76 .35 .299 r
.62205 .70242 m
.62192 .70151 L
s
.943 .561 .298 r
.42978 .87888 m
.43005 .8778 L
s
.526 .271 .006 r
.75365 .58495 m
.74942 .58543 L
s
.76 .35 .299 r
.6222 .70332 m
.62205 .70242 L
s
.943 .561 .298 r
.42945 .87998 m
.42978 .87888 L
s
.801 .162 .719 r
.4215 .88872 m
.42027 .88804 L
s
.76 .35 .299 r
.62237 .70421 m
.6222 .70332 L
s
.943 .561 .298 r
.42905 .88109 m
.42945 .87998 L
s
.42859 .88223 m
.42905 .88109 L
s
.76 .35 .299 r
.62257 .70509 m
.62237 .70421 L
s
.943 .561 .298 r
.42804 .88339 m
.42859 .88223 L
s
.526 .271 .006 r
.75787 .58448 m
.75365 .58495 L
s
.76 .35 .299 r
.6228 .70596 m
.62257 .70509 L
s
.943 .561 .298 r
.4274 .88457 m
.42804 .88339 L
s
.42666 .88578 m
.4274 .88457 L
s
.76 .35 .299 r
.62306 .70682 m
.6228 .70596 L
s
.943 .561 .298 r
.42583 .88702 m
.42666 .88578 L
s
.4249 .88828 m
.42583 .88702 L
s
.42384 .88957 m
.4249 .88828 L
s
.526 .271 .006 r
.63866 .69251 m
.64016 .69116 L
s
.63724 .69384 m
.63866 .69251 L
s
.76 .35 .299 r
.62336 .70767 m
.62306 .70682 L
s
.526 .271 .006 r
.64016 .69116 m
.64173 .68979 L
s
.63589 .69515 m
.63724 .69384 L
s
.64173 .68979 m
.64338 .6884 L
s
.63463 .69644 m
.63589 .69515 L
s
.943 .561 .298 r
.42268 .89089 m
.42384 .88957 L
s
.526 .271 .006 r
.64338 .6884 m
.64511 .68699 L
s
.63346 .6977 m
.63463 .69644 L
s
.64511 .68699 m
.64691 .68555 L
s
.63236 .69894 m
.63346 .6977 L
s
.943 .561 .298 r
.42139 .89224 m
.42268 .89089 L
s
.526 .271 .006 r
.64691 .68555 m
.64879 .6841 L
s
.63133 .70016 m
.63236 .69894 L
s
.64879 .6841 m
.65074 .68262 L
s
.63038 .70136 m
.63133 .70016 L
s
.76 .35 .299 r
.62371 .70851 m
.62336 .70767 L
s
.526 .271 .006 r
.65074 .68262 m
.65278 .68113 L
s
.76208 .584 m
.75787 .58448 L
s
.62949 .70255 m
.63038 .70136 L
s
.65278 .68113 m
.6549 .67961 L
s
.62867 .70371 m
.62949 .70255 L
s
.6549 .67961 m
.65709 .67806 L
s
.62793 .70486 m
.62867 .70371 L
s
.76 .35 .299 r
.62411 .70933 m
.62371 .70851 L
s
.526 .271 .006 r
.65709 .67806 m
.65936 .6765 L
s
.62725 .70599 m
.62793 .70486 L
s
.65936 .6765 m
.66171 .67491 L
s
.62661 .7071 m
.62725 .70599 L
s
.76 .35 .299 r
.62457 .71013 m
.62411 .70933 L
s
.526 .271 .006 r
.66171 .67491 m
.66414 .67331 L
s
.62604 .7082 m
.62661 .7071 L
s
.62553 .70929 m
.62604 .7082 L
s
.66414 .67331 m
.66666 .67167 L
s
.76627 .58354 m
.76208 .584 L
s
.76 .35 .299 r
.62508 .71092 m
.62457 .71013 L
s
.526 .271 .006 r
.62507 .71036 m
.62553 .70929 L
s
.66666 .67167 m
.66926 .67002 L
s
.62466 .71141 m
.62507 .71036 L
s
.66926 .67002 m
.67193 .66834 L
s
.76 .35 .299 r
.62566 .71169 m
.62508 .71092 L
s
.526 .271 .006 r
.62431 .71246 m
.62466 .71141 L
s
.67193 .66834 m
.6747 .66664 L
s
.624 .71349 m
.62431 .71246 L
s
.6747 .66664 m
.67754 .66492 L
s
.76 .35 .299 r
.6263 .71244 m
.62566 .71169 L
s
.526 .271 .006 r
.62373 .71451 m
.624 .71349 L
s
.77041 .58308 m
.76627 .58354 L
s
.67754 .66492 m
.68047 .66317 L
s
.6235 .71551 m
.62373 .71451 L
s
.76 .35 .299 r
.62701 .71317 m
.6263 .71244 L
s
.526 .271 .006 r
.68047 .66317 m
.68349 .66139 L
s
.6233 .71652 m
.6235 .71551 L
s
.62313 .71751 m
.6233 .71652 L
s
.68349 .66139 m
.68658 .65959 L
s
.76 .35 .299 r
.62777 .71388 m
.62701 .71317 L
s
.526 .271 .006 r
.62299 .7185 m
.62313 .71751 L
s
.68658 .65959 m
.68977 .65777 L
s
.77451 .58264 m
.77041 .58308 L
s
.76 .35 .299 r
.62861 .71457 m
.62777 .71388 L
s
.526 .271 .006 r
.62286 .71948 m
.62299 .7185 L
s
.68977 .65777 m
.69303 .65593 L
s
.62276 .72047 m
.62286 .71948 L
s
.76 .35 .299 r
.62953 .71524 m
.62861 .71457 L
s
.526 .271 .006 r
.69303 .65593 m
.69638 .65406 L
s
.62268 .72144 m
.62276 .72047 L
s
.62262 .72242 m
.62268 .72144 L
s
.76 .35 .299 r
.63053 .71589 m
.62953 .71524 L
s
.526 .271 .006 r
.69638 .65406 m
.69981 .65216 L
s
.77854 .58221 m
.77451 .58264 L
s
.62257 .72339 m
.62262 .72242 L
s
.69981 .65216 m
.70332 .65025 L
s
.76 .35 .299 r
.63161 .71651 m
.63053 .71589 L
s
.526 .271 .006 r
.62253 .72436 m
.62257 .72339 L
s
.70332 .65025 m
.70691 .64831 L
s
.6225 .72532 m
.62253 .72436 L
s
.76 .35 .299 r
.63276 .7171 m
.63161 .71651 L
s
.526 .271 .006 r
.7825 .58181 m
.77854 .58221 L
s
.62249 .72629 m
.6225 .72532 L
s
.70691 .64831 m
.71058 .64635 L
s
.62248 .72725 m
.62249 .72629 L
s
.76 .35 .299 r
.63399 .71768 m
.63276 .7171 L
s
.526 .271 .006 r
.71058 .64635 m
.71432 .64437 L
s
.62247 .72821 m
.62248 .72725 L
s
.62247 .72918 m
.62247 .72821 L
s
.76 .35 .299 r
.6353 .71823 m
.63399 .71768 L
s
.526 .271 .006 r
.78637 .58143 m
.7825 .58181 L
s
.71432 .64437 m
.71813 .64237 L
s
.62248 .73014 m
.62247 .72918 L
s
.76 .35 .299 r
.63669 .71876 m
.6353 .71823 L
s
.526 .271 .006 r
.71813 .64237 m
.72201 .64034 L
s
.62249 .7311 m
.62248 .73014 L
s
.6225 .73206 m
.62249 .7311 L
s
.72201 .64034 m
.72595 .63831 L
s
.79013 .58109 m
.78637 .58143 L
s
.76 .35 .299 r
.63816 .71926 m
.63669 .71876 L
s
.526 .271 .006 r
.62251 .73303 m
.6225 .73206 L
s
.62253 .73399 m
.62251 .73303 L
s
.72595 .63831 m
.72994 .63625 L
s
.76 .35 .299 r
.63974 .71974 m
.63816 .71926 L
s
.526 .271 .006 r
.62255 .73495 m
.62253 .73399 L
s
.79376 .58078 m
.79013 .58109 L
s
.72994 .63625 m
.73399 .63418 L
s
.62257 .73591 m
.62255 .73495 L
s
.76 .35 .299 r
.6414 .72018 m
.63974 .71974 L
s
.526 .271 .006 r
.62259 .73688 m
.62257 .73591 L
s
.73399 .63418 m
.73809 .6321 L
s
.62261 .73784 m
.62259 .73688 L
s
.76 .35 .299 r
.64315 .72061 m
.6414 .72018 L
s
.526 .271 .006 r
.79726 .58051 m
.79376 .58078 L
s
.62263 .7388 m
.62261 .73784 L
s
.73809 .6321 m
.74222 .63001 L
s
.62266 .73977 m
.62263 .7388 L
s
.76 .35 .299 r
.64499 .721 m
.64315 .72061 L
s
.526 .271 .006 r
.74222 .63001 m
.74638 .62791 L
s
.62268 .74073 m
.62266 .73977 L
s
.80062 .58028 m
.79726 .58051 L
s
.62271 .74169 m
.62268 .74073 L
s
.74638 .62791 m
.75057 .62581 L
s
.76 .35 .299 r
.64691 .72138 m
.64499 .721 L
s
.526 .271 .006 r
.62274 .74266 m
.62271 .74169 L
s
.62276 .74362 m
.62274 .74266 L
s
.75057 .62581 m
.75477 .6237 L
s
.80381 .58011 m
.80062 .58028 L
s
.76 .35 .299 r
.64891 .72172 m
.64691 .72138 L
s
.526 .271 .006 r
.62279 .74458 m
.62276 .74362 L
s
.62282 .74555 m
.62279 .74458 L
s
.75477 .6237 m
.75898 .6216 L
s
.62284 .74651 m
.62282 .74555 L
s
.76 .35 .299 r
.651 .72205 m
.64891 .72172 L
s
.526 .271 .006 r
.80681 .57998 m
.80381 .58011 L
s
.75898 .6216 m
.76318 .6195 L
s
.62287 .74747 m
.62284 .74651 L
s
.6229 .74843 m
.62287 .74747 L
s
.76 .35 .299 r
.65317 .72235 m
.651 .72205 L
s
.526 .271 .006 r
.76318 .6195 m
.76736 .6174 L
s
.62293 .74939 m
.6229 .74843 L
s
.80961 .57992 m
.80681 .57998 L
s
.62295 .75035 m
.62293 .74939 L
s
.76736 .6174 m
.77151 .61532 L
s
.76 .35 .299 r
.65543 .72262 m
.65317 .72235 L
s
.526 .271 .006 r
.62298 .75131 m
.62295 .75035 L
s
.81219 .57993 m
.80961 .57992 L
s
.62301 .75227 m
.62298 .75131 L
s
.77151 .61532 m
.77561 .61325 L
s
.62304 .75323 m
.62301 .75227 L
s
.76 .35 .299 r
.65777 .72287 m
.65543 .72262 L
s
.526 .271 .006 r
.77561 .61325 m
.77967 .61121 L
s
.62307 .75418 m
.62304 .75323 L
s
.81454 .58 m
.81219 .57993 L
s
.6231 .75514 m
.62307 .75418 L
s
.76 .35 .299 r
.66021 .72309 m
.65777 .72287 L
s
.526 .271 .006 r
.77967 .61121 m
.78365 .60918 L
s
.62312 .75609 m
.6231 .75514 L
s
.81664 .58015 m
.81454 .58 L
s
.62315 .75705 m
.62312 .75609 L
s
.78365 .60918 m
.78754 .60719 L
s
.62318 .758 m
.62315 .75705 L
s
.76 .35 .299 r
.66273 .72329 m
.66021 .72309 L
s
.526 .271 .006 r
.81849 .58037 m
.81664 .58015 L
s
.78754 .60719 m
.79131 .60523 L
s
.62321 .75895 m
.62318 .758 L
s
.62324 .7599 m
.62321 .75895 L
s
.79131 .60523 m
.79495 .60332 L
s
.82006 .58068 m
.81849 .58037 L
s
.76 .35 .299 r
.66534 .72346 m
.66273 .72329 L
s
.526 .271 .006 r
.62327 .76085 m
.62324 .7599 L
s
.79495 .60332 m
.79846 .60145 L
s
.6233 .7618 m
.62327 .76085 L
s
.82136 .58107 m
.82006 .58068 L
s
.62333 .76275 m
.6233 .7618 L
s
.79846 .60145 m
.8018 .59963 L
s
.76 .35 .299 r
.66804 .72361 m
.66534 .72346 L
s
.526 .271 .006 r
.82236 .58155 m
.82136 .58107 L
s
.62336 .7637 m
.62333 .76275 L
s
.8018 .59963 m
.80497 .59787 L
s
.62339 .76465 m
.62336 .7637 L
s
.82306 .58212 m
.82236 .58155 L
s
.80497 .59787 m
.80794 .59617 L
s
.76 .35 .299 r
.67084 .72373 m
.66804 .72361 L
s
.526 .271 .006 r
.62342 .7656 m
.62339 .76465 L
s
.82345 .58278 m
.82306 .58212 L
s
.80794 .59617 m
.81069 .59454 L
s
.62345 .76654 m
.62342 .7656 L
s
.82353 .58354 m
.82345 .58278 L
s
.81069 .59454 m
.81322 .59297 L
s
.62349 .76749 m
.62345 .76654 L
s
.81322 .59297 m
.8155 .59149 L
s
.82329 .5844 m
.82353 .58354 L
s
.76 .35 .299 r
.67372 .72382 m
.67084 .72373 L
s
.526 .271 .006 r
.8155 .59149 m
.81752 .59009 L
s
.62352 .76844 m
.62349 .76749 L
s
.82274 .58535 m
.82329 .5844 L
s
.81752 .59009 m
.81927 .58877 L
s
.82189 .5864 m
.82274 .58535 L
s
.81927 .58877 m
.82072 .58754 L
s
.82072 .58754 m
.82189 .5864 L
s
.62355 .76938 m
.62352 .76844 L
s
.62358 .77033 m
.62355 .76938 L
s
.76 .35 .299 r
.6767 .72389 m
.67372 .72382 L
s
.526 .271 .006 r
.62361 .77128 m
.62358 .77033 L
s
.62364 .77223 m
.62361 .77128 L
s
.62367 .77317 m
.62364 .77223 L
s
.76 .35 .299 r
.67977 .72393 m
.6767 .72389 L
s
.526 .271 .006 r
.6237 .77412 m
.62367 .77317 L
s
.62373 .77507 m
.6237 .77412 L
s
.62376 .77602 m
.62373 .77507 L
s
.76 .35 .299 r
.68293 .72394 m
.67977 .72393 L
s
.526 .271 .006 r
.62379 .77697 m
.62376 .77602 L
s
.62382 .77792 m
.62379 .77697 L
s
.62384 .77888 m
.62382 .77792 L
s
.76 .35 .299 r
.68619 .72393 m
.68293 .72394 L
s
.526 .271 .006 r
.62387 .77983 m
.62384 .77888 L
s
.6239 .78079 m
.62387 .77983 L
s
.62393 .78174 m
.6239 .78079 L
s
.76 .35 .299 r
.68954 .72389 m
.68619 .72393 L
s
.526 .271 .006 r
.62395 .7827 m
.62393 .78174 L
s
.62398 .78366 m
.62395 .7827 L
s
.624 .78462 m
.62398 .78366 L
s
.76 .35 .299 r
.69298 .72383 m
.68954 .72389 L
s
.526 .271 .006 r
.62403 .78558 m
.624 .78462 L
s
.62406 .78654 m
.62403 .78558 L
s
.62408 .78751 m
.62406 .78654 L
s
.76 .35 .299 r
.69651 .72374 m
.69298 .72383 L
s
.526 .271 .006 r
.62411 .78847 m
.62408 .78751 L
s
.62413 .78943 m
.62411 .78847 L
s
.62416 .7904 m
.62413 .78943 L
s
.76 .35 .299 r
.70014 .72362 m
.69651 .72374 L
s
.526 .271 .006 r
.62419 .79137 m
.62416 .7904 L
s
.62421 .79234 m
.62419 .79137 L
s
.62424 .79331 m
.62421 .79234 L
s
.76 .35 .299 r
.70385 .72348 m
.70014 .72362 L
s
.526 .271 .006 r
.62427 .79428 m
.62424 .79331 L
s
.6243 .79525 m
.62427 .79428 L
s
.62432 .79623 m
.6243 .79525 L
s
.62435 .7972 m
.62432 .79623 L
s
.76 .35 .299 r
.70765 .72331 m
.70385 .72348 L
s
.526 .271 .006 r
.62438 .79818 m
.62435 .7972 L
s
.62441 .79916 m
.62438 .79818 L
s
.62444 .80014 m
.62441 .79916 L
s
.76 .35 .299 r
.71154 .72313 m
.70765 .72331 L
s
.526 .271 .006 r
.62447 .80113 m
.62444 .80014 L
s
.6245 .80211 m
.62447 .80113 L
s
.62453 .8031 m
.6245 .80211 L
s
.76 .35 .299 r
.7155 .72291 m
.71154 .72313 L
s
.526 .271 .006 r
.62456 .80409 m
.62453 .8031 L
s
.62459 .80508 m
.62456 .80409 L
s
.62462 .80607 m
.62459 .80508 L
s
.62466 .80706 m
.62462 .80607 L
s
.76 .35 .299 r
.71955 .72268 m
.7155 .72291 L
s
.526 .271 .006 r
.62469 .80806 m
.62466 .80706 L
s
.62473 .80906 m
.62469 .80806 L
s
.62476 .81006 m
.62473 .80906 L
s
.76 .35 .299 r
.72367 .72242 m
.71955 .72268 L
s
.526 .271 .006 r
.6248 .81107 m
.62476 .81006 L
s
.62484 .81207 m
.6248 .81107 L
s
.62489 .81308 m
.62484 .81207 L
s
.76 .35 .299 r
.72786 .72215 m
.72367 .72242 L
s
.526 .271 .006 r
.62493 .81409 m
.62489 .81308 L
s
.62499 .81509 m
.62493 .81409 L
s
.62504 .81611 m
.62499 .81509 L
s
.62511 .81712 m
.62504 .81611 L
s
.76 .35 .299 r
.73211 .72185 m
.72786 .72215 L
s
.526 .271 .006 r
.62518 .81813 m
.62511 .81712 L
s
.62527 .81914 m
.62518 .81813 L
s
.62537 .82015 m
.62527 .81914 L
s
.76 .35 .299 r
.73643 .72154 m
.73211 .72185 L
s
.526 .271 .006 r
.62549 .82116 m
.62537 .82015 L
s
.62564 .82216 m
.62549 .82116 L
s
.62582 .82315 m
.62564 .82216 L
s
.76 .35 .299 r
.74079 .72121 m
.73643 .72154 L
s
.526 .271 .006 r
.62604 .82414 m
.62582 .82315 L
s
.62628 .82512 m
.62604 .82414 L
s
.62658 .82609 m
.62628 .82512 L
s
.76 .35 .299 r
.74519 .72088 m
.74079 .72121 L
s
.526 .271 .006 r
.62693 .82704 m
.62658 .82609 L
s
.62736 .82798 m
.62693 .82704 L
s
.62786 .82889 m
.62736 .82798 L
s
.76 .35 .299 r
.74964 .72053 m
.74519 .72088 L
s
.526 .271 .006 r
.62846 .82979 m
.62786 .82889 L
s
.62915 .83065 m
.62846 .82979 L
s
.62995 .83149 m
.62915 .83065 L
s
.76 .35 .299 r
.75411 .72017 m
.74964 .72053 L
s
.526 .271 .006 r
.63085 .83231 m
.62995 .83149 L
s
.63185 .83309 m
.63085 .83231 L
s
.76 .35 .299 r
.75859 .71981 m
.75411 .72017 L
s
.526 .271 .006 r
.63299 .83384 m
.63185 .83309 L
s
.76 .35 .299 r
.63987 .82732 m
.64155 .82583 L
s
.63831 .82879 m
.63987 .82732 L
s
.63687 .83022 m
.63831 .82879 L
s
.64155 .82583 m
.64334 .8243 L
s
.63554 .83163 m
.63687 .83022 L
s
.64334 .8243 m
.64525 .82275 L
s
.526 .271 .006 r
.63425 .83456 m
.63299 .83384 L
s
.76 .35 .299 r
.64525 .82275 m
.64728 .82117 L
s
.64728 .82117 m
.6494 .81956 L
s
.6494 .81956 m
.65164 .81793 L
s
.76308 .71944 m
.75859 .71981 L
s
.65164 .81793 m
.65398 .81627 L
s
.65398 .81627 m
.65642 .81458 L
s
.526 .271 .006 r
.63565 .83524 m
.63425 .83456 L
s
.76 .35 .299 r
.65642 .81458 m
.65897 .81287 L
s
.65897 .81287 m
.66161 .81113 L
s
.66161 .81113 m
.66451 .80933 L
s
.66451 .80933 m
.66752 .80749 L
s
.76758 .71907 m
.76308 .71944 L
s
.66752 .80749 m
.67064 .80563 L
s
.67064 .80563 m
.67387 .80374 L
s
.67387 .80374 m
.67721 .80183 L
s
.67721 .80183 m
.68066 .79988 L
s
.77205 .71871 m
.76758 .71907 L
s
.68066 .79988 m
.68423 .79791 L
s
.68423 .79791 m
.68791 .7959 L
s
.77648 .71835 m
.77205 .71871 L
s
.68791 .7959 m
.6917 .79387 L
s
.6917 .79387 m
.69561 .79181 L
s
.69561 .79181 m
.69964 .78971 L
s
.78089 .71801 m
.77648 .71835 L
s
.69964 .78971 m
.70378 .78759 L
s
.70378 .78759 m
.70804 .78544 L
s
.78523 .71768 m
.78089 .71801 L
s
.70804 .78544 m
.7124 .78327 L
s
.7124 .78327 m
.71654 .78115 L
s
.78949 .71737 m
.78523 .71768 L
s
.71654 .78115 m
.72079 .77901 L
s
.72079 .77901 m
.72515 .77684 L
s
.79365 .71708 m
.78949 .71737 L
s
.72515 .77684 m
.7296 .77465 L
s
.7296 .77465 m
.73414 .77244 L
s
.7977 .71683 m
.79365 .71708 L
s
.73414 .77244 m
.73876 .77021 L
s
.73876 .77021 m
.74345 .76796 L
s
.80162 .71661 m
.7977 .71683 L
s
.74345 .76796 m
.74819 .76571 L
s
.80539 .71643 m
.80162 .71661 L
s
.74819 .76571 m
.75298 .76344 L
s
.75298 .76344 m
.75779 .76118 L
s
.80899 .71629 m
.80539 .71643 L
s
.75779 .76118 m
.76261 .75891 L
s
.81241 .71621 m
.80899 .71629 L
s
.76261 .75891 m
.76743 .75665 L
s
.76743 .75665 m
.77223 .7544 L
s
.81561 .71618 m
.81241 .71621 L
s
.77223 .7544 m
.77699 .75217 L
s
.8186 .71621 m
.81561 .71618 L
s
.77699 .75217 m
.78168 .74995 L
s
.78168 .74995 m
.7863 .74777 L
s
.82133 .71631 m
.8186 .71621 L
s
.7863 .74777 m
.79081 .74561 L
s
.82379 .71648 m
.82133 .71631 L
s
.79081 .74561 m
.7952 .74349 L
s
.82598 .71673 m
.82379 .71648 L
s
.7952 .74349 m
.79945 .74142 L
s
.82786 .71707 m
.82598 .71673 L
s
.79945 .74142 m
.80353 .7394 L
s
.82942 .71749 m
.82786 .71707 L
s
.80353 .7394 m
.80742 .73743 L
s
.80742 .73743 m
.8111 .73553 L
s
.83065 .718 m
.82942 .71749 L
s
.8111 .73553 m
.81455 .73369 L
s
.83153 .71861 m
.83065 .718 L
s
.81455 .73369 m
.81775 .73193 L
s
.83207 .71932 m
.83153 .71861 L
s
.81775 .73193 m
.82067 .73024 L
s
.83224 .72013 m
.83207 .71932 L
s
.82067 .73024 m
.8233 .72864 L
s
.83205 .72104 m
.83224 .72013 L
s
.8233 .72864 m
.82562 .72713 L
s
.83149 .72205 m
.83205 .72104 L
s
.82562 .72713 m
.82761 .72571 L
s
.83055 .72317 m
.83149 .72205 L
s
.82761 .72571 m
.82926 .72439 L
s
.82926 .72439 m
.83055 .72317 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.19353 .20137 m
.19843 .20677 L
s
[(-2)] .18373 .19058 .90814 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.54595 .05319 m
.55008 .0592 L
s
[(2)] .53771 .04117 .68623 1 Mshowa
.125 Mabswid
.23496 .18395 m
.23785 .18723 L
s
.2771 .16623 m
.27993 .16956 L
s
.31997 .14821 m
.32275 .15158 L
s
.40797 .11121 m
.41064 .11467 L
s
.45315 .09221 m
.45575 .09572 L
s
.49913 .07288 m
.50167 .07643 L
s
.1528 .2185 m
.15578 .22169 L
s
.11274 .23534 m
.11577 .23849 L
s
.59363 .03314 m
.59603 .0368 L
s
.64218 .01273 m
.64451 .01643 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(-1)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(-0.5)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(0.5)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(1)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017a000`40O003h00Oogoo2Woo003oOol:
Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00;Moo`80051oo`00]Goo0P0000=oo`000000Cgoo002C
Ool4000LOol20003Ool2001?Ool009=oo`03001oogoo01Yoo`<000Eoo`03001oo`0004ioo`00U7oo
00<007ooOol05goo0P0000=oo`00Ool01Goo00<007oo0000CWoo002EOol00`00Oomoo`0COol3000:
Ool01000Oomoo`00CGoo002COol01000Oomoo`004Woo0P003Goo00D007ooOomoo`0004aoo`00U7oo
0P004Goo0P003goo00D007ooOomoo`0004aoo`00Y7oo0`004Goo00<007ooOol00Woo00<007ooOol0
BGoo002ROol200000goo001oo`0BOol00`00Oomoo`02Ool00`00Oomoo`18Ool00:1oo`8001Moo`03
001oogoo009oo`03001oogoo04Qoo`00WGoo0`006Goo00<007ooOol00goo00<007ooOol0Agoo002K
Ool2000LOol00`00Oomoo`03Ool00`00Oomoo`17Ool009Uoo`8001ioo`03001oogoo00Aoo`03001o
ogoo04Ioo`00UWoo0`0000=oo`00Ool07Goo00<007ooOol01Goo00<007ooOol0AGoo002DOol20004
Ool00`00Oomoo`0LOol00`00Oomoo`05Ool00`00Oomoo`15Ool0095oo`<002Eoo`03001oogoo00Io
o`03001oogoo04Aoo`00Sgoo0P00:7oo00<007ooOol01Woo00<007ooOol0A7oo002=Ool2000ZOol0
0`00Oomoo`07Ool00`00Oomoo`13Ool008Yoo`<00003Ool007oo02Uoo`03001oogoo00Qoo`03001o
ogoo049oo`00R7oo0P00;goo00<007ooOol027oo00<007ooOol0@Woo001WOol2000MOol2000aOol0
0`00Oomoo`09Ool00`00Oomoo`11Ool006Ioo`04001oogoo000IOol3000cOol00`00Oomoo`0:Ool0
0`00Oomoo`10Ool006Ioo`04001oogoo000GOol3000eOol00`00Oomoo`0:Ool00`00Oomoo`10Ool0
06Ioo`04001oogoo000EOol2000hOol00`00Oomoo`0;Ool00`00Oomoo`0oOol006Ioo`04001oogoo
000BOol3000jOol00`00Oomoo`0;Ool00`00Oomoo`0oOol006Moo`80015oo`8003eoo`03001oogoo
00aoo`03001oogoo03ioo`00Mgoo0`00@7oo00<007ooOol037oo00<007ooOol0?Goo001eOol20000
0goo001oo`10Ool00`00Oomoo`0<Ool00`00Oomoo`0mOol007=oo`8004Eoo`03001oogoo00eoo`03
001oogoo03aoo`00L7oo0`00Agoo00<007ooOol03Goo00<007ooOol0?7oo001^Ool2001:Ool00`00
Oomoo`0>Ool00`00Oomoo`0kOol006aoo`8004aoo`03001oogoo00moo`03001oogoo03Yoo`00JGoo
0`000Woo00<007ooOol0BGoo00<007ooOol03goo00<007ooOol0>Woo001WOol2001AOol00`00Oomo
o`0@Ool00`00Oomoo`0iOol006Aoo`<005=oo`03001oogoo011oo`03001oogoo03Uoo`00HWoo0P00
EWoo00<007ooOol04Goo00<007ooOol0>7oo001POol200000goo001oo`1EOol00`00Oomoo`0BOol0
0`00Oomoo`0gOol005eoo`<005Yoo`03001oogoo019oo`03001oogoo03Moo`00?7oo10006goo0P00
GGoo00<007ooOol04goo00<007ooOol0=Woo000lOol00`00Oomoo`0JOol2001OOol00`00Oomoo`0D
Ool00`00Oomoo`0eOol003eoo`03001oogoo01Ioo`<0065oo`03001oogoo01Aoo`03001oogoo03Eo
o`00=Woo100017oo00<007ooOol04goo0P00I7oo00<007ooOol05Goo00<007ooOol0=7oo000lOol0
1000Oomoo`004Woo0P00IWoo00<007ooOol05Goo00<007ooOol0=7oo000mOol2000@Ool3001XOol0
0`00Oomoo`0FOol00`00Oomoo`0cOol004eoo`8006aoo`03001oogoo01Ioo`03001oogoo039oo`00
BWoo0`0000=oo`00Ool0Jgoo00<007ooOol05Woo00<007ooOol0<Woo0018Ool2001aOol00`00Oomo
o`0GOol00`00Oomoo`0aOol004Ioo`8007=oo`03001oogoo01Moo`03001oogoo035oo`00@goo0`00
MGoo00<007ooOol067oo00<007ooOol0<7oo0011Ool200000goo001oo`1eOol00`00Oomoo`0IOol0
0`00Oomoo`0_Ool003moo`8007Yoo`03001oogoo01Uoo`03001oogoo02moo`00?7oo0`00O7oo00<0
07ooOol06Woo00<007ooOol0;Woo000iOol3001oOol00`00Oomoo`0KOol00`00Oomoo`0]Ool003Qo
o`<0081oo`03001oogoo01]oo`03001oogoo02eoo`00=Goo0`00Pgoo00<007ooOol077oo00<007oo
Ool0;7oo000cOol20026Ool00`00Oomoo`0LOol00`00Oomoo`0/Ool002moo`@008Qoo`03001oogoo
01eoo`03001oogoo02]oo`00;Woo0`00RWoo00<007ooOol07Woo00<007ooOol0:Woo000/Ool2002=
Ool00`00Oomoo`0NOol00`00Oomoo`0ZOol002Yoo`8008moo`03001oogoo01moo`03001oogoo02Uo
o`00:Woo0P00Sgoo00<007ooOol07goo00<007ooOol0:Goo000YOol200000goo001oo`2=Ool00`00
Oomoo`0POol00`00Oomoo`0XOol002Yoo`04001oogoo002>Ool00`00Oomoo`0POol00`00Oomoo`0W
Ool002Uoo`03001oogoo009oo`03001oogoo08]oo`03001oogoo021oo`03001oogoo02Moo`00:Goo
00<007ooOol00goo00<007ooOol0RWoo00<007ooOol08Goo00<007ooOol09Woo000YOol00`00Oomo
o`04Ool00`00Oomoo`29Ool00`00Oomoo`0ROol00`00Oomoo`0UOol002Qoo`8000Moo`03001oogoo
08Qoo`03001oogoo029oo`03001oogoo02Eoo`00:Goo00<007ooOol01Woo00<007ooOol0Qgoo00<0
07ooOol08goo00<007ooOol097oo000YOol00`00Oomoo`07Ool00`00Oomoo`26Ool00`00Oomoo`0S
Ool00`00Oomoo`0TOol002Qoo`03001oogoo00Uoo`03001oogoo08Eoo`03001oogoo02Aoo`03001o
ogoo02=oo`00:7oo00<007ooOol02Woo00<007ooOol0Q7oo00<007ooOol09Goo00<007ooOol08Woo
000XOol00`00Oomoo`0;Ool00`00Oomoo`23Ool00`00Oomoo`0?Ool01D3P@@110440@>000d4000A0
h440@@1100Yoo`03001oogoo029oo`009goo0P003Woo00<007ooOol0PWoo00<007ooOol02Woo014l
h440?>110CcP@@0lh441?>1103cP@@4lh440?>110CcP00]oo`03001oogoo025oo`00:7oo00<007oo
Ool03Goo00<007ooOol0PGoo00<007ooOol017oo00=1043P@@000T4000E0h440@@11043P00=10005
@>110440@@10h003@@000d3P@@1oo`0:Ool00`00Oomoo`0QOol002Qoo`03001oogoo00ioo`03001o
ogoo081oo`0D000lh441?>1103cP@@4lh440?>110CcP@@0lh441?>1103cP@@4lh0=oo`07?>1103cP
@@4lh440?>0037oo00<007ooOol087oo000WOol00`00Oomoo`0@Ool00`00Oomoo`1ZOol015e9GDQM
BD3P0d4000=0h440Ool00goo0T4000U0h440@@11043P@@000440@>000d4000E0h440@@11043P00=1
0003@>1oogoo00Aoo`03@@10h44000910003@>11044000ioo`03001oogoo01moo`009goo00<007oo
Ool04Goo00<007ooOol0JGoo01iMB65YGDQ103cP@@4lh440?>110CcP@@0lh441?>1103cP@@4lh440
?>0003cP@@0lh441?>1103cP@@4;Ool02441?>1103cP@@4lh440?>0?Ool00`00Oomoo`0OOol002Mo
o`03001oogoo019oo`03001oogoo06Qoo`03GDUMB5e900910005@>110440@@10h003@@001D3P@@11
0440@>000d4000<00440@@003goo0T4000I0h440@@11043P@@0BOol00`00Oomoo`0NOol002Moo`03
001oogoo01=oo`03001oogoo06Moo`04GDQQBEe8HFT2Ool02ScP@@4lh440?>110CcP@@0lh4411Goo
00<007ooOol03Woo00Llh441?>1103cP@@4lh00DOol00`00Oomoo`0NOol002Moo`03001oogoo01Ao
o`03001oogoo06Ioo`04GDUMB5e9GDPAOol00`00Oomoo`0<Ool3@@00143P@@1104405goo00<007oo
Ool07Goo000WOol00`00Oomoo`0DOol00`00Oomoo`1VOol015e8HFUMB6594Woo00<007ooOol02Goo
00Plh440?>110CcP@@0lh4416Goo00<007ooOol077oo000VOol00`00Oomoo`0FOol00`00Oomoo`1U
Ool015e9GDQMBEe84Woo00<007ooOol01goo00=1043P@@000T4000=0h440@@006goo00<007ooOol0
77oo000VOol00`00Oomoo`0GOol00`00Oomoo`1TOol015e8HDUMB65Y4Woo00<007ooOol01Goo00Pl
h441?>1103cP@@4lh4407Woo00<007ooOol06goo000VOol00`00Oomoo`0HOol00`00Oomoo`1SOol0
15e9GDQMBEe84Woo00<007ooOol00goo0d4000E0h440@@11043P025oo`03001oogoo01Yoo`009Woo
0P006Woo00<007ooOol0HWoo00AMB65YGDQQBA9oo`0<001oogooOollh440?>110CcP@@0lh4418goo
00<007ooOol06Woo000VOol00`00Oomoo`0JOol00`00Oomoo`1QOol015e9GDQMBEe84Woo00@007oo
@@10h0=10003@>11044002Ioo`03001oogoo01Uoo`004Woo0P0017oo0P0017oo0P001Woo00<007oo
Ool06goo00<007ooOol0H7oo00AMB659GDQQJA9oo`0800110CcP@@0lh441?>1102Qoo`03001oogoo
01Uoo`004Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol07Goo
00<007ooOol0Ggoo00AMBEe8GDUMB15oo`03@@00043P00=10003@>1oogoo02Uoo`03001oogoo01Qo
o`004goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0NOol0
0`00Oomoo`1NOol015e8HFUMB6593goo00Q103cP@@400440?>110CcP;Goo00<007ooOol05goo000;
Ool40005Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo01moo`03
001oogoo03Ioo`03H9ITUVBF02Aoo`04GDUMB5e9GDP=Ool01T3P@@110440@>00009102moo`03001o
ogoo01Moo`004Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo0P008Goo00<0
07ooOol0=7oo00APUVBFH9IT]RAoo`04GDQQBEe8HFT;Ool02D41?>1103cP@@4lh44000110@0aOol0
0`00Oomoo`0FOol0019oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo025oo`03001oogoo039oo`05
H9ITUVBFI9IPUP0TOol015e9GDQMBEe82Woo00=1043P@@000T4000A0h440Ool0039oo`03001oogoo
01Ioo`009Goo00<007ooOol08Woo00<007ooOol0;goo00Mj:GHXI9IPUVBfH9ITUP0TOol015e8HFUM
B65927oo00Plh441?>1103cP@@4lh4400Woo00<007ooOol0<Goo00<007ooOol05Goo000TOol00`00
Oomoo`0TOol00`00Oomoo`0/Ool017HXMRUf:7HY0VBF00=PUVBFI9H097oo00AMBEe8GDUMB0Moo`91
0005@>110440@@10h004Ool00`00Oomoo`0bOol00`00Oomoo`0DOol002Aoo`03001oogoo02Eoo`03
001oogoo02Yoo`09MPQj:GHXMRUf26BfH9ITUV2F02Eoo`04GDQQBEe8HFT5Ool02440?>110CcP@@0l
h441?>05Ool00`00Oomoo`0bOol00`00Oomoo`0DOol002Aoo`03001oogoo02Ioo`03001oogoo02Qo
o`07MRQf:GHXMRUf:7HYH9H00fBF9Goo00AMBEe8GDUMB0Aoo`=10004@>110440@@07Ool00`00Oomo
o`0cOol00`00Oomoo`0COol002Aoo`8002Qoo`03001oogoo02Ioo`0;MPQj:GHXMRUf27XYMRQTUV2F
I;IPUP0UOol015e8HFUMB6590goo00M103cP@@4lh440?>110@08Ool00`00Oomoo`0dOol00`00Oomo
o`0BOol002Aoo`03001oogoo02Qoo`03001oogoo02=oo`09MRUf:7HYMRQf:GHXMRUf:7oo009TUP03
H9ITUWoo02Aoo`04GDUMB5e9GDP2Ool3@@000d3P@@11000:Ool00`00Oomoo`0dOol00`00Oomoo`0B
Ool002Aoo`03001oogoo02Uoo`03001oogoo025oo`07MRUf27XYMRQf:GH8NRT00goo00AT]V2FI9IP
UREoo`0;GDQQBEe8HFUood40?>110CcP@@0lh00<Ool00`00Oomoo`0dOol00`00Oomoo`0AOol002Ao
o`03001oogoo02Yoo`03001oogoo01ioo`08MRQf:GHXMRUf:7HYMRQf:@Aoo`04H9ITUVBFI9HUOol0
15e9GDQMBEe80d4000=0h440@@003Goo00<007ooOol0=7oo00<007ooOol04Goo000SOol00`00Oomo
o`0/Ool00`00Oomoo`0LOol01gHXMRUf27XYMRQf:GH800Ioo`04I9IPUVBfH9HUOol02Ee8HFUMB440
?>110CcP@@0lh00>Ool00`00Oomoo`0dOol2000BOol002=oo`03001oogoo02eoo`03001oogoo01Yo
o`07MRQf:GHXMRUf:7HYMRP01goo0VBF00=PUVBFOol097oo00=MBEe8@@000T4000=0h440@@003goo
00<007ooOol0<Goo0`0000=oo`00Ool04Goo000SOol00`00Oomoo`0^Ool00`00Oomoo`0GOol01gXY
MRQf:GH8NRUf:7HY00Uoo`04I;IPUVBFH9HUOol01ee8@@0lh441?>1103cP011oo`03001oogoo02io
o`<000Aoo`03001oogoo011oo`008goo0P00<7oo00<007ooOol057oo00Qf:7HYMRQf:GHXMRUf:7HY
2Woo00APUVBFI9ITURIoo`910003@>110440015oo`03001oogoo02]oo`<000Moo`03001oogoo011o
o`008goo00<007ooOol0<7oo00<007ooOol04Woo00Mf27XYMRQf:GH8NRUf:00<Ool016BFH9IT]V2F
9Woo00E10CcP@@0lh441015oo`03001oogoo02Qoo`<000]oo`03001oogoo00moo`008goo00<007oo
Ool0<Goo00<007ooOol03goo00Mf:GHXMRUf:7HYMRQf:@0>Ool2I9H00f2FI9Ioo`0UOol015e8GDUM
B5e94Woo00<007ooOol057oo00MMBEe8GDUMB5e9GDQMB@0:Ool3000>Ool00`00Oomoo`0?Ool0029o
o`03001oogoo03=oo`03001oogoo00aoo`08MRQf:GH8NRUf:7HYMPQj:@moo`04I;IPUVBFH9HVOol0
1659GDQQJEe84Woo00<007ooOol037oo011MB65YGDQQBEe8HFUMB659GDQQJEe8HDUMB65YGDQQB@Io
o`<0015oo`03001oogoo00moo`008Woo00<007ooOol0=7oo00<007ooOol02Woo00Qf:7HYMRQf:GHX
MRUf:7HY47oo00APUVBFI9ITURIoo`05@@1MBEe8GDUMB00AOol00`00Oomoo`05Ool05ee8GDUMB5e9
GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDP00goo0`0057oo00<007ooOol03goo
000ROol00`00Oomoo`0eOol00`00Oomoo`06Ool027H8NRUf:7HYMPQj:GHXMRTCOol016BFH9IT]V2F
9Woo00M10Ee8HDUMB65YGDQQB@0?Ool07`00GDQQJEe8HDUMB65YGDQQBEe8HFUMB659GDQQJEe8HDUM
B65YGDQQBEe8HFUMB659GDQQJEe8HDUMB65Y00<001Moo`03001oogoo00moo`008Woo0P00=goo00<0
07ooOol017oo00Qf:7HYMRQf:GHXMRUf:7HY57oo0VBF00=PUVBFOol09Goo02M0h440GDQMBEe8GDUM
B5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMB@00GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUM
B5e9GDP01goo00MMB5e9GDQMBEe8GDT0000JOol00`00Oomoo`0?Ool0029oo`03001oogoo03Moo`0<
001oogooOomf:GH8NRUf:7HYMPQj:GHX5Woo00AT]V2FI9IPURIoo`0P@@0lh441GDQQBEe8HFUMB659
GDQQJEe8HDUMB65YGDQQBEe8HFUMB659GDP005e8HDUMB65YGDQQBEe8HFUMB0aoo`07HDUMB65YGDQQ
BEe8HFT077oo00<007ooOol03goo000ROol00`00Oomoo`0hOol02@00MRQf:GHXMRUf:7HYMRQf:@0H
Ool0162FI9ITUVBF9Woo0T4001M0h440GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9
001MBEe8015oo`08GDQMBEe8GDUMB5e9GDQMBAioo`03001oogoo00ioo`008Goo00<007ooOol0>7oo
00Qj:GHXMRUf27XYMRQf:GH86Woo00ATUV2FI;IPURIoo`04@@4lh440?>0BOol00`00Oomoo`0?Ool0
265YGDQQBEe8HFUMB659GDPPOol00`00Oomoo`0>Ool0025oo`03001oogoo03Ioo`09MRQf:GHXMRUf
:7HYMRQf:GHX01]oo`9TUP03H9ITUWoo02Eoo`04@>110440@@0BOol00`00Oomoo`0=Ool02000GDUM
B5e9GDQMBEe8GDTROol00`00Oomoo`0>Ool0025oo`03001oogoo03Eoo`08MPQj:GHXMRUf27XYMRP0
01eoo`04I;IPUVBFH9HVOol01440?>110CcP4Woo00<007ooOol02Woo0P0000MMB65YGDQQBEe8HFUM
B00TOol00`00Oomoo`0>Ool0025oo`03001oogoo03=oo`08MRUf:7HYMRQf:GHXMRUf:09oo`03001o
ogoo00Ioo`0EMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:F2F00=TURIoo`91
0003@>1107oo015oo`03001oogoo00Moo`<00008GDUMB5e9GDQMBEe8GDUMB2Eoo`03001oogoo00io
o`0087oo0`00<goo00Mf:GH8NRUf:7HYMPQj:@05Ool08000MPQj:GHXMRUf27XYMRQf:GH8NRUf:7HY
MPQj:GHXMRUf27XYMRQf:GH8NRUf:7HYMPQj:GHXI9IPUVBfH9HVOol01441?>1103cP4goo00<007oo
Ool00goo0`0000Uooee8HDUMB65YGDQQBEe8HFT09goo00<007ooOol03Woo000QOol00`00Oomoo`0a
Ool0:GHYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHX
MRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRT00VBF00=PUVBFOol09Goo00A0h440@@1101=oo`03001o
ogoo00<0009oo`08GDUMB5e9GDQMBEe8GDUMB2Uoo`03001oogoo00ioo`0037oo10000goo0P0017oo
0P001Goo00<007ooOol0<Woo01Mf27XYMRQf:GH8NRUf:7HYMPQj:GHXMRUf27XYMRQf:GH8NRUf:7HY
MPQj:GHX00moo`07MRQf:GH8I;IPUVBFH9H09Woo00A103cP@@4lh1=oo`<000=oo`08GDQQJEe8HDUM
B65YGDQQBB]oo`03001oogoo00ioo`0037oo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0004Ool00`00Oomoo`0bOol04GHYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHX00005goo00Ef
:GHXMRUf:7HY02Ioo`910003@>1107oo00moo`@000=oo`08GDUMB5e9GDQMBEe8GDUMB2ioo`03001o
ogoo00eoo`003Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0b
Ool02GHXMRUf27XYMRQf:GH8NRUf:008Ool00`00Oomoo`0DOol01F2FMRUf27XYMRP09Woo00A10CcP
@@0lh0eoo`<000=oo`0:001ooee8HDUMB65YGDQQBEe8HFT`Ool00`00Oomoo`0=Ool000Ioo`@000Ao
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0@goo00<007oo
Ool057oo00ETUWHXMRUf:7HY02Ioo`04@>110440@@09Ool40006Ool02000GDQMBEe8GDUMB5e9GDPb
Ool00`00Oomoo`0=Ool000aoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo04Aoo`03001oogoo01=oo`05H9Ij:GHXMRUf200VOol01440?>110CcP1Woo0`0027oo00QM
B65Y001QBEe8HFUMB659=7oo00<007ooOol03Goo000=Ool20004Ool20004Ool20004Ool20017Ool0
0`00Oomoo`0AOol2I9H017HXMRUf:7HY9Woo0T4000=0h440Ool00Woo0`002Goo00UMBEe8GDUMB000
GDQMBEe8GDT0=Goo00<007ooOol03Goo000OOol00`00Oomoo`17Ool00`00Oomoo`0?Ool01f2FI;IP
UWHYMPQj:GHX02Ioo`04@@4lh440?>03000;Ool01f59GDQQJEe8HDT0065Y03Qoo`03001oogoo00eo
o`007goo00<007ooOol0B7oo00<007ooOol03Goo0VBF00IPUVBFMRQf:GHXMRTVOol0143P@@110440
37oo00QMB5e9GDQMBEe8GDUMB000>Goo00<007ooOol03Goo000OOol00`00Oomoo`19Ool00`00Oomo
o`0;Ool02F2FI;IPUVBFH9Ij:GHXMRUf200TOol200001440?>110CcP2Woo00YQJEe8HDUMB65YGDQQ
BEe8Ool003Yoo`03001oogoo00aoo`007goo00<007ooOol0BWoo00<007ooOol02Goo0VBF00QPUVBF
I9If:GHXMRUf:7HY8Goo0`000Woo0T4000=0h440Ool027oo00MMBEe8GDUMB5e9GDQMB@03Ool00`00
Oomoo`0hOol00`00Oomoo`0<Ool001moo`03001oogoo04]oo`03001oogoo00Moo`0;H9IT]V2FI9IP
UVBfMRQf:GH8NRUf:00NOol30005Ool01441?>1103cP1goo00MMB65YGDQQBEe8HFUMB005Ool00`00
Oomoo`0hOol00`00Oomoo`0<Ool001moo`03001oogoo04aoo`03001oogoo00Aoo`=TUP0:H9ITUVBF
I9IPUWHYMRQf:GHXMRTKOol30008Ool0143P@@1104401Woo00MMB5e9GDQMBEe8GDUMB006Ool00`00
Oomoo`0hOol00`00Oomoo`0<Ool001ioo`8004moo`03001oogoo009oo`0=I9IPUVBfH9ITUV2FI;IP
UWooMPQj:GHXMRT06Goo0`002goo00A103cP@@4lh0Aoo`07HDUMB65YGDQQBEe8HFT027oo00<007oo
Ool0>7oo00<007ooOol037oo000NOol00`00Oomoo`1?Ool00`00Oomoo`03I9H0162FI9ITUVBF0goo
00Af:GHXMRUf:1Ioo`<000ioo`910003@>1107oo009oo`07GDUMB5e9GDQMBEe8GDT02Goo00<007oo
Ool0>7oo00<007ooOol037oo000NOol00`00Oomoo`1@Ool0262FI9IPUVBfH9ITUV2FI;H4Ool017HX
MRUf27XY4goo0`004Goo00A10CcP@@0lh09oo`07HDUMB65YGDQQBEe8HFT02Woo00<007ooOol0>7oo
00<007ooOol037oo000NOol00`00Oomoo`1?Ool01F2FI9ITUVBFH9H00VBF1Woo00Af:GHXMRUf:11o
o`<001Aoo`0;@>110440@@1MB5e9GDQMBEe8GDUMB00<Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool0
01ioo`03001oogoo04eoo`08I;IPUVBFH9IT]V2FI9IPUPMoo`04MPQj:GHXMRT=Ool3000GOol02T40
?>110CcPHDUMB65YGDQQBEe83Woo00<007ooOol0>7oo00<007ooOol02goo000NOol00`00Oomoo`1;
Ool2I9H01f2FI9ITUVBFH9ITUP0000Qoo`04MRUf:7HYMRP:Ool3000JOol2@@001d3PGDUMB5e9GDQM
BEe800moo`03001oogoo03Qoo`03001oogoo00]oo`007Woo00<007ooOol0BWoo00MPUVBfH9ITUV2F
I;IPUP03Ool00`00Oomoo`05Ool017HXMRUf27XY1goo0`007Goo00Q10CcPHDUMB65YGDQQBEe847oo
00<007ooOol0>7oo00<007ooOol02goo000MOol2001:Ool3I9H01F2FI9ITUVBFH9H01Goo00<007oo
Ool017oo00Af:GHXMRUf:0Aoo`<0025oo`06GDUMB5e9GDQMBEe84Goo00<007ooOol0>7oo00<007oo
Ool02goo000MOol00`00Oomoo`17Ool0262FI9IPUVBfH9ITUV2FI;H8Ool00`00Oomoo`03Ool01GH8
NRUf:7HYOol00`0097oo00EMB65YGDQQBEe8019oo`03001oogoo03Qoo`03001oogoo00]oo`007Goo
00<007ooOol0AGoo00=TUV2FI9H00VBF00=PUVBFI9H02goo00<007ooOol00Woo00Ef:GHXMRUf:000
02Moo`05@@10h440@@1MB@0BOol00`00Oomoo`0DOol3@@000d3P@@11000NOol00`00Oomoo`0;Ool0
01eoo`03001oogoo04Aoo`08I;IPUVBFH9IT]V2FI9IPUPeoo`08001oogoo001f:7HYMPQj:BQoo`05
GDQ103cP@@4lh00BOol00`00Oomoo`0:Ool04ScP@@0lh441?>1103cP@@4lh440?>110CcP@@0lh441
?>1101eoo`03001oogoo00Yoo`007Goo00<007ooOol0@Goo0fBF00EPUVBFI9ITUV2F015oo`800005
Oomf:GHXMRUf:00XOol015e9@@11043P0d4000=0h7ooOol03Goo00D007ooOomood3P00=10005@>11
0440@@10h003@@001D3P@@110440@>000d4000E0h440@@11043P009101eoo`03001oogoo00Yoo`00
7Goo00<007ooOol0@7oo00QTUV2FI;IPUVBFH9IT]V2F4Woo00L007ooOomf27XYMRQf:@0XOol05Ue8
HFTlh440?>110CcP@@0lh441?>1103cP@@4lh440?>110CcP@@0lh4410P0001hlh441?>1103cP@@4l
h440?>110CcP@@0lh441?>1103cP@@4lh440?>110CcP@@0lh441?>1103cP@@4MOol00`00Oomoo`0:
Ool001aoo`03001oogoo03moo`05H9ITUVBFI9IPUP03I9HDOol01`00OomoogHYMRQf:GHX02Qoo`03
GDUMB5e900910005@>110440@@10h003@@001T3P@@110440@>1100<0009100030010h44000910005
@>110440@@10h003@@000d3POomoo`07Ool2@@001D3P@@110440@>007Goo00<007ooOol02Woo000L
Ool2000nOol026BfH9ITUV2FI;IPUVBFH9HFOol01`00OomoogHXMRUf27XY02Qoo`0?GDQQBEe8HFTl
h440?>110CcP@@0lh441?>1103cP00@0000:@@4lh440?>110CcP000lh441?>0@Ool02440?>110CcP
@@0lh441?>0NOol00`00Oomoo`0:Ool001aoo`03001oogoo03]oo`9TUP06H9ITUVBFI9IPUVBF67oo
00L007ooOomf:GHXMRUf:00XOol015e9GDQMBEe827oo0`002Woo00<007ooOol047oo0d4000A0h440
@@11021oo`03001oogoo00Yoo`0077oo00<007ooOol0>Goo00QTUV2FI;IPUVBFH9IT]V2F6Woo00L0
07ooOomf27XYMRQf:@0XOol015e8HFUMB6591Goo0`003Woo00<007ooOol03Goo00Llh440?>110CcP
@@0lh00ROol00`00Oomoo`0:Ool001aoo`03001oogoo03Moo`05H9ITUVBFI9IPUP03I9HLOol01`00
OomoogHYMRQf:GHX02Qoo`04GDUMB5e9GDP2Ool3000BOol00`00Oomoo`0:Ool00d40@>110002@@00
0d3P@@11000TOol00`00Oomoo`09Ool001aoo`03001oogoo03Ioo`08H9ITUV2FI;IPUVBFH9IT]Q9o
o`08H9IT]V2FI9IPUVBfH9ITUP=oo`07001oogooMRQf:GH8NRT0:7oo00=MB65900000`005Woo00<0
07ooOol01goo00Plh441?>1103cP@@4lh4409Woo00<007ooOol02Goo000KOol00`00Oomoo`0fOol0
1F2FI9ITUVBFH9H00VBF27oo00=TUV2FI9H00VBF00EPUVBFI9ITUV2F00=TUP05H9ITUVBFI9IPUP03
I9H02F2FI9ITUVBFH9If:GHXMRUf:00WOol300000ee9GDQoo`0HOol00`00Oomoo`04Ool3@@001D3P
@@110440@>00:7oo00<007ooOol02Goo000KOol00`00Oomoo`0eOol0;V2FI9IPUVBfH9ITUWooI;IP
UVBFH9IT]V2FI9IPUVBfH9ITUV2FI;IPUVBFH9IT]V2FI9IPUVBfH9ITUV2FI;IPUVBFH9IT]V2FI9IP
UVBfH9ITUWH8NRUf:7HY97oo0`0000Eooee8HFUMB65901Yoo`0<001oogooOollh440?>110CcP@@0l
h441:Woo00<007ooOol02Goo000KOol00`00Ool0000eOol3I9H01F2FI9ITUVBFH9H00fBF00EPUVBF
I9ITUV2F00=TUP05H9ITUVBFI9IPUP03I9H0162FI9ITUVBF0Woo0VBF00EPUVBFI9ITUV2F009TUP04
MRUf:7HYMRPQOol30004Ool015e9GDQMBEe86Woo00@007oo@@10h0=10003@>11044002aoo`03001o
ogoo00Uoo`006goo0P00=Woo01=PUVBfH9ITUV2FI;IPUVBFH9IT]V2FI9IPUVBfH9ITUV2FI;IPUP0D
Ool01fBFH9IT]WHXMRUf27XY01eoo`@000Moo`04GDQQBEe8HFTJOol023cP000lh440?>110CcP@@0^
Ool00`00Oomoo`09Ool000Moo`D0009oo`8000Aoo`8000Eoo`03001oogoo03Ioo`05H9ITUVBFI9IP
UP03I9H00f2FOomoo`0KOol00`00I9If:003I9H00f2FOomoo`0HOol3000;Ool015e9GDQMBEe867oo
0d4000E0h000@@11043P031oo`03001oogoo00Uoo`002Goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Oomoo`1LOol01`00Oomf:F2FI;IPUVBF01Moo`<000ioo`04GDQQ
JEe8HDTFOol023cP@@0lh441?>1103cP000bOol00`00Oomoo`09Ool000Uoo`05001oogooOol00002
Ool01000Oomoo`000Woo00D007ooOomoo`0005moo`05001f:GHXI9IPUP02I9HDOol3000AOol015e9
GDQMBEe857oo00=1043P@@000T4000=0h440@@000Woo00<007ooOol0<7oo00<007ooOol027oo0000
0goo000000020004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`05001oogooOol0001OOol0
1gHYMPQj:F2FI9IPUVBf011oo`@001Aoo`04GDQQBEe8HFTBOol023cP@@4lh440?>110CcP@@04Ool0
0`00Oomoo`0`Ool00`00Oomoo`08Ool000Uoo`05001oogooOol00002Ool01000Oomoo`000Woo00D0
07ooOomoo`0005ioo`04MRUf:7HYMRP3I9H00f2FOomoo`0;Ool3000HOol015e9GDQMBEe847oo0d40
00E0h440@@11043P00Moo`03001oogoo02moo`03001oogoo00Qoo`0027oo0P0017oo0P0017oo0P00
17oo00<007ooOol0Fgoo00Uf:GH8NRUf:7HYH9IT]V2FI9H02Woo0`006goo00AMB65YGDQQB@ioo`08
?>1103cP@@4lh440?>110@Yoo`03001oogoo02ioo`03001oogoo00Qoo`006Woo0P00Fgoo00Qf:GHX
MRUf:7HYMRQTUV2F0VBF1goo0`007Woo00AMBEe8GDUMB0aoo`03@@10h44000910003@>11044000eo
o`03001oogoo02eoo`03001oogoo00Qoo`006Woo00<007ooOol0FGoo00]f:GH8NRUf:7HYMPQj:F2F
I9IPUVBf00=oo`@0025oo`04GDQQBEe8HFT;Ool02441?>1103cP@@4lh440?>0?Ool00`00Oomoo`0/
Ool00`00Oomoo`08Ool001Uoo`03001oogoo05Uoo`08MRUf:7HYMRQf:GHXMRUoo`=TUP04H9H00000
000UOol015e9GDQMBEe82Goo0T4000E0h440@@11043P01=oo`03001oogoo02]oo`03001oogoo00Qo
o`006Goo00<007ooOol0Egoo00Qf:7HYMPQj:GHXMRUf27XY0Woo00APUP00000002Qoo`04GDQQJEe8
HDT8Ool01ccP@@4lh440?>110CcP01Aoo`03001oogoo02aoo`03001oogoo00Moo`006Goo00<007oo
Ool0EWoo00Uf:7HYMRQf:GHXMRUf:000Ool00`0000=PUVBFI9H0:7oo00AMBEe8GDUMB0Ioo`=10005
@>110440@@10h00FOol00`00Oomoo`0[Ool00`00Oomoo`07Ool001Uoo`03001oogoo05Aoo`07NRUf
:7HYMPQj:GHXMRT0100000IoofBfH9ITUV2FI;HXOol015e8HDUMB65Y1Goo00M103cP@@4lh440?>11
0@0IOol00`00Oomoo`0ZOol00`00Oomoo`07Ool001Uoo`03001oogoo05=oo`05MRUf:7HYMRQf:@03
0002Ool01000Oomoof2F0fBF:Goo00AMBEe8GDUMB0=oo`05@>110440@@10h002@@0LOol00`00Oomo
o`0YOol00`00Oomoo`07Ool001Uoo`03001oogoo055oo`04MPQj:GHXMRT300000gHYOomoo`02Ool0
1`00OomoofBFH9IT]V2F02Uoo`04GDQQJEe8HDT2Ool01ccP@@0lh441?>1103cP01ioo`03001oogoo
02Qoo`03001oogoo00Moo`0067oo0P00DWoo00=f:7HY00000P0000=f:GHXOol01Goo00<007ooOol0
0VBF00=PUVBFOol0:7oo00IMBEe8GDUMB7oo@>03@@000d3P@@11000OOol00`00Oomoo`0XOol00`00
Oomoo`07Ool001Qoo`03001oogoo04ioo`03MRQf:@0000800003MRUf27XY00Qoo`07001oogooI;IP
UVBFH9H0:Goo00YMB659GDQ10CcP@@0lh441?>11029oo`03001oogoo02Moo`03001oogoo00Moo`00
67oo00<007ooOol0C7oo100000Ef:GHXMRUf:7HY00Uoo`04001oogooH9H3I9HYOol015e9GDQMBD3P
0d4000=0h440Ool08goo00<007ooOol09goo00<007ooOol01Woo000HOol00`00Oomoo`19Ool30000
1gHXMRUf27XYMRQf:GH800]oo`07001oogooI9IPUVBfH9H0:Woo00MQJCcP@@0lh441?>11000VOol0
0`00Oomoo`0VOol00`00Oomoo`06Ool001Qoo`03001oogoo04Ioo`<00008MRQf:GHXMRUf:7HYMRQf
:@eoo`03001oogoo009TUP03H9ITUWoo02Uoo`06GDQMBEe8@@10h440:7oo00<007ooOol09Goo00<0
07ooOol01Woo000HOol00`00Oomoo`13Ool300002GooMRUf27XYMRQf:GH8NRUf:00?Ool01`00Oomo
ofBfH9ITUV2F02Yoo`05@@1MB65YGDQQB@0ZOol00`00Oomoo`0TOol00`00Oomoo`06Ool001Qoo`03
001oogoo03moo`@0009oo`09MRQf:GHXMRUf:7HYMRQf:GHX011oo`04001oogooH9H3I9HZOol02440
GDUMB5e9GDQMBEe8GDTKOol055e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB000GDQMBEe8GDUMB5e9GDPO
Ool00`00Oomoo`06Ool001Moo`8003ioo`<000Aoo`08NRUf:7HYMPQj:GHXMRUf21=oo`07001oogoo
I9IPUVBfH9H0:Woo00i10CcPHDUMB65YGDQQBEe8HFUMB659GDQQJEe81goo029MB659GDQQJEe8HDUM
B65YGDQQBEe8HFUMB659GDQQJEe8HDUMB65YGDQQBEe8HFUMB659GDP005e8HDUMB65YGDQQBAmoo`03
001oogoo00Ioo`005goo00<007ooOol0>Woo0`001Woo00Mf:GHXMRUf:7HYMRQf:@0EOol00`00Oomo
o`02I9H00f2FI9Ioo`0YOol0=d3P@@1105e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUM
B5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8GDUMB5e9GDQMBEe8001M
B5e9GDQMBEe801moo`03001oogoo00Ioo`005goo00<007ooOol0=goo0`001Woo00Qf:GH8NRUf:7HY
MPQj:GHX5goo00L007ooOomT]V2FI9IPUP0ZOol09D40?>110CcPHDUMB65YGDQQBEe8HFUMB659GDQQ
JEe8HDUMB65YGDQQBEe8HFUMB659GDQQJEe8HDUMB65YGDQQBEe8HFUMB65900aoo`06GDP005e8HDUM
B65Y87oo00<007ooOol01Goo000GOol00`00Oomoo`0cOol40008Ool027HYMRQf:GHXMRUf:7HYMRPH
Ool01000Oomoof2F0fBF:Woo0T4000=0h440Ool01goo00]MB5e9GDQMBEe8GDUMB5e9GDQMBEe801Qo
o`07GDUMB5e9GDP005e8GDT08Goo00<007ooOol01Goo000GOol00`00Oomoo`0`Ool30009Ool02GXY
MRQf:GH8NRUf:7HYMPQj:@0JOol01`00OomoofBFH9IT]V2F02Yoo`04@@4lh440?>0YOol025e8HDUM
B65YGDQQB@00HFTROol00`00Oomoo`05Ool001Moo`03001oogoo02eoo`<000]oo`08MRUf:7HYMRQf
:GHXMRUf:1aoo`03001oogoo009TUP03H9ITUWoo02Uoo`04@>110440@@0WOol02Ue9GDQMBEe8GDUM
B5e9GDQoo`008Woo00<007ooOol01Goo000FOol00`00Oomoo`0[Ool3000<Ool027H8NRUf:7HYMPQj
:GHXMRTNOol01`00OomoofBfH9ITUV2F02Yoo`04@@0lh441?>0UOol025e8HFUMB659GDQQJEe8HDT4
Ool00`00Oomoo`0OOol00`00Oomoo`05Ool001Ioo`03001oogoo02Moo`@000ioo`07MRQf:GHXMRUf
:7HYMRP04Goo00]f:7HYMRQf:GHXMRUf:7HYMRQf:GHX00Aoo`04001oogooH9H3I9HZOol2@@000d3P
@@1oo`0QOol02Ee8GDUMB5e9GDQMBEe8GDUMB007Ool00`00Oomoo`0NOol00`00Oomoo`05Ool001Io
o`8002Eoo`<0015oo`07MPQj:GHXMRUf27XYMRP017oo02Af:GH8NRUf:7HYMPQj:GHXMRUf27XYMRQf
:GH8NRUf:7HYMPQj:GHXMRUf27XYMRQf:GH8NRUf:7HYMPQj:GooI9IPUVBfH9HZOol01441?>1103cP
8Goo00QMB659GDQQJEe8HDUMB65Y2Woo00<007ooOol07Goo00<007ooOol01Goo000FOol00`00Oomo
o`0QOol3000DOol0:gHYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf
:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRUf:7HY009TUP03H9ITUWoo02Uoo`04@>11
0440@@0OOol025e9GDQMBEe8GDUMB5e9GDP=Ool00`00Oomoo`0LOol00`00Oomoo`05Ool001Ioo`03
001oogoo01ioo`<001Moo`0KMRQf:GH8NRUf:7HYMPQj:GHXMRUf27XYMRQf:GH8NRUf:7HYMPQj:GHX
MRUf27XYMRQf:GH800Ioo`0>MRUf27XYMRQf:GH8NRUf:7HYMPQT]V2FI9IPURYoo`04@@0lh441?>0M
Ool01Ue8HFUMB659GDQQJA5oo`03001oogoo01eoo`03001oogoo00Aoo`005Woo00<007ooOol06Woo
10006goo00af:7HYMRQf:GHXMRUf:7HYMRQf:GHXMRTJOol027HXMRUf:7HYMRQf:GHXI9HZOol2@@00
0d3P@@1oo`0IOol02Ee8GDUMB5e9GDQMBEe8GDUMB00BOol00`00Oomoo`0LOol00`00Oomoo`04Ool0
01Eoo`03001oogoo01Qoo`<004Ioo`07001j:GHXMRUf27XYMRP0:Woo00A10CcP@@0lh1Qoo`09HFUM
B659GDQQJEe8HDUMB65Y01Eoo`03001oogoo01]oo`03001oogoo00Aoo`005Goo00<007ooOol05Goo
0`00BGoo00L0062FMRUf:7HYMRQf:@0ZOol0143P@@1104405Woo00QMB5e9GDQMBEe8GDUMB5e96Goo
00<007ooOol06Woo00<007ooOol017oo000EOol00`00Oomoo`0BOol3001;Ool02000H9ITUV2FNRUf
:7HYMPPZOol01440?>110CcP5Goo00MMB65YGDQQBEe8HFUMB00LOol00`00Oomoo`0IOol00`00Oomo
o`04Ool001Eoo`03001oogoo00ioo`@004ioo`08H9ITUVBFI9If:7HYMRQf:BYoo`910003@>1107oo
019oo`07GDUMB5e9GDQMBEe8GDT07Woo00<007ooOol06Goo00<007ooOol017oo000EOol2000<Ool3
001AOol02F2FI9IPUVBfH9If:GH8NRUf:00ZOol01441?>1103cP4Goo00IMB659GDQQJEe8HDTROol0
0`00Oomoo`0HOol00`00Oomoo`04Ool000eoo`8000Ioo`03001oogoo00Qoo`<005=oo`0:H9ITUVBF
I9IPUVBFMRQf:GHXMRTZOol0143P@@1104403goo00QMBEe8GDUMB5e9GDQMBEe88goo00<007ooOol0
67oo00<007ooOol00goo000<Ool01000Oomoo`0017oo00<007ooOol01Woo0`00E7oo00aT]V2FI9IP
UVBfH9ITUWooNRUf:7HYMPPZOol01440?>110CcP3Goo00QMB65YGDQQBEe8HFUMB6599Woo00<007oo
Ool05goo00<007ooOol00goo000<Ool01000Oomoo`0017oo00<007ooOol00Woo1000EWoo00=TUV2F
I9H00VBF00QPUVBFOomoogHXMRUf:7HY:Woo0T4000=0h440Ool02Woo00QMBEe8GDUMB5e9GDQMBEe8
:Goo00<007ooOol05Woo00<007ooOol00goo000<Ool01000Oomoo`0017oo00<007oo00000P00F7oo
00QPUVBfH9ITUV2FI;IPUVBF0goo00Af:GH8NRUf:2Yoo`04@@4lh440?>09Ool025e8HDUMB65YGDQQ
BEe8HFT/Ool00`00Oomoo`0EOol00`00Oomoo`03Ool000aoo`04001oogoo0004Ool200000goo001o
o`1GOol2I9H01f2FI9ITUVBFH9Ioo`0000=oo`04MRQf:GHXMRTZOol0143P@@1104401goo00QMBEe8
GDUMB5e9GDQMBEe8;Woo00<007ooOol05Goo00<007ooOol00goo000=Ool20006Ool3001FOol026BF
H9IT]V2FI9IPUVBfH9H2Ool02000OomoogooNRUf:7HYMPPZOol01440?>110CcP1Goo00QMB65YGDQQ
BEe8HFUMB659<Goo00<007ooOol057oo00<007ooOol00goo000GOol00`00Oomoo`1BOol01F2FI9IT
UVBFH9H00fBF17oo00P007ooOomoogHXMRUf:7HY:Woo0T4000=0h440Ool00goo00QMB5e9GDQMBEe8
GDUMB5e9<goo00<007ooOol04goo00<007ooOol00goo000HOol00`00Oomoo`1@Ool01f2FI9IPUVBf
H9ITUV2F00Ioo`08001oogooMRQf:GH8NRUf:2Yoo`0=@@4lh440?>110GooHDUMB65YGDQQBEe8HFT0
=goo00<007ooOol04goo00<007ooOol00Woo000IOol2001>Ool00fBFH9ITUP02I9H00f2FI9ITUP07
Ool02000OomoogHYMRQf:GHXMRTZOol0343P@@110440@>1MBEe8GDUMB5e9GDQMBCUoo`03001oogoo
019oo`03001oogoo009oo`006goo00<007oo0000B7oo00UTUV2FI;IPUVBFH9IT]V2FI9H02Goo00P0
07ooOomf27XYMRQf:GH8:Woo00]103cP@@4lh659GDQQJEe8HDUMB65Y03Yoo`03001oogoo019oo`03
001oogoo009oo`0077oo0P00Agoo0fBF00EPUVBFI9ITUV2F00]oo`07001oogooMRUf:7HYMRP0;7oo
00Q1043P@@1105e9GDQMBEe8?Goo00<007ooOol04Goo00<007ooOol00Woo000NOol00`00Oomoo`12
Ool0262FI9IPUVBfH9ITUV2FI;H=Ool01`00OomoogHXMRUf27XY02aoo`07?>1103cP@@4lh440GDP0
?goo00<007ooOol047oo00<007ooOol00Woo000OOol20010Ool00fBFH9ITUP02I9H00f2FI9ITUP0?
Ool01`00OomoogHYMRQf:GHX02eoo`910003@>110440045oo`03001oogoo00moo`03001oogoo009o
o`008Goo0P00?7oo00QPUVBfH9ITUV2FI;IPUVBF4Goo00L007ooOomf27XYMRQf:@0^Ool013cP@@0l
h441@Woo00<007ooOol03Woo00<007ooOol00Woo000FOol50007Ool00`00Oomoo`0hOol3I9H01F2F
I9ITUVBFH9H04goo00L007ooOomf:GHXMRUf:01eOol00`00Oomoo`0>Ool00`00Oomoo`01Ool001Qo
o`03001oogoo00Qoo`8003Ioo`08H9ITUV2FI;IPUVBFH9IT]QEoo`07001oogooMRQf:GH8NRT0MGoo
00<007ooOol03Woo00<007ooOol00Goo000HOol00`00Oomoo`0:Ool00`00Oomoo`0aOol00fBFH9IT
UP02I9H00f2FI9ITUP0GOol01`00OomoogHYMRQf:GHX07Ioo`03001oogoo00eoo`03001oogoo005o
o`0047oo100017oo00<007ooOol02goo0`00;Woo00UPUVBfH9ITUV2FI;IPUVBFH9H067oo00L007oo
Oomf27XYMRQf:@1gOol00`00Oomoo`0<Ool00`00Oomoo`01Ool001Qoo`03001oogoo00aoo`8002ao
o`=TUP05H9ITUVBFI9IPUP0KOol01`00OomoogHYMRQf:GHX07Qoo`03001oogoo00]oo`03001oogoo
005oo`005goo0P0047oo0P00:7oo00QPUVBFH9IT]V2FI9IPUVBf7Goo00L007ooOomf:7HYMPQj:@1i
Ool00`00Oomoo`0:Ool00`00Oomoo`01Ool002]oo`03001oo`0002=oo`03I9IPUVBF009TUP04H9IT
UVBFI9HNOol01`00OomoogHYMRQf:GHX07Uoo`03001oogoo00Yoo`03001oogoo005oo`00;7oo0P00
8Woo00MT]V2FI9IPUVBfH9ITUP0QOol01`00OomoogH8NRUf:7HY07Yoo`03001oogoo00Yoo`40005o
o`5oo`00;Goo0P008Goo00IPUVBFI9ITUV2FI9H7Ool3I9H01F2FI9ITUVBFH9H00fBF00EPUVBFI9IT
UV2F00=TUP05H9ITUVBFI9IPUP03I9H01f2FOomf:7HYMRQf:GHX07]oo`03001oogoo00Uoo`40005o
o`5oo`00;goo00@007ooOol001eoo`0_I9IPUVBfH9ITUV2FI;IPUVBFH9IT]V2FI9IPUVBfH9ITUV2F
I;IPUVBFH9IT]V2FI9IPUVBfH9ITUV2FI;IPUVBFH9IT]V2FI9IPUVBfH9ITUV2FNRUf:7HYMPQj:@1l
Ool00`00Oomoo`08Ool10001Ool1Ool0031oo`<001eoo`9TUP05H9ITUVBFI9IPUP03I9H01F2FI9IT
UVBFH9H00fBF00EPUVBFI9ITUV2F00=TUP05H9ITUVBFI9IPUP03I9H01F2FI9ITUVBFH9H00VBF00If
:GHXMRUf:7HYMRQmOol00`00Oomoo`07Ool10001Ool1Ool0039oo`03001oogoo01aoo`0>H9ITUV2F
I;IPUVBFH9IT]V2FI9IPUVBfH9ITUQMoo`08I9IPUVBfMRQf:GH8NRUf:7moo`03001oogoo00Ioo`40
005oo`5oo`00<goo00<007ooOol0@Woo00H007HYMRQf:GHXMRUoOol00`00Oomoo`06Ool10001Ool1
Ool003Aoo`80045oo`06001oogooNRUf:7HYPGoo00<007ooOol01Goo0@000Goo0Goo000fOol2000o
Ool00`00Oomoo`25Ool00`00Oomoo`04Ool10001Ool1Ool003Moo`8003ioo`03001oogoo08Ioo`03
001oogoo00Aoo`40005oo`00>Goo00<007ooOol0>goo00<007ooOol0Qgoo00<007ooOol00goo0@00
0Goo000jOol3000jOol00`00Oomoo`27Ool00`00Oomoo`03Ool10001Ool003aoo`03001oogoo03Qo
o`03001oogoo08Qoo`03001oogoo009oo`40005oo`00;7oo0P0017oo0P0017oo0P000goo00<007oo
Ool0=goo00<007ooOol0RGoo00D007ooOomoo`00005oo`00:goo00@007ooOol000Qoo`04001oogoo
0003Ool200000goo001oo`0dOol00`00Oomoo`2:Ool01000Oomoo`000Goo000[Ool01000Oomoo`00
2goo00<007ooOol00goo0P00=Goo00<007ooOol0Rgoo00<007oo00000Goo000UOol40002Ool01000
Oomoo`002Goo0P001goo0P00=7oo00<007ooOol0S7oo0@000Goo0@00000[Ool01000Oomoo`002Goo
00<007ooOol027oo00<007ooOol0<Goo00<007ooOol0S7oo0@000Goo0@00000/Ool2000:Ool30009
Ool00`00Ool0000`Ool00`00Oomoo`2=Ool2000004Eoo`80031oo`03001oogoo08aoo`<00000Agoo
00@007ooOol002aoo`03001oogoo08Qoo`@000=oo`00B7oo0`00;7oo00<007ooOol0Q7oo10001goo
001:Ool00`00Oomoo`0ZOol00`00Oomoo`1oOol5000;Ool004]oo`8002Yoo`03001oogoo07]oo`@0
011oo`00CGoo00<007oo00009goo00<007ooOol0Mgoo100057oo001>Ool2000WOol00`00Oomoo`1c
Ool4000HOol004moo`8002Ioo`03001oogoo06ioo`D001aoo`00DGoo00<007oo00008goo00<007oo
Ool0JWoo10008Goo001BOol2000SOol00`00Oomoo`1VOol4000UOol005Aoo`03001oogoo021oo`03
001oogoo065oo`D002Uoo`00B7oo0P002goo0P0000=oo`00Ool07Goo00<007ooOol0GGoo1000;Woo
0017Ool01000Oomoo`0037oo00<007ooOol07Goo00<007ooOol0FGoo1000<Woo0017Ool01000Oomo
o`0037oo0P007Woo00<007ooOol0EGoo1000=Woo0017Ool01000Oomoo`003Woo0P0000=oo`00Ool0
6Goo00<007ooOol0D7oo1@00>Woo0017Ool01000Oomoo`0047oo0P006Woo00<007ooOol0C7oo1000
?goo0018Ool2000BOol2000IOol00`00Oomoo`18Ool40013Ool005ioo`03001oo`0001Ioo`03001o
ogoo04=oo`D004Moo`00Ggoo0P005Woo00<007ooOol0?goo1000C7oo001POol2000DOol00`00Oomo
o`0lOol4001@Ool0069oo`03001oo`00015oo`03001oogoo03Moo`D005Aoo`00Hgoo0P004Goo00<0
07ooOol0<goo1000FGoo001UOol00`00Oomoo`0>Ool00`00Oomoo`0_Ool4001MOol006Ioo`<000eo
o`03001oogoo02]oo`@0065oo`00J7oo00<007ooOol02goo00<007ooOol09Woo1@00IGoo001YOol0
0`00Oomoo`0:Ool00`00Oomoo`0ROol4001ZOol005Qoo`8000Aoo`8000Aoo`8000Aoo`<000Uoo`03
001oogoo01ioo`@006ioo`00Egoo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`07Ool0
0`00Oomoo`0IOol5001bOol005Moo`04001oogoo000;Ool00`00Oomoo`04Ool20007Ool00`00Oomo
o`0EOol4001gOol005Moo`04001oogoo0009Ool20009Ool20005Ool00`00Oomoo`0AOol4001kOol0
05Moo`04001oogoo0009Ool00`00Oomoo`09Ool20004Ool00`00Oomoo`0=Ool4001oOol005Qoo`80
00Yoo`<000]oo`05001oo`00Ool0000:Ool50023Ool007=oo`800003Ool007oo00Eoo`@008Qoo`00
M7oo0`000Woo1000S7oo001fOol3002@Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00
ogoo2Woo001aOol5002COol007=oo`03001oogoo09=oo`00Lgoo00<007ooOol0Tgoo001cOol00`00
Oomoo`2COol007=oo`03001oogoo09=oo`00LWoo0P00UGoo003oOol:Ool00?moo`Yoo`00ogoo2Woo
003oOol:Ool00?moo`Yoo`00\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {-0.0234524, -0.019432, \
0.00351733, 0.00351733}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Six spheres sedimenting in a Newtonian fluid. The same periodic arrangement \
of the spheres occurs in this case.\
\>", "Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["\<\
FU={0,0,-30,0,0,-30,0,0,-30,0,0,-30,0,0,-30,0,0,-30,0,0,0,0,0,0,0,0,0,0,0,0,0,\
0,0,0,0,0};\
\>", "Input"],

Cell["\<\
X[1]=3 Cos[Pi/3.];Y[1]=3 Sin[Pi/3.];Z[1]=1;
X[2]=3 Cos[2 Pi/3.];Y[2]=3 Sin[2 Pi/3.];Z[2]=0;
X[3]=3 Cos[Pi];Y[3]=3 Sin[Pi];Z[3]=1;
X[4]=3 Cos[4 Pi/3.];Y[4]=3 Sin[4 Pi/3.];Z[4]=0;
X[5]=3 Cos[5 Pi/3.];Y[5]=3 Sin[5 Pi/3.];Z[5]=1;
X[6]=3 Cos[2 Pi];Y[6]=3 Sin[2 Pi];Z[6]=0;\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics3D[{{RGBColor[0,0,1],PointSize[0.05],Point[{X[1],Y[1],Z[1]}]},{\
RGBColor[1,0,1],PointSize[0.05],Point[{X[2],Y[2],Z[2]}]},{RGBColor[0,0,1],\
PointSize[0.05],Point[{X[3],Y[3],Z[3]}]},{RGBColor[1,0,1],PointSize[0.05],\
Point[{X[4],Y[4],Z[4]}]},{RGBColor[0,0,1],PointSize[0.05],Point[{X[5],Y[5],Z[\
5]}]},{RGBColor[1,0,1],PointSize[0.05],Point[{X[6],Y[6],Z[6]}]}}],BoxRatios->{\
1,1,1}]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 5.12828e-017 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 0 1 r
.05 w
.536 .54442 Mdot
.79949 .24499 Mdot
.23649 .20789 Mdot
0 0 1 r
.82223 .96607 Mdot
.23676 .94137 Mdot
.51149 .6422 Mdot
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017a000`40O003h00O/7oo0P00Egoo002^
Ool200000goo0000001FOol00:]oo`<000=oo`8005Ioo`00ZGoo0P001Woo00<007oo0000EGoo002W
Ool20008Ool00`00Ool0001EOol00:Aoo`<000Yoo`04001oogoo001DOol00:9oo`8000eoo`05001o
ogooOol0001COol009moo`<000moo`05001oogooOol0001COol009eoo`80019oo`03001oogoo009o
o`03001oogoo051oo`00Vgoo0P005Goo00<007ooOol00Woo00<007ooOol0Cgoo002HOol3000GOol0
0`00Oomoo`02Ool00`00Oomoo`1?Ool009Ioo`8001Yoo`03001oogoo00=oo`03001oogoo04ioo`00
Tgoo0`0077oo00<007ooOol00goo00<007ooOol0CWoo002AOol2000OOol00`00Oomoo`04Ool00`00
Oomoo`1=Ool008moo`80025oo`03001oogoo00Eoo`03001oogoo04aoo`00S7oo0`008goo00<007oo
Ool01Goo00<007ooOol0C7oo002:Ool2000VOol00`00Oomoo`06Ool00`00Oomoo`1;Ool008Moo`<0
02Qoo`03001oogoo00Moo`03001oogoo04Yoo`00QGoo0P00:goo00<007ooOol01goo00<007ooOol0
BWoo0023Ool2000]Ool00`00Oomoo`08Ool00`00Oomoo`19Ool0081oo`<002moo`03001oogoo00Qo
o`03001oogoo04Uoo`00OWoo0P00<Woo00<007ooOol02Goo00<007ooOol0B7oo001kOol3000dOol0
0`00Oomoo`0:Ool00`00Oomoo`17Ool007Uoo`8003Moo`03001oogoo00Yoo`03001oogoo04Moo`00
Mgoo0P00>Goo00<007ooOol02goo00<007ooOol0AWoo001dOol3000kOol00`00Oomoo`0<Ool00`00
Oomoo`15Ool0079oo`8003moo`03001oogoo00]oo`03001oogoo04Eoo`00Kgoo0`00@Goo00<007oo
Ool037oo00<007ooOol0A7oo001]Ool20014Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006]oo`80
04Ioo`03001oogoo00eoo`03001oogoo04=oo`00J7oo0`00B7oo00<007ooOol03Woo00<007ooOol0
@Woo001VOol2001;Ool00`00Oomoo`0>Ool00`00Oomoo`12Ool006=oo`<004eoo`03001oogoo00mo
o`03001oogoo045oo`00HGoo0P00D7oo00<007ooOol047oo00<007ooOol0@7oo001NOol3001BOol0
0`00Oomoo`0@Ool00`00Oomoo`10Ool005aoo`8005Eoo`03001oogoo015oo`03001oogoo03moo`00
FWoo0P00Egoo00<007ooOol04Goo00<007ooOol0?goo001GOol3001IOol00`00Oomoo`0BOol00`00
Oomoo`0nOol005Eoo`8005aoo`03001oogoo01=oo`03001oogoo03eoo`00DWoo0`00GWoo00<007oo
Ool04goo00<007ooOol0?Goo001@Ool2001QOol00`00Oomoo`0DOol00`00Oomoo`0lOol004ioo`80
06=oo`03001oogoo01Eoo`03001oogoo03]oo`00Bgoo0`00IGoo00<007ooOol05Goo00<007ooOol0
>goo0019Ool2001YOol00`00Oomoo`0EOol00`00Oomoo`0jOol004Ioo`<006]oo`03001oogoo01Eo
o`03001oogoo03Yoo`00A7oo0P00KWoo00<007ooOol05Woo00<007ooOol0>Goo0012Ool2001`Ool0
0`00Oomoo`0GOol00`00Oomoo`0hOol003moo`<0079oo`03001oogoo01Moo`03001oogoo03Qoo`00
?Goo0P00MGoo00<007ooOol067oo00<007ooOol0=goo000jOol30004O1mcOol00`00Oomoo`0IOol0
0`00Oomoo`0fOol003Qoo`800003Ooml7g`O00El7g9oo`03001oogoo01Uoo`03001oogoo03Ioo`00
=Woo0P000Woo2G`OLGoo00<007ooOol06Woo00<007ooOol0=Goo000cOol30003Ool;O1m`Ool00`00
Oomoo`0JOol00`00Oomoo`0eOol0035oo`8000Eoo`el7fmoo`03001oogoo01]oo`03001oogoo03Ao
o`00;Woo0`001goo3G`OKgoo00<007ooOol077oo00<007ooOol0<goo000/Ool2000:Ool=O1m_Ool0
0`00Oomoo`0LOol00`00Oomoo`0cOol002Yoo`8000aoo`el7fmoo`03001oogoo01eoo`03001oogoo
039oo`009goo0`003Woo3G`OKgoo00<007ooOol07Woo00<007ooOol0<Goo000UOol2000BOol;O1m`
Ool00`00Oomoo`0JOol4O1l00`00Oomoo`0aOol0029oo`<001Eoo`Ul7g5oo`03001oogoo01Uoo`Il
7`03001oogoo031oo`0087oo0P006Goo1g`OLgoo00<007ooOol05goo1g`O00<007`OOol0<7oo000N
Ool2000LOol5O1mdOol00`00Oomoo`0FOol9O1l00`00O1moo`0_Ool001]oo`<009Moo`03001oogoo
01Eoo`]l7`03001l7goo02ioo`006Goo0P00VWoo00<007ooOol05Goo2g`O00<007`OOol0;Woo000G
Ool2002LOol00`00Oomoo`0EOol<O1l00`00Oomoo`0]Ool001Moo`8009aoo`03001oogoo01Eoo`el
7`03001oogoo02aoo`005goo00<007oo0000Vgoo00<007ooOol05Goo3G`O00<007ooOol0;7oo000G
Ool01000Oomoo`00VWoo00<007ooOol05Woo2g`O0Woo00<007ooOol0:goo000FOol00`00Oomoo`02
Ool00`00Oomoo`2GOol00`00Oomoo`0GOol9O1l3Ool00`00Oomoo`0[Ool001Ioo`03001oogoo00=o
o`03001oogoo09Ioo`03001oogoo01Qoo`Ml7`Eoo`03001oogoo02Yoo`005Woo00<007ooOol017oo
00<007ooOol0UGoo00<007ooOol06Goo1G`O1goo00<007ooOol0:Goo000FOol00`00Oomoo`05Ool0
0`00Oomoo`2DOol00`00Oomoo`0UOol00`00Oomoo`0YOol001Ioo`03001oogoo00Ioo`03001oogoo
09=oo`03001oogoo02Ioo`03001oogoo02Qoo`005Woo00<007ooOol01goo00<007ooOol0TWoo00<0
07ooOol09goo00<007ooOol09goo000EOol00`00Oomoo`09Ool00`00Oomoo`2AOol00`00Oomoo`0W
Ool00`00Oomoo`0WOol001Eoo`03001oogoo00Yoo`03001oogoo091oo`03001oogoo02Qoo`03001o
ogoo02Ioo`005Goo00<007ooOol02goo00<007ooOol0Sgoo00<007ooOol0:7oo00<007ooOol09Woo
000EOol00`00Oomoo`0<Ool00`00Oomoo`2?Ool00`00Oomoo`0XOol00`00Oomoo`0UOol001Eoo`03
001oogoo00eoo`03001oogoo08ioo`03001oogoo02Uoo`03001oogoo02Aoo`005Goo00<007ooOol0
3Woo00<007ooOol0SGoo00<007ooOol0:Goo00<007ooOol097oo000EOol00`00Oomoo`0?Ool00`00
Oomoo`2<Ool00`00Oomoo`0ZOol00`00Oomoo`0SOol001Aoo`03001oogoo015oo`03001oogoo08]o
o`03001oogoo02]oo`03001oogoo029oo`0057oo00<007ooOol04Woo00<007ooOol0RWoo00<007oo
Ool0:goo00<007ooOol08Woo000DOol00`00Oomoo`0COol00`00Oomoo`29Ool00`00Oomoo`0/Ool0
0`00Oomoo`0QOol001Aoo`03001oogoo01Aoo`03001oogoo08Qoo`03001oogoo02aoo`03001oogoo
025oo`0057oo00<007ooOol05Goo00<007ooOol0Qgoo00<007ooOol0;Goo00<007ooOol087oo000D
Ool00`00Oomoo`0FOol00`00Oomoo`26Ool00`00Oomoo`0^Ool00`00Oomoo`0OOol001=oo`03001o
ogoo01Moo`03001oogoo08Ioo`03001oogoo02ioo`03001oogoo01moo`004goo00<007ooOol067oo
00<007ooOol0QGoo00<007ooOol0;goo00<007ooOol07Woo000COol00`00Oomoo`0IOol00`00Oomo
o`24Ool00`00Oomoo`0`Ool00`00Oomoo`0MOol001=oo`03001oogoo01Yoo`03001oogoo08=oo`03
001oogoo031oo`03001oogoo01eoo`004goo00<007ooOol06goo00<007ooOol0PWoo00<007ooOol0
<Goo00<007ooOol077oo000COol00`00Oomoo`0LOol00`00Oomoo`21Ool00`00Oomoo`0aOol00`00
Oomoo`0LOol0019oo`03001oogoo01ioo`03001oogoo081oo`03001oogoo039oo`03001oogoo01]o
o`004Woo00<007ooOol07goo00<007ooOol0Ogoo00<007ooOol0<goo00<007ooOol06Woo000BOol0
0`00Oomoo`0POol00`00Oomoo`1oOol00`00Oomoo`0bOol00`00Oomoo`0JOol0019oo`03001oogoo
025oo`03001oogoo07ioo`03001oogoo03=oo`03001oogoo01Uoo`004Woo00<007ooOol08Woo00<0
07ooOol0OGoo00<007ooOol0=7oo00<007ooOol067oo000BOol00`00Oomoo`0SOol00`00Oomoo`1l
Ool00`00Oomoo`0dOol00`00Oomoo`0HOol0019oo`03001oogoo02Aoo`03001oogoo07]oo`03001o
ogoo03Eoo`03001oogoo01Moo`004Goo00<007ooOol09Woo00<007ooOol0NWoo00<007ooOol0=Goo
00<007ooOol05goo000AOol00`00Oomoo`0WOol00`00Oomoo`1iOol00`00Oomoo`0fOol00`00Oomo
o`0FOol0015oo`03001oogoo02Qoo`03001oogoo07Qoo`03001oogoo03Moo`03001oogoo01Eoo`00
4Goo00<007ooOol0:Goo00<007ooOol0Mgoo00<007ooOol0=goo00<007ooOol05Goo000AOol00`00
Oomoo`0ZOol00`00Oomoo`1fOol00`00Oomoo`0hOol00`00Oomoo`0DOol0015oo`03001oogoo02]o
o`03001oogoo07Eoo`03001oogoo03Uoo`03001oogoo01=oo`0047oo00<007ooOol0;Goo00<007oo
Ool0M7oo00<007ooOol0>Goo00<007ooOol04goo000@Ool00`00Oomoo`0^Ool00`00Oomoo`1cOol0
0`00Oomoo`0jOol00`00Oomoo`0BOol0011oo`03001oogoo02moo`03001oogoo079oo`03001oogoo
03Yoo`03001oogoo019oo`0047oo00<007ooOol0<7oo00<007ooOol0LGoo00<007ooOol0>Woo0P00
4goo000@Ool00`00Oomoo`0aOol00`00Oomoo`1`Ool00`00Oomoo`0gOol300000goo001oo`0BOol0
011oo`03001oogoo039oo`03001oogoo06moo`03001oogoo03Aoo`<000Aoo`03001oogoo015oo`00
47oo00<007ooOol0<goo00<007ooOol0Kgoo00<007ooOol0<7oo0`001goo00<007ooOol04Goo000?
Ool00`00Oomoo`0eOol00`00Oomoo`1^Ool00`00Oomoo`0]Ool3000;Ool00`00Oomoo`0@Ool000mo
o`03001oogoo03Ioo`03001oogoo06eoo`03001oogoo02Yoo`<000ioo`03001oogoo011oo`003goo
00<007ooOol0=goo00<007ooOol0K7oo00<007ooOol09goo0`004Goo00<007ooOol047oo000?Ool0
0`00Oomoo`0hOol00`00Oomoo`1[Ool00`00Oomoo`0SOol4000DOol00`00Oomoo`0@Ool000moo`03
001oogoo03Uoo`03001oogoo06Yoo`03001oogoo021oo`<001Qoo`03001oogoo011oo`003goo00<0
07ooOol0>Woo00<007ooOol0JGoo00<007ooOol07Goo0`006goo00<007ooOol047oo000>Ool00`00
Oomoo`0lOol00`00Oomoo`1XOol00`00Oomoo`0JOol3000NOol00`00Oomoo`0@Ool000ioo`03001o
ogoo03eoo`03001oogoo06Moo`03001oogoo01Moo`<0025oo`03001oogoo011oo`003Woo00<007oo
Ool0?Woo00<007ooOol0IWoo00<007ooOol057oo0`009Goo00<007ooOol03goo000>Ool00`00Oomo
o`0oOol00`00Oomoo`1UOol00`00Oomoo`0AOol3000XOol00`00Oomoo`0?Ool000ioo`03001oogoo
041oo`03001oogoo06Aoo`03001oogoo00ioo`<002]oo`03001oogoo00moo`003Woo00<007ooOol0
@Goo00<007ooOol0Hgoo00<007ooOol02goo0`00;Woo00<007ooOol03goo000>Ool00`00Oomoo`12
Ool00`00Oomoo`1ROol00`00Oomoo`08Ool3000aOol00`00Oomoo`0?Ool000eoo`03001oogoo04Ao
o`03001oogoo065oo`03001oogoo00Eoo`<003Aoo`03001oogoo00moo`003Goo00<007ooOol0AGoo
00<007ooOol0H7oo00<007ooOol00Woo0`00=goo00<007ooOol03goo000=Ool00`00Oomoo`16Ool0
0`00Oomoo`1OOol00`00Ool00002000kOol00`00Oomoo`0>Ool000eoo`03001oogoo04Moo`03001o
ogoo05eoo`<003ioo`03001oogoo00ioo`003Goo00<007ooOol0B7oo00<007ooOol0FGoo0`000Woo
00<007ooOol0?7oo00<007ooOol03Woo000=Ool00`00Oomoo`18Ool00`00Oomoo`1EOol40005Ool0
0`00Oomoo`0lOol00`00Oomoo`0>Ool000aoo`03001oogoo04Yoo`03001oogoo055oo`<000Uoo`03
001oogoo03aoo`03001oogoo00ioo`0037oo00<007ooOol0Bgoo00<007ooOol0CGoo0`0037oo00<0
07ooOol0?7oo00<007ooOol03Woo000<Ool00`00Oomoo`1<Ool00`00Oomoo`19Ool3000?Ool00`00
Oomoo`0lOol00`00Oomoo`0>Ool000aoo`03001oogoo04eoo`03001oogoo04Eoo`<0019oo`03001o
ogoo03eoo`03001oogoo00eoo`0037oo00<007ooOol0CWoo00<007ooOol0@Goo0`005Goo00<007oo
Ool0?Goo00<007ooOol03Goo000<Ool00`00Oomoo`1?Ool00`00Oomoo`0mOol3000HOol00`00Oomo
o`0mOol00`00Oomoo`0=Ool000]oo`03001oogoo055oo`03001oogoo02Uoo`El7`]oo`<001]oo`03
001oogoo03eoo`03001oogoo00eoo`002goo00<007ooOol0DWoo00<007ooOol09goo1g`O1goo0`00
7Woo00<007ooOol0?Goo00<007ooOol03Goo000;Ool00`00Oomoo`1COol00`00Oomoo`0UOol9O1l3
Ool3000QOol00`00Oomoo`0mOol00`00Oomoo`0=Ool000]oo`03001oogoo05Aoo`03001oogoo02=o
o`]l7`8002Aoo`03001oogoo03eoo`03001oogoo00eoo`002goo00<007ooOol0EGoo00<007ooOol0
8Goo3G`O9Goo00<007ooOol0?Goo00<007ooOol03Goo000;Ool00`00Oomoo`1FOol00`00Oomoo`0P
Ool=O1lUOol00`00Oomoo`0nOol00`00Oomoo`0<Ool000]oo`03001oogoo05Moo`03001oogoo01mo
o`el7bEoo`03001oogoo03ioo`03001oogoo00aoo`002Woo00<007ooOol0FGoo00<007ooOol07Goo
00<007`OO1l02g`O9Goo00<007ooOol0?Woo00<007ooOol037oo000:Ool00`00Oomoo`1JOol00`00
Oomoo`0HOol400000gooO1ml7`0;O1lVOol00`00Oomoo`0mOol00`00Oomoo`0<Ool000Yoo`03001o
ogoo05]oo`03001oogoo01Aoo`<000Ioo`]l7bMoo`03001oogoo03eoo`03001oogoo00aoo`002Woo
00<007ooOol0G7oo00<007ooOol047oo0`002Woo2G`O:7oo00<007ooOol0?Goo00<007ooOol037oo
000:Ool00`00Oomoo`1MOol00`00Oomoo`0<Ool3000>Ool7O1lYOol00`00Oomoo`0mOol00`00Oomo
o`0<Ool000Yoo`03001oogoo05ioo`03001oogoo00Qoo`<0019oo`El7bYoo`03001oogoo03ioo`03
001oogoo00]oo`002Goo00<007ooOol0H7oo00<007ooOol017oo0`00A7oo00<007ooOol0?Woo00<0
07ooOol02goo0009Ool00`00Oomoo`1QOol00`00Oomoo`030017Ool00`00Oomoo`0nOol00`00Oomo
o`0;Ool000Uoo`03001oogoo069oo`8004Yoo`03001oogoo03ioo`03001oogoo00]oo`002Goo00<0
07ooOol0HWoo00<007ooOol0B7oo0P00@7oo00<007ooOol02goo0009Ool00`00Oomoo`1ROol00`00
Oomoo`15Ool30002Ool00`00Oomoo`0mOol00`00Oomoo`0;Ool000Uoo`03001oogoo069oo`03001o
ogoo045oo`@000Ioo`03001oogoo03aoo`03001oogoo00]oo`002Goo00<007ooOol0HWoo00<007oo
Ool0?Woo0`002Woo00<007ooOol0?7oo00<007ooOol02goo0008Ool00`00Oomoo`1SOol00`00Oomo
o`0kOol3000>Ool00`00Oomoo`0lOol00`00Oomoo`0:Ool000Qoo`03001oogoo06=oo`03001oogoo
03Qoo`<0019oo`03001oogoo03]oo`03001oogoo00Yoo`0027oo00<007ooOol0Hgoo00<007ooOol0
=Goo0`005Woo00<007ooOol0>Woo00<007ooOol02Woo0008Ool00`00Oomoo`1SOol00`00Oomoo`0a
Ool4000JOol00`00Oomoo`0iOol00`00Oomoo`0:Ool000Qoo`03001oogoo06=oo`03001oogoo02io
o`<001moo`03001oogoo03Qoo`03001oogoo00Yoo`0027oo00<007ooOol0Hgoo00<007ooOol057oo
1@0O4Woo0`008Woo00<007ooOol0>7oo00<007ooOol02Woo0007Ool00`00Oomoo`1TOol00`00Oomo
o`0COol701l>Ool3000VOol00`00Oomoo`0gOol00`00Oomoo`0:Ool000Moo`03001oogoo06Aoo`03
001oogoo019oo`T07`Yoo`<002Yoo`03001oogoo03Moo`03001oogoo00Uoo`001goo00<007ooOol0
I7oo00<007ooOol04Goo2`0O1Goo1000;Woo00<007ooOol0=Woo00<007ooOol02Goo0007Ool00`00
Oomoo`1SOol00`00Oomoo`0AOol=01l017oo00000000<goo00<007ooOol0=Goo00<007ooOol02Goo
0007Ool00`00Oomoo`1SOol00`00Oomoo`0AOol;01l3000fOol00`00Oomoo`0eOol00`00Oomoo`09
Ool000Moo`03001oogoo06=oo`03001oogoo015oo`P07`<000807cQoo`03001oogoo03Aoo`03001o
ogoo00Uoo`001goo00<007ooOol0Hgoo00<007ooOol04Goo1@0O0`001@0O>Goo00<007ooOol0<goo
00<007ooOol02Goo0006Ool00`00Oomoo`1TOol00`00Oomoo`0AOol00`0O00000002000801ljOol0
0`00Oomoo`0bOol00`00Oomoo`09Ool000Ioo`03001oogoo06Aoo`03001oogoo00moo`<000/07cao
o`03001oogoo035oo`03001oogoo00Uoo`001Woo00<007ooOol0I7oo00<007ooOol037oo0`0017oo
2@0O?Goo00<007ooOol0<Woo00<007ooOol027oo0006Ool00`00Oomoo`1TOol00`00Oomoo`09Ool3
0008Ool701loOol00`00Oomoo`0aOol00`00Oomoo`08Ool000Ioo`03001oogoo06Aoo`03001oogoo
00Ioo`<000aoo`D07d5oo`03001oogoo031oo`03001oogoo00Qoo`001Woo00<007ooOol0I7oo00<0
07ooOol00Woo1000EWoo00<007ooOol0;goo00<007ooOol027oo0005Ool00`00Oomoo`1UOol00`00
Ool00002001KOol00`00Oomoo`0^Ool00`00Oomoo`08Ool000Eoo`03001oogoo06Aoo`<005moo`03
001oogoo02eoo`03001oogoo00Qoo`001Goo00<007ooOol0HGoo0`0000=oo`00Ool0Ggoo00<007oo
Ool0;Goo00<007ooOol027oo0005Ool00`00Oomoo`1NOol30004Ool00`00Oomoo`1OOol00`00Oomo
o`0]Ool00`00Oomoo`07Ool000Eoo`03001oogoo05Yoo`@000Moo`03001oogoo061oo`03001oogoo
02aoo`03001oogoo00Moo`001Goo00<007ooOol0Egoo0`002goo00<007ooOol0HGoo00<007ooOol0
:goo00<007ooOol01goo0005Ool00`00Oomoo`1DOol3000>Ool00`00Oomoo`1ROol00`00Oomoo`0Z
Ool00`00Oomoo`07Ool000Aoo`03001oogoo059oo`<0015oo`03001oogoo069oo`03001oogoo02Yo
o`03001oogoo00Moo`0017oo00<007ooOol0CWoo100057oo00<007ooOol0Hgoo00<007ooOol0:Goo
00<007ooOol01goo0004Ool00`00Oomoo`1;Ool3000HOol00`00Oomoo`1TOol00`00Oomoo`0XOol0
0`00Oomoo`07Ool000Aoo`03001oogoo04Qoo`<001]oo`03001oogoo06Eoo`03001oogoo02Qoo`03
001oogoo00Ioo`0017oo00<007ooOol0AGoo0`007Woo00<007ooOol0IWoo00<007ooOol09goo00<0
07ooOol01Woo0004Ool00`00Oomoo`12Ool3000QOol00`00Oomoo`1VOol00`00Oomoo`0WOol00`00
Oomoo`06Ool000=oo`03001oogoo03moo`@002Aoo`03001oogoo06Moo`03001oogoo02Ioo`03001o
ogoo00Ioo`000goo00<007ooOol0?7oo0`00:7oo00<007ooOol0J7oo00<007ooOol09Goo00<007oo
Ool01Woo0003Ool00`00Oomoo`0iOol3000[Ool00`00Oomoo`1YOol00`00Oomoo`0TOol00`00Oomo
o`06Ool000=oo`03001oogoo03Ioo`<002eoo`03001oogoo06]oo`03001oogoo02=oo`03001oogoo
00Ioo`000goo00<007ooOol0<goo0`00<7oo00<007ooOol0K7oo00<007ooOol08Woo00<007ooOol0
1Woo0003Ool00`00Oomoo`0_Ool4000cOol00`00Oomoo`1/Ool00`00Oomoo`0SOol00`00Oomoo`05
Ool0009oo`03001oogoo02eoo`<003Moo`03001oogoo06eoo`03001oogoo029oo`03001oogoo00Eo
o`000Woo00<007ooOol0:Woo0`00>Woo00<007ooOol0KWoo00<007ooOol08Goo00<007ooOol01Goo
0002Ool00`00Oomoo`0WOol3000mOol00`00Oomoo`1_Ool00`00Oomoo`0POol00`00Oomoo`05Ool0
009oo`03001oogoo02Aoo`<0041oo`03001oogoo071oo`03001oogoo01moo`03001oogoo00Eoo`00
0Woo00<007ooOol087oo1000@goo00<007ooOol0L7oo00<007ooOol07goo00<007ooOol01Goo0002
Ool00`00Oomoo`0MOol30017Ool00`00Oomoo`1aOol00`00Oomoo`0NOol00`00Oomoo`05Ool0009o
o`03001oogoo01Yoo`<004Yoo`03001oogoo079oo`03001oogoo01ioo`03001oogoo00Aoo`0000=o
o`00Ool06Goo0`00CGoo00<007ooOol0Lgoo00<007ooOol07Goo00<007ooOol017oo00000goo001o
o`0FOol3001@Ool00`00Oomoo`1dOol00`00Oomoo`0LOol00`00Oomoo`04Ool00003Ool007oo019o
o`@005=oo`03001oogoo07Aoo`03001oogoo01aoo`03001oogoo00Aoo`0000=oo`00Ool03goo0`00
Egoo00<007ooOol0MGoo00<007ooOol06goo00<007ooOol017oo00000goo001oo`0<Ool3001JOol0
0`00Oomoo`1fOol00`00Oomoo`0JOol00`00Oomoo`04Ool00003Ool007oo00Uoo`<005eoo`03001o
ogoo07Moo`03001oogoo01Uoo`03001oogoo00Aoo`0000<007ooOol01Woo0`00H7oo00<007ooOol0
N7oo00<007ooOol067oo00<007ooOol017oo00000`00Oomoo`02Ool4001SOol00`00Oomoo`1iOol0
0`00Oomoo`0HOol00`00Oomoo`03Ool00003001oo`00008006Moo`03001oogoo07Uoo`03001oogoo
01Qoo`03001oogoo00=oo`000P00JWoo00<007ooOol0NWoo00<007ooOol05goo00<007ooOol00goo
00000goo0000001YOol00`00Oomoo`1kOol00`00Oomoo`0FOol00`00Oomoo`03Ool000=oo`03001o
ogoo06Ioo`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo00=oo`0017oo00<007ooOol0IGoo
00<007ooOol0OGoo00<007ooOol057oo00<007ooOol00goo0005Ool2001UOol00`00Oomoo`1mOol0
0`00Oomoo`0DOol00`00Oomoo`03Ool000Moo`03001oogoo069oo`03001oogoo07ioo`03001oogoo
01Aoo`03001oogoo009oo`0027oo0P00HWoo00<007ooOol0Ogoo00<007ooOol04goo00<007ooOol0
0Woo000:Ool00`00Oomoo`1OOol00`00Oomoo`20Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000]o
o`8005ioo`03001oogoo089oo`03001oogoo015oo`03001oogoo009oo`003Goo00<007ooOol0Fgoo
00<007ooOol0PWoo00<007ooOol04Goo00<007ooOol00Woo000>Ool00`00Oomoo`1JOol00`00Oomo
o`23Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool000moo`8005Yoo`03001oogoo08Aoo`03001oogoo
00moo`03001oogoo009oo`004Goo00<007ooOol0Egoo00<007ooOol0QGoo00<007ooOol03Woo00<0
07ooOol00Woo000BOol2001GOol00`00Oomoo`26Ool00`00Oomoo`0>Ool00`00Oomoo`01Ool001Ao
o`03001oogoo05Aoo`03001oogoo08Moo`03001oogoo00eoo`03001oogoo005oo`005Goo00<007oo
Ool0Dgoo00<007ooOol0Qgoo00<007ooOol03Goo00<007ooOol00Goo000FOol2001COol00`00Oomo
o`28Ool00`00Oomoo`0<Ool00`00Oomoo`01Ool001Qoo`03001oogoo051oo`03001oogoo08Uoo`03
001oogoo00]oo`03001oogoo005oo`006Goo0P00D7oo00<007ooOol0RWoo00<007ooOol02Woo00<0
07ooOol00Goo000KOol00`00Oomoo`1=Ool00`00Oomoo`2;Ool00`00Oomoo`09Ool00`00Oomoo`01
Ool001aoo`8004eoo`03001oogoo08]oo`03001oogoo00Yoo`40005oo`5oo`007Woo00<007ooOol0
BWoo00<007ooOol0S7oo00<007ooOol02Goo0@000Goo0Goo000OOol00`00Oomoo`19Ool00`00Oomo
o`2=Ool00`00Oomoo`08Ool10001Ool1Ool0021oo`8004Uoo`03001oogoo08ioo`03001oogoo00Mo
o`40005oo`5oo`008Woo00<007ooOol0AWoo00<007ooOol0Sgoo00<007ooOol01Woo0@000Goo0Goo
000SOol20016Ool00`00Oomoo`2?Ool00`00Oomoo`06Ool10001Ool1Ool002Eoo`03001oogoo04=o
o`03001oogoo091oo`03001oogoo00Eoo`40005oo`5oo`009Woo0P00@goo00<007ooOol0TGoo00<0
07ooOol01Goo0@000Goo000XOol00`00Oomoo`10Ool00`00Oomoo`2BOol00`00Oomoo`04Ool10001
Ool002Uoo`03001oogoo03moo`03001oogoo09=oo`03001oogoo00=oo`40005oo`00:Woo0P0047oo
1@0O:Woo00<007ooOol0U7oo00<007ooOol00Woo0@000Goo000/Ool00`00Oomoo`0<Ool701lYOol0
0`00Oomoo`2DOol00`00Oomoo`02Ool10001Ool002eoo`8000]oo`T07bQoo`03001oogoo09Eoo`05
001oogooOol00001Ool002moo`03001oogoo00Moo`/07bMoo`03001oogoo09Ioo`04001oogoo0001
Ool0031oo`03001oogoo00Eoo`d07bIoo`03001oogoo09Moo`03001oo`00005oo`00<Goo0P001Goo
3@0O9Goo00<007ooOol0VGoo0@000Goo0@00000cOol00`00Oomoo`02Ool=01lUOol00`00Oomoo`2I
Ool10001Ool1000003Aoo`80009oo`d07bEoo`03001oogoo06Yoo`D07b]oo`800000=Woo00<007oo
01l0300O9Goo00<007ooOol0JGoo1`0O:Goo0`00000gOol2000;01lVOol00`00Oomoo`1XOol901lT
Ool40003Ool003Uoo`0300007`0O00L07bMoo`03001oogoo06Moo`/07aioo`D000Moo`00>Woo00<0
000O01l01@0O:7oo00<007ooOol0IWoo3@0O6Goo100037oo000kOol00`0001l07`0301lYOol00`00
Oomoo`1VOol=01lEOol4000@Ool003eoo`03001oogoo02Yoo`03001oogoo06Ioo`d07a1oo`D001Ao
o`00?Woo0P00:Woo00<007ooOol0IWoo3@0O37oo10006Goo0010Ool00`00Oomoo`0WOol00`00Oomo
o`1VOol=01l7Ool5000MOol0045oo`03001oogoo02Ioo`03001oogoo06Moo`/07`Aoo`@0029oo`00
@Woo0P009Woo00<007ooOol0J7oo2@0O00=oo`0000000P009Woo0014Ool00`00Oomoo`0SOol00`00
Oomoo`1YOol701l2000ZOol004Eoo`8002=oo`03001oogoo06Uoo`0300007`0O00<07beoo`00Agoo
00<007ooOol087oo00<007ooOol0I7oo1@00<goo0018Ool2000POol00`00Oomoo`1POol4000hOol0
04Yoo`03001oogoo01eoo`03001oogoo05]oo`D003aoo`00Bgoo00<007ooOol077oo00<007ooOol0
Egoo1000@Goo001<Ool2000LOol00`00Oomoo`1COol40015Ool004ioo`03001oogoo01Uoo`03001o
ogoo04ioo`D004Uoo`00Cgoo0P006Goo00<007ooOol0BWoo1000CWoo001AOol00`00Oomoo`0FOol0
0`00Oomoo`15Ool5001BOol0059oo`8001Ioo`03001oogoo045oo`@005Moo`00E7oo00<007ooOol0
4goo00<007ooOol0?Goo1000Fgoo001EOol00`00Oomoo`0BOol00`00Oomoo`0hOol5001OOol005Io
o`80015oo`03001oogoo03Eoo`@006Aoo`00F7oo00<007ooOol03Woo00<007ooOol0<7oo1@00J7oo
001IOol2000>Ool00`00Oomoo`0/Ool4001]Ool005]oo`03001oogoo00]oo`03001oogoo02Moo`D0
075oo`00G7oo00<007ooOol02Woo00<007ooOol08goo1000MWoo001MOol2000:Ool00`00Oomoo`0O
Ool4001jOol005moo`03001oogoo00Moo`03001oogoo01Yoo`D007ioo`00H7oo0P001goo00<007oo
Ool05Woo1000Pgoo001ROol00`00Oomoo`04Ool00`00Oomoo`0AOol50027Ool006=oo`8000Aoo`03
001oogoo00eoo`@008aoo`00IGoo00D007ooOomoo`0000]oo`@0091oo`00IWoo00@007ooOol000Io
o`D009Aoo`00Igoo0`000Woo1000VGoo001YOol3002MOol00001\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.0486402, \
-4.72903*^-05, 0.00324458, 0.00324458}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["dt=0.01;", "Input"],

Cell["NSPHR=6;NDIM=6 NSPHR;Ng=3 NSPHR; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\StokesianDynamics\\\\data.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\StokesianDynamics\\data.m", 9]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];
X[3,0]=X[3];Y[3,0]=Y[3];Z[3,0]=Z[3];
X[4,0]=X[4];Y[4,0]=Y[4];Z[4,0]=Z[4];
X[5,0]=X[5];Y[5,0]=Y[5];Z[5,0]=Z[5];
X[6,0]=X[6];Y[6,0]=Y[6];Z[6,0]=Z[6];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<310,{<<\"C:\\\\StokesianDynamics\\\\NEWTON2.m\";
X[1,t]=X[1,t-1]+UNEW[1]*dt;Y[1,t]=Y[1,t-1]+UNEW[2]*dt;Z[1,t]=Z[1,t-1]+UNEW[3]*\
dt;X[2,t]=X[2,t-1]+UNEW[4]*dt;Y[2,t]=Y[2,t-1]+UNEW[5]*dt;Z[2,t]=Z[2,t-1]+UNEW[\
6]*dt;X[3,t]=X[3,t-1]+UNEW[7]*dt;Y[3,t]=Y[3,t-1]+UNEW[8]*dt;Z[3,t]=Z[3,t-1]+\
UNEW[9]*dt;X[4,t]=X[4,t-1]+UNEW[10]*dt;Y[4,t]=Y[4,t-1]+UNEW[11]*dt;Z[4,t]=Z[4,\
t-1]+UNEW[12]*dt;X[5,t]=X[5,t-1]+UNEW[13]*dt;Y[5,t]=Y[5,t-1]+UNEW[14]*dt;Z[5,\
t]=Z[5,t-1]+UNEW[15]*dt;X[6,t]=X[6,t-1]+UNEW[16]*dt;Y[6,t]=Y[6,t-1]+UNEW[17]*\
dt;Z[6,t]=Z[6,t-1]+UNEW[18]*dt;Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"],

Cell[BoxData[
    \(100\)], "Print"],

Cell[BoxData[
    \(101\)], "Print"],

Cell[BoxData[
    \(102\)], "Print"],

Cell[BoxData[
    \(103\)], "Print"],

Cell[BoxData[
    \(104\)], "Print"],

Cell[BoxData[
    \(105\)], "Print"],

Cell[BoxData[
    \(106\)], "Print"],

Cell[BoxData[
    \(107\)], "Print"],

Cell[BoxData[
    \(108\)], "Print"],

Cell[BoxData[
    \(109\)], "Print"],

Cell[BoxData[
    \(110\)], "Print"],

Cell[BoxData[
    \(111\)], "Print"],

Cell[BoxData[
    \(112\)], "Print"],

Cell[BoxData[
    \(113\)], "Print"],

Cell[BoxData[
    \(114\)], "Print"],

Cell[BoxData[
    \(115\)], "Print"],

Cell[BoxData[
    \(116\)], "Print"],

Cell[BoxData[
    \(117\)], "Print"],

Cell[BoxData[
    \(118\)], "Print"],

Cell[BoxData[
    \(119\)], "Print"],

Cell[BoxData[
    \(120\)], "Print"],

Cell[BoxData[
    \(121\)], "Print"],

Cell[BoxData[
    \(122\)], "Print"],

Cell[BoxData[
    \(123\)], "Print"],

Cell[BoxData[
    \(124\)], "Print"],

Cell[BoxData[
    \(125\)], "Print"],

Cell[BoxData[
    \(126\)], "Print"],

Cell[BoxData[
    \(127\)], "Print"],

Cell[BoxData[
    \(128\)], "Print"],

Cell[BoxData[
    \(129\)], "Print"],

Cell[BoxData[
    \(130\)], "Print"],

Cell[BoxData[
    \(131\)], "Print"],

Cell[BoxData[
    \(132\)], "Print"],

Cell[BoxData[
    \(133\)], "Print"],

Cell[BoxData[
    \(134\)], "Print"],

Cell[BoxData[
    \(135\)], "Print"],

Cell[BoxData[
    \(136\)], "Print"],

Cell[BoxData[
    \(137\)], "Print"],

Cell[BoxData[
    \(138\)], "Print"],

Cell[BoxData[
    \(139\)], "Print"],

Cell[BoxData[
    \(140\)], "Print"],

Cell[BoxData[
    \(141\)], "Print"],

Cell[BoxData[
    \(142\)], "Print"],

Cell[BoxData[
    \(143\)], "Print"],

Cell[BoxData[
    \(144\)], "Print"],

Cell[BoxData[
    \(145\)], "Print"],

Cell[BoxData[
    \(146\)], "Print"],

Cell[BoxData[
    \(147\)], "Print"],

Cell[BoxData[
    \(148\)], "Print"],

Cell[BoxData[
    \(149\)], "Print"],

Cell[BoxData[
    \(150\)], "Print"],

Cell[BoxData[
    \(151\)], "Print"],

Cell[BoxData[
    \(152\)], "Print"],

Cell[BoxData[
    \(153\)], "Print"],

Cell[BoxData[
    \(154\)], "Print"],

Cell[BoxData[
    \(155\)], "Print"],

Cell[BoxData[
    \(156\)], "Print"],

Cell[BoxData[
    \(157\)], "Print"],

Cell[BoxData[
    \(158\)], "Print"],

Cell[BoxData[
    \(159\)], "Print"],

Cell[BoxData[
    \(160\)], "Print"],

Cell[BoxData[
    \(161\)], "Print"],

Cell[BoxData[
    \(162\)], "Print"],

Cell[BoxData[
    \(163\)], "Print"],

Cell[BoxData[
    \(164\)], "Print"],

Cell[BoxData[
    \(165\)], "Print"],

Cell[BoxData[
    \(166\)], "Print"],

Cell[BoxData[
    \(167\)], "Print"],

Cell[BoxData[
    \(168\)], "Print"],

Cell[BoxData[
    \(169\)], "Print"],

Cell[BoxData[
    \(170\)], "Print"],

Cell[BoxData[
    \(171\)], "Print"],

Cell[BoxData[
    \(172\)], "Print"],

Cell[BoxData[
    \(173\)], "Print"],

Cell[BoxData[
    \(174\)], "Print"],

Cell[BoxData[
    \(175\)], "Print"],

Cell[BoxData[
    \(176\)], "Print"],

Cell[BoxData[
    \(177\)], "Print"],

Cell[BoxData[
    \(178\)], "Print"],

Cell[BoxData[
    \(179\)], "Print"],

Cell[BoxData[
    \(180\)], "Print"],

Cell[BoxData[
    \(181\)], "Print"],

Cell[BoxData[
    \(182\)], "Print"],

Cell[BoxData[
    \(183\)], "Print"],

Cell[BoxData[
    \(184\)], "Print"],

Cell[BoxData[
    \(185\)], "Print"],

Cell[BoxData[
    \(186\)], "Print"],

Cell[BoxData[
    \(187\)], "Print"],

Cell[BoxData[
    \(188\)], "Print"],

Cell[BoxData[
    \(189\)], "Print"],

Cell[BoxData[
    \(190\)], "Print"],

Cell[BoxData[
    \(191\)], "Print"],

Cell[BoxData[
    \(192\)], "Print"],

Cell[BoxData[
    \(193\)], "Print"],

Cell[BoxData[
    \(194\)], "Print"],

Cell[BoxData[
    \(195\)], "Print"],

Cell[BoxData[
    \(196\)], "Print"],

Cell[BoxData[
    \(197\)], "Print"],

Cell[BoxData[
    \(198\)], "Print"],

Cell[BoxData[
    \(199\)], "Print"],

Cell[BoxData[
    \(200\)], "Print"],

Cell[BoxData[
    \(201\)], "Print"],

Cell[BoxData[
    \(202\)], "Print"],

Cell[BoxData[
    \(203\)], "Print"],

Cell[BoxData[
    \(204\)], "Print"],

Cell[BoxData[
    \(205\)], "Print"],

Cell[BoxData[
    \(206\)], "Print"],

Cell[BoxData[
    \(207\)], "Print"],

Cell[BoxData[
    \(208\)], "Print"],

Cell[BoxData[
    \(209\)], "Print"],

Cell[BoxData[
    \(210\)], "Print"],

Cell[BoxData[
    \(211\)], "Print"],

Cell[BoxData[
    \(212\)], "Print"],

Cell[BoxData[
    \(213\)], "Print"],

Cell[BoxData[
    \(214\)], "Print"],

Cell[BoxData[
    \(215\)], "Print"],

Cell[BoxData[
    \(216\)], "Print"],

Cell[BoxData[
    \(217\)], "Print"],

Cell[BoxData[
    \(218\)], "Print"],

Cell[BoxData[
    \(219\)], "Print"],

Cell[BoxData[
    \(220\)], "Print"],

Cell[BoxData[
    \(221\)], "Print"],

Cell[BoxData[
    \(222\)], "Print"],

Cell[BoxData[
    \(223\)], "Print"],

Cell[BoxData[
    \(224\)], "Print"],

Cell[BoxData[
    \(225\)], "Print"],

Cell[BoxData[
    \(226\)], "Print"],

Cell[BoxData[
    \(227\)], "Print"],

Cell[BoxData[
    \(228\)], "Print"],

Cell[BoxData[
    \(229\)], "Print"],

Cell[BoxData[
    \(230\)], "Print"],

Cell[BoxData[
    \(231\)], "Print"],

Cell[BoxData[
    \(232\)], "Print"],

Cell[BoxData[
    \(233\)], "Print"],

Cell[BoxData[
    \(234\)], "Print"],

Cell[BoxData[
    \(235\)], "Print"],

Cell[BoxData[
    \(236\)], "Print"],

Cell[BoxData[
    \(237\)], "Print"],

Cell[BoxData[
    \(238\)], "Print"],

Cell[BoxData[
    \(239\)], "Print"],

Cell[BoxData[
    \(240\)], "Print"],

Cell[BoxData[
    \(241\)], "Print"],

Cell[BoxData[
    \(242\)], "Print"],

Cell[BoxData[
    \(243\)], "Print"],

Cell[BoxData[
    \(244\)], "Print"],

Cell[BoxData[
    \(245\)], "Print"],

Cell[BoxData[
    \(246\)], "Print"],

Cell[BoxData[
    \(247\)], "Print"],

Cell[BoxData[
    \(248\)], "Print"],

Cell[BoxData[
    \(249\)], "Print"],

Cell[BoxData[
    \(250\)], "Print"],

Cell[BoxData[
    \(251\)], "Print"],

Cell[BoxData[
    \(252\)], "Print"],

Cell[BoxData[
    \(253\)], "Print"],

Cell[BoxData[
    \(254\)], "Print"],

Cell[BoxData[
    \(255\)], "Print"],

Cell[BoxData[
    \(256\)], "Print"],

Cell[BoxData[
    \(257\)], "Print"],

Cell[BoxData[
    \(258\)], "Print"],

Cell[BoxData[
    \(259\)], "Print"],

Cell[BoxData[
    \(260\)], "Print"],

Cell[BoxData[
    \(261\)], "Print"],

Cell[BoxData[
    \(262\)], "Print"],

Cell[BoxData[
    \(263\)], "Print"],

Cell[BoxData[
    \(264\)], "Print"],

Cell[BoxData[
    \(265\)], "Print"],

Cell[BoxData[
    \(266\)], "Print"],

Cell[BoxData[
    \(267\)], "Print"],

Cell[BoxData[
    \(268\)], "Print"],

Cell[BoxData[
    \(269\)], "Print"],

Cell[BoxData[
    \(270\)], "Print"],

Cell[BoxData[
    \(271\)], "Print"],

Cell[BoxData[
    \(272\)], "Print"],

Cell[BoxData[
    \(273\)], "Print"],

Cell[BoxData[
    \(274\)], "Print"],

Cell[BoxData[
    \(275\)], "Print"],

Cell[BoxData[
    \(276\)], "Print"],

Cell[BoxData[
    \(277\)], "Print"],

Cell[BoxData[
    \(278\)], "Print"],

Cell[BoxData[
    \(279\)], "Print"],

Cell[BoxData[
    \(280\)], "Print"],

Cell[BoxData[
    \(281\)], "Print"],

Cell[BoxData[
    \(282\)], "Print"],

Cell[BoxData[
    \(283\)], "Print"],

Cell[BoxData[
    \(284\)], "Print"],

Cell[BoxData[
    \(285\)], "Print"],

Cell[BoxData[
    \(286\)], "Print"],

Cell[BoxData[
    \(287\)], "Print"],

Cell[BoxData[
    \(288\)], "Print"],

Cell[BoxData[
    \(289\)], "Print"],

Cell[BoxData[
    \(290\)], "Print"],

Cell[BoxData[
    \(291\)], "Print"],

Cell[BoxData[
    \(292\)], "Print"],

Cell[BoxData[
    \(293\)], "Print"],

Cell[BoxData[
    \(294\)], "Print"],

Cell[BoxData[
    \(295\)], "Print"],

Cell[BoxData[
    \(296\)], "Print"],

Cell[BoxData[
    \(297\)], "Print"],

Cell[BoxData[
    \(298\)], "Print"],

Cell[BoxData[
    \(299\)], "Print"],

Cell[BoxData[
    \(300\)], "Print"],

Cell[BoxData[
    \(301\)], "Print"],

Cell[BoxData[
    \(302\)], "Print"],

Cell[BoxData[
    \(303\)], "Print"],

Cell[BoxData[
    \(304\)], "Print"],

Cell[BoxData[
    \(305\)], "Print"],

Cell[BoxData[
    \(306\)], "Print"],

Cell[BoxData[
    \(307\)], "Print"],

Cell[BoxData[
    \(308\)], "Print"],

Cell[BoxData[
    \(309\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "d1=ScatterPlot3D[Table[{X[1,t],Y[1,t],Z[1,t]},{t,0,307}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined->True,PlotStyle->{RGBColor[Random[],Random[],Random[]],\
Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "d2=ScatterPlot3D[Table[{X[2,t],Y[2,t],Z[2,t]},{t,0,307}],",
  StyleBox["BoxRatios-", "MR",
    FontWeight->"Bold"],
  StyleBox[">", "MR"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "d3=ScatterPlot3D[Table[{X[3,t],Chop[Y[3,t]],Z[3,t]},{t,0,307}],",
  StyleBox["BoxRatios-", "MR",
    FontWeight->"Bold"],
  StyleBox[">", "MR"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "d4=ScatterPlot3D[Table[{X[4,t],Y[4,t],Z[4,t]},{t,0,307}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "d5=ScatterPlot3D[Table[{X[5,t],Y[5,t],Z[5,t]},{t,0,307}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "d6=ScatterPlot3D[Table[{X[6,t],Chop[Y[6,t]],Z[6,t]},{t,0,307}],",
  StyleBox["BoxRatios->", "MR",
    FontWeight->"Bold"],
  "{1,1,1},PlotJoined->True,\n\
PlotStyle->{RGBColor[Random[],Random[],Random[]],Thickness[0.015]},",
  "DisplayFunction\[Rule]Identity",
  "]"
}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[d1,d2,d3,d4,d5,d6,DisplayFunction\[Rule]$DisplayFunction]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 -5.20417e-017 1.16608 [
[.20979 .17958 -11.3443 -9 ]
[.20979 .17958 .65575 0 ]
[.35306 .11908 -5.39426 -9 ]
[.35306 .11908 .60574 0 ]
[.50499 .05497 -5.1164 -9 ]
[.50499 .05497 .8836 0 ]
[.0976 .88816 -6.75531 0 ]
[.0976 .88816 5.24469 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.32899 1.05038 -3.16592 0 ]
[.32899 1.05038 2.83408 9 ]
[.0622 .33146 -24 -2.67905 ]
[.0622 .33146 0 6.32095 ]
[.04021 .46908 -24 -2.80194 ]
[.04021 .46908 0 6.19806 ]
[.01599 .62072 -18 -2.93868 ]
[.01599 .62072 0 6.06132 ]
[-0.01083 .78864 -6 -3.09177 ]
[-0.01083 .78864 0 5.90823 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.21948 .19046 m
.22433 .1959 L
s
[(-2)] .20979 .17958 .89071 1 Mshowa
.36215 .13047 m
.3667 .13617 L
s
[(0)] .35306 .11908 .79809 1 Mshowa
.5134 .06688 m
.5176 .07283 L
s
[(2)] .50499 .05497 .70547 1 Mshowa
.125 Mabswid
.11767 .23327 m
.1207 .23642 L
s
.15114 .2192 m
.15413 .22239 L
s
.18507 .20493 m
.18802 .20816 L
s
.25439 .17578 m
.25725 .17909 L
s
.28979 .1609 m
.29261 .16424 L
s
.32571 .14579 m
.32849 .14917 L
s
.39913 .11492 m
.40181 .11838 L
s
.43666 .09915 m
.43928 .10264 L
s
.47474 .08313 m
.47731 .08667 L
s
.55264 .05038 m
.5551 .05399 L
s
.59248 .03363 m
.59488 .03728 L
s
.63293 .01662 m
.63527 .02031 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.09942 .8737 m
.10033 .86647 L
s
[(-2)] .0976 .88816 .12588 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.3298 1.03583 m
.3302 1.02855 L
s
[(2)] .32899 1.05038 .05531 -1 Mshowa
.125 Mabswid
.13153 .8963 m
.13203 .89196 L
s
.1626 .91817 m
.16306 .91382 L
s
.19269 .93934 m
.19311 .93499 L
s
.25007 .97972 m
.25042 .97536 L
s
.27745 .99899 m
.27776 .99463 L
s
.30402 1.01769 m
.30429 1.01332 L
s
.06621 .85034 m
.06681 .846 L
s
.03186 .82616 m
.0325 .82183 L
s
.35483 1.05344 m
.35504 1.04907 L
s
.37914 1.07055 m
.37932 1.06618 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.07571 .32599 m
.08246 .32326 L
s
[(-150)] .0622 .33146 1 -0.40466 Mshowa
.05385 .46394 m
.06067 .46136 L
s
[(-100)] .04021 .46908 1 -0.37735 Mshowa
.02976 .61595 m
.03664 .61356 L
s
[(-50)] .01599 .62072 1 -0.34696 Mshowa
.00308 .78429 m
.01004 .78211 L
s
[(0)] -0.01083 .78864 1 -0.31294 Mshowa
.125 Mabswid
.0715 .35255 m
.07556 .35093 L
s
.06721 .37961 m
.07128 .37801 L
s
.06284 .40718 m
.06692 .4056 L
s
.05839 .43529 m
.06247 .43372 L
s
.04922 .49315 m
.05332 .49162 L
s
.0445 .52294 m
.04861 .52143 L
s
.03968 .55332 m
.0438 .55184 L
s
.03477 .58432 m
.0389 .58286 L
s
.02464 .64823 m
.02878 .64682 L
s
.01942 .68118 m
.02357 .6798 L
s
.01409 .71483 m
.01825 .71347 L
s
.00864 .74919 m
.01281 .74786 L
s
.07984 .29992 m
.08389 .29827 L
s
.0839 .27433 m
.08794 .27265 L
s
.08788 .24919 m
.09191 .2475 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.712 .702 .795 r
.015 w
.53415 .63105 m
.53411 .62891 L
s
.53419 .63315 m
.53415 .63105 L
s
.53422 .6352 m
.53419 .63315 L
s
.53411 .62891 m
.53407 .62673 L
s
.53426 .63721 m
.53422 .6352 L
s
.53407 .62673 m
.53403 .62451 L
s
.53429 .63917 m
.53426 .63721 L
s
.53403 .62451 m
.53398 .62225 L
s
.53432 .64108 m
.53429 .63917 L
s
.53398 .62225 m
.53393 .61995 L
s
.53435 .64295 m
.53432 .64108 L
s
.53393 .61995 m
.53389 .61762 L
s
.53437 .64477 m
.53435 .64295 L
s
.53389 .61762 m
.53383 .61525 L
s
.53383 .61525 m
.53378 .61284 L
s
.53439 .64655 m
.53437 .64477 L
s
.53378 .61284 m
.53373 .61041 L
s
.53441 .64827 m
.53439 .64655 L
s
.53373 .61041 m
.53368 .60794 L
s
.53443 .64995 m
.53441 .64827 L
s
.53368 .60794 m
.53362 .60545 L
s
.53445 .65158 m
.53443 .64995 L
s
.53362 .60545 m
.53356 .60293 L
s
.53356 .60293 m
.53351 .60038 L
s
.53446 .65316 m
.53445 .65158 L
s
.53351 .60038 m
.53345 .59781 L
s
.53447 .6547 m
.53446 .65316 L
s
.53345 .59781 m
.53339 .59522 L
s
.53448 .65618 m
.53447 .6547 L
s
.53339 .59522 m
.53333 .59262 L
s
.53333 .59262 m
.53327 .59 L
s
.53448 .65762 m
.53448 .65618 L
s
.53327 .59 m
.53321 .58736 L
s
.53449 .65901 m
.53448 .65762 L
s
.53321 .58736 m
.53314 .58472 L
s
.53314 .58472 m
.53308 .58206 L
s
.53449 .66035 m
.53449 .65901 L
s
.53308 .58206 m
.53302 .5794 L
s
.53302 .5794 m
.53296 .57673 L
s
.53449 .66164 m
.53449 .66035 L
s
.53296 .57673 m
.5329 .57406 L
s
.53125 .4838 m
.53124 .48211 L
s
.5329 .57406 m
.53284 .5714 L
s
.53448 .66288 m
.53449 .66164 L
s
.53127 .48551 m
.53125 .4838 L
s
.53284 .5714 m
.53277 .56873 L
s
.53129 .48725 m
.53127 .48551 L
s
.53277 .56873 m
.53271 .56607 L
s
.53448 .66408 m
.53448 .66288 L
s
.53131 .48902 m
.53129 .48725 L
s
.53271 .56607 m
.53265 .56342 L
s
.53132 .49081 m
.53131 .48902 L
s
.53265 .56342 m
.53259 .56078 L
s
.53447 .66524 m
.53448 .66408 L
s
.53135 .49263 m
.53132 .49081 L
s
.53259 .56078 m
.53253 .55815 L
s
.53137 .49448 m
.53135 .49263 L
s
.53253 .55815 m
.53248 .55553 L
s
.53139 .49636 m
.53137 .49448 L
s
.53446 .66634 m
.53447 .66524 L
s
.53248 .55553 m
.53242 .55293 L
s
.53142 .49826 m
.53139 .49636 L
s
.53242 .55293 m
.53236 .55035 L
s
.53144 .5002 m
.53142 .49826 L
s
.53236 .55035 m
.53231 .54778 L
s
.53231 .54778 m
.53225 .54524 L
s
.53147 .50216 m
.53144 .5002 L
s
.53444 .66741 m
.53446 .66634 L
s
.53225 .54524 m
.5322 .54272 L
s
.5315 .50416 m
.53147 .50216 L
s
.5322 .54272 m
.53215 .54022 L
s
.53153 .50618 m
.5315 .50416 L
s
.53215 .54022 m
.53209 .53775 L
s
.53156 .50824 m
.53153 .50618 L
s
.53209 .53775 m
.53204 .5353 L
s
.53159 .51032 m
.53156 .50824 L
s
.53204 .5353 m
.532 .53288 L
s
.53162 .51244 m
.53159 .51032 L
s
.53443 .66843 m
.53444 .66741 L
s
.532 .53288 m
.53195 .53049 L
s
.53166 .51459 m
.53162 .51244 L
s
.53195 .53049 m
.5319 .52813 L
s
.5317 .51677 m
.53166 .51459 L
s
.5319 .52813 m
.53186 .5258 L
s
.53174 .51898 m
.5317 .51677 L
s
.53186 .5258 m
.53182 .52349 L
s
.53178 .52122 m
.53174 .51898 L
s
.53182 .52349 m
.53178 .52122 L
s
.53441 .6694 m
.53443 .66843 L
s
.53439 .67034 m
.53441 .6694 L
s
.53437 .67123 m
.53439 .67034 L
s
.53434 .67209 m
.53437 .67123 L
s
.53431 .6729 m
.53434 .67209 L
s
.53429 .67368 m
.53431 .6729 L
s
.53425 .67442 m
.53429 .67368 L
s
.176 .125 .589 r
.77558 .46464 m
.77633 .46372 L
s
.712 .702 .795 r
.53422 .67513 m
.53425 .67442 L
s
.176 .125 .589 r
.77476 .46554 m
.77558 .46464 L
s
.712 .702 .795 r
.53419 .6758 m
.53422 .67513 L
s
.176 .125 .589 r
.77389 .46641 m
.77476 .46554 L
s
.712 .702 .795 r
.53415 .67644 m
.53419 .6758 L
s
.176 .125 .589 r
.77296 .46726 m
.77389 .46641 L
s
.77197 .46809 m
.77296 .46726 L
s
.712 .702 .795 r
.53411 .67705 m
.53415 .67644 L
s
.176 .125 .589 r
.77092 .4689 m
.77197 .46809 L
s
.712 .702 .795 r
.53407 .67763 m
.53411 .67705 L
s
.176 .125 .589 r
.76983 .46969 m
.77092 .4689 L
s
.712 .702 .795 r
.53403 .67819 m
.53407 .67763 L
s
.176 .125 .589 r
.76868 .47046 m
.76983 .46969 L
s
.76749 .47121 m
.76868 .47046 L
s
.712 .702 .795 r
.53399 .67872 m
.53403 .67819 L
s
.176 .125 .589 r
.76626 .47194 m
.76749 .47121 L
s
.712 .702 .795 r
.53394 .67923 m
.53399 .67872 L
s
.176 .125 .589 r
.76497 .47266 m
.76626 .47194 L
s
.712 .702 .795 r
.5339 .67971 m
.53394 .67923 L
s
.176 .125 .589 r
.76365 .47337 m
.76497 .47266 L
s
.7623 .47406 m
.76365 .47337 L
s
.712 .702 .795 r
.53385 .68018 m
.5339 .67971 L
s
.176 .125 .589 r
.7609 .47475 m
.7623 .47406 L
s
.712 .702 .795 r
.5338 .68063 m
.53385 .68018 L
s
.176 .125 .589 r
.75948 .47542 m
.7609 .47475 L
s
.712 .702 .795 r
.53375 .68106 m
.5338 .68063 L
s
.176 .125 .589 r
.75803 .47609 m
.75948 .47542 L
s
.75655 .47674 m
.75803 .47609 L
s
.712 .702 .795 r
.5337 .68148 m
.53375 .68106 L
s
.176 .125 .589 r
.75504 .4774 m
.75655 .47674 L
s
.712 .702 .795 r
.53365 .68189 m
.5337 .68148 L
s
.176 .125 .589 r
.75352 .47805 m
.75504 .4774 L
s
.712 .702 .795 r
.5336 .68229 m
.53365 .68189 L
s
.176 .125 .589 r
.75198 .47869 m
.75352 .47805 L
s
.098 .036 .682 r
.28007 .43636 m
.27932 .43534 L
s
.712 .702 .795 r
.53354 .68269 m
.5336 .68229 L
s
.176 .125 .589 r
.75043 .47934 m
.75198 .47869 L
s
.098 .036 .682 r
.28088 .43736 m
.28007 .43636 L
s
.176 .125 .589 r
.74887 .47999 m
.75043 .47934 L
s
.098 .036 .682 r
.28175 .43835 m
.28088 .43736 L
s
.712 .702 .795 r
.53349 .68307 m
.53354 .68269 L
s
.098 .036 .682 r
.28267 .43932 m
.28175 .43835 L
s
.176 .125 .589 r
.7473 .48064 m
.74887 .47999 L
s
.098 .036 .682 r
.28365 .44028 m
.28267 .43932 L
s
.712 .702 .795 r
.53344 .68346 m
.53349 .68307 L
s
.176 .125 .589 r
.74573 .48129 m
.7473 .48064 L
s
.098 .036 .682 r
.28468 .44122 m
.28365 .44028 L
s
.712 .702 .795 r
.53338 .68385 m
.53344 .68346 L
s
.098 .036 .682 r
.28577 .44214 m
.28468 .44122 L
s
.176 .125 .589 r
.74416 .48195 m
.74573 .48129 L
s
.098 .036 .682 r
.2869 .44305 m
.28577 .44214 L
s
.176 .125 .589 r
.74258 .48261 m
.74416 .48195 L
s
.712 .702 .795 r
.53333 .68423 m
.53338 .68385 L
s
.098 .036 .682 r
.28808 .44395 m
.2869 .44305 L
s
.176 .125 .589 r
.74102 .48329 m
.74258 .48261 L
s
.098 .036 .682 r
.28931 .44484 m
.28808 .44395 L
s
.712 .702 .795 r
.53327 .68462 m
.53333 .68423 L
s
.176 .125 .589 r
.73946 .48397 m
.74102 .48329 L
s
.098 .036 .682 r
.29058 .44572 m
.28931 .44484 L
s
.712 .702 .795 r
.53322 .68502 m
.53327 .68462 L
s
.098 .036 .682 r
.29189 .44658 m
.29058 .44572 L
s
.176 .125 .589 r
.73792 .48466 m
.73946 .48397 L
s
.098 .036 .682 r
.29323 .44744 m
.29189 .44658 L
s
.176 .125 .589 r
.73638 .48536 m
.73792 .48466 L
s
.712 .702 .795 r
.53316 .68542 m
.53322 .68502 L
s
.098 .036 .682 r
.29461 .4483 m
.29323 .44744 L
s
.176 .125 .589 r
.73487 .48608 m
.73638 .48536 L
s
.098 .036 .682 r
.29602 .44914 m
.29461 .4483 L
s
.712 .702 .795 r
.53311 .68584 m
.53316 .68542 L
s
.176 .125 .589 r
.73337 .4868 m
.73487 .48608 L
s
.098 .036 .682 r
.29746 .44998 m
.29602 .44914 L
s
.712 .702 .795 r
.53305 .68626 m
.53311 .68584 L
s
.176 .125 .589 r
.7319 .48755 m
.73337 .4868 L
s
.098 .036 .682 r
.29892 .45082 m
.29746 .44998 L
s
.30041 .45165 m
.29892 .45082 L
s
.176 .125 .589 r
.73045 .4883 m
.7319 .48755 L
s
.712 .702 .795 r
.533 .6867 m
.53305 .68626 L
s
.098 .036 .682 r
.30191 .45248 m
.30041 .45165 L
s
.176 .125 .589 r
.72902 .48908 m
.73045 .4883 L
s
.712 .702 .795 r
.53295 .68715 m
.533 .6867 L
s
.098 .036 .682 r
.30343 .45331 m
.30191 .45248 L
s
.176 .125 .589 r
.72763 .48987 m
.72902 .48908 L
s
.098 .036 .682 r
.30497 .45415 m
.30343 .45331 L
s
.712 .702 .795 r
.53289 .68762 m
.53295 .68715 L
s
.176 .125 .589 r
.72626 .49068 m
.72763 .48987 L
s
.098 .036 .682 r
.30651 .45498 m
.30497 .45415 L
s
.176 .125 .589 r
.72493 .49151 m
.72626 .49068 L
s
.712 .702 .795 r
.53284 .68811 m
.53289 .68762 L
s
.098 .036 .682 r
.30806 .45582 m
.30651 .45498 L
s
.176 .125 .589 r
.72362 .49235 m
.72493 .49151 L
s
.098 .036 .682 r
.30962 .45666 m
.30806 .45582 L
s
.712 .702 .795 r
.53279 .68862 m
.53284 .68811 L
s
.176 .125 .589 r
.72236 .49322 m
.72362 .49235 L
s
.098 .036 .682 r
.31117 .4575 m
.30962 .45666 L
s
.712 .702 .795 r
.53274 .68915 m
.53279 .68862 L
s
.176 .125 .589 r
.72112 .4941 m
.72236 .49322 L
s
.098 .036 .682 r
.31273 .45835 m
.31117 .4575 L
s
.176 .125 .589 r
.71993 .495 m
.72112 .4941 L
s
.712 .702 .795 r
.53269 .6897 m
.53274 .68915 L
s
.098 .036 .682 r
.31427 .45921 m
.31273 .45835 L
s
.176 .125 .589 r
.71877 .49593 m
.71993 .495 L
s
.098 .036 .682 r
.31581 .46008 m
.31427 .45921 L
s
.712 .702 .795 r
.53264 .69028 m
.53269 .6897 L
s
.176 .125 .589 r
.71765 .49687 m
.71877 .49593 L
s
.098 .036 .682 r
.31734 .46095 m
.31581 .46008 L
s
.176 .125 .589 r
.71657 .49784 m
.71765 .49687 L
s
.712 .702 .795 r
.53259 .69087 m
.53264 .69028 L
s
.098 .036 .682 r
.31885 .46183 m
.31734 .46095 L
s
.176 .125 .589 r
.71553 .49882 m
.71657 .49784 L
s
.098 .036 .682 r
.32034 .46273 m
.31885 .46183 L
s
.712 .702 .795 r
.53255 .6915 m
.53259 .69087 L
s
.176 .125 .589 r
.71452 .49983 m
.71553 .49882 L
s
.098 .036 .682 r
.32182 .46364 m
.32034 .46273 L
s
.176 .125 .589 r
.71356 .50085 m
.71452 .49983 L
s
.712 .702 .795 r
.5325 .69215 m
.53255 .6915 L
s
.098 .036 .682 r
.32327 .46455 m
.32182 .46364 L
s
.176 .125 .589 r
.71264 .5019 m
.71356 .50085 L
s
.712 .702 .795 r
.53246 .69283 m
.5325 .69215 L
s
.098 .036 .682 r
.3247 .46549 m
.32327 .46455 L
s
.176 .125 .589 r
.71175 .50296 m
.71264 .5019 L
s
.098 .036 .682 r
.32611 .46643 m
.3247 .46549 L
s
.712 .702 .795 r
.53241 .69354 m
.53246 .69283 L
s
.176 .125 .589 r
.71091 .50405 m
.71175 .50296 L
s
.098 .036 .682 r
.32749 .46739 m
.32611 .46643 L
s
.176 .125 .589 r
.7101 .50515 m
.71091 .50405 L
s
.712 .702 .795 r
.53237 .69427 m
.53241 .69354 L
s
.098 .036 .682 r
.32883 .46836 m
.32749 .46739 L
s
.176 .125 .589 r
.70933 .50628 m
.7101 .50515 L
s
.712 .702 .795 r
.53233 .69503 m
.53237 .69427 L
s
.098 .036 .682 r
.33015 .46935 m
.32883 .46836 L
s
.176 .125 .589 r
.70861 .50742 m
.70933 .50628 L
s
.098 .036 .682 r
.33143 .47035 m
.33015 .46935 L
s
.176 .125 .589 r
.70792 .50858 m
.70861 .50742 L
s
.712 .702 .795 r
.53229 .69582 m
.53233 .69503 L
s
.176 .125 .589 r
.70726 .50976 m
.70792 .50858 L
s
.098 .036 .682 r
.33268 .47137 m
.33143 .47035 L
s
.712 .702 .795 r
.53225 .69664 m
.53229 .69582 L
s
.176 .125 .589 r
.70665 .51096 m
.70726 .50976 L
s
.098 .036 .682 r
.33389 .4724 m
.33268 .47137 L
s
.176 .125 .589 r
.70607 .51218 m
.70665 .51096 L
s
.712 .702 .795 r
.53222 .69749 m
.53225 .69664 L
s
.098 .036 .682 r
.33507 .47345 m
.33389 .4724 L
s
.176 .125 .589 r
.70552 .51341 m
.70607 .51218 L
s
.098 .036 .682 r
.33621 .47451 m
.33507 .47345 L
s
.712 .702 .795 r
.53218 .69837 m
.53222 .69749 L
s
.176 .125 .589 r
.70501 .51466 m
.70552 .51341 L
s
.098 .036 .682 r
.33731 .4756 m
.33621 .47451 L
s
.176 .125 .589 r
.70454 .51593 m
.70501 .51466 L
s
.712 .702 .795 r
.53215 .69928 m
.53218 .69837 L
s
.098 .036 .682 r
.33838 .47669 m
.33731 .4756 L
s
.176 .125 .589 r
.7041 .51721 m
.70454 .51593 L
s
.712 .702 .795 r
.53211 .70022 m
.53215 .69928 L
s
.098 .036 .682 r
.3394 .47781 m
.33838 .47669 L
s
.176 .125 .589 r
.70369 .51851 m
.7041 .51721 L
s
.098 .036 .682 r
.34039 .47893 m
.3394 .47781 L
s
.176 .125 .589 r
.70332 .51983 m
.70369 .51851 L
s
.712 .702 .795 r
.53208 .70119 m
.53211 .70022 L
s
.176 .125 .589 r
.70297 .52116 m
.70332 .51983 L
s
.098 .036 .682 r
.34134 .48008 m
.34039 .47893 L
s
.712 .702 .795 r
.53205 .70218 m
.53208 .70119 L
s
.176 .125 .589 r
.70266 .52251 m
.70297 .52116 L
s
.098 .036 .682 r
.34225 .48124 m
.34134 .48008 L
s
.176 .125 .589 r
.70238 .52387 m
.70266 .52251 L
s
.712 .702 .795 r
.53202 .7032 m
.53205 .70218 L
s
.098 .036 .682 r
.34312 .48242 m
.34225 .48124 L
s
.176 .125 .589 r
.70214 .52524 m
.70238 .52387 L
s
.098 .036 .682 r
.34395 .48361 m
.34312 .48242 L
s
.712 .702 .795 r
.532 .70426 m
.53202 .7032 L
s
.176 .125 .589 r
.70192 .52663 m
.70214 .52524 L
s
.098 .036 .682 r
.34474 .48482 m
.34395 .48361 L
s
.176 .125 .589 r
.70173 .52804 m
.70192 .52663 L
s
.712 .702 .795 r
.53197 .70534 m
.532 .70426 L
s
.098 .036 .682 r
.34549 .48604 m
.34474 .48482 L
s
.176 .125 .589 r
.70157 .52946 m
.70173 .52804 L
s
.712 .702 .795 r
.53195 .70644 m
.53197 .70534 L
s
.176 .125 .589 r
.70143 .53089 m
.70157 .52946 L
s
.098 .036 .682 r
.34621 .48728 m
.34549 .48604 L
s
.176 .125 .589 r
.70133 .53234 m
.70143 .53089 L
s
.712 .702 .795 r
.53192 .70758 m
.53195 .70644 L
s
.098 .036 .682 r
.34689 .48853 m
.34621 .48728 L
s
.176 .125 .589 r
.70126 .5338 m
.70133 .53234 L
s
.098 .036 .682 r
.34753 .48979 m
.34689 .48853 L
s
.712 .702 .795 r
.5319 .70874 m
.53192 .70758 L
s
.176 .125 .589 r
.70121 .53528 m
.70126 .5338 L
s
.098 .036 .682 r
.34813 .49107 m
.34753 .48979 L
s
.176 .125 .589 r
.70119 .53676 m
.70121 .53528 L
s
.712 .702 .795 r
.53188 .70993 m
.5319 .70874 L
s
.176 .125 .589 r
.7012 .53827 m
.70119 .53676 L
s
.098 .036 .682 r
.3487 .49237 m
.34813 .49107 L
s
.712 .702 .795 r
.53186 .71114 m
.53188 .70993 L
s
.176 .125 .589 r
.70124 .53978 m
.7012 .53827 L
s
.098 .036 .682 r
.34924 .49368 m
.3487 .49237 L
s
.176 .125 .589 r
.7013 .54131 m
.70124 .53978 L
s
.712 .702 .795 r
.53184 .71238 m
.53186 .71114 L
s
.098 .036 .682 r
.34974 .495 m
.34924 .49368 L
s
.176 .125 .589 r
.70139 .54286 m
.7013 .54131 L
s
.098 .036 .682 r
.3502 .49633 m
.34974 .495 L
s
.712 .702 .795 r
.53183 .71364 m
.53184 .71238 L
s
.176 .125 .589 r
.70151 .54441 m
.70139 .54286 L
s
.098 .036 .682 r
.35063 .49768 m
.3502 .49633 L
s
.176 .125 .589 r
.70165 .54598 m
.70151 .54441 L
s
.712 .702 .795 r
.53181 .71493 m
.53183 .71364 L
s
.176 .125 .589 r
.70183 .54757 m
.70165 .54598 L
s
.098 .036 .682 r
.35103 .49904 m
.35063 .49768 L
s
.712 .702 .795 r
.5318 .71624 m
.53181 .71493 L
s
.176 .125 .589 r
.70203 .54917 m
.70183 .54757 L
s
.098 .036 .682 r
.3514 .50041 m
.35103 .49904 L
s
.176 .125 .589 r
.70226 .55078 m
.70203 .54917 L
s
.712 .702 .795 r
.53178 .71758 m
.5318 .71624 L
s
.098 .036 .682 r
.35173 .50179 m
.3514 .50041 L
s
.176 .125 .589 r
.70252 .55241 m
.70226 .55078 L
s
.712 .702 .795 r
.53177 .71894 m
.53178 .71758 L
s
.098 .036 .682 r
.35204 .50319 m
.35173 .50179 L
s
.176 .125 .589 r
.70281 .55405 m
.70252 .55241 L
s
.70312 .5557 m
.70281 .55405 L
s
.098 .036 .682 r
.35231 .50459 m
.35204 .50319 L
s
.712 .702 .795 r
.53176 .72032 m
.53177 .71894 L
s
.176 .125 .589 r
.70347 .55737 m
.70312 .5557 L
s
.098 .036 .682 r
.35256 .50601 m
.35231 .50459 L
s
.712 .702 .795 r
.53175 .72173 m
.53176 .72032 L
s
.176 .125 .589 r
.70385 .55906 m
.70347 .55737 L
s
.098 .036 .682 r
.35277 .50744 m
.35256 .50601 L
s
.176 .125 .589 r
.70425 .56076 m
.70385 .55906 L
s
.712 .702 .795 r
.53174 .72316 m
.53175 .72173 L
s
.176 .125 .589 r
.70469 .56248 m
.70425 .56076 L
s
.098 .036 .682 r
.35295 .50889 m
.35277 .50744 L
s
.712 .702 .795 r
.53173 .72461 m
.53174 .72316 L
s
.176 .125 .589 r
.70516 .56421 m
.70469 .56248 L
s
.098 .036 .682 r
.35311 .51034 m
.35295 .50889 L
s
.176 .125 .589 r
.70566 .56596 m
.70516 .56421 L
s
.712 .702 .795 r
.53173 .72608 m
.53173 .72461 L
s
.098 .036 .682 r
.35324 .5118 m
.35311 .51034 L
s
.176 .125 .589 r
.7062 .56772 m
.70566 .56596 L
s
.712 .702 .795 r
.53172 .72757 m
.53173 .72608 L
s
.176 .125 .589 r
.70677 .5695 m
.7062 .56772 L
s
.098 .036 .682 r
.35334 .51328 m
.35324 .5118 L
s
.176 .125 .589 r
.70737 .5713 m
.70677 .5695 L
s
.712 .702 .795 r
.53172 .72909 m
.53172 .72757 L
s
.098 .036 .682 r
.35341 .51476 m
.35334 .51328 L
s
.176 .125 .589 r
.70801 .57311 m
.70737 .5713 L
s
.70868 .57495 m
.70801 .57311 L
s
.712 .702 .795 r
.53171 .73062 m
.53172 .72909 L
s
.098 .036 .682 r
.35346 .51626 m
.35341 .51476 L
s
.176 .125 .589 r
.70939 .57679 m
.70868 .57495 L
s
.098 .036 .682 r
.35347 .51777 m
.35346 .51626 L
s
.712 .702 .795 r
.53171 .73218 m
.53171 .73062 L
s
.176 .125 .589 r
.71014 .57866 m
.70939 .57679 L
s
.71092 .58055 m
.71014 .57866 L
s
.098 .036 .682 r
.35346 .51928 m
.35347 .51777 L
s
.712 .702 .795 r
.53171 .73375 m
.53171 .73218 L
s
.176 .125 .589 r
.71174 .58245 m
.71092 .58055 L
s
.098 .036 .682 r
.35343 .52081 m
.35346 .51928 L
s
.176 .125 .589 r
.7126 .58437 m
.71174 .58245 L
s
.712 .702 .795 r
.53171 .73535 m
.53171 .73375 L
s
.176 .125 .589 r
.7135 .58631 m
.7126 .58437 L
s
.098 .036 .682 r
.35336 .52235 m
.35343 .52081 L
s
.176 .125 .589 r
.71444 .58827 m
.7135 .58631 L
s
.712 .702 .795 r
.53171 .73697 m
.53171 .73535 L
s
.176 .125 .589 r
.71542 .59024 m
.71444 .58827 L
s
.098 .036 .682 r
.35327 .5239 m
.35336 .52235 L
s
.712 .702 .795 r
.53171 .73861 m
.53171 .73697 L
s
.176 .125 .589 r
.71644 .59224 m
.71542 .59024 L
s
.7175 .59425 m
.71644 .59224 L
s
.098 .036 .682 r
.35315 .52546 m
.35327 .5239 L
s
.712 .702 .795 r
.53171 .74027 m
.53171 .73861 L
s
.176 .125 .589 r
.7186 .59628 m
.7175 .59425 L
s
.71974 .59833 m
.7186 .59628 L
s
.098 .036 .682 r
.35301 .52704 m
.35315 .52546 L
s
.712 .702 .795 r
.53172 .74195 m
.53171 .74027 L
s
.176 .125 .589 r
.72093 .6004 m
.71974 .59833 L
s
.72215 .60248 m
.72093 .6004 L
s
.098 .036 .682 r
.35284 .52862 m
.35301 .52704 L
s
.176 .125 .589 r
.72341 .60459 m
.72215 .60248 L
s
.712 .702 .795 r
.53172 .74365 m
.53172 .74195 L
s
.176 .125 .589 r
.72471 .60671 m
.72341 .60459 L
s
.098 .036 .682 r
.35264 .53021 m
.35284 .52862 L
s
.176 .125 .589 r
.72605 .60885 m
.72471 .60671 L
s
.712 .702 .795 r
.53173 .74537 m
.53172 .74365 L
s
.176 .125 .589 r
.72743 .611 m
.72605 .60885 L
s
.72885 .61317 m
.72743 .611 L
s
.098 .036 .682 r
.35241 .53182 m
.35264 .53021 L
s
.176 .125 .589 r
.73031 .61535 m
.72885 .61317 L
s
.712 .702 .795 r
.53174 .74711 m
.53173 .74537 L
s
.176 .125 .589 r
.7318 .61755 m
.73031 .61535 L
s
.73332 .61976 m
.7318 .61755 L
s
.098 .036 .682 r
.35215 .53344 m
.35241 .53182 L
s
.176 .125 .589 r
.73488 .62199 m
.73332 .61976 L
s
.712 .702 .795 r
.53174 .74888 m
.53174 .74711 L
s
.176 .125 .589 r
.73646 .62423 m
.73488 .62199 L
s
.73808 .62647 m
.73646 .62423 L
s
.098 .036 .682 r
.35187 .53506 m
.35215 .53344 L
s
.176 .125 .589 r
.73972 .62873 m
.73808 .62647 L
s
.712 .702 .795 r
.53175 .75066 m
.53174 .74888 L
s
.176 .125 .589 r
.74139 .631 m
.73972 .62873 L
s
.74308 .63328 m
.74139 .631 L
s
.74479 .63556 m
.74308 .63328 L
s
.74652 .63784 m
.74479 .63556 L
s
.098 .036 .682 r
.35156 .5367 m
.35187 .53506 L
s
.176 .125 .589 r
.74826 .64014 m
.74652 .63784 L
s
.712 .702 .795 r
.53176 .75247 m
.53175 .75066 L
s
.176 .125 .589 r
.75001 .64243 m
.74826 .64014 L
s
.75178 .64473 m
.75001 .64243 L
s
.75355 .64702 m
.75178 .64473 L
s
.75532 .64932 m
.75355 .64702 L
s
.7571 .65161 m
.75532 .64932 L
s
.098 .036 .682 r
.35121 .53836 m
.35156 .5367 L
s
.712 .702 .795 r
.53177 .7543 m
.53176 .75247 L
s
.176 .125 .589 r
.75887 .6539 m
.7571 .65161 L
s
.76064 .65618 m
.75887 .6539 L
s
.76239 .65846 m
.76064 .65618 L
s
.76414 .66073 m
.76239 .65846 L
s
.76587 .66299 m
.76414 .66073 L
s
.76758 .66524 m
.76587 .66299 L
s
.712 .702 .795 r
.53463 .91175 m
.53459 .90942 L
s
.53468 .91406 m
.53463 .91175 L
s
.53459 .90942 m
.53455 .90705 L
s
.53471 .91633 m
.53468 .91406 L
s
.53179 .75614 m
.53177 .7543 L
s
.53455 .90705 m
.5345 .90464 L
s
.53475 .91857 m
.53471 .91633 L
s
.098 .036 .682 r
.35084 .54002 m
.35121 .53836 L
s
.176 .125 .589 r
.76928 .66748 m
.76758 .66524 L
s
.712 .702 .795 r
.5345 .90464 m
.53445 .90221 L
s
.53479 .92077 m
.53475 .91857 L
s
.176 .125 .589 r
.77094 .6697 m
.76928 .66748 L
s
.712 .702 .795 r
.53445 .90221 m
.5344 .89975 L
s
.53482 .92293 m
.53479 .92077 L
s
.176 .125 .589 r
.77258 .67191 m
.77094 .6697 L
s
.712 .702 .795 r
.5344 .89975 m
.53435 .89726 L
s
.53485 .92506 m
.53482 .92293 L
s
.176 .125 .589 r
.77419 .67411 m
.77258 .67191 L
s
.712 .702 .795 r
.53435 .89726 m
.5343 .89474 L
s
.5318 .75802 m
.53179 .75614 L
s
.176 .125 .589 r
.77577 .67629 m
.77419 .67411 L
s
.712 .702 .795 r
.53488 .92715 m
.53485 .92506 L
s
.5343 .89474 m
.53425 .8922 L
s
.098 .036 .682 r
.35044 .5417 m
.35084 .54002 L
s
.176 .125 .589 r
.77731 .67845 m
.77577 .67629 L
s
.712 .702 .795 r
.53491 .9292 m
.53488 .92715 L
s
.53425 .8922 m
.53419 .88964 L
s
.176 .125 .589 r
.77882 .68059 m
.77731 .67845 L
s
.712 .702 .795 r
.53419 .88964 m
.53414 .88705 L
s
.176 .125 .589 r
.78028 .68272 m
.77882 .68059 L
s
.712 .702 .795 r
.53493 .93122 m
.53491 .9292 L
s
.53181 .75991 m
.5318 .75802 L
s
.53414 .88705 m
.53408 .88444 L
s
.176 .125 .589 r
.7817 .68482 m
.78028 .68272 L
s
.098 .036 .682 r
.35001 .54339 m
.35044 .5417 L
s
.712 .702 .795 r
.53496 .93319 m
.53493 .93122 L
s
.176 .125 .589 r
.78307 .68691 m
.7817 .68482 L
s
.712 .702 .795 r
.53408 .88444 m
.53402 .88182 L
s
.53183 .76183 m
.53181 .75991 L
s
.176 .125 .589 r
.7844 .68897 m
.78307 .68691 L
s
.712 .702 .795 r
.53498 .93513 m
.53496 .93319 L
s
.53402 .88182 m
.53396 .87917 L
s
.176 .125 .589 r
.78568 .69101 m
.7844 .68897 L
s
.098 .036 .682 r
.34954 .54509 m
.35001 .54339 L
s
.712 .702 .795 r
.53396 .87917 m
.5339 .87651 L
s
.53499 .93703 m
.53498 .93513 L
s
.53185 .76377 m
.53183 .76183 L
s
.176 .125 .589 r
.7869 .69302 m
.78568 .69101 L
s
.712 .702 .795 r
.5339 .87651 m
.53384 .87384 L
s
.176 .125 .589 r
.78807 .69501 m
.7869 .69302 L
s
.098 .036 .682 r
.34905 .5468 m
.34954 .54509 L
s
.712 .702 .795 r
.53501 .93889 m
.53499 .93703 L
s
.53384 .87384 m
.53378 .87115 L
s
.53186 .76573 m
.53185 .76377 L
s
.176 .125 .589 r
.78919 .69698 m
.78807 .69501 L
s
.712 .702 .795 r
.53378 .87115 m
.53372 .86846 L
s
.53502 .94071 m
.53501 .93889 L
s
.53188 .76771 m
.53186 .76573 L
s
.176 .125 .589 r
.79024 .69892 m
.78919 .69698 L
s
.098 .036 .682 r
.34852 .54853 m
.34905 .5468 L
s
.712 .702 .795 r
.53372 .86846 m
.53366 .86576 L
s
.176 .125 .589 r
.79124 .70084 m
.79024 .69892 L
s
.712 .702 .795 r
.53366 .86576 m
.5336 .86305 L
s
.5319 .76972 m
.53188 .76771 L
s
.53503 .94249 m
.53502 .94071 L
s
.098 .036 .682 r
.34796 .55027 m
.34852 .54853 L
s
.176 .125 .589 r
.79218 .70273 m
.79124 .70084 L
s
.712 .702 .795 r
.5336 .86305 m
.53354 .86033 L
s
.53192 .77176 m
.5319 .76972 L
s
.53504 .94423 m
.53503 .94249 L
s
.53354 .86033 m
.53348 .85761 L
s
.176 .125 .589 r
.79305 .7046 m
.79218 .70273 L
s
.712 .702 .795 r
.53195 .77381 m
.53192 .77176 L
s
.098 .036 .682 r
.34736 .55202 m
.34796 .55027 L
s
.712 .702 .795 r
.53348 .85761 m
.53342 .8549 L
s
.176 .125 .589 r
.79387 .70643 m
.79305 .7046 L
s
.712 .702 .795 r
.53505 .94594 m
.53504 .94423 L
s
.53342 .8549 m
.53336 .85218 L
s
.53197 .7759 m
.53195 .77381 L
s
.098 .036 .682 r
.34674 .55379 m
.34736 .55202 L
s
.176 .125 .589 r
.79461 .70825 m
.79387 .70643 L
s
.712 .702 .795 r
.53336 .85218 m
.5333 .84946 L
s
.532 .77801 m
.53197 .7759 L
s
.5333 .84946 m
.53324 .84675 L
s
.53505 .94761 m
.53505 .94594 L
s
.53202 .78014 m
.532 .77801 L
s
.176 .125 .589 r
.7953 .71003 m
.79461 .70825 L
s
.098 .036 .682 r
.34607 .55557 m
.34674 .55379 L
s
.712 .702 .795 r
.53324 .84675 m
.53318 .84405 L
s
.53205 .7823 m
.53202 .78014 L
s
.53318 .84405 m
.53312 .84136 L
s
.176 .125 .589 r
.79591 .71179 m
.7953 .71003 L
s
.712 .702 .795 r
.53505 .94924 m
.53505 .94761 L
s
.53208 .78448 m
.53205 .7823 L
s
.098 .036 .682 r
.34537 .55737 m
.34607 .55557 L
s
.712 .702 .795 r
.53312 .84136 m
.53306 .83867 L
s
.53211 .78669 m
.53208 .78448 L
s
.53306 .83867 m
.53301 .836 L
s
.176 .125 .589 r
.79646 .71352 m
.79591 .71179 L
s
.712 .702 .795 r
.53301 .836 m
.53295 .83334 L
s
.53214 .78892 m
.53211 .78669 L
s
.098 .036 .682 r
.34463 .55917 m
.34537 .55737 L
s
.712 .702 .795 r
.53295 .83334 m
.53289 .83069 L
s
.53505 .95083 m
.53505 .94924 L
s
.53217 .79119 m
.53214 .78892 L
s
.176 .125 .589 r
.79694 .71522 m
.79646 .71352 L
s
.712 .702 .795 r
.53289 .83069 m
.53284 .82806 L
s
.53221 .79347 m
.53217 .79119 L
s
.53284 .82806 m
.53279 .82545 L
s
.53225 .79579 m
.53221 .79347 L
s
.098 .036 .682 r
.34386 .561 m
.34463 .55917 L
s
.712 .702 .795 r
.53279 .82545 m
.53273 .82286 L
s
.53228 .79812 m
.53225 .79579 L
s
.53273 .82286 m
.53268 .82028 L
s
.53232 .80049 m
.53228 .79812 L
s
.176 .125 .589 r
.79736 .7169 m
.79694 .71522 L
s
.712 .702 .795 r
.53268 .82028 m
.53263 .81773 L
s
.53236 .80288 m
.53232 .80049 L
s
.53505 .95239 m
.53505 .95083 L
s
.53263 .81773 m
.53258 .8152 L
s
.5324 .80529 m
.53236 .80288 L
s
.53258 .8152 m
.53254 .81269 L
s
.53245 .80773 m
.5324 .80529 L
s
.53254 .81269 m
.53249 .8102 L
s
.53249 .8102 m
.53245 .80773 L
s
.098 .036 .682 r
.34305 .56284 m
.34386 .561 L
s
.176 .125 .589 r
.7977 .71855 m
.79736 .7169 L
s
.098 .036 .682 r
.3422 .56469 m
.34305 .56284 L
s
.712 .702 .795 r
.53504 .95391 m
.53505 .95239 L
s
.176 .125 .589 r
.79798 .72017 m
.7977 .71855 L
s
.098 .036 .682 r
.34131 .56655 m
.3422 .56469 L
s
.712 .702 .795 r
.53504 .95539 m
.53504 .95391 L
s
.176 .125 .589 r
.79818 .72176 m
.79798 .72017 L
s
.098 .036 .682 r
.34039 .56844 m
.34131 .56655 L
s
.33942 .57033 m
.34039 .56844 L
s
.176 .125 .589 r
.79832 .72333 m
.79818 .72176 L
s
.712 .702 .795 r
.53502 .95684 m
.53504 .95539 L
s
.098 .036 .682 r
.33841 .57224 m
.33942 .57033 L
s
.176 .125 .589 r
.79839 .72487 m
.79832 .72333 L
s
.098 .036 .682 r
.33737 .57417 m
.33841 .57224 L
s
.712 .702 .795 r
.53501 .95825 m
.53502 .95684 L
s
.098 .036 .682 r
.33628 .57611 m
.33737 .57417 L
s
.176 .125 .589 r
.79838 .72639 m
.79839 .72487 L
s
.098 .036 .682 r
.33516 .57806 m
.33628 .57611 L
s
.176 .125 .589 r
.79831 .72788 m
.79838 .72639 L
s
.712 .702 .795 r
.535 .95963 m
.53501 .95825 L
s
.098 .036 .682 r
.33399 .58003 m
.33516 .57806 L
s
.33278 .58201 m
.33399 .58003 L
s
.176 .125 .589 r
.79817 .72934 m
.79831 .72788 L
s
.098 .036 .682 r
.33154 .58401 m
.33278 .58201 L
s
.712 .702 .795 r
.53498 .96098 m
.535 .95963 L
s
.098 .036 .682 r
.33025 .58602 m
.33154 .58401 L
s
.176 .125 .589 r
.79796 .73078 m
.79817 .72934 L
s
.098 .036 .682 r
.32893 .58804 m
.33025 .58602 L
s
.712 .702 .795 r
.53496 .96229 m
.53498 .96098 L
s
.098 .036 .682 r
.32756 .59008 m
.32893 .58804 L
s
.176 .125 .589 r
.79769 .73219 m
.79796 .73078 L
s
.098 .036 .682 r
.32616 .59213 m
.32756 .59008 L
s
.32472 .59419 m
.32616 .59213 L
s
.176 .125 .589 r
.79734 .73358 m
.79769 .73219 L
s
.712 .702 .795 r
.53494 .96357 m
.53496 .96229 L
s
.098 .036 .682 r
.32325 .59626 m
.32472 .59419 L
s
.32175 .59834 m
.32325 .59626 L
s
.32021 .60044 m
.32175 .59834 L
s
.176 .125 .589 r
.79693 .73495 m
.79734 .73358 L
s
.098 .036 .682 r
.31864 .60254 m
.32021 .60044 L
s
.712 .702 .795 r
.53492 .96483 m
.53494 .96357 L
s
.098 .036 .682 r
.31704 .60465 m
.31864 .60254 L
s
.31542 .60677 m
.31704 .60465 L
s
.176 .125 .589 r
.79645 .73629 m
.79693 .73495 L
s
.098 .036 .682 r
.31377 .60889 m
.31542 .60677 L
s
.3121 .61103 m
.31377 .60889 L
s
.712 .702 .795 r
.53489 .96605 m
.53492 .96483 L
s
.098 .036 .682 r
.3104 .61316 m
.3121 .61103 L
s
.176 .125 .589 r
.79591 .73761 m
.79645 .73629 L
s
.098 .036 .682 r
.30869 .6153 m
.3104 .61316 L
s
.30697 .61745 m
.30869 .6153 L
s
.30523 .61959 m
.30697 .61745 L
s
.176 .125 .589 r
.79531 .73891 m
.79591 .73761 L
s
.712 .702 .795 r
.53486 .96724 m
.53489 .96605 L
s
.098 .036 .682 r
.30348 .62174 m
.30523 .61959 L
s
.30173 .62389 m
.30348 .62174 L
s
.29997 .62603 m
.30173 .62389 L
s
.29821 .62818 m
.29997 .62603 L
s
.176 .125 .589 r
.79464 .74019 m
.79531 .73891 L
s
.098 .036 .682 r
.29645 .63032 m
.29821 .62818 L
s
.712 .702 .795 r
.53483 .96841 m
.53486 .96724 L
s
.098 .036 .682 r
.2947 .63246 m
.29645 .63032 L
s
.29296 .63459 m
.2947 .63246 L
s
.29123 .63671 m
.29296 .63459 L
s
.176 .125 .589 r
.79391 .74145 m
.79464 .74019 L
s
.098 .036 .682 r
.28951 .63883 m
.29123 .63671 L
s
.28781 .64094 m
.28951 .63883 L
s
.712 .702 .795 r
.5348 .96955 m
.53483 .96841 L
s
.098 .036 .682 r
.28613 .64304 m
.28781 .64094 L
s
.28448 .64513 m
.28613 .64304 L
s
.176 .125 .589 r
.79313 .74269 m
.79391 .74145 L
s
.098 .036 .682 r
.28285 .64721 m
.28448 .64513 L
s
.28125 .64928 m
.28285 .64721 L
s
.27968 .65133 m
.28125 .64928 L
s
.712 .702 .795 r
.53477 .97067 m
.5348 .96955 L
s
.176 .125 .589 r
.79228 .74391 m
.79313 .74269 L
s
.098 .036 .682 r
.27815 .65337 m
.27968 .65133 L
s
.27665 .6554 m
.27815 .65337 L
s
.2752 .65741 m
.27665 .6554 L
s
.27379 .65941 m
.2752 .65741 L
s
.176 .125 .589 r
.79138 .74511 m
.79228 .74391 L
s
.712 .702 .795 r
.53473 .97177 m
.53477 .97067 L
s
.098 .036 .682 r
.27242 .66139 m
.27379 .65941 L
s
.2711 .66335 m
.27242 .66139 L
s
.26983 .66529 m
.2711 .66335 L
s
.176 .125 .589 r
.79043 .7463 m
.79138 .74511 L
s
.098 .036 .682 r
.26861 .66722 m
.26983 .66529 L
s
.712 .702 .795 r
.5347 .97284 m
.53473 .97177 L
s
.098 .036 .682 r
.26745 .66913 m
.26861 .66722 L
s
.26634 .67102 m
.26745 .66913 L
s
.176 .125 .589 r
.78942 .74747 m
.79043 .7463 L
s
.098 .036 .682 r
.26528 .67289 m
.26634 .67102 L
s
.26429 .67474 m
.26528 .67289 L
s
.712 .702 .795 r
.53466 .97389 m
.5347 .97284 L
s
.176 .125 .589 r
.78836 .74863 m
.78942 .74747 L
s
.098 .036 .682 r
.26336 .67656 m
.26429 .67474 L
s
.26248 .67837 m
.26336 .67656 L
s
.26167 .68016 m
.26248 .67837 L
s
.176 .125 .589 r
.78725 .74977 m
.78836 .74863 L
s
.712 .702 .795 r
.53462 .97492 m
.53466 .97389 L
s
.098 .036 .682 r
.26093 .68193 m
.26167 .68016 L
s
.26025 .68368 m
.26093 .68193 L
s
.176 .125 .589 r
.7861 .7509 m
.78725 .74977 L
s
.098 .036 .682 r
.25963 .6854 m
.26025 .68368 L
s
.712 .702 .795 r
.53458 .97594 m
.53462 .97492 L
s
.098 .036 .682 r
.25908 .68711 m
.25963 .6854 L
s
.176 .125 .589 r
.7849 .75201 m
.7861 .7509 L
s
.098 .036 .682 r
.2586 .68879 m
.25908 .68711 L
s
.268 .595 .352 r
.70202 .28334 m
.70153 .28202 L
s
.712 .702 .795 r
.53453 .97693 m
.53458 .97594 L
s
.098 .036 .682 r
.25819 .69046 m
.2586 .68879 L
s
.176 .125 .589 r
.78366 .75312 m
.7849 .75201 L
s
.268 .595 .352 r
.70255 .28466 m
.70202 .28334 L
s
.098 .036 .682 r
.25785 .6921 m
.25819 .69046 L
s
.25757 .69372 m
.25785 .6921 L
s
.268 .595 .352 r
.70311 .28596 m
.70255 .28466 L
s
.712 .702 .795 r
.53449 .97792 m
.53453 .97693 L
s
.176 .125 .589 r
.78239 .75422 m
.78366 .75312 L
s
.098 .036 .682 r
.25737 .69533 m
.25757 .69372 L
s
.268 .595 .352 r
.7037 .28726 m
.70311 .28596 L
s
.098 .036 .682 r
.25723 .69691 m
.25737 .69533 L
s
.176 .125 .589 r
.78108 .75531 m
.78239 .75422 L
s
.268 .595 .352 r
.70434 .28854 m
.7037 .28726 L
s
.712 .702 .795 r
.53444 .97889 m
.53449 .97792 L
s
.098 .036 .682 r
.25716 .69847 m
.25723 .69691 L
s
.268 .595 .352 r
.70501 .28981 m
.70434 .28854 L
s
.098 .036 .682 r
.25716 .70001 m
.25716 .69847 L
s
.176 .125 .589 r
.77973 .75639 m
.78108 .75531 L
s
.098 .036 .682 r
.25723 .70153 m
.25716 .70001 L
s
.712 .702 .795 r
.5344 .97985 m
.53444 .97889 L
s
.268 .595 .352 r
.70572 .29107 m
.70501 .28981 L
s
.176 .125 .589 r
.77835 .75746 m
.77973 .75639 L
s
.098 .036 .682 r
.25737 .70304 m
.25723 .70153 L
s
.268 .595 .352 r
.70647 .29232 m
.70572 .29107 L
s
.098 .036 .682 r
.25758 .70452 m
.25737 .70304 L
s
.712 .702 .795 r
.53435 .9808 m
.5344 .97985 L
s
.176 .125 .589 r
.77695 .75854 m
.77835 .75746 L
s
.268 .595 .352 r
.70726 .29356 m
.70647 .29232 L
s
.098 .036 .682 r
.25785 .70599 m
.25758 .70452 L
s
.268 .595 .352 r
.7081 .29478 m
.70726 .29356 L
s
.098 .036 .682 r
.25819 .70743 m
.25785 .70599 L
s
.176 .125 .589 r
.77552 .7596 m
.77695 .75854 L
s
.712 .702 .795 r
.5343 .98174 m
.53435 .9808 L
s
.268 .595 .352 r
.70898 .29599 m
.7081 .29478 L
s
.098 .036 .682 r
.2586 .70886 m
.25819 .70743 L
s
.176 .125 .589 r
.77407 .76067 m
.77552 .7596 L
s
.268 .595 .352 r
.7099 .29719 m
.70898 .29599 L
s
.098 .036 .682 r
.25907 .71028 m
.2586 .70886 L
s
.712 .702 .795 r
.53425 .98267 m
.5343 .98174 L
s
.098 .036 .682 r
.25961 .71167 m
.25907 .71028 L
s
.268 .595 .352 r
.71087 .29837 m
.7099 .29719 L
s
.176 .125 .589 r
.7726 .76173 m
.77407 .76067 L
s
.098 .036 .682 r
.26021 .71305 m
.25961 .71167 L
s
.712 .702 .795 r
.5342 .9836 m
.53425 .98267 L
s
.268 .595 .352 r
.71188 .29954 m
.71087 .29837 L
s
.176 .125 .589 r
.77111 .76279 m
.7726 .76173 L
s
.098 .036 .682 r
.26087 .71442 m
.26021 .71305 L
s
.268 .595 .352 r
.71293 .3007 m
.71188 .29954 L
s
.712 .702 .795 r
.53415 .98453 m
.5342 .9836 L
s
.098 .036 .682 r
.26159 .71577 m
.26087 .71442 L
s
.176 .125 .589 r
.76961 .76386 m
.77111 .76279 L
s
.268 .595 .352 r
.71404 .30184 m
.71293 .3007 L
s
.098 .036 .682 r
.26237 .71711 m
.26159 .71577 L
s
.268 .595 .352 r
.71519 .30297 m
.71404 .30184 L
s
.176 .125 .589 r
.76811 .76493 m
.76961 .76386 L
s
.712 .702 .795 r
.5341 .98545 m
.53415 .98453 L
s
.098 .036 .682 r
.26321 .71843 m
.26237 .71711 L
s
.268 .595 .352 r
.71639 .30408 m
.71519 .30297 L
s
.921 .567 .212 r
.3388 .26056 m
.33932 .25928 L
s
.176 .125 .589 r
.76659 .766 m
.76811 .76493 L
s
.098 .036 .682 r
.26411 .71974 m
.26321 .71843 L
s
.268 .595 .352 r
.71763 .30518 m
.71639 .30408 L
s
.712 .702 .795 r
.53405 .98638 m
.5341 .98545 L
s
.921 .567 .212 r
.33824 .26182 m
.3388 .26056 L
s
.098 .036 .682 r
.26506 .72104 m
.26411 .71974 L
s
.176 .125 .589 r
.76507 .76707 m
.76659 .766 L
s
.268 .595 .352 r
.71893 .30626 m
.71763 .30518 L
s
.921 .567 .212 r
.33764 .26307 m
.33824 .26182 L
s
.098 .036 .682 r
.26606 .72233 m
.26506 .72104 L
s
.712 .702 .795 r
.53399 .9873 m
.53405 .98638 L
s
.921 .567 .212 r
.33701 .2643 m
.33764 .26307 L
s
.176 .125 .589 r
.76355 .76815 m
.76507 .76707 L
s
.268 .595 .352 r
.72027 .30733 m
.71893 .30626 L
s
.098 .036 .682 r
.26711 .7236 m
.26606 .72233 L
s
.921 .567 .212 r
.33633 .26551 m
.33701 .2643 L
s
.268 .595 .352 r
.72166 .30838 m
.72027 .30733 L
s
.176 .125 .589 r
.76203 .76924 m
.76355 .76815 L
s
.712 .702 .795 r
.53394 .98823 m
.53399 .9873 L
s
.098 .036 .682 r
.26821 .72487 m
.26711 .7236 L
s
.921 .567 .212 r
.33562 .26671 m
.33633 .26551 L
s
.268 .595 .352 r
.7231 .30942 m
.72166 .30838 L
s
.098 .036 .682 r
.26935 .72613 m
.26821 .72487 L
s
.176 .125 .589 r
.76052 .77034 m
.76203 .76924 L
s
.921 .567 .212 r
.33486 .2679 m
.33562 .26671 L
s
.712 .702 .795 r
.53389 .98917 m
.53394 .98823 L
s
.268 .595 .352 r
.72459 .31044 m
.7231 .30942 L
s
.098 .036 .682 r
.27054 .72738 m
.26935 .72613 L
s
.921 .567 .212 r
.33405 .26906 m
.33486 .2679 L
s
.176 .125 .589 r
.75902 .77144 m
.76052 .77034 L
s
.268 .595 .352 r
.72613 .31145 m
.72459 .31044 L
s
.921 .567 .212 r
.33321 .27021 m
.33405 .26906 L
s
.098 .036 .682 r
.27177 .72862 m
.27054 .72738 L
s
.712 .702 .795 r
.53384 .99011 m
.53389 .98917 L
s
.176 .125 .589 r
.75752 .77256 m
.75902 .77144 L
s
.268 .595 .352 r
.72771 .31244 m
.72613 .31145 L
s
.921 .567 .212 r
.33232 .27134 m
.33321 .27021 L
s
.098 .036 .682 r
.27304 .72986 m
.27177 .72862 L
s
.712 .702 .795 r
.53378 .99106 m
.53384 .99011 L
s
.176 .125 .589 r
.75604 .77368 m
.75752 .77256 L
s
.268 .595 .352 r
.72934 .31342 m
.72771 .31244 L
s
.921 .567 .212 r
.33138 .27245 m
.33232 .27134 L
s
.098 .036 .682 r
.27434 .73109 m
.27304 .72986 L
s
.921 .567 .212 r
.3304 .27354 m
.33138 .27245 L
s
.268 .595 .352 r
.73101 .31438 m
.72934 .31342 L
s
.176 .125 .589 r
.75458 .77482 m
.75604 .77368 L
s
.098 .036 .682 r
.27567 .73232 m
.27434 .73109 L
s
.712 .702 .795 r
.53373 .99202 m
.53378 .99106 L
s
.921 .567 .212 r
.32937 .27462 m
.3304 .27354 L
s
.268 .595 .352 r
.73273 .31533 m
.73101 .31438 L
s
.098 .036 .682 r
.27704 .73355 m
.27567 .73232 L
s
.176 .125 .589 r
.75313 .77597 m
.75458 .77482 L
s
.921 .567 .212 r
.32829 .27567 m
.32937 .27462 L
s
.712 .702 .795 r
.53368 .99298 m
.53373 .99202 L
s
.268 .595 .352 r
.73448 .31627 m
.73273 .31533 L
s
.098 .036 .682 r
.27843 .73477 m
.27704 .73355 L
s
.176 .125 .589 r
.7517 .77713 m
.75313 .77597 L
s
.921 .567 .212 r
.32716 .2767 m
.32829 .27567 L
s
.268 .595 .352 r
.73628 .31719 m
.73448 .31627 L
s
.098 .036 .682 r
.27985 .73599 m
.27843 .73477 L
s
.712 .702 .795 r
.53363 .99397 m
.53368 .99298 L
s
.176 .125 .589 r
.7503 .77831 m
.7517 .77713 L
s
.921 .567 .212 r
.32599 .27772 m
.32716 .2767 L
s
.268 .595 .352 r
.73812 .3181 m
.73628 .31719 L
s
.098 .036 .682 r
.28129 .73721 m
.27985 .73599 L
s
.921 .567 .212 r
.32476 .27871 m
.32599 .27772 L
s
.176 .125 .589 r
.74892 .7795 m
.7503 .77831 L
s
.712 .702 .795 r
.53358 .99496 m
.53363 .99397 L
s
.268 .595 .352 r
.74 .319 m
.73812 .3181 L
s
.098 .036 .682 r
.28275 .73843 m
.28129 .73721 L
s
.921 .567 .212 r
.32348 .27968 m
.32476 .27871 L
s
.176 .125 .589 r
.74757 .7807 m
.74892 .7795 L
s
.268 .595 .352 r
.74191 .31988 m
.74 .319 L
s
.098 .036 .682 r
.28422 .73965 m
.28275 .73843 L
s
.712 .702 .795 r
.53352 .99597 m
.53358 .99496 L
s
.921 .567 .212 r
.32215 .28063 m
.32348 .27968 L
s
.176 .125 .589 r
.74624 .78192 m
.74757 .7807 L
s
.268 .595 .352 r
.74385 .32075 m
.74191 .31988 L
s
.098 .036 .682 r
.28571 .74088 m
.28422 .73965 L
s
.921 .567 .212 r
.32077 .28156 m
.32215 .28063 L
s
.712 .702 .795 r
.53347 .997 m
.53352 .99597 L
s
.176 .125 .589 r
.74495 .78316 m
.74624 .78192 L
s
.268 .595 .352 r
.74582 .32162 m
.74385 .32075 L
s
.098 .036 .682 r
.2872 .74211 m
.28571 .74088 L
s
.921 .567 .212 r
.31933 .28247 m
.32077 .28156 L
s
.176 .125 .589 r
.74369 .78442 m
.74495 .78316 L
s
.268 .595 .352 r
.74782 .32247 m
.74582 .32162 L
s
.098 .036 .682 r
.2887 .74334 m
.2872 .74211 L
s
.712 .702 .795 r
.53342 .99804 m
.53347 .997 L
s
.921 .567 .212 r
.31785 .28336 m
.31933 .28247 L
s
.176 .125 .589 r
.74246 .78569 m
.74369 .78442 L
s
.268 .595 .352 r
.74984 .32332 m
.74782 .32247 L
s
.098 .036 .682 r
.29021 .74457 m
.2887 .74334 L
s
.921 .567 .212 r
.31631 .28422 m
.31785 .28336 L
s
.176 .125 .589 r
.74126 .78697 m
.74246 .78569 L
s
.268 .595 .352 r
.75189 .32416 m
.74984 .32332 L
s
.098 .036 .682 r
.29171 .74582 m
.29021 .74457 L
s
.921 .567 .212 r
.31472 .28507 m
.31631 .28422 L
s
.176 .125 .589 r
.7401 .78828 m
.74126 .78697 L
s
.098 .036 .682 r
.29321 .74706 m
.29171 .74582 L
s
.268 .595 .352 r
.75395 .32499 m
.75189 .32416 L
s
.921 .567 .212 r
.31308 .28589 m
.31472 .28507 L
s
.176 .125 .589 r
.73897 .7896 m
.7401 .78828 L
s
.098 .036 .682 r
.29471 .74832 m
.29321 .74706 L
s
.268 .595 .352 r
.75602 .32582 m
.75395 .32499 L
s
.921 .567 .212 r
.31139 .28669 m
.31308 .28589 L
s
.176 .125 .589 r
.73788 .79094 m
.73897 .7896 L
s
.098 .036 .682 r
.2962 .74958 m
.29471 .74832 L
s
.268 .595 .352 r
.75811 .32665 m
.75602 .32582 L
s
.921 .567 .212 r
.30965 .28747 m
.31139 .28669 L
s
.176 .125 .589 r
.73683 .7923 m
.73788 .79094 L
s
.098 .036 .682 r
.29768 .75086 m
.2962 .74958 L
s
.268 .595 .352 r
.7602 .32747 m
.75811 .32665 L
s
.921 .567 .212 r
.30786 .28823 m
.30965 .28747 L
s
.176 .125 .589 r
.73582 .79367 m
.73683 .7923 L
s
.098 .036 .682 r
.29914 .75214 m
.29768 .75086 L
s
.268 .595 .352 r
.7623 .32829 m
.7602 .32747 L
s
.921 .567 .212 r
.30603 .28898 m
.30786 .28823 L
s
.176 .125 .589 r
.73484 .79506 m
.73582 .79367 L
s
.098 .036 .682 r
.30059 .75343 m
.29914 .75214 L
s
.268 .595 .352 r
.7644 .32911 m
.7623 .32829 L
s
.921 .567 .212 r
.30415 .2897 m
.30603 .28898 L
s
.176 .125 .589 r
.7339 .79647 m
.73484 .79506 L
s
.098 .036 .682 r
.30202 .75473 m
.30059 .75343 L
s
.268 .595 .352 r
.7665 .32993 m
.7644 .32911 L
s
.921 .567 .212 r
.30223 .2904 m
.30415 .2897 L
s
.176 .125 .589 r
.733 .7979 m
.7339 .79647 L
s
.098 .036 .682 r
.30343 .75605 m
.30202 .75473 L
s
.268 .595 .352 r
.76858 .33075 m
.7665 .32993 L
s
.176 .125 .589 r
.73214 .79934 m
.733 .7979 L
s
.921 .567 .212 r
.30026 .29109 m
.30223 .2904 L
s
.098 .036 .682 r
.30482 .75737 m
.30343 .75605 L
s
.268 .595 .352 r
.77066 .33157 m
.76858 .33075 L
s
.176 .125 .589 r
.73132 .8008 m
.73214 .79934 L
s
.098 .036 .682 r
.30618 .75871 m
.30482 .75737 L
s
.921 .567 .212 r
.29825 .29175 m
.30026 .29109 L
s
.268 .595 .352 r
.77272 .3324 m
.77066 .33157 L
s
.176 .125 .589 r
.73054 .80228 m
.73132 .8008 L
s
.098 .036 .682 r
.30752 .76006 m
.30618 .75871 L
s
.921 .567 .212 r
.29621 .29241 m
.29825 .29175 L
s
.268 .595 .352 r
.77476 .33324 m
.77272 .3324 L
s
.176 .125 .589 r
.72979 .80378 m
.73054 .80228 L
s
.098 .036 .682 r
.30883 .76142 m
.30752 .76006 L
s
.921 .567 .212 r
.29413 .29304 m
.29621 .29241 L
s
.176 .125 .589 r
.72908 .80529 m
.72979 .80378 L
s
.268 .595 .352 r
.77678 .33408 m
.77476 .33324 L
s
.098 .036 .682 r
.31011 .7628 m
.30883 .76142 L
s
.176 .125 .589 r
.72841 .80682 m
.72908 .80529 L
s
.268 .595 .352 r
.77877 .33494 m
.77678 .33408 L
s
.921 .567 .212 r
.29202 .29367 m
.29413 .29304 L
s
.098 .036 .682 r
.31135 .76419 m
.31011 .7628 L
s
.176 .125 .589 r
.72778 .80836 m
.72841 .80682 L
s
.268 .595 .352 r
.78073 .3358 m
.77877 .33494 L
s
.921 .567 .212 r
.28988 .29428 m
.29202 .29367 L
s
.098 .036 .682 r
.31257 .76559 m
.31135 .76419 L
s
.176 .125 .589 r
.72718 .80992 m
.72778 .80836 L
s
.268 .595 .352 r
.78266 .33667 m
.78073 .3358 L
s
.098 .036 .682 r
.31375 .76701 m
.31257 .76559 L
s
.921 .567 .212 r
.28771 .29488 m
.28988 .29428 L
s
.176 .125 .589 r
.72662 .8115 m
.72718 .80992 L
s
.268 .595 .352 r
.78455 .33756 m
.78266 .33667 L
s
.098 .036 .682 r
.3149 .76844 m
.31375 .76701 L
s
.176 .125 .589 r
.7261 .81309 m
.72662 .8115 L
s
.921 .567 .212 r
.28552 .29547 m
.28771 .29488 L
s
.268 .595 .352 r
.7864 .33846 m
.78455 .33756 L
s
.176 .125 .589 r
.72561 .81469 m
.7261 .81309 L
s
.098 .036 .682 r
.31601 .76988 m
.3149 .76844 L
s
.921 .567 .212 r
.28332 .29605 m
.28552 .29547 L
s
.176 .125 .589 r
.72516 .81632 m
.72561 .81469 L
s
.268 .595 .352 r
.78821 .33937 m
.7864 .33846 L
s
.098 .036 .682 r
.31708 .77134 m
.31601 .76988 L
s
.176 .125 .589 r
.72474 .81795 m
.72516 .81632 L
s
.268 .595 .352 r
.78997 .3403 m
.78821 .33937 L
s
.921 .567 .212 r
.28109 .29662 m
.28332 .29605 L
s
.098 .036 .682 r
.31812 .77281 m
.31708 .77134 L
s
.176 .125 .589 r
.72435 .8196 m
.72474 .81795 L
s
.268 .595 .352 r
.79167 .34125 m
.78997 .3403 L
s
.098 .036 .682 r
.31912 .7743 m
.31812 .77281 L
s
.921 .567 .212 r
.27885 .29719 m
.28109 .29662 L
s
.176 .125 .589 r
.724 .82127 m
.72435 .8196 L
s
.098 .036 .682 r
.32008 .7758 m
.31912 .7743 L
s
.268 .595 .352 r
.79333 .34222 m
.79167 .34125 L
s
.176 .125 .589 r
.72369 .82295 m
.724 .82127 L
s
.921 .567 .212 r
.27661 .29776 m
.27885 .29719 L
s
.098 .036 .682 r
.321 .77732 m
.32008 .7758 L
s
.268 .595 .352 r
.79492 .3432 m
.79333 .34222 L
s
.176 .125 .589 r
.7234 .82464 m
.72369 .82295 L
s
.921 .567 .212 r
.27436 .29832 m
.27661 .29776 L
s
.098 .036 .682 r
.32189 .77884 m
.321 .77732 L
s
.176 .125 .589 r
.72315 .82635 m
.7234 .82464 L
s
.268 .595 .352 r
.79646 .34421 m
.79492 .3432 L
s
.176 .125 .589 r
.72293 .82807 m
.72315 .82635 L
s
.098 .036 .682 r
.32274 .78039 m
.32189 .77884 L
s
.268 .595 .352 r
.79793 .34524 m
.79646 .34421 L
s
.921 .567 .212 r
.2721 .29888 m
.27436 .29832 L
s
.176 .125 .589 r
.72274 .8298 m
.72293 .82807 L
s
.098 .036 .682 r
.32355 .78194 m
.32274 .78039 L
s
.268 .595 .352 r
.79934 .34629 m
.79793 .34524 L
s
.176 .125 .589 r
.72258 .83155 m
.72274 .8298 L
s
.921 .567 .212 r
.26986 .29945 m
.2721 .29888 L
s
.098 .036 .682 r
.32432 .78351 m
.32355 .78194 L
s
.268 .595 .352 r
.80068 .34736 m
.79934 .34629 L
s
.176 .125 .589 r
.72245 .83331 m
.72258 .83155 L
s
.098 .036 .682 r
.32506 .7851 m
.32432 .78351 L
s
.921 .567 .212 r
.26762 .30001 m
.26986 .29945 L
s
.268 .595 .352 r
.80196 .34846 m
.80068 .34736 L
s
.176 .125 .589 r
.72236 .83508 m
.72245 .83331 L
s
.098 .036 .682 r
.32575 .78669 m
.32506 .7851 L
s
.176 .125 .589 r
.72229 .83687 m
.72236 .83508 L
s
.268 .595 .352 r
.80316 .34958 m
.80196 .34846 L
s
.921 .567 .212 r
.26539 .30059 m
.26762 .30001 L
s
.176 .125 .589 r
.72225 .83867 m
.72229 .83687 L
s
.098 .036 .682 r
.32641 .7883 m
.32575 .78669 L
s
.268 .595 .352 r
.80428 .35073 m
.80316 .34958 L
s
.176 .125 .589 r
.72225 .84048 m
.72225 .83867 L
s
.098 .036 .682 r
.32704 .78993 m
.32641 .7883 L
s
.921 .567 .212 r
.26317 .30117 m
.26539 .30059 L
s
.268 .595 .352 r
.80533 .35191 m
.80428 .35073 L
s
.176 .125 .589 r
.72227 .84231 m
.72225 .84048 L
s
.098 .036 .682 r
.32762 .79156 m
.32704 .78993 L
s
.268 .595 .352 r
.80631 .35311 m
.80533 .35191 L
s
.176 .125 .589 r
.72233 .84415 m
.72227 .84231 L
s
.921 .567 .212 r
.26098 .30175 m
.26317 .30117 L
s
.098 .036 .682 r
.32817 .79321 m
.32762 .79156 L
s
.268 .595 .352 r
.8072 .35434 m
.80631 .35311 L
s
.176 .125 .589 r
.72241 .846 m
.72233 .84415 L
s
.921 .567 .212 r
.25881 .30235 m
.26098 .30175 L
s
.098 .036 .682 r
.32869 .79487 m
.32817 .79321 L
s
.176 .125 .589 r
.72252 .84786 m
.72241 .846 L
s
.268 .595 .352 r
.80801 .3556 m
.8072 .35434 L
s
.176 .125 .589 r
.72267 .84974 m
.72252 .84786 L
s
.098 .036 .682 r
.32917 .79654 m
.32869 .79487 L
s
.268 .595 .352 r
.80875 .35689 m
.80801 .3556 L
s
.921 .567 .212 r
.25667 .30297 m
.25881 .30235 L
s
.176 .125 .589 r
.72284 .85163 m
.72267 .84974 L
s
.268 .595 .352 r
.8094 .3582 m
.80875 .35689 L
s
.098 .036 .682 r
.32962 .79822 m
.32917 .79654 L
s
.176 .125 .589 r
.72305 .85353 m
.72284 .85163 L
s
.268 .595 .352 r
.80996 .35955 m
.8094 .3582 L
s
.921 .567 .212 r
.25456 .30359 m
.25667 .30297 L
s
.098 .036 .682 r
.33003 .79992 m
.32962 .79822 L
s
.176 .125 .589 r
.72328 .85545 m
.72305 .85353 L
s
.268 .595 .352 r
.81044 .36093 m
.80996 .35955 L
s
.098 .036 .682 r
.3304 .80162 m
.33003 .79992 L
s
.176 .125 .589 r
.72354 .85738 m
.72328 .85545 L
s
.921 .567 .212 r
.25248 .30423 m
.25456 .30359 L
s
.268 .595 .352 r
.81084 .36233 m
.81044 .36093 L
s
.176 .125 .589 r
.72384 .85932 m
.72354 .85738 L
s
.098 .036 .682 r
.33075 .80334 m
.3304 .80162 L
s
.268 .595 .352 r
.81115 .36377 m
.81084 .36233 L
s
.176 .125 .589 r
.72417 .86128 m
.72384 .85932 L
s
.921 .567 .212 r
.25045 .30489 m
.25248 .30423 L
s
.098 .036 .682 r
.33106 .80507 m
.33075 .80334 L
s
.268 .595 .352 r
.81138 .36524 m
.81115 .36377 L
s
.176 .125 .589 r
.72453 .86325 m
.72417 .86128 L
s
.098 .036 .682 r
.33134 .80681 m
.33106 .80507 L
s
.176 .125 .589 r
.72492 .86523 m
.72453 .86325 L
s
.268 .595 .352 r
.81152 .36674 m
.81138 .36524 L
s
.921 .567 .212 r
.24846 .30557 m
.25045 .30489 L
s
.176 .125 .589 r
.72534 .86723 m
.72492 .86523 L
s
.268 .595 .352 r
.81157 .36827 m
.81152 .36674 L
s
.098 .036 .682 r
.33159 .80856 m
.33134 .80681 L
s
.176 .125 .589 r
.72579 .86924 m
.72534 .86723 L
s
.268 .595 .352 r
.81154 .36983 m
.81157 .36827 L
s
.098 .036 .682 r
.3318 .81032 m
.33159 .80856 L
s
.921 .567 .212 r
.24651 .30627 m
.24846 .30557 L
s
.176 .125 .589 r
.72628 .87126 m
.72579 .86924 L
s
.268 .595 .352 r
.81142 .37143 m
.81154 .36983 L
s
.098 .036 .682 r
.33199 .8121 m
.3318 .81032 L
s
.176 .125 .589 r
.7268 .8733 m
.72628 .87126 L
s
.268 .595 .352 r
.81122 .37305 m
.81142 .37143 L
s
.921 .567 .212 r
.24462 .30699 m
.24651 .30627 L
s
.176 .125 .589 r
.72736 .87536 m
.7268 .8733 L
s
.098 .036 .682 r
.33214 .81388 m
.33199 .8121 L
s
.268 .595 .352 r
.81093 .37471 m
.81122 .37305 L
s
.176 .125 .589 r
.72795 .87743 m
.72736 .87536 L
s
.268 .595 .352 r
.81056 .3764 m
.81093 .37471 L
s
.098 .036 .682 r
.33227 .81567 m
.33214 .81388 L
s
.921 .567 .212 r
.24278 .30774 m
.24462 .30699 L
s
.176 .125 .589 r
.72858 .87951 m
.72795 .87743 L
s
.268 .595 .352 r
.8101 .37812 m
.81056 .3764 L
s
.098 .036 .682 r
.33236 .81748 m
.33227 .81567 L
s
.176 .125 .589 r
.72924 .88161 m
.72858 .87951 L
s
.268 .595 .352 r
.80957 .37987 m
.8101 .37812 L
s
.921 .567 .212 r
.241 .30851 m
.24278 .30774 L
s
.176 .125 .589 r
.72994 .88372 m
.72924 .88161 L
s
.268 .595 .352 r
.80895 .38165 m
.80957 .37987 L
s
.098 .036 .682 r
.33242 .81929 m
.33236 .81748 L
s
.176 .125 .589 r
.73067 .88585 m
.72994 .88372 L
s
.268 .595 .352 r
.80825 .38345 m
.80895 .38165 L
s
.098 .036 .682 r
.33246 .82112 m
.33242 .81929 L
s
.176 .125 .589 r
.73144 .888 m
.73067 .88585 L
s
.268 .595 .352 r
.80748 .38529 m
.80825 .38345 L
s
.921 .567 .212 r
.23928 .30931 m
.241 .30851 L
s
.268 .595 .352 r
.80663 .38716 m
.80748 .38529 L
s
.176 .125 .589 r
.73225 .89016 m
.73144 .888 L
s
.098 .036 .682 r
.33246 .82295 m
.33246 .82112 L
s
.268 .595 .352 r
.80571 .38906 m
.80663 .38716 L
s
.176 .125 .589 r
.7331 .89233 m
.73225 .89016 L
s
.921 .567 .212 r
.23762 .31014 m
.23928 .30931 L
s
.268 .595 .352 r
.80471 .39098 m
.80571 .38906 L
s
.098 .036 .682 r
.33244 .8248 m
.33246 .82295 L
s
.176 .125 .589 r
.73398 .89452 m
.7331 .89233 L
s
.268 .595 .352 r
.80364 .39293 m
.80471 .39098 L
s
.176 .125 .589 r
.73491 .89673 m
.73398 .89452 L
s
.268 .595 .352 r
.80251 .39491 m
.80364 .39293 L
s
.098 .036 .682 r
.33238 .82666 m
.33244 .8248 L
s
.921 .567 .212 r
.23603 .311 m
.23762 .31014 L
s
.176 .125 .589 r
.73587 .89895 m
.73491 .89673 L
s
.268 .595 .352 r
.80131 .39691 m
.80251 .39491 L
s
.176 .125 .589 r
.73688 .90119 m
.73587 .89895 L
s
.098 .036 .682 r
.3323 .82852 m
.33238 .82666 L
s
.268 .595 .352 r
.80004 .39894 m
.80131 .39691 L
s
.79872 .401 m
.80004 .39894 L
s
.176 .125 .589 r
.73792 .90344 m
.73688 .90119 L
s
.921 .567 .212 r
.23451 .31188 m
.23603 .311 L
s
.268 .595 .352 r
.79734 .40307 m
.79872 .401 L
s
.098 .036 .682 r
.33218 .8304 m
.3323 .82852 L
s
.176 .125 .589 r
.739 .90571 m
.73792 .90344 L
s
.268 .595 .352 r
.7959 .40517 m
.79734 .40307 L
s
.176 .125 .589 r
.74013 .90799 m
.739 .90571 L
s
.268 .595 .352 r
.79442 .40729 m
.7959 .40517 L
s
.098 .036 .682 r
.33204 .83229 m
.33218 .8304 L
s
.176 .125 .589 r
.74129 .91029 m
.74013 .90799 L
s
.921 .567 .212 r
.23307 .31281 m
.23451 .31188 L
s
.268 .595 .352 r
.79288 .40943 m
.79442 .40729 L
s
.176 .125 .589 r
.74249 .9126 m
.74129 .91029 L
s
.268 .595 .352 r
.7913 .41159 m
.79288 .40943 L
s
.098 .036 .682 r
.33187 .83418 m
.33204 .83229 L
s
.268 .595 .352 r
.78968 .41376 m
.7913 .41159 L
s
.176 .125 .589 r
.74373 .91493 m
.74249 .9126 L
s
.268 .595 .352 r
.78802 .41596 m
.78968 .41376 L
s
.176 .125 .589 r
.74502 .91727 m
.74373 .91493 L
s
.921 .567 .212 r
.23169 .31376 m
.23307 .31281 L
s
.268 .595 .352 r
.78633 .41817 m
.78802 .41596 L
s
.098 .036 .682 r
.33166 .83609 m
.33187 .83418 L
s
.176 .125 .589 r
.74633 .91962 m
.74502 .91727 L
s
.268 .595 .352 r
.7846 .42039 m
.78633 .41817 L
s
.176 .125 .589 r
.74769 .92199 m
.74633 .91962 L
s
.268 .595 .352 r
.78285 .42263 m
.7846 .42039 L
s
.098 .036 .682 r
.33143 .83801 m
.33166 .83609 L
s
.268 .595 .352 r
.78108 .42488 m
.78285 .42263 L
s
.176 .125 .589 r
.74909 .92437 m
.74769 .92199 L
s
.921 .567 .212 r
.2304 .31475 m
.23169 .31376 L
s
.268 .595 .352 r
.77928 .42713 m
.78108 .42488 L
s
.176 .125 .589 r
.75052 .92677 m
.74909 .92437 L
s
.268 .595 .352 r
.77748 .4294 m
.77928 .42713 L
s
.176 .125 .589 r
.75198 .92917 m
.75052 .92677 L
s
.098 .036 .682 r
.33117 .83994 m
.33143 .83801 L
s
.268 .595 .352 r
.77565 .43168 m
.77748 .4294 L
s
.176 .125 .589 r
.75348 .93159 m
.75198 .92917 L
s
.268 .595 .352 r
.77382 .43396 m
.77565 .43168 L
s
.921 .567 .212 r
.22918 .31578 m
.2304 .31475 L
s
.176 .125 .589 r
.75501 .93402 m
.75348 .93159 L
s
.268 .595 .352 r
.77199 .43625 m
.77382 .43396 L
s
.098 .036 .682 r
.33087 .84188 m
.33117 .83994 L
s
.176 .125 .589 r
.75657 .93646 m
.75501 .93402 L
s
.268 .595 .352 r
.77016 .43854 m
.77199 .43625 L
s
.176 .125 .589 r
.75817 .9389 m
.75657 .93646 L
s
.268 .595 .352 r
.76832 .44084 m
.77016 .43854 L
s
.176 .125 .589 r
.75978 .94136 m
.75817 .9389 L
s
.268 .595 .352 r
.7665 .44314 m
.76832 .44084 L
s
.098 .036 .682 r
.33055 .84384 m
.33087 .84188 L
s
.176 .125 .589 r
.76143 .94382 m
.75978 .94136 L
s
.921 .567 .212 r
.22805 .31684 m
.22918 .31578 L
s
.268 .595 .352 r
.76468 .44543 m
.7665 .44314 L
s
.176 .125 .589 r
.7631 .94629 m
.76143 .94382 L
s
.268 .595 .352 r
.76288 .44773 m
.76468 .44543 L
s
.098 .036 .682 r
.33019 .8458 m
.33055 .84384 L
s
.268 .595 .352 r
.76109 .45002 m
.76288 .44773 L
s
.75933 .45231 m
.76109 .45002 L
s
.921 .567 .212 r
.227 .31794 m
.22805 .31684 L
s
.268 .595 .352 r
.75758 .4546 m
.75933 .45231 L
s
.098 .036 .682 r
.32981 .84777 m
.33019 .8458 L
s
.268 .595 .352 r
.75586 .45688 m
.75758 .4546 L
s
.75417 .45916 m
.75586 .45688 L
s
.098 .036 .682 r
.32939 .84976 m
.32981 .84777 L
s
.921 .567 .212 r
.22603 .31908 m
.227 .31794 L
s
.268 .595 .352 r
.75251 .46143 m
.75417 .45916 L
s
.75088 .46369 m
.75251 .46143 L
s
.098 .036 .682 r
.32894 .85176 m
.32939 .84976 L
s
.268 .595 .352 r
.74929 .46594 m
.75088 .46369 L
s
.921 .567 .212 r
.22515 .32026 m
.22603 .31908 L
s
.268 .595 .352 r
.74773 .46818 m
.74929 .46594 L
s
.098 .036 .682 r
.32846 .85376 m
.32894 .85176 L
s
.268 .595 .352 r
.74621 .47041 m
.74773 .46818 L
s
.74473 .47263 m
.74621 .47041 L
s
.921 .567 .212 r
.22436 .32148 m
.22515 .32026 L
s
.098 .036 .682 r
.32794 .85578 m
.32846 .85376 L
s
.268 .595 .352 r
.74329 .47484 m
.74473 .47263 L
s
.7419 .47704 m
.74329 .47484 L
s
.098 .036 .682 r
.32739 .85782 m
.32794 .85578 L
s
.921 .567 .212 r
.22366 .32274 m
.22436 .32148 L
s
.268 .595 .352 r
.74054 .47922 m
.7419 .47704 L
s
.098 .036 .682 r
.3268 .85986 m
.32739 .85782 L
s
.268 .595 .352 r
.73923 .48139 m
.74054 .47922 L
s
.921 .567 .212 r
.22305 .32404 m
.22366 .32274 L
s
.268 .595 .352 r
.73797 .48355 m
.73923 .48139 L
s
.098 .036 .682 r
.32618 .86192 m
.3268 .85986 L
s
.268 .595 .352 r
.73675 .4857 m
.73797 .48355 L
s
.921 .567 .212 r
.22253 .32538 m
.22305 .32404 L
s
.098 .036 .682 r
.32553 .86398 m
.32618 .86192 L
s
.268 .595 .352 r
.73558 .48783 m
.73675 .4857 L
s
.73445 .48995 m
.73558 .48783 L
s
.098 .036 .682 r
.32484 .86606 m
.32553 .86398 L
s
.921 .567 .212 r
.2221 .32676 m
.22253 .32538 L
s
.268 .595 .352 r
.73337 .49206 m
.73445 .48995 L
s
.098 .036 .682 r
.32411 .86816 m
.32484 .86606 L
s
.268 .595 .352 r
.73233 .49415 m
.73337 .49206 L
s
.921 .567 .212 r
.22176 .32819 m
.2221 .32676 L
s
.098 .036 .682 r
.32335 .87026 m
.32411 .86816 L
s
.268 .595 .352 r
.73134 .49623 m
.73233 .49415 L
s
.73039 .49829 m
.73134 .49623 L
s
.921 .567 .212 r
.22151 .32966 m
.22176 .32819 L
s
.098 .036 .682 r
.32255 .87238 m
.32335 .87026 L
s
.268 .595 .352 r
.72949 .50034 m
.73039 .49829 L
s
.098 .036 .682 r
.32171 .87451 m
.32255 .87238 L
s
.921 .567 .212 r
.22136 .33117 m
.22151 .32966 L
s
.268 .595 .352 r
.72864 .50238 m
.72949 .50034 L
s
.098 .036 .682 r
.32083 .87665 m
.32171 .87451 L
s
.921 .567 .212 r
.2213 .33272 m
.22136 .33117 L
s
.268 .595 .352 r
.72783 .5044 m
.72864 .50238 L
s
.156 .65 .561 r
.51662 .23852 m
.51657 .23575 L
s
.51667 .24124 m
.51662 .23852 L
s
.51672 .24393 m
.51667 .24124 L
s
.098 .036 .682 r
.31992 .87881 m
.32083 .87665 L
s
.156 .65 .561 r
.51657 .23575 m
.51652 .23294 L
s
.51676 .24657 m
.51672 .24393 L
s
.51652 .23294 m
.51646 .23009 L
s
.51681 .24916 m
.51676 .24657 L
s
.51646 .23009 m
.5164 .22719 L
s
.51685 .25172 m
.51681 .24916 L
s
.5164 .22719 m
.51634 .22425 L
s
.51689 .25423 m
.51685 .25172 L
s
.268 .595 .352 r
.72706 .50641 m
.72783 .5044 L
s
.921 .567 .212 r
.22134 .33432 m
.2213 .33272 L
s
.156 .65 .561 r
.51634 .22425 m
.51628 .22128 L
s
.51693 .25671 m
.51689 .25423 L
s
.098 .036 .682 r
.31896 .88097 m
.31992 .87881 L
s
.156 .65 .561 r
.51628 .22128 m
.51622 .21826 L
s
.51696 .25914 m
.51693 .25671 L
s
.51622 .21826 m
.51615 .2152 L
s
.51699 .26153 m
.51696 .25914 L
s
.268 .595 .352 r
.72633 .50841 m
.72706 .50641 L
s
.156 .65 .561 r
.51615 .2152 m
.51609 .21211 L
s
.51703 .26388 m
.51699 .26153 L
s
.921 .567 .212 r
.22146 .33596 m
.22134 .33432 L
s
.098 .036 .682 r
.31797 .88315 m
.31896 .88097 L
s
.156 .65 .561 r
.51609 .21211 m
.51602 .20898 L
s
.51706 .2662 m
.51703 .26388 L
s
.268 .595 .352 r
.72565 .51039 m
.72633 .50841 L
s
.156 .65 .561 r
.51602 .20898 m
.51595 .20581 L
s
.51708 .26847 m
.51706 .2662 L
s
.098 .036 .682 r
.31694 .88535 m
.31797 .88315 L
s
.921 .567 .212 r
.22168 .33764 m
.22146 .33596 L
s
.156 .65 .561 r
.51595 .20581 m
.51588 .20262 L
s
.51711 .27071 m
.51708 .26847 L
s
.268 .595 .352 r
.72501 .51237 m
.72565 .51039 L
s
.156 .65 .561 r
.51588 .20262 m
.5158 .19939 L
s
.098 .036 .682 r
.31587 .88755 m
.31694 .88535 L
s
.156 .65 .561 r
.51713 .27292 m
.51711 .27071 L
s
.921 .567 .212 r
.22199 .33936 m
.22168 .33764 L
s
.156 .65 .561 r
.5158 .19939 m
.51573 .19613 L
s
.51716 .27508 m
.51713 .27292 L
s
.268 .595 .352 r
.72441 .51433 m
.72501 .51237 L
s
.098 .036 .682 r
.31475 .88977 m
.31587 .88755 L
s
.921 .567 .212 r
.22239 .34113 m
.22199 .33936 L
s
.156 .65 .561 r
.51573 .19613 m
.51565 .19285 L
s
.51718 .27722 m
.51716 .27508 L
s
.268 .595 .352 r
.72385 .51627 m
.72441 .51433 L
s
.098 .036 .682 r
.3136 .892 m
.31475 .88977 L
s
.156 .65 .561 r
.51565 .19285 m
.51557 .18955 L
s
.5172 .27932 m
.51718 .27722 L
s
.921 .567 .212 r
.22288 .34293 m
.22239 .34113 L
s
.156 .65 .561 r
.51557 .18955 m
.51549 .18622 L
s
.098 .036 .682 r
.31241 .89424 m
.3136 .892 L
s
.156 .65 .561 r
.51721 .28138 m
.5172 .27932 L
s
.268 .595 .352 r
.72333 .51821 m
.72385 .51627 L
s
.921 .567 .212 r
.22345 .34478 m
.22288 .34293 L
s
.156 .65 .561 r
.51549 .18622 m
.51541 .18287 L
s
.098 .036 .682 r
.31118 .89649 m
.31241 .89424 L
s
.156 .65 .561 r
.51723 .28342 m
.51721 .28138 L
s
.921 .567 .212 r
.22412 .34667 m
.22345 .34478 L
s
.268 .595 .352 r
.72285 .52013 m
.72333 .51821 L
s
.156 .65 .561 r
.51541 .18287 m
.51533 .17952 L
s
.098 .036 .682 r
.30992 .89876 m
.31118 .89649 L
s
.156 .65 .561 r
.51725 .28542 m
.51723 .28342 L
s
.921 .567 .212 r
.22487 .3486 m
.22412 .34667 L
s
.156 .65 .561 r
.51533 .17952 m
.51525 .17614 L
s
.268 .595 .352 r
.72241 .52205 m
.72285 .52013 L
s
.098 .036 .682 r
.30861 .90103 m
.30992 .89876 L
s
.156 .65 .561 r
.51726 .28739 m
.51725 .28542 L
s
.921 .567 .212 r
.2257 .35057 m
.22487 .3486 L
s
.156 .65 .561 r
.51525 .17614 m
.51517 .17276 L
s
.098 .036 .682 r
.30726 .90332 m
.30861 .90103 L
s
.268 .595 .352 r
.72201 .52395 m
.72241 .52205 L
s
.156 .65 .561 r
.51727 .28933 m
.51726 .28739 L
s
.921 .567 .212 r
.22662 .35258 m
.2257 .35057 L
s
.156 .65 .561 r
.51517 .17276 m
.51509 .16938 L
s
.098 .036 .682 r
.30588 .90561 m
.30726 .90332 L
s
.921 .567 .212 r
.22761 .35463 m
.22662 .35258 L
s
.156 .65 .561 r
.51728 .29124 m
.51727 .28933 L
s
.51509 .16938 m
.51501 .16599 L
s
.268 .595 .352 r
.72164 .52584 m
.72201 .52395 L
s
.098 .036 .682 r
.30447 .90792 m
.30588 .90561 L
s
.921 .567 .212 r
.22868 .35671 m
.22761 .35463 L
s
.156 .65 .561 r
.51501 .16599 m
.51492 .16261 L
s
.51729 .29312 m
.51728 .29124 L
s
.921 .567 .212 r
.22983 .35883 m
.22868 .35671 L
s
.098 .036 .682 r
.30302 .91024 m
.30447 .90792 L
s
.268 .595 .352 r
.72131 .52772 m
.72164 .52584 L
s
.921 .567 .212 r
.23106 .36099 m
.22983 .35883 L
s
.156 .65 .561 r
.51492 .16261 m
.51484 .15923 L
s
.098 .036 .682 r
.30153 .91256 m
.30302 .91024 L
s
.156 .65 .561 r
.51729 .29498 m
.51729 .29312 L
s
.921 .567 .212 r
.23235 .36318 m
.23106 .36099 L
s
.268 .595 .352 r
.72102 .52959 m
.72131 .52772 L
s
.156 .65 .561 r
.51484 .15923 m
.51476 .15586 L
s
.098 .036 .682 r
.30001 .9149 m
.30153 .91256 L
s
.921 .567 .212 r
.23371 .3654 m
.23235 .36318 L
s
.156 .65 .561 r
.5173 .29681 m
.51729 .29498 L
s
.921 .567 .212 r
.23513 .36765 m
.23371 .3654 L
s
.098 .036 .682 r
.29846 .91724 m
.30001 .9149 L
s
.156 .65 .561 r
.51476 .15586 m
.51468 .15251 L
s
.921 .567 .212 r
.23662 .36994 m
.23513 .36765 L
s
.268 .595 .352 r
.72076 .53145 m
.72102 .52959 L
s
.921 .567 .212 r
.23816 .37225 m
.23662 .36994 L
s
.098 .036 .682 r
.29689 .91959 m
.29846 .91724 L
s
.156 .65 .561 r
.5173 .2986 m
.5173 .29681 L
s
.51468 .15251 m
.5146 .14917 L
s
.921 .567 .212 r
.23976 .37459 m
.23816 .37225 L
s
.24141 .37696 m
.23976 .37459 L
s
.098 .036 .682 r
.29528 .92194 m
.29689 .91959 L
s
.268 .595 .352 r
.72053 .5333 m
.72076 .53145 L
s
.921 .567 .212 r
.24311 .37935 m
.24141 .37696 L
s
.156 .65 .561 r
.5146 .14917 m
.51452 .14585 L
s
.921 .567 .212 r
.24486 .38177 m
.24311 .37935 L
s
.098 .036 .682 r
.29365 .9243 m
.29528 .92194 L
s
.156 .65 .561 r
.51731 .30038 m
.5173 .2986 L
s
.921 .567 .212 r
.24664 .3842 m
.24486 .38177 L
s
.24846 .38666 m
.24664 .3842 L
s
.156 .65 .561 r
.51452 .14585 m
.51444 .14256 L
s
.098 .036 .682 r
.29199 .92667 m
.29365 .9243 L
s
.921 .567 .212 r
.25031 .38913 m
.24846 .38666 L
s
.268 .595 .352 r
.72035 .53514 m
.72053 .5333 L
s
.921 .567 .212 r
.25219 .39162 m
.25031 .38913 L
s
.2541 .39412 m
.25219 .39162 L
s
.156 .65 .561 r
.51731 .30212 m
.51731 .30038 L
s
.51444 .14256 m
.51436 .13929 L
s
.921 .567 .212 r
.25602 .39664 m
.2541 .39412 L
s
.25797 .39916 m
.25602 .39664 L
s
.25992 .4017 m
.25797 .39916 L
s
.26189 .40424 m
.25992 .4017 L
s
.156 .65 .561 r
.51436 .13929 m
.51429 .13606 L
s
.921 .567 .212 r
.26385 .40679 m
.26189 .40424 L
s
.268 .595 .352 r
.72019 .53697 m
.72035 .53514 L
s
.921 .567 .212 r
.26582 .40934 m
.26385 .40679 L
s
.26779 .4119 m
.26582 .40934 L
s
.156 .65 .561 r
.51731 .30384 m
.51731 .30212 L
s
.921 .567 .212 r
.26974 .41445 m
.26779 .4119 L
s
.156 .65 .561 r
.51429 .13606 m
.51421 .13286 L
s
.921 .567 .212 r
.27169 .417 m
.26974 .41445 L
s
.27362 .41955 m
.27169 .417 L
s
.27553 .4221 m
.27362 .41955 L
s
.156 .65 .561 r
.51421 .13286 m
.51414 .12971 L
s
.921 .567 .212 r
.27743 .42463 m
.27553 .4221 L
s
.268 .595 .352 r
.72007 .53879 m
.72019 .53697 L
s
.921 .567 .212 r
.27929 .42716 m
.27743 .42463 L
s
.156 .65 .561 r
.51731 .30553 m
.51731 .30384 L
s
.921 .567 .212 r
.28113 .42969 m
.27929 .42716 L
s
.156 .65 .561 r
.51414 .12971 m
.51407 .12659 L
s
.921 .567 .212 r
.28295 .4322 m
.28113 .42969 L
s
.28472 .4347 m
.28295 .4322 L
s
.156 .65 .561 r
.51407 .12659 m
.514 .12352 L
s
.268 .595 .352 r
.71998 .5406 m
.72007 .53879 L
s
.921 .567 .212 r
.28646 .43719 m
.28472 .4347 L
s
.156 .65 .561 r
.51731 .3072 m
.51731 .30553 L
s
.921 .567 .212 r
.28817 .43966 m
.28646 .43719 L
s
.156 .65 .561 r
.514 .12352 m
.51394 .1205 L
s
.921 .567 .212 r
.28983 .44212 m
.28817 .43966 L
s
.156 .65 .561 r
.51394 .1205 m
.51387 .11754 L
s
.921 .567 .212 r
.29146 .44456 m
.28983 .44212 L
s
.156 .65 .561 r
.51387 .11754 m
.51381 .11463 L
s
.268 .595 .352 r
.71993 .54241 m
.71998 .5406 L
s
.921 .567 .212 r
.29304 .44699 m
.29146 .44456 L
s
.156 .65 .561 r
.51381 .11463 m
.51375 .11178 L
s
.5173 .30884 m
.51731 .3072 L
s
.921 .567 .212 r
.29458 .4494 m
.29304 .44699 L
s
.156 .65 .561 r
.51375 .11178 m
.51369 .10899 L
s
.51369 .10899 m
.51364 .10627 L
s
.5135 .09851 m
.51346 .09607 L
s
.51364 .10627 m
.51359 .10361 L
s
.921 .567 .212 r
.29607 .4518 m
.29458 .4494 L
s
.156 .65 .561 r
.51354 .10102 m
.5135 .09851 L
s
.51359 .10361 m
.51354 .10102 L
s
.268 .595 .352 r
.7199 .5442 m
.71993 .54241 L
s
.921 .567 .212 r
.29751 .45417 m
.29607 .4518 L
s
.156 .65 .561 r
.5173 .31046 m
.5173 .30884 L
s
.921 .567 .212 r
.29891 .45653 m
.29751 .45417 L
s
.30026 .45887 m
.29891 .45653 L
s
.268 .595 .352 r
.71992 .54599 m
.7199 .5442 L
s
.921 .567 .212 r
.30156 .46118 m
.30026 .45887 L
s
.156 .65 .561 r
.51729 .31205 m
.5173 .31046 L
s
.921 .567 .212 r
.30282 .46348 m
.30156 .46118 L
s
.268 .595 .352 r
.71996 .54777 m
.71992 .54599 L
s
.921 .567 .212 r
.30402 .46576 m
.30282 .46348 L
s
.156 .65 .561 r
.51728 .31361 m
.51729 .31205 L
s
.921 .567 .212 r
.30517 .46802 m
.30402 .46576 L
s
.268 .595 .352 r
.72004 .54954 m
.71996 .54777 L
s
.921 .567 .212 r
.30628 .47027 m
.30517 .46802 L
s
.156 .65 .561 r
.51727 .31515 m
.51728 .31361 L
s
.921 .567 .212 r
.30734 .47249 m
.30628 .47027 L
s
.268 .595 .352 r
.72014 .5513 m
.72004 .54954 L
s
.921 .567 .212 r
.30834 .47469 m
.30734 .47249 L
s
.156 .65 .561 r
.51726 .31667 m
.51727 .31515 L
s
.921 .567 .212 r
.3093 .47687 m
.30834 .47469 L
s
.268 .595 .352 r
.72029 .55305 m
.72014 .5513 L
s
.921 .567 .212 r
.31021 .47904 m
.3093 .47687 L
s
.156 .65 .561 r
.51725 .31816 m
.51726 .31667 L
s
.921 .567 .212 r
.31108 .48118 m
.31021 .47904 L
s
.268 .595 .352 r
.72046 .5548 m
.72029 .55305 L
s
.921 .567 .212 r
.3119 .48331 m
.31108 .48118 L
s
.156 .65 .561 r
.51724 .31962 m
.51725 .31816 L
s
.268 .595 .352 r
.72067 .55653 m
.72046 .5548 L
s
.921 .567 .212 r
.31267 .48541 m
.3119 .48331 L
s
.3134 .4875 m
.31267 .48541 L
s
.156 .65 .561 r
.51722 .32106 m
.51724 .31962 L
s
.268 .595 .352 r
.72091 .55826 m
.72067 .55653 L
s
.921 .567 .212 r
.31408 .48958 m
.3134 .4875 L
s
.268 .595 .352 r
.72118 .55998 m
.72091 .55826 L
s
.921 .567 .212 r
.31471 .49163 m
.31408 .48958 L
s
.156 .65 .561 r
.5172 .32247 m
.51722 .32106 L
s
.921 .567 .212 r
.31531 .49367 m
.31471 .49163 L
s
.268 .595 .352 r
.72149 .5617 m
.72118 .55998 L
s
.156 .65 .561 r
.51719 .32386 m
.5172 .32247 L
s
.921 .567 .212 r
.31586 .49569 m
.31531 .49367 L
s
.268 .595 .352 r
.72183 .5634 m
.72149 .5617 L
s
.921 .567 .212 r
.31637 .49769 m
.31586 .49569 L
s
.156 .65 .561 r
.51717 .32521 m
.51719 .32386 L
s
.921 .567 .212 r
.31684 .49968 m
.31637 .49769 L
s
.268 .595 .352 r
.72221 .5651 m
.72183 .5634 L
s
.921 .567 .212 r
.31727 .50165 m
.31684 .49968 L
s
.156 .65 .561 r
.51715 .32654 m
.51717 .32521 L
s
.268 .595 .352 r
.72262 .56679 m
.72221 .5651 L
s
.921 .567 .212 r
.31766 .50361 m
.31727 .50165 L
s
.156 .65 .561 r
.51712 .32785 m
.51715 .32654 L
s
.921 .567 .212 r
.31801 .50555 m
.31766 .50361 L
s
.268 .595 .352 r
.72307 .56847 m
.72262 .56679 L
s
.921 .567 .212 r
.31832 .50748 m
.31801 .50555 L
s
.156 .65 .561 r
.5171 .32912 m
.51712 .32785 L
s
.268 .595 .352 r
.72355 .57014 m
.72307 .56847 L
s
.921 .567 .212 r
.3186 .50939 m
.31832 .50748 L
s
.268 .595 .352 r
.72407 .5718 m
.72355 .57014 L
s
.156 .65 .561 r
.51707 .33037 m
.5171 .32912 L
s
.921 .567 .212 r
.31883 .51129 m
.3186 .50939 L
s
.31903 .51318 m
.31883 .51129 L
s
.268 .595 .352 r
.72463 .57346 m
.72407 .5718 L
s
.156 .65 .561 r
.51705 .33158 m
.51707 .33037 L
s
.921 .567 .212 r
.3192 .51505 m
.31903 .51318 L
s
.268 .595 .352 r
.72523 .5751 m
.72463 .57346 L
s
.921 .567 .212 r
.31932 .51691 m
.3192 .51505 L
s
.156 .65 .561 r
.51702 .33277 m
.51705 .33158 L
s
.268 .595 .352 r
.72586 .57674 m
.72523 .5751 L
s
.921 .567 .212 r
.31942 .51875 m
.31932 .51691 L
s
.156 .65 .561 r
.51699 .33392 m
.51702 .33277 L
s
.921 .567 .212 r
.31947 .52059 m
.31942 .51875 L
s
.268 .595 .352 r
.72653 .57837 m
.72586 .57674 L
s
.921 .567 .212 r
.31949 .52241 m
.31947 .52059 L
s
.156 .65 .561 r
.51695 .33504 m
.51699 .33392 L
s
.268 .595 .352 r
.72725 .57999 m
.72653 .57837 L
s
.921 .567 .212 r
.31948 .52421 m
.31949 .52241 L
s
.268 .595 .352 r
.728 .5816 m
.72725 .57999 L
s
.156 .65 .561 r
.51692 .33614 m
.51695 .33504 L
s
.921 .567 .212 r
.31943 .52601 m
.31948 .52421 L
s
.268 .595 .352 r
.7288 .5832 m
.728 .5816 L
s
.921 .567 .212 r
.31935 .52779 m
.31943 .52601 L
s
.156 .65 .561 r
.51688 .3372 m
.51692 .33614 L
s
.921 .567 .212 r
.31923 .52956 m
.31935 .52779 L
s
.268 .595 .352 r
.72964 .58479 m
.7288 .5832 L
s
.156 .65 .561 r
.51685 .33822 m
.51688 .3372 L
s
.921 .567 .212 r
.31908 .53132 m
.31923 .52956 L
s
.268 .595 .352 r
.73053 .58637 m
.72964 .58479 L
s
.921 .567 .212 r
.31889 .53307 m
.31908 .53132 L
s
.156 .65 .561 r
.51681 .33921 m
.51685 .33822 L
s
.268 .595 .352 r
.73145 .58794 m
.73053 .58637 L
s
.921 .567 .212 r
.31867 .53481 m
.31889 .53307 L
s
.268 .595 .352 r
.73242 .5895 m
.73145 .58794 L
s
.921 .567 .212 r
.31841 .53653 m
.31867 .53481 L
s
.156 .65 .561 r
.51676 .34017 m
.51681 .33921 L
s
.268 .595 .352 r
.73344 .59105 m
.73242 .5895 L
s
.921 .567 .212 r
.31812 .53824 m
.31841 .53653 L
s
.156 .65 .561 r
.51672 .34109 m
.51676 .34017 L
s
.921 .567 .212 r
.31779 .53994 m
.31812 .53824 L
s
.268 .595 .352 r
.7345 .59259 m
.73344 .59105 L
s
.921 .567 .212 r
.31742 .54163 m
.31779 .53994 L
s
.156 .65 .561 r
.51667 .34198 m
.51672 .34109 L
s
.268 .595 .352 r
.73561 .59411 m
.7345 .59259 L
s
.921 .567 .212 r
.31702 .54331 m
.31742 .54163 L
s
.268 .595 .352 r
.73677 .59563 m
.73561 .59411 L
s
.156 .65 .561 r
.51663 .34283 m
.51667 .34198 L
s
.921 .567 .212 r
.31658 .54497 m
.31702 .54331 L
s
.268 .595 .352 r
.73797 .59714 m
.73677 .59563 L
s
.921 .567 .212 r
.3161 .54663 m
.31658 .54497 L
s
.156 .65 .561 r
.51658 .34364 m
.51663 .34283 L
s
.268 .595 .352 r
.73922 .59863 m
.73797 .59714 L
s
.921 .567 .212 r
.31558 .54827 m
.3161 .54663 L
s
.156 .65 .561 r
.51652 .34441 m
.51658 .34364 L
s
.921 .567 .212 r
.31502 .54989 m
.31558 .54827 L
s
.268 .595 .352 r
.74052 .60011 m
.73922 .59863 L
s
.921 .567 .212 r
.31442 .55151 m
.31502 .54989 L
s
.268 .595 .352 r
.74187 .60158 m
.74052 .60011 L
s
.156 .65 .561 r
.51647 .34515 m
.51652 .34441 L
s
.921 .567 .212 r
.31379 .55311 m
.31442 .55151 L
s
.268 .595 .352 r
.74327 .60304 m
.74187 .60158 L
s
.156 .65 .561 r
.51641 .34585 m
.51647 .34515 L
s
.921 .567 .212 r
.31311 .5547 m
.31379 .55311 L
s
.268 .595 .352 r
.74471 .60449 m
.74327 .60304 L
s
.921 .567 .212 r
.31239 .55627 m
.31311 .5547 L
s
.156 .65 .561 r
.51636 .34651 m
.51641 .34585 L
s
.268 .595 .352 r
.7462 .60592 m
.74471 .60449 L
s
.921 .567 .212 r
.31162 .55783 m
.31239 .55627 L
s
.268 .595 .352 r
.74774 .60735 m
.7462 .60592 L
s
.921 .567 .212 r
.31081 .55938 m
.31162 .55783 L
s
.156 .65 .561 r
.51629 .34713 m
.51636 .34651 L
s
.921 .567 .212 r
.30996 .56091 m
.31081 .55938 L
s
.268 .595 .352 r
.74932 .60876 m
.74774 .60735 L
s
.156 .65 .561 r
.51623 .34772 m
.51629 .34713 L
s
.921 .567 .212 r
.30906 .56243 m
.30996 .56091 L
s
.268 .595 .352 r
.75095 .61016 m
.74932 .60876 L
s
.921 .567 .212 r
.30812 .56394 m
.30906 .56243 L
s
.156 .65 .561 r
.51617 .34826 m
.51623 .34772 L
s
.268 .595 .352 r
.75262 .61155 m
.75095 .61016 L
s
.921 .567 .212 r
.30713 .56543 m
.30812 .56394 L
s
.268 .595 .352 r
.75434 .61293 m
.75262 .61155 L
s
.156 .65 .561 r
.5161 .34877 m
.51617 .34826 L
s
.921 .567 .212 r
.30609 .5669 m
.30713 .56543 L
s
.268 .595 .352 r
.7561 .6143 m
.75434 .61293 L
s
.921 .567 .212 r
.305 .56836 m
.30609 .5669 L
s
.156 .65 .561 r
.51603 .34924 m
.5161 .34877 L
s
.268 .595 .352 r
.75791 .61566 m
.7561 .6143 L
s
.921 .567 .212 r
.30386 .5698 m
.305 .56836 L
s
.268 .595 .352 r
.75975 .617 m
.75791 .61566 L
s
.156 .65 .561 r
.51596 .34967 m
.51603 .34924 L
s
.921 .567 .212 r
.30267 .57123 m
.30386 .5698 L
s
.268 .595 .352 r
.76162 .61834 m
.75975 .617 L
s
.921 .567 .212 r
.30144 .57264 m
.30267 .57123 L
s
.156 .65 .561 r
.51589 .35006 m
.51596 .34967 L
s
.268 .595 .352 r
.76354 .61967 m
.76162 .61834 L
s
.921 .567 .212 r
.30015 .57403 m
.30144 .57264 L
s
.156 .65 .561 r
.51581 .35042 m
.51589 .35006 L
s
.268 .595 .352 r
.76549 .62099 m
.76354 .61967 L
s
.921 .567 .212 r
.29881 .57541 m
.30015 .57403 L
s
.268 .595 .352 r
.76746 .6223 m
.76549 .62099 L
s
.921 .567 .212 r
.29742 .57677 m
.29881 .57541 L
s
.156 .65 .561 r
.51573 .35074 m
.51581 .35042 L
s
.268 .595 .352 r
.76947 .62361 m
.76746 .6223 L
s
.921 .567 .212 r
.29597 .57811 m
.29742 .57677 L
s
.156 .65 .561 r
.51565 .35103 m
.51573 .35074 L
s
.921 .567 .212 r
.29448 .57944 m
.29597 .57811 L
s
.268 .595 .352 r
.7715 .62491 m
.76947 .62361 L
s
.921 .567 .212 r
.29294 .58075 m
.29448 .57944 L
s
.268 .595 .352 r
.77356 .6262 m
.7715 .62491 L
s
.156 .65 .561 r
.51557 .35128 m
.51565 .35103 L
s
.921 .567 .212 r
.29134 .58204 m
.29294 .58075 L
s
.268 .595 .352 r
.77563 .62749 m
.77356 .6262 L
s
.156 .65 .561 r
.51549 .35151 m
.51557 .35128 L
s
.921 .567 .212 r
.28969 .58332 m
.29134 .58204 L
s
.268 .595 .352 r
.77772 .62877 m
.77563 .62749 L
s
.921 .567 .212 r
.28799 .58458 m
.28969 .58332 L
s
.268 .595 .352 r
.77983 .63005 m
.77772 .62877 L
s
.156 .65 .561 r
.5154 .3517 m
.51549 .35151 L
s
.921 .567 .212 r
.28625 .58582 m
.28799 .58458 L
s
.268 .595 .352 r
.78194 .63133 m
.77983 .63005 L
s
.156 .65 .561 r
.51532 .35186 m
.5154 .3517 L
s
.921 .567 .212 r
.28445 .58705 m
.28625 .58582 L
s
.268 .595 .352 r
.78406 .63261 m
.78194 .63133 L
s
.156 .65 .561 r
.51523 .352 m
.51532 .35186 L
s
.268 .595 .352 r
.78619 .63388 m
.78406 .63261 L
s
.921 .567 .212 r
.28261 .58826 m
.28445 .58705 L
s
.268 .595 .352 r
.78831 .63516 m
.78619 .63388 L
s
.921 .567 .212 r
.28072 .58946 m
.28261 .58826 L
s
.156 .65 .561 r
.51514 .35211 m
.51523 .352 L
s
.268 .595 .352 r
.79043 .63644 m
.78831 .63516 L
s
.921 .567 .212 r
.27879 .59064 m
.28072 .58946 L
s
.268 .595 .352 r
.79254 .63772 m
.79043 .63644 L
s
.156 .65 .561 r
.51505 .3522 m
.51514 .35211 L
s
.921 .567 .212 r
.27682 .59181 m
.27879 .59064 L
s
.268 .595 .352 r
.79464 .639 m
.79254 .63772 L
s
.921 .567 .212 r
.2748 .59296 m
.27682 .59181 L
s
.156 .65 .561 r
.51496 .35227 m
.51505 .3522 L
s
.268 .595 .352 r
.79673 .64029 m
.79464 .639 L
s
.921 .567 .212 r
.27275 .5941 m
.2748 .59296 L
s
.268 .595 .352 r
.79879 .64159 m
.79673 .64029 L
s
.156 .65 .561 r
.51486 .35233 m
.51496 .35227 L
s
.921 .567 .212 r
.27066 .59523 m
.27275 .5941 L
s
.268 .595 .352 r
.80084 .64289 m
.79879 .64159 L
s
.921 .567 .212 r
.26853 .59635 m
.27066 .59523 L
s
.156 .65 .561 r
.51477 .35236 m
.51486 .35233 L
s
.268 .595 .352 r
.80285 .64419 m
.80084 .64289 L
s
.921 .567 .212 r
.26638 .59746 m
.26853 .59635 L
s
.268 .595 .352 r
.80484 .64551 m
.80285 .64419 L
s
.156 .65 .561 r
.51468 .35239 m
.51477 .35236 L
s
.921 .567 .212 r
.26419 .59856 m
.26638 .59746 L
s
.268 .595 .352 r
.80679 .64684 m
.80484 .64551 L
s
.156 .65 .561 r
.51458 .35241 m
.51468 .35239 L
s
.268 .595 .352 r
.8087 .64818 m
.80679 .64684 L
s
.921 .567 .212 r
.26198 .59965 m
.26419 .59856 L
s
.268 .595 .352 r
.81057 .64953 m
.8087 .64818 L
s
.921 .567 .212 r
.25975 .60073 m
.26198 .59965 L
s
.156 .65 .561 r
.51449 .35242 m
.51458 .35241 L
s
.268 .595 .352 r
.8124 .65089 m
.81057 .64953 L
s
.921 .567 .212 r
.25751 .60181 m
.25975 .60073 L
s
.268 .595 .352 r
.81418 .65227 m
.8124 .65089 L
s
.156 .65 .561 r
.51439 .35242 m
.51449 .35242 L
s
.921 .567 .212 r
.25524 .60289 m
.25751 .60181 L
s
.268 .595 .352 r
.81591 .65366 m
.81418 .65227 L
s
.81759 .65507 m
.81591 .65366 L
s
.156 .65 .561 r
.51429 .35243 m
.51439 .35242 L
s
.921 .567 .212 r
.25297 .60396 m
.25524 .60289 L
s
.268 .595 .352 r
.81921 .65649 m
.81759 .65507 L
s
.921 .567 .212 r
.25068 .60503 m
.25297 .60396 L
s
.156 .65 .561 r
.5142 .35243 m
.51429 .35243 L
s
.268 .595 .352 r
.82077 .65793 m
.81921 .65649 L
s
.921 .567 .212 r
.2484 .60609 m
.25068 .60503 L
s
.268 .595 .352 r
.82227 .65939 m
.82077 .65793 L
s
.156 .65 .561 r
.5141 .35245 m
.5142 .35243 L
s
.921 .567 .212 r
.24611 .60716 m
.2484 .60609 L
s
.268 .595 .352 r
.8237 .66087 m
.82227 .65939 L
s
.82507 .66237 m
.8237 .66087 L
s
.921 .567 .212 r
.24383 .60823 m
.24611 .60716 L
s
.156 .65 .561 r
.51401 .35247 m
.5141 .35245 L
s
.268 .595 .352 r
.82637 .66389 m
.82507 .66237 L
s
.921 .567 .212 r
.24155 .60931 m
.24383 .60823 L
s
.268 .595 .352 r
.82759 .66543 m
.82637 .66389 L
s
.156 .65 .561 r
.51391 .35251 m
.51401 .35247 L
s
.268 .595 .352 r
.82874 .66699 m
.82759 .66543 L
s
.921 .567 .212 r
.23929 .61039 m
.24155 .60931 L
s
.268 .595 .352 r
.82982 .66858 m
.82874 .66699 L
s
.156 .65 .561 r
.51382 .35256 m
.51391 .35251 L
s
.921 .567 .212 r
.23704 .61147 m
.23929 .61039 L
s
.268 .595 .352 r
.83082 .67018 m
.82982 .66858 L
s
.921 .567 .212 r
.23482 .61257 m
.23704 .61147 L
s
.268 .595 .352 r
.83174 .67182 m
.83082 .67018 L
s
.156 .65 .561 r
.51372 .35263 m
.51382 .35256 L
s
.268 .595 .352 r
.83258 .67347 m
.83174 .67182 L
s
.921 .567 .212 r
.23261 .61367 m
.23482 .61257 L
s
.268 .595 .352 r
.83333 .67515 m
.83258 .67347 L
s
.156 .65 .561 r
.51363 .35272 m
.51372 .35263 L
s
.268 .595 .352 r
.83401 .67686 m
.83333 .67515 L
s
.921 .567 .212 r
.23044 .61479 m
.23261 .61367 L
s
.268 .595 .352 r
.8346 .67859 m
.83401 .67686 L
s
.156 .65 .561 r
.51354 .35283 m
.51363 .35272 L
s
.921 .567 .212 r
.2283 .61592 m
.23044 .61479 L
s
.268 .595 .352 r
.83511 .68035 m
.8346 .67859 L
s
.83553 .68213 m
.83511 .68035 L
s
.921 .567 .212 r
.22619 .61706 m
.2283 .61592 L
s
.156 .65 .561 r
.51345 .35298 m
.51354 .35283 L
s
.268 .595 .352 r
.83587 .68394 m
.83553 .68213 L
s
.921 .567 .212 r
.22412 .61821 m
.22619 .61706 L
s
.268 .595 .352 r
.83612 .68578 m
.83587 .68394 L
s
.83628 .68764 m
.83612 .68578 L
s
.156 .65 .561 r
.51336 .35316 m
.51345 .35298 L
s
.921 .567 .212 r
.2221 .61939 m
.22412 .61821 L
s
.268 .595 .352 r
.83636 .68953 m
.83628 .68764 L
s
.83635 .69145 m
.83636 .68953 L
s
.921 .567 .212 r
.22013 .62058 m
.2221 .61939 L
s
.156 .65 .561 r
.51328 .35337 m
.51336 .35316 L
s
.268 .595 .352 r
.83626 .69339 m
.83635 .69145 L
s
.83608 .69536 m
.83626 .69339 L
s
.921 .567 .212 r
.2182 .62179 m
.22013 .62058 L
s
.268 .595 .352 r
.83582 .69736 m
.83608 .69536 L
s
.156 .65 .561 r
.51319 .35362 m
.51328 .35337 L
s
.268 .595 .352 r
.83547 .69938 m
.83582 .69736 L
s
.921 .567 .212 r
.21633 .62302 m
.2182 .62179 L
s
.268 .595 .352 r
.83504 .70143 m
.83547 .69938 L
s
.83453 .70351 m
.83504 .70143 L
s
.156 .65 .561 r
.51311 .35391 m
.51319 .35362 L
s
.921 .567 .212 r
.21452 .62428 m
.21633 .62302 L
s
.268 .595 .352 r
.83394 .70561 m
.83453 .70351 L
s
.83327 .70774 m
.83394 .70561 L
s
.921 .567 .212 r
.21277 .62556 m
.21452 .62428 L
s
.268 .595 .352 r
.83252 .70989 m
.83327 .70774 L
s
.156 .65 .561 r
.51303 .35424 m
.51311 .35391 L
s
.268 .595 .352 r
.83169 .71207 m
.83252 .70989 L
s
.921 .567 .212 r
.21108 .62686 m
.21277 .62556 L
s
.268 .595 .352 r
.8308 .71427 m
.83169 .71207 L
s
.82982 .7165 m
.8308 .71427 L
s
.156 .65 .561 r
.51295 .35462 m
.51303 .35424 L
s
.268 .595 .352 r
.82878 .71875 m
.82982 .7165 L
s
.921 .567 .212 r
.20946 .62819 m
.21108 .62686 L
s
.268 .595 .352 r
.82768 .72102 m
.82878 .71875 L
s
.8265 .72332 m
.82768 .72102 L
s
.921 .567 .212 r
.20791 .62954 m
.20946 .62819 L
s
.268 .595 .352 r
.82527 .72564 m
.8265 .72332 L
s
.156 .65 .561 r
.51288 .35505 m
.51295 .35462 L
s
.268 .595 .352 r
.82397 .72798 m
.82527 .72564 L
s
.82262 .73033 m
.82397 .72798 L
s
.921 .567 .212 r
.20643 .63092 m
.20791 .62954 L
s
.268 .595 .352 r
.82121 .73271 m
.82262 .73033 L
s
.156 .65 .561 r
.5128 .35553 m
.51288 .35505 L
s
.268 .595 .352 r
.81975 .73511 m
.82121 .73271 L
s
.81824 .73753 m
.81975 .73511 L
s
.921 .567 .212 r
.20502 .63233 m
.20643 .63092 L
s
.268 .595 .352 r
.81669 .73996 m
.81824 .73753 L
s
.8151 .74241 m
.81669 .73996 L
s
.81347 .74487 m
.8151 .74241 L
s
.156 .65 .561 r
.51273 .35607 m
.5128 .35553 L
s
.921 .567 .212 r
.2037 .63378 m
.20502 .63233 L
s
.268 .595 .352 r
.81181 .74735 m
.81347 .74487 L
s
.81011 .74984 m
.81181 .74735 L
s
.80839 .75234 m
.81011 .74984 L
s
.921 .567 .212 r
.20245 .63525 m
.2037 .63378 L
s
.268 .595 .352 r
.80664 .75486 m
.80839 .75234 L
s
.156 .65 .561 r
.51267 .35666 m
.51273 .35607 L
s
.268 .595 .352 r
.80488 .75738 m
.80664 .75486 L
s
.8031 .75991 m
.80488 .75738 L
s
.8013 .76245 m
.8031 .75991 L
s
.921 .567 .212 r
.20128 .63675 m
.20245 .63525 L
s
.268 .595 .352 r
.7995 .765 m
.8013 .76245 L
s
.79769 .76756 m
.7995 .765 L
s
.156 .65 .561 r
.5126 .35731 m
.51267 .35666 L
s
.268 .595 .352 r
.79589 .77011 m
.79769 .76756 L
s
.921 .567 .212 r
.2002 .63828 m
.20128 .63675 L
s
.268 .595 .352 r
.79408 .77268 m
.79589 .77011 L
s
.79228 .77524 m
.79408 .77268 L
s
.79049 .77781 m
.79228 .77524 L
s
.921 .567 .212 r
.1992 .63985 m
.2002 .63828 L
s
.156 .65 .561 r
.51254 .35802 m
.5126 .35731 L
s
.268 .595 .352 r
.78871 .78038 m
.79049 .77781 L
s
.78694 .78295 m
.78871 .78038 L
s
.78519 .78551 m
.78694 .78295 L
s
.921 .567 .212 r
.19829 .64145 m
.1992 .63985 L
s
.268 .595 .352 r
.78347 .78808 m
.78519 .78551 L
s
.156 .65 .561 r
.51249 .3588 m
.51254 .35802 L
s
.268 .595 .352 r
.78177 .79064 m
.78347 .78808 L
s
.78009 .7932 m
.78177 .79064 L
s
.921 .567 .212 r
.19747 .64309 m
.19829 .64145 L
s
.19674 .64476 m
.19747 .64309 L
s
.156 .65 .561 r
.51243 .35964 m
.51249 .3588 L
s
.921 .567 .212 r
.1961 .64646 m
.19674 .64476 L
s
.156 .65 .561 r
.51238 .36054 m
.51243 .35964 L
s
.921 .567 .212 r
.19555 .6482 m
.1961 .64646 L
s
.19509 .64997 m
.19555 .6482 L
s
.156 .65 .561 r
.51233 .36151 m
.51238 .36054 L
s
.921 .567 .212 r
.19472 .65179 m
.19509 .64997 L
s
.156 .65 .561 r
.51229 .36256 m
.51233 .36151 L
s
.921 .567 .212 r
.19445 .65363 m
.19472 .65179 L
s
.19427 .65552 m
.19445 .65363 L
s
.156 .65 .561 r
.51225 .36367 m
.51229 .36256 L
s
.921 .567 .212 r
.19418 .65744 m
.19427 .65552 L
s
.156 .65 .561 r
.51221 .36486 m
.51225 .36367 L
s
.921 .567 .212 r
.19419 .65939 m
.19418 .65744 L
s
.19429 .66139 m
.19419 .65939 L
s
.156 .65 .561 r
.51218 .36611 m
.51221 .36486 L
s
.921 .567 .212 r
.19448 .66342 m
.19429 .66139 L
s
.156 .65 .561 r
.51215 .36745 m
.51218 .36611 L
s
.921 .567 .212 r
.19476 .66548 m
.19448 .66342 L
s
.19513 .66758 m
.19476 .66548 L
s
.156 .65 .561 r
.51213 .36886 m
.51215 .36745 L
s
.921 .567 .212 r
.1956 .66972 m
.19513 .66758 L
s
.156 .65 .561 r
.51532 .54419 m
.51526 .54115 L
s
.51537 .5472 m
.51532 .54419 L
s
.51526 .54115 m
.51521 .53807 L
s
.51543 .55017 m
.51537 .5472 L
s
.921 .567 .212 r
.19615 .67189 m
.1956 .66972 L
s
.156 .65 .561 r
.51521 .53807 m
.51515 .53496 L
s
.51547 .55311 m
.51543 .55017 L
s
.51515 .53496 m
.51509 .53182 L
s
.51552 .55601 m
.51547 .55311 L
s
.51211 .37034 m
.51213 .36886 L
s
.51509 .53182 m
.51502 .52864 L
s
.51557 .55888 m
.51552 .55601 L
s
.51502 .52864 m
.51496 .52543 L
s
.51561 .56171 m
.51557 .55888 L
s
.51496 .52543 m
.51489 .52219 L
s
.51565 .5645 m
.51561 .56171 L
s
.921 .567 .212 r
.19679 .6741 m
.19615 .67189 L
s
.156 .65 .561 r
.51489 .52219 m
.51482 .51893 L
s
.51569 .56726 m
.51565 .5645 L
s
.51482 .51893 m
.51475 .51563 L
s
.51573 .56999 m
.51569 .56726 L
s
.51475 .51563 m
.51468 .51231 L
s
.51209 .3719 m
.51211 .37034 L
s
.921 .567 .212 r
.19751 .67634 m
.19679 .6741 L
s
.156 .65 .561 r
.51576 .57268 m
.51573 .56999 L
s
.51468 .51231 m
.5146 .50896 L
s
.5158 .57534 m
.51576 .57268 L
s
.5146 .50896 m
.51453 .50559 L
s
.921 .567 .212 r
.19832 .67861 m
.19751 .67634 L
s
.156 .65 .561 r
.51583 .57797 m
.5158 .57534 L
s
.51453 .50559 m
.51445 .5022 L
s
.51208 .37353 m
.51209 .3719 L
s
.51586 .58056 m
.51583 .57797 L
s
.51445 .5022 m
.51437 .49879 L
s
.921 .567 .212 r
.19921 .68092 m
.19832 .67861 L
s
.156 .65 .561 r
.51437 .49879 m
.5143 .49536 L
s
.51589 .58312 m
.51586 .58056 L
s
.921 .567 .212 r
.20018 .68326 m
.19921 .68092 L
s
.156 .65 .561 r
.5143 .49536 m
.51422 .49192 L
s
.51591 .58565 m
.51589 .58312 L
s
.51207 .37524 m
.51208 .37353 L
s
.921 .567 .212 r
.20123 .68563 m
.20018 .68326 L
s
.156 .65 .561 r
.51422 .49192 m
.51414 .48847 L
s
.51594 .58815 m
.51591 .58565 L
s
.51414 .48847 m
.51406 .485 L
s
.921 .567 .212 r
.20235 .68804 m
.20123 .68563 L
s
.156 .65 .561 r
.51596 .59061 m
.51594 .58815 L
s
.51207 .37703 m
.51207 .37524 L
s
.51406 .485 m
.51398 .48153 L
s
.921 .567 .212 r
.20355 .69047 m
.20235 .68804 L
s
.156 .65 .561 r
.51598 .59305 m
.51596 .59061 L
s
.51398 .48153 m
.51389 .47806 L
s
.921 .567 .212 r
.20482 .69293 m
.20355 .69047 L
s
.156 .65 .561 r
.51206 .3789 m
.51207 .37703 L
s
.51389 .47806 m
.51381 .47459 L
s
.516 .59546 m
.51598 .59305 L
s
.921 .567 .212 r
.20615 .69542 m
.20482 .69293 L
s
.156 .65 .561 r
.51381 .47459 m
.51373 .47112 L
s
.921 .567 .212 r
.20755 .69794 m
.20615 .69542 L
s
.156 .65 .561 r
.51601 .59784 m
.516 .59546 L
s
.51207 .38084 m
.51206 .3789 L
s
.51373 .47112 m
.51365 .46766 L
s
.921 .567 .212 r
.20901 .70049 m
.20755 .69794 L
s
.156 .65 .561 r
.51603 .6002 m
.51601 .59784 L
s
.921 .567 .212 r
.21053 .70305 m
.20901 .70049 L
s
.156 .65 .561 r
.51365 .46766 m
.51357 .4642 L
s
.51207 .38285 m
.51207 .38084 L
s
.921 .567 .212 r
.21211 .70565 m
.21053 .70305 L
s
.156 .65 .561 r
.51357 .4642 m
.51349 .46076 L
s
.51604 .60252 m
.51603 .6002 L
s
.921 .567 .212 r
.21373 .70826 m
.21211 .70565 L
s
.156 .65 .561 r
.51209 .38494 m
.51207 .38285 L
s
.51349 .46076 m
.51341 .45733 L
s
.921 .567 .212 r
.21541 .7109 m
.21373 .70826 L
s
.21712 .71356 m
.21541 .7109 L
s
.156 .65 .561 r
.51606 .60482 m
.51604 .60252 L
s
.51341 .45733 m
.51333 .45392 L
s
.5121 .38711 m
.51209 .38494 L
s
.921 .567 .212 r
.21888 .71623 m
.21712 .71356 L
s
.156 .65 .561 r
.51333 .45392 m
.51325 .45053 L
s
.921 .567 .212 r
.22068 .71892 m
.21888 .71623 L
s
.156 .65 .561 r
.51607 .60709 m
.51606 .60482 L
s
.51212 .38935 m
.5121 .38711 L
s
.921 .567 .212 r
.2225 .72163 m
.22068 .71892 L
s
.156 .65 .561 r
.51325 .45053 m
.51317 .44716 L
s
.921 .567 .212 r
.22436 .72436 m
.2225 .72163 L
s
.156 .65 .561 r
.51317 .44716 m
.5131 .44382 L
s
.921 .567 .212 r
.22624 .72709 m
.22436 .72436 L
s
.156 .65 .561 r
.51214 .39166 m
.51212 .38935 L
s
.51607 .60934 m
.51607 .60709 L
s
.921 .567 .212 r
.22814 .72984 m
.22624 .72709 L
s
.156 .65 .561 r
.5131 .44382 m
.51302 .44051 L
s
.921 .567 .212 r
.23006 .7326 m
.22814 .72984 L
s
.156 .65 .561 r
.51217 .39404 m
.51214 .39166 L
s
.51302 .44051 m
.51295 .43724 L
s
.921 .567 .212 r
.23199 .73536 m
.23006 .7326 L
s
.23393 .73814 m
.23199 .73536 L
s
.156 .65 .561 r
.5122 .3965 m
.51217 .39404 L
s
.51295 .43724 m
.51288 .434 L
s
.51608 .61156 m
.51607 .60934 L
s
.921 .567 .212 r
.23588 .74092 m
.23393 .73814 L
s
.156 .65 .561 r
.51288 .434 m
.51281 .43081 L
s
.51223 .39902 m
.5122 .3965 L
s
.921 .567 .212 r
.23782 .7437 m
.23588 .74092 L
s
.156 .65 .561 r
.51281 .43081 m
.51274 .42765 L
s
.51227 .40161 m
.51223 .39902 L
s
.921 .567 .212 r
.23977 .74649 m
.23782 .7437 L
s
.156 .65 .561 r
.51274 .42765 m
.51268 .42454 L
s
.921 .567 .212 r
.2417 .74928 m
.23977 .74649 L
s
.156 .65 .561 r
.51231 .40427 m
.51227 .40161 L
s
.51609 .61375 m
.51608 .61156 L
s
.51268 .42454 m
.51262 .42148 L
s
.51235 .40699 m
.51231 .40427 L
s
.921 .567 .212 r
.24363 .75207 m
.2417 .74928 L
s
.156 .65 .561 r
.51262 .42148 m
.51256 .41847 L
s
.5124 .40977 m
.51235 .40699 L
s
.51256 .41847 m
.5125 .41552 L
s
.51245 .41262 m
.5124 .40977 L
s
.5125 .41552 m
.51245 .41262 L
s
.921 .567 .212 r
.24554 .75485 m
.24363 .75207 L
s
.24744 .75764 m
.24554 .75485 L
s
.156 .65 .561 r
.51609 .61593 m
.51609 .61375 L
s
.921 .567 .212 r
.24932 .76042 m
.24744 .75764 L
s
.25117 .7632 m
.24932 .76042 L
s
.253 .76597 m
.25117 .7632 L
s
.156 .65 .561 r
.51609 .61807 m
.51609 .61593 L
s
.921 .567 .212 r
.2548 .76874 m
.253 .76597 L
s
.156 .65 .561 r
.51609 .6202 m
.51609 .61807 L
s
.51609 .6223 m
.51609 .6202 L
s
.51609 .62437 m
.51609 .6223 L
s
.51609 .62643 m
.51609 .62437 L
s
.51608 .62846 m
.51609 .62643 L
s
.51607 .63046 m
.51608 .62846 L
s
.51607 .63245 m
.51607 .63046 L
s
.51606 .63441 m
.51607 .63245 L
s
.51604 .63635 m
.51606 .63441 L
s
.51603 .63827 m
.51604 .63635 L
s
.51602 .64016 m
.51603 .63827 L
s
.516 .64204 m
.51602 .64016 L
s
.51598 .64389 m
.516 .64204 L
s
.51596 .64571 m
.51598 .64389 L
s
.51594 .64752 m
.51596 .64571 L
s
.51592 .6493 m
.51594 .64752 L
s
.5159 .65105 m
.51592 .6493 L
s
.51587 .65278 m
.5159 .65105 L
s
.51584 .65449 m
.51587 .65278 L
s
.51581 .65618 m
.51584 .65449 L
s
.51578 .65783 m
.51581 .65618 L
s
.51575 .65947 m
.51578 .65783 L
s
.51571 .66107 m
.51575 .65947 L
s
.51568 .66265 m
.51571 .66107 L
s
.51564 .66421 m
.51568 .66265 L
s
.5156 .66574 m
.51564 .66421 L
s
.51555 .66723 m
.5156 .66574 L
s
.51551 .66871 m
.51555 .66723 L
s
.51546 .67015 m
.51551 .66871 L
s
.51541 .67157 m
.51546 .67015 L
s
.51536 .67295 m
.51541 .67157 L
s
.51531 .67431 m
.51536 .67295 L
s
.51525 .67564 m
.51531 .67431 L
s
.5152 .67693 m
.51525 .67564 L
s
.51514 .6782 m
.5152 .67693 L
s
.51507 .67944 m
.51514 .6782 L
s
.51501 .68065 m
.51507 .67944 L
s
.51494 .68183 m
.51501 .68065 L
s
.51488 .68298 m
.51494 .68183 L
s
.5148 .6841 m
.51488 .68298 L
s
.51473 .68519 m
.5148 .6841 L
s
.51466 .68625 m
.51473 .68519 L
s
.51458 .68728 m
.51466 .68625 L
s
.5145 .68829 m
.51458 .68728 L
s
.51442 .68927 m
.5145 .68829 L
s
.51434 .69022 m
.51442 .68927 L
s
.51425 .69115 m
.51434 .69022 L
s
.51417 .69206 m
.51425 .69115 L
s
.51408 .69294 m
.51417 .69206 L
s
.51399 .6938 m
.51408 .69294 L
s
.5139 .69465 m
.51399 .6938 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.21948 .19046 m
.22433 .1959 L
s
[(-2)] .20979 .17958 .89071 1 Mshowa
.36215 .13047 m
.3667 .13617 L
s
[(0)] .35306 .11908 .79809 1 Mshowa
.5134 .06688 m
.5176 .07283 L
s
[(2)] .50499 .05497 .70547 1 Mshowa
.125 Mabswid
.11767 .23327 m
.1207 .23642 L
s
.15114 .2192 m
.15413 .22239 L
s
.18507 .20493 m
.18802 .20816 L
s
.25439 .17578 m
.25725 .17909 L
s
.28979 .1609 m
.29261 .16424 L
s
.32571 .14579 m
.32849 .14917 L
s
.39913 .11492 m
.40181 .11838 L
s
.43666 .09915 m
.43928 .10264 L
s
.47474 .08313 m
.47731 .08667 L
s
.55264 .05038 m
.5551 .05399 L
s
.59248 .03363 m
.59488 .03728 L
s
.63293 .01662 m
.63527 .02031 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.09942 .8737 m
.10033 .86647 L
s
[(-2)] .0976 .88816 .12588 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.3298 1.03583 m
.3302 1.02855 L
s
[(2)] .32899 1.05038 .05531 -1 Mshowa
.125 Mabswid
.13153 .8963 m
.13203 .89196 L
s
.1626 .91817 m
.16306 .91382 L
s
.19269 .93934 m
.19311 .93499 L
s
.25007 .97972 m
.25042 .97536 L
s
.27745 .99899 m
.27776 .99463 L
s
.30402 1.01769 m
.30429 1.01332 L
s
.06621 .85034 m
.06681 .846 L
s
.03186 .82616 m
.0325 .82183 L
s
.35483 1.05344 m
.35504 1.04907 L
s
.37914 1.07055 m
.37932 1.06618 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017a000`40O003h00Oogoo2Woo003oOol:
Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo002eOol2001BOol00;=oo`80
0003Ool00000055oo`00/Goo0P000goo0P00DGoo002^Ool30005Ool00`00Ool0001@Ool00:aoo`80
00Qoo`03001oo`00051oo`00ZWoo0P0000=oo`00Ool01goo00@007ooOol004moo`00R7oo10006goo
0`0037oo00D007ooOomoo`0004ioo`00R7oo00<007ooOol06Woo0P003goo00D007ooOomoo`0004io
o`00RGoo00<007ooOol05Woo0`004Goo00<007ooOol00Woo00<007ooOol0Bgoo002:Ool00`00Oomo
o`0COol3000COol00`00Oomoo`03Ool00`00Oomoo`1:Ool008Qoo`04001oogoo000BOol2000GOol0
0`00Oomoo`02Ool00`00Oomoo`1:Ool008Uoo`80011oo`<001Uoo`03001oogoo00=oo`03001oogoo
04Uoo`00VGoo0P0077oo00<007ooOol00goo00<007ooOol0BGoo002GOol2000NOol00`00Oomoo`04
Ool00`00Oomoo`18Ool009Aoo`<00003Ool007oo01eoo`03001oogoo00Eoo`03001oogoo04Moo`00
TWoo0P008goo00<007ooOol01Goo00<007ooOol0Agoo002@Ool2000UOol00`00Oomoo`06Ool00`00
Oomoo`16Ool008eoo`<002Moo`03001oogoo00Ioo`03001oogoo04Ioo`00Rgoo0P000Woo00<007oo
Ool09Goo00<007ooOol01goo00<007ooOol0AGoo0029Ool2000/Ool00`00Oomoo`08Ool00`00Oomo
o`14Ool008Ioo`<002ioo`03001oogoo00Qoo`03001oogoo04Aoo`00Q7oo0P00<Goo00<007ooOol0
2Goo00<007ooOol0@goo001ROol2000NOol200000goo001oo`0`Ool00`00Oomoo`0:Ool00`00Oomo
o`12Ool0065oo`04001oogoo000JOol3000;Ool00a9a4Y4>L00WOol00`00Oomoo`0:Ool00`00Oomo
o`12Ool0065oo`04001oogoo000HOol2000=Ool44Y4WOol00`00Oomoo`0;Ool00`00Oomoo`11Ool0
065oo`04001oogoo000EOol3000?Ool011:A3W0BTA9a9goo00<007ooOol02goo00<007ooOol0@Goo
001QOol01000Oomoo`004goo0P0000=oo`00Ool03goo11:A9goo00<007ooOol037oo00<007ooOol0
@7oo001ROol2000BOol2000DOol011:A4W4BT@i`9goo00<007ooOol03Goo00<007ooOol0?goo001c
Ool3000FOol44Y4XOol00`00Oomoo`0<Ool00`00Oomoo`0oOol0075oo`8001Uoo`044Y4>L1:A4W4X
Ool00`00Oomoo`0=Ool00`00Oomoo`0nOol006moo`800003Ool007oo01Qoo`@BTBQoo`03001oogoo
00eoo`03001oogoo03ioo`00K7oo0`007Woo00<BLA:A3W00:7oo00<007ooOol03Woo00<007ooOol0
?Goo001ZOol2000POol44Y4XOol00`00Oomoo`0?Ool00`00Oomoo`0lOol006Qoo`80029oo`044Y4>
L1:A4W4XOol00`00Oomoo`0?Ool00`00Oomoo`0lOol006Eoo`<00003Ool007oo025oo`@BTBQoo`03
001oogoo011oo`03001oogoo03]oo`00Hgoo0P00:7oo00<BLA:A3W00:7oo00<007ooOol04Goo00<0
07ooOol0>Woo001QOol2000YOol44Y4XOol00`00Oomoo`0AOol00`00Oomoo`0jOol003ioo`@001ao
o`<002]oo`044Y4>L1:A4W4XOol00`00Oomoo`0BOol00`00Oomoo`0iOol003ioo`03001oogoo01]o
o`8002ioo`@BTBQoo`03001oogoo019oo`03001oogoo03Uoo`00?goo00<007ooOol05goo0`00<Goo
00<BLA:A3W00:7oo00<007ooOol04goo00<007ooOol0>7oo000hOol40004Ool00`00Oomoo`0COol3
000dOol34Y4XOol00`00Oomoo`0DOol00`00Oomoo`0gOol003ioo`04001oogoo000COol3000dOol0
11:A3W0BTA9a:7oo00<007ooOol057oo00<007ooOol0=goo000oOol2000AOol3000gOol44Y4XOol0
0`00Oomoo`0EOol00`00Oomoo`0fOol0051oo`8003Yoo`044Y4BLA:A3W0XOol00`00Oomoo`0EOol0
0`00Oomoo`0fOol004eoo`<003eoo`<BTBQoo`03001oogoo01Ioo`03001oogoo03Eoo`00Bgoo1000
?Goo00DBT@i`4Y4BLA:A02Moo`03001oogoo01Moo`03001oogoo03Aoo`00BGoo0P00@Woo11:A:7oo
00<007ooOol05Woo00<007ooOol0=7oo0017Ool20014Ool0119a4Y4>L1:A:7oo00<007ooOol05goo
00<007ooOol0<goo0014Ool30016Ool44Y4XOol00`00Oomoo`0HOol00`00Oomoo`0bOol0049oo`80
0003Ool0000004Ioo`043W0BTA9a4Y4XOol00`00Oomoo`0HOol00`00Oomoo`0bOol0041oo`8004ao
o`<BTBQoo`03001oogoo01Uoo`03001oogoo035oo`00?7oo1000CGoo00@BLA:A3W0BTBQoo`03001o
ogoo01Uoo`03001oogoo035oo`00>goo0`00Cgoo11:A:7oo00<007ooOol06Woo00<007ooOol0<7oo
000iOol2001BOol010i`4Y4BLA:A:7oo00<007ooOol06goo00<007ooOol0;goo000fOol3001DOol4
4Y4XOol00`00Oomoo`0KOol00`00Oomoo`0_Ool003=oo`<005Moo`044W4BT@i`4Y4XOol00`00Oomo
o`0LOol00`00Oomoo`0^Ool0035oo`@005Qoo`@BTBQoo`03001oogoo01aoo`03001oogoo02ioo`00
;goo0P00G7oo00@>L1:A4W4BTBQoo`03001oogoo01eoo`03001oogoo02eoo`00:goo00@007oo0000
05ioo`@BTBQoo`03001oogoo01ioo`03001oogoo02aoo`00:Woo0`00H7oo00@BLA:A3W0BTBQoo`03
001oogoo01ioo`03001oogoo02aoo`00:7oo0P00Hgoo11:A:7oo00<007ooOol07goo00<007ooOol0
:goo000VOol2001UOol010i`4Y4BLA:A:7oo00<007ooOol087oo00<007ooOol0:Woo000SOol3001W
Ool44Y4XOol00`00Oomoo`0POol00`00Oomoo`0ZOol002Aoo`8006Moo`044W4BT@i`4Y4XOol00`00
Oomoo`0QOol00`00Oomoo`0YOol002Aoo`03001oo`0003Uoo`=b9P03MRIoogoo02Moo`@BTBQoo`03
001oogoo025oo`03001oogoo02Uoo`0097oo00@007ooOol003Qoo`04MRIb9GI6LRDYOol010i`4Y4B
LA:A:Goo00<007ooOol08Goo00<007ooOol0:7oo000SOol00`00Oomoo`02Ool00`00Oomoo`0dOol2
LRH00gHVLRIb9P0YOol44Y4YOol00`00Oomoo`0ROol00`00Oomoo`0WOol002=oo`03001oogoo00=o
o`03001oogoo03=oo`05LREfAW8UMRIb9@0YOol0119a4Y4>L1:A:Goo00<007ooOol08Woo00<007oo
Ool09goo000SOol20005Ool00`00Oomoo`0aOol00g8VMRIb9P02LRH00gHVOomoo`0WOol44Y4YOol0
0`00Oomoo`0SOol00`00Oomoo`0VOol002=oo`03001oogoo00Eoo`03001oogoo02ioo`07MRIb9GI6
LREf9W8UMTH0:Woo00@>L1:A4W4BTBUoo`03001oogoo02=oo`03001oogoo02Ioo`008goo00<007oo
Ool01Woo00<007ooOol0;7oo0W8V00Ef9W8VLRIb9WHV02]oo`@BTBUoo`05000RBQi:8TXNBP0ROol0
0`00Oomoo`0UOol002=oo`03001oogoo00Moo`03001oogoo02Uoo`08LREf9W8UMTIb9GHVLREfARao
o`044W4BT@i`4Y4YOol01P007TXRBai:8T/NBR9oo`03001oogoo02Aoo`008Woo00<007ooOol02Goo
00<007ooOol09Goo00=b9WHVLRH00W8V00Ef9W8VLRIb9WHV02eoo`@BTBUoo`06000RBQi:8TXNBR9:
8Woo00<007ooOol097oo000ROol00`00Oomoo`0:Ool00`00Oomoo`0POol037I6LREf9W8UMTIb9GHV
LREfAW8UMRIb9Bmoo`043W0BTA9a4Y4YOol01`00OolRBai:8T/NBR9;029oo`03001oogoo02=oo`00
8Woo00<007ooOol02goo00<007ooOol06goo0g8V00Ef9W8VLRIb9WHV00=b9P03MRIb9W8V035oo`@B
TBUoo`08001ooai:8TXNBR9:7TXRBR9oo`03001oogoo029oo`008Goo0P003Woo00<007ooOol05goo
00ib9GI6LREf9W8UMTIb9GHVLREfAW8UMRIb9GI6=7oo00@BLA:A3W0BTBUoo`09001oogoo7TXRBai:
8T/NBR9;025oo`03001oogoo029oo`008Woo00<007ooOol03Goo00<007ooOol04goo0g8V00Ef9W8V
LRIb9WHV00=b9P03MRIb9Woo03Moo`@BTBUoo`0:001oogooOolNBR9:7TXRBQi:8TXQOol00`00Oomo
o`0QOol0029oo`03001oogoo00ioo`03001oogoo011oo`0;MTIb9GHVLREfAW8UMRIb9GI6LREf9P0l
Ool010i`4Y4BLA:A:Goo00<007ooOol00Woo00LNBR9;7TXRBai:8T/NBP0OOol00`00Oomoo`0QOol0
025oo`03001oogoo011oo`03001oogoo00ioo`05MRIb9W8VLRIf9P03LRH00gHVOomoo`0mOol44Y4Y
Ool00`00Oomoo`03Ool021i:8TXNBR9:7TXRBQi:8TXNOol00`00Oomoo`0POol0025oo`03001oogoo
015oo`03001oogoo00aoo`07MTIb9GHVLREfAW8UMRH0@Woo00@BLA:A3W0BTBUoo`03001oogoo00Ao
o`097TXRBai:8T/NBR9;7TXRBai:01eoo`03001oogoo01moo`008Goo00<007ooOol04Woo00<007oo
Ool02Woo00If9W8VLRIb9WHVLRI4Ool44Y4YOol00`00Oomoo`05Ool02Qi:8TXNBR9:7TXRBQi:8TXN
BR9:6goo00<007ooOol07goo000QOol2000DOol00`00Oomoo`09Ool01G8UMRIb9GI6LRD0AGoo00@>
L1:A4W4BTBUoo`03001oogoo00Qoo`0:7TXRBai:8T/NBR9;7TXRBai:8T/IOol00`00Oomoo`0NOol0
021oo`8001Ioo`03001oogoo00Qoo`9b9P03MRIb9W8V04Eoo`@BTBUoo`03001oogoo00Yoo`0:8TXN
BR9:7TXRBQi:8TXNBR9:7TXGOol00`00Oomoo`0NOol000aoo`D0009oo`8000Aoo`8000Ioo`03001o
ogoo01Eoo`03001oogoo00Moo`04LREfAW8UMRI6Ool0119a4Y4>L1:A:Woo00<007ooOol02goo00XN
BR9;7TXRBai:8T/NBR9;7TXRBaIoo`03001oogoo01eoo`003Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0EOol00`00Oomoo`07Ool017HVLRIb9W8VAWoo11:A
:Woo00<007ooOol03Woo00XNBR9:7TXRBQi:8TXNBR9:7TXRBQAoo`03001oogoo01aoo`003Woo00<0
07ooOol017oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00Ioo`04
LREf9W8UMTI6Ool010i`4Y4BLA:A:Woo00<007ooOol047oo00TRBai:8T/NBR9;7TXRBai:8T/04goo
00<007ooOol077oo0006Ool40004Ool00`00Oomoo`02Ool20003Ool01000Oomoo`0017oo00<007oo
Ool067oo00<007ooOol01Goo0W8V00=f9W8VLRH0AGoo11:A:Woo00<007ooOol04Woo00PNBR9:7TXR
BQi:8TXNBR9:4goo00<007ooOol06goo000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol06Goo00<007ooOol017oo00Eb9GI6LREf9W8U04Aoo`054Y4BLA:A3W0BT@0Z
Ool00`00Oomoo`0DOol01b9;7TXRBai:8T/NBR9;01=oo`03001oogoo01Yoo`003Goo0P0017oo0`00
0goo0P0017oo0P0077oo00<007ooOol017oo0g8V00=f9W8VOol0@Woo1A:A:Woo00<007ooOol05Woo
00HNBR9:7TXRBQi:8TXBOol00`00Oomoo`0JOol0021oo`03001oogoo01]oo`03001oogoo00=oo`05
MRIb9GI6LREf9P13Ool01A:A3W0BTA9a4Y40:Woo00<007ooOol05goo00DNBR9;7TXRBai:01=oo`03
001oogoo01Uoo`0087oo00<007ooOol077oo00<007ooOol00goo00Ef9W8VLRIb9WHV049oo`@BTB]o
o`03001oogoo01Qoo`057TXRBQi:8TXNBP0BOol00`00Oomoo`0IOol001moo`03001oogoo01ioo`03
001oogoo009oo`05LREf9W8UMTIb9@12Ool011:A4W4BT@i`:goo00<007ooOol067oo00DRBai:8T/N
BR9;01=oo`03001oogoo01Qoo`007goo00<007ooOol07goo00<007ooOol00Woo00=b9WHVLRH00W8V
@Goo11:A:goo00<007ooOol06Goo00@RBQi:8TXNBQAoo`03001oogoo01Moo`007goo00<007ooOol0
87oo00X007ooOomoogI6LREf9W8UMTIb9D1oo`044Y4>L1:A4W4[Ool00`00Oomoo`0HOol01B9;7TXR
Bai:8T/057oo00<007ooOol05goo000OOol00`00Oomoo`0QOol01000Oomoogoo0W8V00=f9W8VLRH0
@7oo11:A:goo00<007ooOol067oo00DNBR9:7TXRBQi:01Eoo`03001oogoo01Ioo`007Woo0P0097oo
00T007ooOomoogI6LREf9W8UMTH0?goo00@BTA9a4Y4>L2]oo`03001oogoo01Qoo`048T/NBR9;7TXF
Ool00`00Oomoo`0FOol001moo`03001oogoo02=oo`04001oogooOol2LRH00gHVLRIb9P0nOol44Y4[
Ool00`00Oomoo`0GOol01B9:7TXRBQi:8TX05goo00<007ooOol05Goo000NOol00`00Oomoo`0UOol0
2@00Oomoog8UMTIb9GHVLREfAP0mOol011:A3W0BTA9a:goo00<007ooOol05goo00DNBR9;7TXRBai:
01Qoo`03001oogoo01Aoo`007Woo00<007ooOol09Woo00<007ooOol00g8V00=f9W8VLRH0?7oo11:A
:goo00<007ooOol05Woo00HNBR9:7TXRBQi:8TXHOol00`00Oomoo`0DOol001ioo`03001oogoo02Mo
o`08001oogooOomfAW8UMRIb9Caoo`044Y4BLA:A3W0[Ool00`00Oomoo`0FOol01B9;7TXRBai:8T/0
6Woo00<007ooOol04goo000NOol00`00Oomoo`0XOol00`00Oomoo`03LRH00gHVLRIoo`0jOol44Y4[
Ool00`00Oomoo`0EOol01B9:7TXRBQi:8TX077oo00<007ooOol04Woo000NOol00`00Oomoo`0YOol0
2000Oomoog8UMTIb9GHVLRDjOol011:A3W0BTA9a:goo00<007ooOol05Goo00DNBR9;7TXRBai:01ao
o`03001oogoo019oo`007Goo0P00;7oo00<007ooMRH00g8V00=f9W8VOol0>7oo11:A;7oo00<007oo
Ool04goo00DNBR9:7TXRBQi:01ioo`03001oogoo015oo`007Woo00<007ooOol0:goo00P007ooOomb
9GI6LREf9W8U>7oo00@BTA9a4Y4>L2aoo`03001oogoo019oo`057TXRBai:8T/NBP0OOol00`00Oomo
o`0AOol001eoo`03001oogoo02eoo`03001oogHV00=b9P03MRIoogoo03Ioo`@BTBaoo`03001oogoo
015oo`067TXRBQi:8TXNBR9:7goo0P004Woo000MOol00`00Oomoo`0^Ool01`00Oomf9W8UMTIb9GHV
03Moo`044Y4>L1:A4W4/Ool00`00Oomoo`0@Ool01Qi:8T/NBR9;7TXRBaeoo`<00003Ool007oo015o
o`007Goo00<007ooOol0;goo00<007ooMRH00g8V=goo11:A;7oo00<007ooOol047oo00DRBQi:8TXN
BR9:01]oo`<000Aoo`03001oogoo011oo`007Goo00<007ooOol0<7oo00H0078UMRIb9GI6LRDfOol0
11:A4W4BT@i`;7oo00<007ooOol03goo00DRBai:8T/NBR9;01Uoo`<000Moo`03001oogoo011oo`00
7Goo00<007ooOol0<Goo00<0078VMRH00g8V=Woo0a:A;7oo00<007ooOol03Woo00HRBQi:8TXNBR9:
7TXFOol3000;Ool00`00Oomoo`0?Ool001aoo`8003Aoo`06MTIb9GHVLREfAW8U=7oo00@BT@i`4Y4B
LBaoo`03001oogoo00eoo`068T/NBR9;7TXRBai:57oo0`003Woo00<007ooOol03goo000LOol00`00
Oomoo`0cOol223D0178VMRIb9W8V=7oo11:A;7oo00<007ooOol03Goo00DNBR9:7TXRBQi:019oo`<0
015oo`03001oogoo00moo`0077oo00<007ooOol0<goo00P8=@PdMTIb9GHVLREfAPPd<Woo00@BTA9a
4Y4>L2aoo`03001oogoo00aoo`057TXRBai:8T/NBP0@Ool3000DOol00`00Oomoo`0?Ool001aoo`03
001oogoo03Aoo`0523Eb9W8VLRIf9P02LRH00`PeOomoo`0`Ool34Y4/Ool00`00Oomoo`0;Ool01Ai:
8TXNBR9:7TX03Woo0`005goo00<007ooOol03goo000LOol00`00Oomoo`0fOol020PdMTIb9GHVLRD<
=@Pd23D`Ool00`i`4Y4BL@0/Ool00`00Oomoo`0:Ool01Qi:8T/NBR9;7TXRB`]oo`<001Yoo`03001o
ogoo00moo`0077oo00<007ooOol0=goo0g8V00=f9W8V23D00`Pe;Goo11:A;7oo00<007ooOol02Woo
00DRBQi:8TXNBR9:00Uoo`<001eoo`03001oogoo00moo`0077oo00<007ooOol0=goo00Yf9W8UMTIb
9GHV23@<=@Pd23D8=2aoo`044Y4BLA:A3W0/Ool00`00Oomoo`09Ool02b9;7TXRBai:8T]ooaAb454D
LQ1aOol0100087oo00<007ooOol03goo000KOol3000iOol01GHVLRIb9W8VMRH01PPe:Woo11:A;7oo
00<007ooOol027oo00HRBQi:8TXNBR9:Ool357800a1b5780000UOol00`00Oomoo`0>Ool001]oo`03
001oogoo03Uoo`0<LREf9W8UMTIb9@Pe23@<=@Pd23D8=0`e:Woo00<>L1:A4W40;7oo00<007ooOol0
1goo00`RBai:8T/NBR9;7TXDLQ1A578@LAAb454VOol00`00Oomoo`0>Ool000Moo`D0009oo`8000Ao
o`8000Eoo`03001oogoo03Yoo`03LRIf9W8V009b9PL8=BUoo`<BTBaoo`03001oogoo00Moo`057TXR
BQi:8TXNBP0357800a1b578DLP0WOol00`00Oomoo`0>Ool000Uoo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00Woo00<007ooOol0>Woo00efAW8UMRIb9GI6Ool8=@Pd33D8=0Pe23@<
=@0XOol00a9a4Y4>L00/Ool00`00Oomoo`07Ool02R9;7TXRBai:578@DAAb474DLQ1A:7oo00<007oo
Ool03Woo0009Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo
03]oo`9b9P03MRIb9W8V009oo`H8=BIoo`@BT@=J^003F]Uoogoo02Moo`03001oogoo00Aoo`06000R
BQi:8TXNBR9:0QAb00<@LQAb5780:Goo00<007ooOol03Woo00000goo000000020004Ool01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo03aoo`05MTIb9GHVLRD00002
Ool01@Pd33D8=0Pe23@09Woo00PBT@i`4Y4BLE[IE[QJfEJh:Goo00l007ooOomoo`00578@LB9;7TXR
Bai:8T/@DAAb4740;7oo00<007ooOol03Woo0009Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo009oo`03001oogoo03aoo`=b9P04MRIoo`00Ool623DUOol44Y400eZhF]UJ^002F[PX
Ool400002AAb478RBQi:8TXNBR9:7TXDLP0^Ool00`00Oomoo`0>Ool000Qoo`8000Aoo`8000Aoo`80
00Aoo`8003ioo`0=MRIb9GI6LREf9Woo001oo`Pe23@<=@Pd23D09Woo00PBLA:A3W1JfEJhF]UF^5[I
9Woo0`0000Yooa1A578@LAAb7TXRBai:8T/NBS5oo`03001oogoo00eoo`006Woo00<007ooOol0?Goo
00=b9WHVLRH00W8V0Woo00<007oo23D00`Pe9Woo0a:A00EooeZhF[QJfEZh02=oo`<0009oo`0:000D
LQAb478DLQi:8TXNBR9:7TXbOol00`00Oomoo`0=Ool001Yoo`03001oogoo03ioo`04LREf9W8UMTH3
Ool01P0023@8=@Pd33D8=2Eoo`083W0BTA9aOomF^5[IE[QJfB1oo`<000Eoo`0:000DLQ1a578@DB9;
7TXRBai:8T/bOol00`00Oomoo`0=Ool001Yoo`03001oogoo03ioo`9b9P03MRIb9Woo009oo`030008
=@Pe00<8=BAoo`@BT@03OomJfEZh009J^1eoo`<000Qoo`09000@LQAb578RBQi:8TXNBR9:03=oo`03
001oogoo00eoo`006Woo00<007ooOol0?Woo00Ab9GI6LREf9PAoo`05000<=@Pd23D8=00TOol02A:A
4W4BT@i`OomF^5[IE[QJf@0JOol3000:Ool02QAb000DLQ1A578NBR9;7TXRBai:<goo00<007ooOol0
3Goo000JOol00`00Oomoo`0nOol017HVLRIb9W8V1Goo10Pe97oo11:A00EooeZhF[QJfEZh01Moo`<0
00eoo`09478001Ab578@LR9:7TXRBQi:03Aoo`03001oogoo00eoo`006Goo00<007ooOol0?goo00Ab
9GHVLREfAPEoo`0423D8=0`e23@UOol020i`4Y4BLGooE[QJfEJhF]TDOol3000@Ool02AAb000DLQ1a
578NBR9;7TXRB`0dOol00`00Oomoo`0=Ool001Uoo`03001oogoo03moo`9b9P03MRIb9Woo00Aoo`@8
=BEoo`<BT@03OomJfEZh009J^15oo`<0019oo`8DLP08000@LQAb7TXRBQi:8TXNBSEoo`03001oogoo
00aoo`006Goo0P00@7oo00Ab9GI6LREf9PEoo`0433D8=0Pe23@TOol02A:A4W4BT@i`OomF^5[IE[QJ
f@0>Ool3000EOol02Q1A578001Ab454RBai:8T/NBR9;=Goo00<007ooOol037oo000IOol00`00Oomo
o`0oOol017HVLRIb9W8V1Goo10Pe00<007ooOol08Goo11:A00EooeZhF[QJfEZh00]oo`<001Qoo`09
578@LP00579ooai:8TXNBR9:03Ioo`03001oogoo00aoo`006Goo00<007ooOol0?goo00Ab9GHVLREf
APEoo`0623D8=0`e23Aoo`008Woo00TBT@i`4Y4BLGooE[QJfEJhF]T027oo0`006goo00T@LAAb000D
LWoo8T/NBR9;7TX0=Woo00<007ooOol037oo000IOol00`00Oomoo`0oOol2LRH00gHVLRIoo`03Ool5
23D2Ool00`00Oomoo`0POol34Y400gooF]UJ^002F[P5Ool3000NOol257801`00479ooai:8TXNBR9:
03Ioo`03001oogoo00aoo`0067oo00<007ooOol0@7oo00Ab9GI6LREf9PAoo`0523@<=@Pd23D8=003
Ool00`00Oomoo`0NOol02A:A4W4BT@i`OomF^5[IE[QJf@02Ool3000QOol02A1A578001AbOolRBai:
8T/NBP0fOol00`00Oomoo`0<Ool001Qoo`03001oogoo041oo`04MRIb9W8VLRH4Ool423D5Ool00`00
Oomoo`0MOol54Y42F[P015[IF[P0000097oo00TDLQ1b000DLWoo7TXRBQi:8TX0=Woo00<007ooOol0
37oo000HOol00`00Oomoo`0oOol01GI6LREf9W8UMTH017oo00@8=0Pe23@<=@Ioo`03001oogoo01ao
o`094Y4>L1:A4W4BTEJhF]UF^5[I02Ioo`09474DLP00579oob9;7TXRBai:03Ioo`03001oogoo00ao
o`0067oo00<007ooOol0?goo0g8V00=f9W8VOol00Woo1@Pe1goo00<007ooOol077oo11:A00AJfEZh
F[QJ^2Ioo`<DLP06000DLQi:8TXNBR9:=goo00<007ooOol02goo000GOol20010Ool01G8UMRIb9GI6
LRD017oo00D8=@Pd33D8=0Pe00Qoo`03001oogoo01Qoo`<000084W4BT@i`4Y5F^5[IE[QJfBIoo`09
454DLQ1a000@DB9;7TXRBai:03Moo`03001oogoo00]oo`0067oo00<007ooOol0?Woo0W8V00=f9W8V
LRH00goo1@Pe2Woo00<007ooOol057oo0`000goo11:A0UZh00=JfEZhOol09Woo00P@LQAb000DLQi:
8TXNBR9:=goo00<007ooOol02goo000GOol00`00Oomoo`0nOol01WHVLREfAW8UMRIb9@=oo`0523@<
=@Pd23D8=00;Ool00`00Oomoo`0@Ool30006Ool020i`4Y4BLA:AE[QJfEJhF]TWOol021Ab4540011a
8T/NBR9;7TXgOol00`00Oomoo`0;Ool001Moo`03001oogoo03eoo`9b9P04MRIb9W8VLRH3Ool523D=
Ool00`00Oomoo`0<Ool30009Ool44Y4015[IF[QJ^5Zh9goo0QAb00L001Ab7TXRBQi:8TXNBP0fOol0
0`00Oomoo`0;Ool001Moo`03001oogoo03aoo`06MRIb9GI6LREf9W8U17oo00D<=@Pd23D8=0`e00io
o`03001oogoo00Qoo`<000aoo`084W4BT@i`4Y5F^5[IE[QJfBMoo`09578@L@00454RBai:8T/NBR9;
03Ioo`03001oogoo00]oo`005goo00<007ooOol0>goo0W8V00Ef9W8VLRIb9WHV00=oo`D8=A1oo`03
001oogoo00Aoo`<000moo`@BT@9J^003F]UJ^7oo02Moo`09578001Ab478RBQi:8TXNBR9:03Eoo`03
001oogoo00]oo`005goo00<007ooOol0>Woo00Mf9W8UMTIb9GHVLREfAP04Ool01@Pd23D8=0`e23@0
4Goo00<007ooOol00`004Woo00P>L1:A4W4BTEJhF]UF^5[I:7oo00T@D@00474DLQi:8T/NBR9;7TX0
=Woo00<007ooOol02Woo000FOol2000kOol2LRH01GHVLRIb9W8VMRH017oo1@Pe4goo0P005Goo11:A
00AJfEZhF[QJ^2Qoo`03578001Ab008DLP057TXRBQi:8TXNBP0eOol00`00Oomoo`0:Ool001Moo`03
001oogoo03Moo`07LREf9W8UMTIb9GHVLRD01Goo00H8=0Pe23@<=@Pd23DCOol00`00Oomoo`0DOol0
219a4Y4>L1:AE[QJfEJhF]TXOol20000211A578@LB9;7TXRBai:8T/eOol00`00Oomoo`0:Ool001Io
o`03001oogoo03Ioo`05MRIb9W8VLRIf9P03LRH6Ool523DDOol00`00Oomoo`0DOol44Y42F[P00e[I
F[Qoo`0TOol3000017oo5780011b0QAb00DRBQi:8TXNBR9:03Aoo`03001oogoo00Yoo`005Woo00<0
07ooOol0=7oo00Ub9GI6LREf9W8UMTIb9GHVLRD01Woo00D8=@Pd33D8=0Pe01Eoo`03001oogoo01Ao
o`083W0BTA9a4Y5F^5[IE[QJfB5oo`@000Eoo`0:4740011A578NBR9;7TXRBai:8T/cOol00`00Oomo
o`0:Ool001Ioo`03001oogoo039oo`9b9P05MRIb9W8VLRIf9P02LRH7Ool623DEOol00`00Oomoo`0D
Ool44Y4015[IF[QJ^5Zh7Woo0`002Goo00/DLP00578@LQAb7TXRBQi:8TXNBR9:039oo`03001oogoo
00Yoo`005Woo00<007ooOol0<7oo00Ub9GHVLREfAW8UMRIb9GI6LRD027oo00H8=@Pd33D8=0Pe23@F
Ool00`00Oomoo`0DOol0219a4Y4>L1:AE[QJfEJhF]TKOol3000=Ool02aAb000DLQ1A578NBR9;7TXR
Bai:8T/0<Goo00<007ooOol02Woo000FOol00`00Oomoo`0^Ool01GHVLRIb9W8VMRH00g8V00=f9Woo
Ool027oo1@Pe5goo00<007ooOol057oo11:A0UZh00=JfEZhOol05goo0`004Goo00/DLP00578@LQAb
7TXRBQi:8TXNBR9:031oo`03001oogoo00Yoo`005Woo00<007ooOol0;7oo00Ub9GI6LREf9W8UMTIb
9GHVLRD02goo00D8=0`e23@8=@Pd01Qoo`03001oogoo01Aoo`083W0BTA9a4Y5F^5[IE[QJfAAoo`@0
01Aoo`0<454DLP00578@DGoo7TXRBai:8T/NBR9;<7oo00<007ooOol02Goo000EOol3000[Ool2LRH0
1GHVLRIb9W8VMRH00W8V37oo1PPe67oo00<007ooOol057oo11:A00AJfEZhF[QJ^15oo`<001Uoo`0=
478DLP00578@LWoo7TXRBQi:8TXNBR9:7TX0;Woo00<007ooOol02Goo000EOol00`00Oomoo`0ZOol0
27HVLREfAW8UMRIb9GI6LRD=Ool01PPd33D8=0Pe23@<=AUoo`03001oogoo01Aoo`084W4BT@i`4Y5F
^5[IE[QJf@ioo`<001aoo`0?578@DAAb000DLQ1AOolNBR9;7TXRBai:8T/NBR9;02aoo`03001oogoo
00Uoo`0027oo0P0017oo0P001Goo00<007ooOol0:7oo0g8V00Ef9W8VLRIb9WHV00moo`D8=AYoo`03
001oogoo01Aoo`@BT@9J^003F]UJ^7oo00Yoo`<0021oo`03578@LP00008DLP0:479ooai:8TXNBR9:
7TXRBQi:8TX[Ool00`00Oomoo`09Ool000Moo`04001oogoo0002Ool01000Oomoo`0017oo00<007oo
Ool09goo00Mb9GHVLREfAW8UMRIb9@0@Ool01@`e23@8=@Pd33D06goo00<007ooOol057oo00P>L1:A
4W4BTEJhF]UF^5[I1goo100097oo00DDLQ1A000@LAAb00=oo`088T/NBR9;7TXRBai:8T/NBRUoo`03
001oogoo00Uoo`002Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo02Ioo`=b9P04MRIb
9W8VLRH@Ool623DKOol00`00Oomoo`0DOol44Y4015[IF[QJ^5Zh17oo0`00:Goo00<DLQ1b00000QAb
17oo00LNBR9:7TXRBQi:8TXNBP0XOol00`00Oomoo`09Ool00003Ool00000008000=oo`8000=oo`04
001oogoo0004Ool00`00Oomoo`0VOol01WHVLREfAW8UMRIb9A5oo`0523@8=@Pd33D8=00LOol00`00
Oomoo`0DOol02A9a4Y4>L1:AE[QJfEJhF]Uoo`03000]Ool01AAb4540011a578017oo00PNBR9;7TXR
Bai:8T/NBR9;9Woo00<007ooOol02Goo0008Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo
Ool09Woo0W8V00=f9W8VLRH04Woo1@Pe7Goo00<007ooOol057oo11:A0UZh0`00<7oo0QAb00@@LP00
578DLPEoo`078TXNBR9:7TXRBQi:8TX09Woo00<007ooOol027oo0008Ool30003Ool20004Ool00`00
Oomoo`0VOol01G8UMTIb9GHVLRD04Goo00D8=0Pe23@<=@Pd01ioo`03001oogoo01Aoo`033W0BT@00
00<00003E[QJfGoo035oo`05474DLQ1A000@L@06Ool0229;7TXRBai:8T/NBR9;7TXTOol00`00Oomo
o`08Ool001Aoo`8002Ioo`03LRIf9W8V009b9Q5oo`H8=Aeoo`03001oogoo01Aoo`<0008BT@04F]UJ
^5ZhF[PcOol257800`00578DLP07Ool01ai:8TXNBR9:7TXRBQi:02=oo`03001oogoo00Qoo`0057oo
00<007ooOol09Goo00EfAW8UMRIb9GI6011oo`0623@8=@Pd33D8=0Pe7Woo00<007ooOol04Goo0`00
00Uooa9a4Y4>L1:AE[QJfEJhF]T0=7oo00D@LAAb000DLQ1a00Moo`087TXRBai:8T/NBR9;7TXRBb5o
o`03001oogoo00Qoo`0057oo00<007ooOol09Goo0g8V00=f9WooOol03Woo1PPe7goo00<007ooOol0
3Goo100017oo11:A0UZh00=JfEZhOol0<goo0aAb00<001Ab578027oo00LRBQi:8TXNBR9:7TXRBP0P
Ool00`00Oomoo`08Ool001Aoo`03001oogoo02Eoo`04MRIb9GI6LRD@Ool01@Pe23@<=@Pd23D087oo
00<007ooOol02Woo0`0027oo00P>L1:A4W4BTEJhF]UF^5[I=Goo00DDLQ1a578001Ab00Uoo`068T/N
BR9;7TXRBai:87oo00<007ooOol027oo000DOol00`00Oomoo`0UOol0178VMRIb9W8V3goo1@Pe8Goo
00<007ooOol01goo0`002goo11:A00AJfEZhF[QJ^3Ioo`<DLP03000DLWoo00Qoo`068TXNBR9:7TXR
BQi:7goo00<007ooOol027oo000COol00`00Oomoo`0VOol01GI6LREf9W8UMTH03Goo00H8=@Pd33D8
=0Pe23@QOol00`00Oomoo`04Ool3000>Ool0219a4Y4>L1:AE[QJfEJhF]TgOol01AAb4740011A5780
2Goo00HRBai:8T/NBR9;7TXOOol00`00Oomoo`07Ool001=oo`03001oogoo02Ioo`=b9P03MRIb9Woo
00aoo`D8=B9oo`03001oogoo00@0011oo`DBT@9J^003F]UJ^7oo03Ioo`06478DLQAb000@LQAb2Goo
00DRBQi:8TXNBR9:01moo`03001oogoo00Moo`004goo00<007ooOol09goo00Ab9GI6LREf9Paoo`05
23@<=@Pd23D8=00SOol3000DOol02A:A3W0BTA9a4Y5F^5[IE[QJf@0hOol01A1A578@L@0045402Woo
00DRBai:8T/NBR9;01ioo`03001oogoo00Moo`004goo00<007ooOol09goo00Ef9W8VLRIb9WHV00]o
o`D8=B1oo`@001Ioo`DBT@04F]UJ^5ZhF[PiOol01A1b578DLP0047802Goo00DNBR9:7TXRBQi:01io
o`03001oogoo00Moo`004Woo0P00:Woo00Af9W8UMTIb9@Yoo`0533D8=0Pe23@<=@0NOol30003Ool0
0`00Oomoo`0DOol02A:A4W4BT@i`OomF^5[IE[QJf@0iOol01QAb454DLQ1a000@D@Uoo`047TXRBai:
8T/NOol00`00Oomoo`07Ool001=oo`03001oogoo02Qoo`04LRIf9W8VLRH:Ool523DJOol40006Ool0
0`00Oomoo`0DOol44Y401GooF[QJ^5[IF[P0>Woo00DDLQ1b578DLP0000Uoo`048TXNBR9:7TXNOol0
0`00Oomoo`07Ool0019oo`03001oogoo02Uoo`05MTIb9GHVLREfAP09Ool010Pe23@<=@Pd67oo0`00
2Woo00<007ooOol057oo00TBT@i`4Y4BLGooE[QJfEJhF]T0>goo00DDLQ1A578001Ab00Qoo`047TXR
Bai:8T/NOol00`00Oomoo`07Ool0019oo`03001oogoo02Yoo`9b9P03MRIb9W8V00Qoo`@8=AEoo`<0
00eoo`03001oogoo01Aoo`@BT@03OomJfEZh009J^3]oo`8DLP04478DLP005787Ool0129:7TXRBQi:
7Woo00<007ooOol01goo000BOol00`00Oomoo`0ZOol01G8UMTIb9GHVLRD027oo00@<=@Pd23D8=19o
o`<0011oo`03001oogoo01Aoo`094Y4BLA:A3W1ooeJhF]UF^5[I03aoo`05474DLQ1A57800007Ool0
11i:8T/NBR9;7goo00<007ooOol01Woo000BOol00`00Oomoo`0[Ool3LRH00gHVLRIoo`06Ool423D>
Ool4000COol00`00Oomoo`0IOol2F[P00e[IF[Qoo`0kOol357800a1b57800005Ool01Ai:8TXNBR9:
7TX07goo00<007ooOol01Woo000BOol00`00Oomoo`0/Ool0178UMTIb9GHV1goo00@8=@Pd33D8=0]o
o`<001Moo`03001oogoo01Uoo`04E[QJfEJhF]TmOol01QAb474DLQ1A578000Aoo`058T/NBR9;7TXR
B`0OOol00`00Oomoo`06Ool0019oo`03001oogoo02aoo`05MRIb9W8VLRIf9P06Ool523D7Ool3000J
Ool00`00Oomoo`0IOol015[IF[QJ^5Zh?Goo00H@LQAb578DLQ1b0003Ool01B9:7TXRBQi:8TX087oo
00<007ooOol01Woo000AOol2000_Ool01GHVLREfAW8UMRH01Goo00H<=@Pd23D8=0`e23@3Ool3000M
Ool00`00Oomoo`0IOol015JhF]UF^5[I?Woo00H@DAAb474DLWoo0002Ool01Ai:8T/NBR9;7TX087oo
00<007ooOol01Woo000AOol00`00Oomoo`0^Ool00g8VMRIb9P02LRH00gHVOomoo`03Ool423D4000P
Ool00`00Oomoo`0IOol2F[P00e[IF[Qoo`0mOol011Ab478DLQAb0Woo00H007oo8TXNBR9:7TXQOol0
0`00Oomoo`06Ool0015oo`03001oogoo031oo`04MRIb9GI6LRD5Ool01`Pd0000000023@<=@Pd025o
o`03001oogoo01Uoo`04E[QJfEJhF]TnOol0111a578@DAAb0goo00D001i:8T/NBR9;025oo`03001o
ogoo00Ioo`004Goo00<007ooOol0<7oo00=b9WHVLRH00W8V0Woo0`001`Pe87oo00<007ooOol06Goo
00AJfEZhF[QJ^3ioo`<DLP09479oogoo8TXNBP007TXRBQi:029oo`03001oogoo00Eoo`004Goo00<0
07ooOol0<Goo00=b9GHVLRD00`0017oo00L8=0`e23@8=@Pd33D8=00OOol00`00Oomoo`0IOol015Jh
F]UF^5[I?Woo00@@DAAb474DLP9oo`057TXRBai:000NBP0SOol00`00Oomoo`05Ool0015oo`03001o
ogoo031oo`@0009b9PIoo`L8=Aioo`03001oogoo01Uoo`9J^003F]UJ^7oo03eoo`0:578@LQAb579o
oai:8TXNBR9:000TOol00`00Oomoo`05Ool0015oo`03001oogoo02eoo`<0009oo`05MTIb9GHVLREf
AP06Ool01`Pd33D8=0Pe23@<=@Pd01eoo`03001oogoo01Uoo`04E[QJfEJhF]TmOol031Ab474DLQ1A
579oob9;7TXRBai:8T/002=oo`03001oogoo00Eoo`0047oo00<007ooOol0:goo0`001Woo0W8V00=f
9W8VLRH01Woo1`Pe77oo00<007ooOol06Goo00AJfEZhF[QJ^3aoo`03578@LQAb008DLP06478RBQi:
8TXNBR9:0Woo00<007ooOol087oo00<007ooOol01Goo000@Ool2000YOol30009Ool01G8UMTIb9GHV
LRD01goo00L8=0`e23@8=@Pd33D8=00KOol00`00Oomoo`0IOol015JhF]UF^5[I>goo00`DLQ1a578@
DAAb474RBai:8T/NBR9;7TX3Ool00`00Oomoo`0OOol00`00Oomoo`05Ool0011oo`03001oogoo02Ao
o`@000eoo`=b9P03MRIb9Woo00Moo`H8=AYoo`03001oogoo01Uoo`9J^003F]UJ^7oo03Uoo`03578@
LQAb008DLP07478DLQi:8TXNBR9:7TX01Goo00<007ooOol07Woo00<007ooOol01Goo000@Ool00`00
Oomoo`0QOol3000AOol01WHVLREfAW8UMRIb9@Qoo`0633D8=0Pe23@<=@Pd6Goo00<007ooOol06Goo
00AF^5[IE[QJfCUoo`0<578@LAAb454DLQ1a578NBR9;7TXRBai:1goo00<007ooOol07Woo00<007oo
Ool017oo000@Ool00`00Oomoo`0NOol3000FOol3LRH00gHVOomoo`07Ool623DHOol00`00Oomoo`0I
Ool015[IF[QJ^5Zh>7oo00<DLQ1b57800QAb00L@LQAbOolRBQi:8TXNBP08Ool00`00Oomoo`0NOol0
0`00Oomoo`04Ool0011oo`03001oogoo01Yoo`@001Uoo`05MRIb9GI6LREf9P09Ool01P`e23@8=@Pd
33D8=1Moo`03001oogoo01Uoo`04E[QJfEJhF]TfOol01a1A578@LAAb454DLQ1a009oo`058T/NBR9;
7TXRB`09Ool00`00Oomoo`0MOol00`00Oomoo`04Ool000moo`03001oogoo01Qoo`<001ioo`04MRIb
9W8VLRH:Ool623DFOol00`00Oomoo`0IOol2F[P00e[IF[Qoo`0cOol357801A1b578DLQAb47800Woo
00DRBQi:8TXNBR9:00]oo`03001oogoo01aoo`03001oogoo00Aoo`003goo00<007ooOol05Goo0`00
8Goo00Ab9GHVLREfAP]oo`0633D8=0Pe23@<=@Pd5Goo00<007ooOol06Goo00AF^5[IE[QJfC=oo`08
578@DAAb474DLQ1A578@L@=oo`057TXRBai:8T/NBP0<Ool00`00Oomoo`0KOol00`00Oomoo`04Ool0
00moo`03001oogoo019oo`<003Aoo`D8=AAoo`03001oogoo01Yoo`04F]UJ^5ZhF[PbOol35780111b
578DLQAb0goo00HRBQi:8TXNBR9:7TX>Ool00`00Oomoo`0JOol00`00Oomoo`04Ool000moo`03001o
ogoo00ioo`@003Moo`0623@<=@Pd23D8=0`e4goo00<007ooOol06Woo00AF^5[IE[QJfC5oo`07578@
DAAb474DLQ1A578017oo00DNBR9;7TXRBai:00moo`03001oogoo01Yoo`03001oogoo00Aoo`003Woo
0`0037oo0`00?7oo1@Pe4goo00<007ooOol06Woo0UZh00=JfEZhOol0;goo0aAb00@@LQAb578DLPAo
o`057TXRBQi:8TXNBP0AOol00`00Oomoo`0IOol00`00Oomoo`04Ool000Moo`8000Ioo`03001oogoo
00Qoo`<0041oo`0523@<=@Pd23D8=00BOol00`00Oomoo`0JOol015JhF]UF^5[I;goo00HDLQ1A578@
LAAb4546Ool0129;7TXRBai:4goo00<007ooOol06Goo00<007ooOol00goo0006Ool01000Oomoo`00
17oo00<007ooOol01Woo0`00@goo1@Pe4Woo00<007ooOol06Woo00AJfEZhF[QJ^2ioo`<DLP03478D
LQAb00Ioo`058TXNBR9:7TXRBP0DOol00`00Oomoo`0HOol00`00Oomoo`03Ool000Ioo`04001oogoo
0004Ool00`00Oomoo`02Ool40017Ool010Pe23@<=@Pd4Woo00<007ooOol06Woo00AF^5[IE[QJfBio
o`05454DLQ1a578@D@08Ool00b9;7TXRB`0FOol00`00Oomoo`0GOol00`00Oomoo`03Ool000Ioo`04
001oogoo0004Ool00`00Ool00002001;Ool423DBOol00`00Oomoo`0JOol2F[P00e[IF[Qoo`0/Ool2
5780111b578DLQAb27oo00<NBR9:7TX05goo00<007ooOol05Woo00<007ooOol00goo0006Ool01000
Oomoo`0017oo0P00CWoo00D<=@Pd23D8=0`e015oo`03001oogoo01Yoo`04E[QJfEJhF]T]Ool01AAb
474DLQ1A57808goo00<007ooOol05Woo00<007ooOol00goo0007Ool20006Ool2001=Ool523DAOol0
0`00Oomoo`0JOol015[IF[QJ^5Zh;Goo00D@LQAb578DLQ1b02Aoo`03001oogoo01Eoo`03001oogoo
00=oo`004Goo00<007ooOol0BWoo00D8=@Pd33D8=0Pe015oo`03001oogoo01Yoo`04E[QJfEJhF]T/
Ool01A1a578@DAAb47409Woo00<007ooOol057oo00<007ooOol00goo000BOol00`00Oomoo`1:Ool4
23DAOol00`00Oomoo`0JOol2F[P00e[IF[Qoo`0[Ool357800a1b579oo`0VOol00`00Oomoo`0DOol0
0`00Oomoo`02Ool001=oo`8004Yoo`0423@8=@Pd33DAOol00`00Oomoo`0JOol015JhF]UF^5[I;7oo
00@@DAAb474DLRUoo`03001oogoo01=oo`03001oogoo009oo`005Goo0P00B7oo10Pe4Goo00<007oo
Ool06Woo00AJfEZhF[QJ^2aoo`04578@LQAb578ZOol00`00Oomoo`0BOol00`00Oomoo`02Ool001Eo
o`<004Moo`0423@<=@Pd23DAOol00`00Oomoo`0JOol015JhF]UF^5[I:goo00DDLQ1a578@DAAb02Yo
o`03001oogoo019oo`03001oogoo009oo`0067oo00<007ooOol0A7oo10Pe4Goo00<007ooOol06Woo
0UZh00=JfEZhOol0:Woo00D@LQAb578DLQ1b02]oo`03001oogoo015oo`03001oogoo009oo`006Goo
00<007ooOol0@Woo00D<=@Pd23D8=0`e015oo`03001oogoo01Yoo`04E[QJfEJhF]T[Ool011Ab454D
LQ1a;Goo00<007ooOol047oo00<007ooOol00Woo000JOol20012Ool523DAOol00`00Oomoo`0JOol0
15[IF[QJ^5Zh:goo0QAb00<@LQAbOol0;Goo00<007ooOol03goo00<007ooOol00Woo000LOol00`00
Oomoo`0oOol010Pe23@<=@Pd4Woo00<007ooOol06Woo00AF^5[IE[QJfB]oo`04578@LAAb454_Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool001eoo`8003moo`@8=A9oo`03001oogoo01Yoo`9J^003F]UJ
^7oo02Yoo`04478DLQAb578_Ool00`00Oomoo`0?Ool00`00Oomoo`01Ool001ioo`8003ioo`0433D8
=0Pe23@BOol00`00Oomoo`0JOol015JhF]UF^5[I:goo00DDLQ1A578@LAAb02moo`03001oogoo00io
o`03001oogoo005oo`0087oo0P00>goo1@Pe4Woo00<007ooOol06Woo00AJfEZhF[QJ^2]oo`8DLP03
478DLQAb031oo`03001oogoo00eoo`03001oogoo005oo`008Woo00<007ooOol0>7oo00D8=0Pe23@<
=@Pd019oo`03001oogoo01Yoo`04E[QJfEJhF]T/Ool0111a578@DAAb<Goo00<007ooOol037oo00<0
07ooOol00Goo000SOol00`00Oomoo`0gOol423DCOol00`00Oomoo`0JOol2F[P00e[IF[Qoo`0[Ool3
57800a1bOomoo`0`Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool002Aoo`800003Ool007oo03=oo`05
23D8=0`e23@8=@0COol00`00Oomoo`0JOol015JhF]UF^5[I;7oo00@@DAAb474DLS=oo`03001oogoo
00Yoo`03001oogoo005oo`009Woo00<007ooOol0<goo1@Pe4goo00<007ooOol06Woo00AJfEZhF[QJ
^2aoo`03578@LQAb008DLS9oo`03001oogoo00Yoo`03001oogoo005oo`009Woo0`00<goo00@<=@Pd
23D8=1Aoo`03001oogoo01Yoo`04E[QJfEJhF]T/Ool01A1a578@DAAb4740<goo00<007ooOol02Woo
0@000Goo0Goo000YOol00`00Oomoo`0_Ool523DDOol00`00Oomoo`0JOol2F[P00e[IF[Qoo`0/Ool2
57800a1b579oo`0cOol00`00Oomoo`09Ool10001Ool1Ool002Yoo`03001oogoo02ioo`0523@8=@Pd
33D8=00DOol00`00Oomoo`0JOol015JhF]UF^5[I;Goo00DDLQ1a578@DAAb03Aoo`03001oogoo00Qo
o`40005oo`5oo`00:goo0P00;Goo1@Pe5Goo00<007ooOol06Woo00AJfEZhF[QJ^2eoo`05478DLQAb
578@LP0eOol00`00Oomoo`07Ool10001Ool1Ool002eoo`03001oo`0002Yoo`0523D8=0`e23@8=@0E
Ool00`00Oomoo`0JOol015JhF]UF^5[I;Woo00@@DAAb474DLSEoo`03001oogoo00Moo`40005oo`5o
o`00;Woo0P00:Woo10Pe5Woo00<007ooOol06Woo0UZh00=JfEZhOol0;Goo00<DLQ1b57800QAb=Goo
00<007ooOol01Woo0@000Goo0Goo000`Ool00`00Oomoo`0VOol01@Pd33D8=0Pe23@05Goo00<007oo
Ool06goo00AF^5[IE[QJfBmoo`04578@DAAb474fOol00`00Oomoo`05Ool10001Ool1Ool002Ioo`@0
00Moo`03001oogoo02Aoo`D8=AIoo`03001oogoo01]oo`04F]UJ^5ZhF[P_Ool257800a1b578DLP0f
Ool00`00Oomoo`05Ool10001Ool002Ioo`03001oogoo00Uoo`8002=oo`0623@<=@Pd23D8=0`e5Woo
00<007ooOol06goo00AF^5[IE[QJfBmoo`05578@LAAb454DLP0gOol00`00Oomoo`04Ool10001Ool0
02Moo`03001oogoo00Yoo`03001oogoo021oo`D8=AMoo`03001oogoo01]oo`9J^003F]UJ^7oo02mo
o`<DLP03478DLWoo03Ioo`03001oogoo00=oo`40005oo`0087oo100017oo00<007ooOol02Woo0P00
7goo00D<=@Pd23D8=0`e01Qoo`03001oogoo01]oo`04E[QJfEJhF]TaOol011Ab474DLQ1A=goo00<0
07ooOol00goo0@000Goo000VOol01000Oomoo`0037oo0P007Goo1PPe67oo00<007ooOol06goo00AJ
fEZhF[QJ^35oo`05478DLQAb578@LP0gOol00`00Oomoo`02Ool10001Ool002Moo`8000moo`03001o
ogoo01Yoo`0523@8=@Pd33D8=00IOol00`00Oomoo`0KOol015JhF]UF^5[I<Goo00DDLQ1A578@LAAb
03Qoo`05001oogooOol00001Ool003Uoo`8001Yoo`@8=AYoo`03001oogoo01]oo`9J^003F]UJ^7oo
035oo`03578@LQAb008DLSQoo`04001oogoo0001Ool003]oo`03001oogoo01Qoo`0333D8=0Pe01Yo
o`03001oogoo01]oo`04E[QJfEJhF]TcOol01AAb454DLQ1a5780>7oo00<007oo00000Goo000lOol3
000dOol00`00Oomoo`0KOol015[IF[QJ^5Zh<goo0QAb00<@LQAb5780>Goo0@000Goo0@00000nOol0
0`00Oomoo`0bOol00`00Oomoo`0KOol015JhF]UF^5[I=7oo00D@LAAb454DLQ1a03Qoo`40005oo`40
0000?goo00<007ooOol0<Goo00<007ooOol06goo0UZh00=JfEZhOol0=7oo0QAb00<@LQAbOol0>7oo
0P000010Ool2000aOol00`00Oomoo`0KOol015JhF]UF^5[I=Goo00DDLQ1a578@DAAb03Moo`<00000
@Woo00<007ooOol0;Woo00<007ooOol06goo00AJfEZhF[QJ^3Moo`8DLSAoo`@000=oo`00@goo0`00
;Goo00<007ooOol06goo00AF^5[IE[QJfFUoo`@000Moo`00AGoo00<007ooOol0:goo00<007ooOol0
6goo0UZh00=JfEZhOol0I7oo10002goo0016Ool2000[Ool00`00Oomoo`0KOol015JhF]UF^5[IH7oo
1@003goo0018Ool00`00Oomoo`0XOol00`00Oomoo`0KOol015[IF[QJ^5ZhG7oo100057oo0019Ool0
0`00Oomoo`0WOol00`00Oomoo`0KOol015JhF]UF^5[IF7oo100067oo001:Ool3000VOol00`00Oomo
o`0KOol2F[P00e[IF[Qoo`1BOol5000LOol004aoo`03001oogoo02Aoo`03001oogoo01]oo`04E[QJ
fEJhF]U?Ool4000QOol004eoo`8002Aoo`03001oogoo01]oo`04F]UJ^5ZhF[Q;Ool4000UOol004mo
o`03001oogoo025oo`03001oogoo01]oo`04E[QJfEJhF]U7Ool4000YOol004=oo`8000]oo`03001o
ogoo021oo`03001oogoo01]oo`9J^003F]UJ^7oo045oo`D002eoo`00@Woo00@007ooOol000]oo`<0
01moo`03001oogoo01]oo`04E[QJfEJhF]TnOol4000bOol0049oo`04001oogoo000=Ool00`00Oomo
o`0MOol00`00Oomoo`0KOol015[IF[QJ^5Zh>Woo1000=Woo0012Ool01000Oomoo`003Woo0P007Goo
00<007ooOol06goo00AF^5[IE[QJfCEoo`D003Yoo`00@Woo00@007ooOol0011oo`03001oogoo01Yo
o`03001oogoo051oo`@003moo`00@goo0P004Woo00<007ooOol06Goo00<007ooOol0C7oo1000@goo
001HOol3000HOol00`00Oomoo`18Ool40017Ool005Yoo`03001oogoo01Ioo`03001oogoo04=oo`D0
04]oo`00Fgoo0P005Woo00<007ooOol0?goo1000D7oo001MOol00`00Oomoo`0BOol00`00Oomoo`0l
Ool4001DOol005ioo`03001oo`00015oo`03001oogoo03Moo`D005Qoo`00Ggoo0P004Goo00<007oo
Ool0<goo1000GGoo001QOol00`00Oomoo`0>Ool00`00Oomoo`0_Ool4001QOol0069oo`8000ioo`03
001oogoo02]oo`@006Eoo`00I7oo00<007ooOol02goo00<007ooOol09Woo1@00JGoo001UOol2000;
Ool00`00Oomoo`0ROol4001^Ool006Ioo`8000Yoo`03001oogoo01ioo`@0079oo`00J7oo00<007oo
Ool01goo00<007ooOol06Goo1@00MWoo001YOol20007Ool00`00Oomoo`0EOol4001kOol005ioo`@0
00Uoo`8000Eoo`03001oogoo015oo`@007moo`00GWoo00<007ooOol02goo0P0017oo00<007ooOol0
3Goo1000Pgoo001OOol00`00Oomoo`0<Ool01@00Oomoogoo00002Woo1@00Qgoo001POol00`00Oomo
o`0<Ool01000Oomoo`001Woo1000S7oo001NOol01000Oomoo`003Woo0`000Woo1000T7oo001OOol2
000AOol3002DOol00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool0
0?moo`Yoo`00\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.000684668, -0.0257195, \
0.00342601, 0.00342601}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[%,ViewPoint->{1,1,1},DisplayFunction\[Rule]$DisplayFunction]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98974 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0773503 1.1547 -5.24754e-017 1.1547 [
[.40512 .98086 -6.30824 0 ]
[.40512 .98086 5.69176 9 ]
[.29122 .95283 -3.34437 0 ]
[.29122 .95283 2.65563 9 ]
[.15639 .91957 -3.5773 0 ]
[.15639 .91957 2.4227 9 ]
[.58043 .98442 -5.73921 0 ]
[.58043 .98442 6.26079 9 ]
[.70999 .95253 -2.65359 0 ]
[.70999 .95253 3.34641 9 ]
[.86729 .91372 -2.38089 0 ]
[.86729 .91372 3.61911 9 ]
[.88793 .42688 0 -6.89616 ]
[.88793 .42688 24 2.10384 ]
[.92109 .54116 0 -6.54085 ]
[.92109 .54116 24 2.45915 ]
[.96053 .67736 0 -6.13548 ]
[.96053 .67736 18 2.86452 ]
[1.00821 .84243 0 -5.66866 ]
[1.00821 .84243 6 3.33134 ]
[ 0 0 0 0 ]
[ 1 .98974 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .98974 m
0 .86603 L
s
.40586 .96645 m
.40623 .95924 L
s
[(-2)] .40512 .98086 .05137 -1 Mshowa
.29286 .93849 m
.29368 .93132 L
s
[(0)] .29122 .95283 .11479 -1 Mshowa
.15912 .9054 m
.16048 .89831 L
s
[(2)] .15639 .91957 .19243 -1 Mshowa
.125 Mabswid
.47974 .98473 m
.47979 .9804 L
s
.45603 .97886 m
.45614 .97454 L
s
.43142 .97278 m
.43159 .96845 L
s
.37929 .95987 m
.37957 .95555 L
s
.35164 .95303 m
.35199 .94872 L
s
.32286 .94591 m
.32328 .9416 L
s
.26158 .93075 m
.26215 .92646 L
s
.22892 .92267 m
.22957 .91839 L
s
.1948 .91423 m
.19554 .90996 L
s
.12176 .89615 m
.12267 .89192 L
s
.0826 .88646 m
.0836 .88225 L
s
.04151 .8763 m
.04261 .87211 L
s
.25 Mabswid
.5 .98974 m
1 .86603 L
s
.5798 .97 m
.57949 .96279 L
s
[(-2)] .58043 .98442 -0.04347 -1 Mshowa
.70833 .93819 m
.70751 .93102 L
s
[(0)] .70999 .95253 -0.11547 -1 Mshowa
.86437 .89959 m
.86291 .89252 L
s
[(2)] .86729 .91372 -0.20637 -1 Mshowa
.125 Mabswid
.60976 .96258 m
.6095 .95826 L
s
.64111 .95483 m
.64077 .95051 L
s
.67393 .94671 m
.67351 .9424 L
s
.74444 .92926 m
.74386 .92497 L
s
.78239 .91987 m
.78171 .91559 L
s
.82231 .90999 m
.82154 .90573 L
s
.55113 .97709 m
.55101 .97276 L
s
.52368 .98389 m
.52362 .97956 L
s
.90874 .88861 m
.90776 .88439 L
s
.95561 .87701 m
.95452 .87282 L
s
.25 Mabswid
.85714 .37115 m
1 .86603 L
s
.87519 .43366 m
.86882 .43705 L
s
[(-150)] .88793 .42688 -1 .53248 Mshowa
.90794 .54712 m
.90137 .5501 L
s
[(-100)] .92109 .54116 -1 .45352 Mshowa
.94696 .68229 m
.94018 .68476 L
s
[(-50)] .96053 .67736 -1 .36344 Mshowa
.99424 .84606 m
.98725 .84787 L
s
[(0)] 1.00821 .84243 -1 .2597 Mshowa
.125 Mabswid
.88131 .45487 m
.87746 .45686 L
s
.88764 .47679 m
.88377 .47873 L
s
.89418 .49944 m
.89028 .50134 L
s
.90094 .52287 m
.89702 .52472 L
s
.91519 .57224 m
.91122 .57397 L
s
.9227 .59826 m
.91871 .59993 L
s
.93049 .62524 m
.92647 .62685 L
s
.93857 .65323 m
.93453 .65478 L
s
.95568 .71249 m
.95158 .7139 L
s
.96474 .74389 m
.96062 .74522 L
s
.97417 .77656 m
.97003 .77782 L
s
.984 .81059 m
.97983 .81176 L
s
.86926 .41312 m
.86546 .4152 L
s
.86351 .39322 m
.85974 .39534 L
s
.85794 .37393 m
.85419 .37609 L
s
.25 Mabswid
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
.85714 .37115 m
.5 .57735 L
s
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.14286 .37115 m
.5 .57735 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
0 0 m
1 0 L
1 .98974 L
0 .98974 L
closepath
clip
newpath
.921 .567 .212 r
.015 w
.42863 .60378 m
.42894 .60215 L
s
.42832 .60538 m
.42863 .60378 L
s
.42894 .60215 m
.42927 .60049 L
s
.42804 .60695 m
.42832 .60538 L
s
.42927 .60049 m
.42961 .5988 L
s
.42777 .60849 m
.42804 .60695 L
s
.42961 .5988 m
.42997 .59708 L
s
.42751 .61 m
.42777 .60849 L
s
.42997 .59708 m
.43034 .59533 L
s
.42727 .61147 m
.42751 .61 L
s
.43034 .59533 m
.43072 .59356 L
s
.42705 .61291 m
.42727 .61147 L
s
.43072 .59356 m
.43111 .59176 L
s
.42684 .61431 m
.42705 .61291 L
s
.43111 .59176 m
.43151 .58993 L
s
.42665 .61569 m
.42684 .61431 L
s
.43151 .58993 m
.43193 .58808 L
s
.42648 .61703 m
.42665 .61569 L
s
.43193 .58808 m
.43235 .58621 L
s
.43235 .58621 m
.43278 .58432 L
s
.42632 .61833 m
.42648 .61703 L
s
.43278 .58432 m
.43322 .58241 L
s
.42618 .6196 m
.42632 .61833 L
s
.43322 .58241 m
.43367 .58048 L
s
.42606 .62084 m
.42618 .6196 L
s
.43367 .58048 m
.43412 .57853 L
s
.43412 .57853 m
.43458 .57657 L
s
.42595 .62204 m
.42606 .62084 L
s
.43458 .57657 m
.43505 .57459 L
s
.42586 .62321 m
.42595 .62204 L
s
.43505 .57459 m
.43552 .5726 L
s
.098 .036 .682 r
.65012 .49097 m
.65049 .49031 L
s
.921 .567 .212 r
.43552 .5726 m
.43599 .5706 L
s
.42579 .62435 m
.42586 .62321 L
s
.43599 .5706 m
.43647 .56859 L
s
.42574 .62546 m
.42579 .62435 L
s
.43647 .56859 m
.43695 .56658 L
s
.098 .036 .682 r
.64971 .49161 m
.65012 .49097 L
s
.921 .567 .212 r
.43695 .56658 m
.43743 .56456 L
s
.4257 .62653 m
.42574 .62546 L
s
.45151 .49145 m
.45164 .49016 L
s
.43743 .56456 m
.43791 .56253 L
s
.43791 .56253 m
.43839 .5605 L
s
.098 .036 .682 r
.64927 .49222 m
.64971 .49161 L
s
.921 .567 .212 r
.45137 .49277 m
.45151 .49145 L
s
.42568 .62756 m
.4257 .62653 L
s
.43839 .5605 m
.43887 .55848 L
s
.45122 .4941 m
.45137 .49277 L
s
.43887 .55848 m
.43934 .55645 L
s
.42568 .62857 m
.42568 .62756 L
s
.45106 .49545 m
.45122 .4941 L
s
.43934 .55645 m
.43982 .55442 L
s
.098 .036 .682 r
.6488 .49282 m
.64927 .49222 L
s
.921 .567 .212 r
.45089 .49682 m
.45106 .49545 L
s
.43982 .55442 m
.44029 .55241 L
s
.4257 .62954 m
.42568 .62857 L
s
.45072 .49822 m
.45089 .49682 L
s
.44029 .55241 m
.44076 .55039 L
s
.45053 .49964 m
.45072 .49822 L
s
.44076 .55039 m
.44122 .54839 L
s
.098 .036 .682 r
.64829 .4934 m
.6488 .49282 L
s
.921 .567 .212 r
.42573 .63049 m
.4257 .62954 L
s
.45034 .50107 m
.45053 .49964 L
s
.44122 .54839 m
.44167 .54639 L
s
.44167 .54639 m
.44212 .54441 L
s
.45013 .50254 m
.45034 .50107 L
s
.44212 .54441 m
.44257 .54244 L
s
.44992 .50402 m
.45013 .50254 L
s
.42578 .6314 m
.42573 .63049 L
s
.44257 .54244 m
.443 .54048 L
s
.44969 .50553 m
.44992 .50402 L
s
.098 .036 .682 r
.64776 .49395 m
.64829 .4934 L
s
.921 .567 .212 r
.443 .54048 m
.44343 .53853 L
s
.44946 .50706 m
.44969 .50553 L
s
.44343 .53853 m
.44385 .53661 L
s
.44921 .50861 m
.44946 .50706 L
s
.44385 .53661 m
.44426 .5347 L
s
.44896 .51019 m
.44921 .50861 L
s
.44426 .5347 m
.44466 .5328 L
s
.42585 .63228 m
.42578 .6314 L
s
.44869 .51179 m
.44896 .51019 L
s
.44466 .5328 m
.44506 .53093 L
s
.44841 .51341 m
.44869 .51179 L
s
.44506 .53093 m
.44544 .52908 L
s
.098 .036 .682 r
.6472 .49449 m
.64776 .49395 L
s
.921 .567 .212 r
.44813 .51506 m
.44841 .51341 L
s
.44544 .52908 m
.44581 .52725 L
s
.44783 .51673 m
.44813 .51506 L
s
.44581 .52725 m
.44618 .52544 L
s
.44752 .51843 m
.44783 .51673 L
s
.44618 .52544 m
.44653 .52365 L
s
.4472 .52014 m
.44752 .51843 L
s
.44653 .52365 m
.44687 .52189 L
s
.44687 .52189 m
.4472 .52014 L
s
.42593 .63313 m
.42585 .63228 L
s
.098 .036 .682 r
.6466 .49502 m
.6472 .49449 L
s
.921 .567 .212 r
.42603 .63395 m
.42593 .63313 L
s
.098 .036 .682 r
.64598 .49553 m
.6466 .49502 L
s
.921 .567 .212 r
.42615 .63475 m
.42603 .63395 L
s
.098 .036 .682 r
.64534 .49602 m
.64598 .49553 L
s
.921 .567 .212 r
.42629 .63551 m
.42615 .63475 L
s
.098 .036 .682 r
.64467 .4965 m
.64534 .49602 L
s
.921 .567 .212 r
.42644 .63625 m
.42629 .63551 L
s
.4266 .63696 m
.42644 .63625 L
s
.098 .036 .682 r
.64397 .49697 m
.64467 .4965 L
s
.921 .567 .212 r
.42678 .63765 m
.4266 .63696 L
s
.098 .036 .682 r
.64325 .49743 m
.64397 .49697 L
s
.921 .567 .212 r
.42698 .63832 m
.42678 .63765 L
s
.098 .036 .682 r
.64252 .49788 m
.64325 .49743 L
s
.921 .567 .212 r
.42719 .63896 m
.42698 .63832 L
s
.098 .036 .682 r
.64176 .49832 m
.64252 .49788 L
s
.921 .567 .212 r
.42741 .63957 m
.42719 .63896 L
s
.098 .036 .682 r
.64099 .49876 m
.64176 .49832 L
s
.921 .567 .212 r
.42765 .64017 m
.42741 .63957 L
s
.098 .036 .682 r
.6402 .49918 m
.64099 .49876 L
s
.921 .567 .212 r
.4279 .64075 m
.42765 .64017 L
s
.098 .036 .682 r
.6394 .49961 m
.6402 .49918 L
s
.921 .567 .212 r
.42816 .64131 m
.4279 .64075 L
s
.098 .036 .682 r
.63858 .50003 m
.6394 .49961 L
s
.921 .567 .212 r
.42844 .64185 m
.42816 .64131 L
s
.098 .036 .682 r
.63776 .50045 m
.63858 .50003 L
s
.921 .567 .212 r
.42872 .64237 m
.42844 .64185 L
s
.098 .036 .682 r
.63693 .50086 m
.63776 .50045 L
s
.63609 .50128 m
.63693 .50086 L
s
.921 .567 .212 r
.42902 .64288 m
.42872 .64237 L
s
.098 .036 .682 r
.63524 .5017 m
.63609 .50128 L
s
.921 .567 .212 r
.42933 .64338 m
.42902 .64288 L
s
.098 .036 .682 r
.63439 .50212 m
.63524 .5017 L
s
.921 .567 .212 r
.42965 .64386 m
.42933 .64338 L
s
.098 .036 .682 r
.63354 .50255 m
.63439 .50212 L
s
.921 .567 .212 r
.42997 .64433 m
.42965 .64386 L
s
.098 .036 .682 r
.63269 .50299 m
.63354 .50255 L
s
.921 .567 .212 r
.43031 .6448 m
.42997 .64433 L
s
.098 .036 .682 r
.63184 .50343 m
.63269 .50299 L
s
.921 .567 .212 r
.43065 .64525 m
.43031 .6448 L
s
.098 .036 .682 r
.631 .50387 m
.63184 .50343 L
s
.921 .567 .212 r
.431 .6457 m
.43065 .64525 L
s
.098 .036 .682 r
.63016 .50433 m
.631 .50387 L
s
.62933 .5048 m
.63016 .50433 L
s
.921 .567 .212 r
.43136 .64614 m
.431 .6457 L
s
.098 .036 .682 r
.62851 .50528 m
.62933 .5048 L
s
.921 .567 .212 r
.43172 .64659 m
.43136 .64614 L
s
.098 .036 .682 r
.62769 .50577 m
.62851 .50528 L
s
.921 .567 .212 r
.43209 .64702 m
.43172 .64659 L
s
.098 .036 .682 r
.62689 .50627 m
.62769 .50577 L
s
.921 .567 .212 r
.43246 .64746 m
.43209 .64702 L
s
.098 .036 .682 r
.6261 .50679 m
.62689 .50627 L
s
.921 .567 .212 r
.43283 .6479 m
.43246 .64746 L
s
.098 .036 .682 r
.62533 .50732 m
.6261 .50679 L
s
.62457 .50787 m
.62533 .50732 L
s
.921 .567 .212 r
.4332 .64834 m
.43283 .6479 L
s
.098 .036 .682 r
.62382 .50843 m
.62457 .50787 L
s
.921 .567 .212 r
.43358 .64879 m
.4332 .64834 L
s
.098 .036 .682 r
.6231 .50901 m
.62382 .50843 L
s
.921 .567 .212 r
.43396 .64924 m
.43358 .64879 L
s
.098 .036 .682 r
.62239 .50961 m
.6231 .50901 L
s
.6217 .51023 m
.62239 .50961 L
s
.921 .567 .212 r
.43434 .6497 m
.43396 .64924 L
s
.098 .036 .682 r
.62103 .51086 m
.6217 .51023 L
s
.156 .65 .561 r
.26325 .43908 m
.26262 .43824 L
s
.921 .567 .212 r
.43471 .65016 m
.43434 .6497 L
s
.098 .036 .682 r
.62038 .51151 m
.62103 .51086 L
s
.156 .65 .561 r
.26394 .4399 m
.26325 .43908 L
s
.26469 .44072 m
.26394 .4399 L
s
.921 .567 .212 r
.43509 .65064 m
.43471 .65016 L
s
.098 .036 .682 r
.61976 .51218 m
.62038 .51151 L
s
.156 .65 .561 r
.26549 .44153 m
.26469 .44072 L
s
.098 .036 .682 r
.61915 .51287 m
.61976 .51218 L
s
.156 .65 .561 r
.26634 .44233 m
.26549 .44153 L
s
.921 .567 .212 r
.43546 .65113 m
.43509 .65064 L
s
.156 .65 .561 r
.26725 .44312 m
.26634 .44233 L
s
.098 .036 .682 r
.61856 .51358 m
.61915 .51287 L
s
.921 .567 .212 r
.43583 .65163 m
.43546 .65113 L
s
.156 .65 .561 r
.26821 .4439 m
.26725 .44312 L
s
.098 .036 .682 r
.618 .5143 m
.61856 .51358 L
s
.156 .65 .561 r
.26921 .44467 m
.26821 .4439 L
s
.098 .036 .682 r
.61746 .51505 m
.618 .5143 L
s
.921 .567 .212 r
.4362 .65214 m
.43583 .65163 L
s
.156 .65 .561 r
.27026 .44544 m
.26921 .44467 L
s
.098 .036 .682 r
.61695 .51581 m
.61746 .51505 L
s
.156 .65 .561 r
.27135 .4462 m
.27026 .44544 L
s
.921 .567 .212 r
.43656 .65267 m
.4362 .65214 L
s
.156 .65 .561 r
.27249 .44696 m
.27135 .4462 L
s
.098 .036 .682 r
.61645 .51659 m
.61695 .51581 L
s
.156 .65 .561 r
.27366 .44771 m
.27249 .44696 L
s
.098 .036 .682 r
.61598 .51739 m
.61645 .51659 L
s
.921 .567 .212 r
.43692 .65321 m
.43656 .65267 L
s
.156 .65 .561 r
.27487 .44846 m
.27366 .44771 L
s
.098 .036 .682 r
.61553 .51821 m
.61598 .51739 L
s
.921 .567 .212 r
.43727 .65377 m
.43692 .65321 L
s
.156 .65 .561 r
.27611 .44921 m
.27487 .44846 L
s
.098 .036 .682 r
.6151 .51905 m
.61553 .51821 L
s
.156 .65 .561 r
.27738 .44995 m
.27611 .44921 L
s
.098 .036 .682 r
.6147 .5199 m
.6151 .51905 L
s
.921 .567 .212 r
.43762 .65435 m
.43727 .65377 L
s
.156 .65 .561 r
.27869 .45069 m
.27738 .44995 L
s
.098 .036 .682 r
.61431 .52078 m
.6147 .5199 L
s
.156 .65 .561 r
.28001 .45143 m
.27869 .45069 L
s
.921 .567 .212 r
.43795 .65494 m
.43762 .65435 L
s
.098 .036 .682 r
.61395 .52167 m
.61431 .52078 L
s
.156 .65 .561 r
.28136 .45217 m
.28001 .45143 L
s
.098 .036 .682 r
.61361 .52258 m
.61395 .52167 L
s
.921 .567 .212 r
.43829 .65556 m
.43795 .65494 L
s
.156 .65 .561 r
.28273 .45291 m
.28136 .45217 L
s
.098 .036 .682 r
.6133 .5235 m
.61361 .52258 L
s
.156 .65 .561 r
.28412 .45366 m
.28273 .45291 L
s
.921 .567 .212 r
.43861 .65619 m
.43829 .65556 L
s
.098 .036 .682 r
.613 .52444 m
.6133 .5235 L
s
.156 .65 .561 r
.28552 .4544 m
.28412 .45366 L
s
.098 .036 .682 r
.61272 .5254 m
.613 .52444 L
s
.921 .567 .212 r
.43892 .65685 m
.43861 .65619 L
s
.156 .65 .561 r
.28693 .45515 m
.28552 .4544 L
s
.098 .036 .682 r
.61247 .52638 m
.61272 .5254 L
s
.156 .65 .561 r
.28834 .4559 m
.28693 .45515 L
s
.921 .567 .212 r
.43923 .65752 m
.43892 .65685 L
s
.098 .036 .682 r
.61223 .52737 m
.61247 .52638 L
s
.156 .65 .561 r
.28976 .45665 m
.28834 .4559 L
s
.098 .036 .682 r
.61202 .52837 m
.61223 .52737 L
s
.921 .567 .212 r
.43953 .65822 m
.43923 .65752 L
s
.156 .65 .561 r
.29119 .45741 m
.28976 .45665 L
s
.098 .036 .682 r
.61182 .52939 m
.61202 .52837 L
s
.61165 .53043 m
.61182 .52939 L
s
.156 .65 .561 r
.29261 .45817 m
.29119 .45741 L
s
.921 .567 .212 r
.43982 .65894 m
.43953 .65822 L
s
.098 .036 .682 r
.61149 .53148 m
.61165 .53043 L
s
.156 .65 .561 r
.29403 .45894 m
.29261 .45817 L
s
.921 .567 .212 r
.4401 .65968 m
.43982 .65894 L
s
.098 .036 .682 r
.61135 .53255 m
.61149 .53148 L
s
.156 .65 .561 r
.29544 .45972 m
.29403 .45894 L
s
.098 .036 .682 r
.61123 .53363 m
.61135 .53255 L
s
.921 .567 .212 r
.44037 .66044 m
.4401 .65968 L
s
.156 .65 .561 r
.29683 .4605 m
.29544 .45972 L
s
.098 .036 .682 r
.61113 .53472 m
.61123 .53363 L
s
.156 .65 .561 r
.29822 .46129 m
.29683 .4605 L
s
.098 .036 .682 r
.61104 .53583 m
.61113 .53472 L
s
.921 .567 .212 r
.44063 .66123 m
.44037 .66044 L
s
.098 .036 .682 r
.61098 .53695 m
.61104 .53583 L
s
.156 .65 .561 r
.29959 .46209 m
.29822 .46129 L
s
.921 .567 .212 r
.44088 .66203 m
.44063 .66123 L
s
.098 .036 .682 r
.61093 .53809 m
.61098 .53695 L
s
.156 .65 .561 r
.30095 .4629 m
.29959 .46209 L
s
.098 .036 .682 r
.61089 .53923 m
.61093 .53809 L
s
.921 .567 .212 r
.44112 .66286 m
.44088 .66203 L
s
.156 .65 .561 r
.30228 .46371 m
.30095 .4629 L
s
.098 .036 .682 r
.61088 .5404 m
.61089 .53923 L
s
.61088 .54157 m
.61088 .5404 L
s
.156 .65 .561 r
.3036 .46454 m
.30228 .46371 L
s
.921 .567 .212 r
.44135 .66372 m
.44112 .66286 L
s
.098 .036 .682 r
.6109 .54276 m
.61088 .54157 L
s
.156 .65 .561 r
.30488 .46538 m
.3036 .46454 L
s
.098 .036 .682 r
.61093 .54396 m
.6109 .54276 L
s
.921 .567 .212 r
.44157 .66459 m
.44135 .66372 L
s
.156 .65 .561 r
.30615 .46622 m
.30488 .46538 L
s
.098 .036 .682 r
.61098 .54518 m
.61093 .54396 L
s
.921 .567 .212 r
.44178 .66549 m
.44157 .66459 L
s
.098 .036 .682 r
.61105 .5464 m
.61098 .54518 L
s
.156 .65 .561 r
.30738 .46708 m
.30615 .46622 L
s
.098 .036 .682 r
.61113 .54764 m
.61105 .5464 L
s
.156 .65 .561 r
.30859 .46795 m
.30738 .46708 L
s
.921 .567 .212 r
.44198 .66641 m
.44178 .66549 L
s
.098 .036 .682 r
.61123 .5489 m
.61113 .54764 L
s
.156 .65 .561 r
.30976 .46883 m
.30859 .46795 L
s
.098 .036 .682 r
.61135 .55016 m
.61123 .5489 L
s
.921 .567 .212 r
.44217 .66735 m
.44198 .66641 L
s
.098 .036 .682 r
.61148 .55144 m
.61135 .55016 L
s
.156 .65 .561 r
.3109 .46972 m
.30976 .46883 L
s
.098 .036 .682 r
.61163 .55274 m
.61148 .55144 L
s
.921 .567 .212 r
.44235 .66831 m
.44217 .66735 L
s
.156 .65 .561 r
.31201 .47062 m
.3109 .46972 L
s
.098 .036 .682 r
.6118 .55404 m
.61163 .55274 L
s
.61198 .55536 m
.6118 .55404 L
s
.921 .567 .212 r
.44252 .6693 m
.44235 .66831 L
s
.156 .65 .561 r
.31308 .47153 m
.31201 .47062 L
s
.098 .036 .682 r
.61218 .55669 m
.61198 .55536 L
s
.156 .65 .561 r
.31412 .47246 m
.31308 .47153 L
s
.098 .036 .682 r
.6124 .55804 m
.61218 .55669 L
s
.921 .567 .212 r
.44268 .67031 m
.44252 .6693 L
s
.098 .036 .682 r
.61264 .5594 m
.6124 .55804 L
s
.156 .65 .561 r
.31513 .47339 m
.31412 .47246 L
s
.921 .567 .212 r
.44283 .67133 m
.44268 .67031 L
s
.098 .036 .682 r
.61289 .56077 m
.61264 .5594 L
s
.61316 .56216 m
.61289 .56077 L
s
.156 .65 .561 r
.31609 .47434 m
.31513 .47339 L
s
.921 .567 .212 r
.44297 .67238 m
.44283 .67133 L
s
.098 .036 .682 r
.61346 .56356 m
.61316 .56216 L
s
.156 .65 .561 r
.31702 .4753 m
.31609 .47434 L
s
.098 .036 .682 r
.61376 .56498 m
.61346 .56356 L
s
.921 .567 .212 r
.44309 .67345 m
.44297 .67238 L
s
.098 .036 .682 r
.61409 .56641 m
.61376 .56498 L
s
.156 .65 .561 r
.31791 .47627 m
.31702 .4753 L
s
.098 .036 .682 r
.61444 .56786 m
.61409 .56641 L
s
.921 .567 .212 r
.44321 .67454 m
.44309 .67345 L
s
.098 .036 .682 r
.61481 .56932 m
.61444 .56786 L
s
.156 .65 .561 r
.31877 .47725 m
.31791 .47627 L
s
.098 .036 .682 r
.6152 .57079 m
.61481 .56932 L
s
.61561 .57229 m
.6152 .57079 L
s
.921 .567 .212 r
.44332 .67564 m
.44321 .67454 L
s
.156 .65 .561 r
.31959 .47824 m
.31877 .47725 L
s
.098 .036 .682 r
.61604 .57379 m
.61561 .57229 L
s
.156 .65 .561 r
.32036 .47925 m
.31959 .47824 L
s
.098 .036 .682 r
.61649 .57532 m
.61604 .57379 L
s
.921 .567 .212 r
.44343 .67677 m
.44332 .67564 L
s
.098 .036 .682 r
.61696 .57686 m
.61649 .57532 L
s
.156 .65 .561 r
.32111 .48026 m
.32036 .47925 L
s
.098 .036 .682 r
.61746 .57841 m
.61696 .57686 L
s
.921 .567 .212 r
.44352 .67792 m
.44343 .67677 L
s
.098 .036 .682 r
.61798 .57998 m
.61746 .57841 L
s
.61852 .58157 m
.61798 .57998 L
s
.156 .65 .561 r
.32181 .48129 m
.32111 .48026 L
s
.921 .567 .212 r
.4436 .67908 m
.44352 .67792 L
s
.098 .036 .682 r
.61909 .58317 m
.61852 .58157 L
s
.61967 .58479 m
.61909 .58317 L
s
.156 .65 .561 r
.32248 .48233 m
.32181 .48129 L
s
.098 .036 .682 r
.62029 .58643 m
.61967 .58479 L
s
.921 .567 .212 r
.44367 .68027 m
.4436 .67908 L
s
.098 .036 .682 r
.62092 .58809 m
.62029 .58643 L
s
.156 .65 .561 r
.32311 .48338 m
.32248 .48233 L
s
.098 .036 .682 r
.62158 .58976 m
.62092 .58809 L
s
.62227 .59144 m
.62158 .58976 L
s
.921 .567 .212 r
.44374 .68147 m
.44367 .68027 L
s
.098 .036 .682 r
.62298 .59315 m
.62227 .59144 L
s
.156 .65 .561 r
.32371 .48443 m
.32311 .48338 L
s
.098 .036 .682 r
.62371 .59487 m
.62298 .59315 L
s
.62447 .5966 m
.62371 .59487 L
s
.921 .567 .212 r
.44379 .68269 m
.44374 .68147 L
s
.098 .036 .682 r
.62526 .59836 m
.62447 .5966 L
s
.156 .65 .561 r
.32426 .4855 m
.32371 .48443 L
s
.098 .036 .682 r
.62606 .60012 m
.62526 .59836 L
s
.62689 .60191 m
.62606 .60012 L
s
.62775 .6037 m
.62689 .60191 L
s
.62863 .60551 m
.62775 .6037 L
s
.921 .567 .212 r
.44384 .68392 m
.44379 .68269 L
s
.156 .65 .561 r
.32479 .48658 m
.32426 .4855 L
s
.098 .036 .682 r
.62953 .60734 m
.62863 .60551 L
s
.63045 .60918 m
.62953 .60734 L
s
.63139 .61103 m
.63045 .60918 L
s
.63235 .61289 m
.63139 .61103 L
s
.63334 .61477 m
.63235 .61289 L
s
.63434 .61665 m
.63334 .61477 L
s
.921 .567 .212 r
.44388 .68518 m
.44384 .68392 L
s
.098 .036 .682 r
.63536 .61855 m
.63434 .61665 L
s
.156 .65 .561 r
.32528 .48767 m
.32479 .48658 L
s
.098 .036 .682 r
.63639 .62045 m
.63536 .61855 L
s
.63744 .62236 m
.63639 .62045 L
s
.6385 .62428 m
.63744 .62236 L
s
.63957 .6262 m
.6385 .62428 L
s
.64066 .62812 m
.63957 .6262 L
s
.64175 .63005 m
.64066 .62812 L
s
.64285 .63199 m
.64175 .63005 L
s
.64395 .63392 m
.64285 .63199 L
s
.64506 .63585 m
.64395 .63392 L
s
.64617 .63779 m
.64506 .63585 L
s
.64728 .63972 m
.64617 .63779 L
s
.64839 .64164 m
.64728 .63972 L
s
.64949 .64356 m
.64839 .64164 L
s
.65059 .64548 m
.64949 .64356 L
s
.65169 .64739 m
.65059 .64548 L
s
.65277 .64929 m
.65169 .64739 L
s
.65384 .65119 m
.65277 .64929 L
s
.6549 .65307 m
.65384 .65119 L
s
.65595 .65494 m
.6549 .65307 L
s
.65697 .6568 m
.65595 .65494 L
s
.65799 .65865 m
.65697 .6568 L
s
.65898 .66048 m
.65799 .65865 L
s
.65995 .6623 m
.65898 .66048 L
s
.6609 .6641 m
.65995 .6623 L
s
.921 .567 .212 r
.44391 .68645 m
.44388 .68518 L
s
.098 .036 .682 r
.66182 .66589 m
.6609 .6641 L
s
.156 .65 .561 r
.32573 .48877 m
.32528 .48767 L
s
.098 .036 .682 r
.66272 .66766 m
.66182 .66589 L
s
.66359 .66942 m
.66272 .66766 L
s
.66444 .67115 m
.66359 .66942 L
s
.66525 .67287 m
.66444 .67115 L
s
.66604 .67457 m
.66525 .67287 L
s
.921 .567 .212 r
.44393 .68774 m
.44391 .68645 L
s
.156 .65 .561 r
.32615 .48988 m
.32573 .48877 L
s
.098 .036 .682 r
.66679 .67625 m
.66604 .67457 L
s
.66751 .67791 m
.66679 .67625 L
s
.6682 .67955 m
.66751 .67791 L
s
.156 .65 .561 r
.32654 .49099 m
.32615 .48988 L
s
.921 .567 .212 r
.44395 .68904 m
.44393 .68774 L
s
.098 .036 .682 r
.66885 .68117 m
.6682 .67955 L
s
.66947 .68277 m
.66885 .68117 L
s
.67005 .68434 m
.66947 .68277 L
s
.156 .65 .561 r
.32689 .49212 m
.32654 .49099 L
s
.921 .567 .212 r
.44395 .69036 m
.44395 .68904 L
s
.098 .036 .682 r
.67059 .6859 m
.67005 .68434 L
s
.6711 .68744 m
.67059 .6859 L
s
.156 .65 .561 r
.32722 .49326 m
.32689 .49212 L
s
.921 .567 .212 r
.44395 .6917 m
.44395 .69036 L
s
.098 .036 .682 r
.67157 .68895 m
.6711 .68744 L
s
.672 .69044 m
.67157 .68895 L
s
.156 .65 .561 r
.32751 .4944 m
.32722 .49326 L
s
.921 .567 .212 r
.44394 .69306 m
.44395 .6917 L
s
.098 .036 .682 r
.67239 .69192 m
.672 .69044 L
s
.67274 .69337 m
.67239 .69192 L
s
.156 .65 .561 r
.32777 .49556 m
.32751 .4944 L
s
.921 .567 .212 r
.44392 .69443 m
.44394 .69306 L
s
.098 .036 .682 r
.67306 .6948 m
.67274 .69337 L
s
.156 .65 .561 r
.328 .49672 m
.32777 .49556 L
s
.921 .567 .212 r
.44389 .69581 m
.44392 .69443 L
s
.098 .036 .682 r
.67333 .6962 m
.67306 .6948 L
s
.67356 .69759 m
.67333 .6962 L
s
.921 .567 .212 r
.44386 .69722 m
.44389 .69581 L
s
.156 .65 .561 r
.3282 .49789 m
.328 .49672 L
s
.098 .036 .682 r
.67376 .69896 m
.67356 .69759 L
s
.921 .567 .212 r
.44381 .69863 m
.44386 .69722 L
s
.156 .65 .561 r
.32837 .49907 m
.3282 .49789 L
s
.098 .036 .682 r
.67391 .7003 m
.67376 .69896 L
s
.921 .567 .212 r
.44376 .70007 m
.44381 .69863 L
s
.156 .65 .561 r
.32851 .50026 m
.32837 .49907 L
s
.098 .036 .682 r
.67402 .70163 m
.67391 .7003 L
s
.921 .567 .212 r
.4437 .70152 m
.44376 .70007 L
s
.156 .65 .561 r
.32862 .50146 m
.32851 .50026 L
s
.098 .036 .682 r
.67409 .70294 m
.67402 .70163 L
s
.921 .567 .212 r
.44364 .70299 m
.4437 .70152 L
s
.156 .65 .561 r
.32871 .50266 m
.32862 .50146 L
s
.098 .036 .682 r
.67412 .70422 m
.67409 .70294 L
s
.921 .567 .212 r
.44356 .70447 m
.44364 .70299 L
s
.156 .65 .561 r
.32876 .50388 m
.32871 .50266 L
s
.098 .036 .682 r
.67411 .70549 m
.67412 .70422 L
s
.921 .567 .212 r
.44348 .70597 m
.44356 .70447 L
s
.156 .65 .561 r
.32879 .5051 m
.32876 .50388 L
s
.098 .036 .682 r
.67406 .70674 m
.67411 .70549 L
s
.921 .567 .212 r
.44339 .70748 m
.44348 .70597 L
s
.156 .65 .561 r
.32879 .50633 m
.32879 .5051 L
s
.921 .567 .212 r
.44329 .70901 m
.44339 .70748 L
s
.098 .036 .682 r
.67398 .70797 m
.67406 .70674 L
s
.921 .567 .212 r
.44318 .71056 m
.44329 .70901 L
s
.156 .65 .561 r
.32876 .50757 m
.32879 .50633 L
s
.098 .036 .682 r
.67385 .70919 m
.67398 .70797 L
s
.921 .567 .212 r
.44306 .71212 m
.44318 .71056 L
s
.156 .65 .561 r
.32871 .50881 m
.32876 .50757 L
s
.921 .567 .212 r
.44294 .7137 m
.44306 .71212 L
s
.098 .036 .682 r
.67368 .71038 m
.67385 .70919 L
s
.156 .65 .561 r
.32863 .51007 m
.32871 .50881 L
s
.921 .567 .212 r
.4428 .7153 m
.44294 .7137 L
s
.4187 .84072 m
.41906 .83881 L
s
.41835 .84261 m
.4187 .84072 L
s
.41906 .83881 m
.41944 .83688 L
s
.41801 .84447 m
.41835 .84261 L
s
.41944 .83688 m
.41983 .83493 L
s
.41769 .84632 m
.41801 .84447 L
s
.41983 .83493 m
.42024 .83296 L
s
.42024 .83296 m
.42065 .83097 L
s
.41738 .84814 m
.41769 .84632 L
s
.42065 .83097 m
.42108 .82897 L
s
.41709 .84994 m
.41738 .84814 L
s
.098 .036 .682 r
.67348 .71156 m
.67368 .71038 L
s
.156 .65 .561 r
.32852 .51133 m
.32863 .51007 L
s
.921 .567 .212 r
.44266 .71691 m
.4428 .7153 L
s
.42108 .82897 m
.42151 .82694 L
s
.41681 .85172 m
.41709 .84994 L
s
.42151 .82694 m
.42196 .8249 L
s
.41655 .85348 m
.41681 .85172 L
s
.42196 .8249 m
.42242 .82284 L
s
.4163 .85522 m
.41655 .85348 L
s
.44251 .71854 m
.44266 .71691 L
s
.42242 .82284 m
.42288 .82077 L
s
.156 .65 .561 r
.32839 .5126 m
.32852 .51133 L
s
.921 .567 .212 r
.42288 .82077 m
.42335 .81868 L
s
.41608 .85693 m
.4163 .85522 L
s
.098 .036 .682 r
.67323 .71272 m
.67348 .71156 L
s
.921 .567 .212 r
.42335 .81868 m
.42383 .81658 L
s
.44235 .72019 m
.44251 .71854 L
s
.41586 .85862 m
.41608 .85693 L
s
.42383 .81658 m
.42431 .81447 L
s
.41567 .86028 m
.41586 .85862 L
s
.156 .65 .561 r
.32823 .51388 m
.32839 .5126 L
s
.921 .567 .212 r
.42431 .81447 m
.4248 .81234 L
s
.44217 .72185 m
.44235 .72019 L
s
.4248 .81234 m
.4253 .81021 L
s
.098 .036 .682 r
.67295 .71387 m
.67323 .71272 L
s
.921 .567 .212 r
.41549 .86193 m
.41567 .86028 L
s
.442 .72354 m
.44217 .72185 L
s
.4253 .81021 m
.4258 .80807 L
s
.156 .65 .561 r
.32804 .51517 m
.32823 .51388 L
s
.921 .567 .212 r
.41533 .86355 m
.41549 .86193 L
s
.4258 .80807 m
.4263 .80591 L
s
.44181 .72524 m
.442 .72354 L
s
.4263 .80591 m
.4268 .80375 L
s
.41519 .86515 m
.41533 .86355 L
s
.098 .036 .682 r
.67263 .715 m
.67295 .71387 L
s
.921 .567 .212 r
.44161 .72695 m
.44181 .72524 L
s
.4268 .80375 m
.42731 .80159 L
s
.156 .65 .561 r
.32782 .51646 m
.32804 .51517 L
s
.921 .567 .212 r
.42731 .80159 m
.42782 .79942 L
s
.41507 .86673 m
.41519 .86515 L
s
.4414 .72869 m
.44161 .72695 L
s
.42782 .79942 m
.42832 .79725 L
s
.156 .65 .561 r
.32758 .51777 m
.32782 .51646 L
s
.921 .567 .212 r
.44118 .73044 m
.4414 .72869 L
s
.42832 .79725 m
.42883 .79507 L
s
.098 .036 .682 r
.67228 .71612 m
.67263 .715 L
s
.921 .567 .212 r
.41496 .86829 m
.41507 .86673 L
s
.44095 .73222 m
.44118 .73044 L
s
.42883 .79507 m
.42933 .7929 L
s
.42933 .7929 m
.42983 .79072 L
s
.156 .65 .561 r
.32731 .51908 m
.32758 .51777 L
s
.921 .567 .212 r
.44071 .73401 m
.44095 .73222 L
s
.41487 .86983 m
.41496 .86829 L
s
.42983 .79072 m
.43033 .78855 L
s
.44046 .73581 m
.44071 .73401 L
s
.43033 .78855 m
.43082 .78638 L
s
.098 .036 .682 r
.67189 .71722 m
.67228 .71612 L
s
.921 .567 .212 r
.4402 .73764 m
.44046 .73581 L
s
.156 .65 .561 r
.32701 .5204 m
.32731 .51908 L
s
.921 .567 .212 r
.4148 .87135 m
.41487 .86983 L
s
.43082 .78638 m
.43131 .78421 L
s
.43993 .73949 m
.4402 .73764 L
s
.43131 .78421 m
.43179 .78205 L
s
.43964 .74135 m
.43993 .73949 L
s
.43179 .78205 m
.43227 .7799 L
s
.156 .65 .561 r
.32668 .52173 m
.32701 .5204 L
s
.921 .567 .212 r
.43227 .7799 m
.43274 .77775 L
s
.43935 .74323 m
.43964 .74135 L
s
.41475 .87284 m
.4148 .87135 L
s
.098 .036 .682 r
.67147 .71831 m
.67189 .71722 L
s
.921 .567 .212 r
.43274 .77775 m
.43321 .77561 L
s
.43905 .74513 m
.43935 .74323 L
s
.43321 .77561 m
.43366 .77348 L
s
.43873 .74705 m
.43905 .74513 L
s
.43366 .77348 m
.43411 .77137 L
s
.4384 .74899 m
.43873 .74705 L
s
.156 .65 .561 r
.32632 .52307 m
.32668 .52173 L
s
.921 .567 .212 r
.43411 .77137 m
.43455 .76926 L
s
.43807 .75094 m
.4384 .74899 L
s
.41471 .87432 m
.41475 .87284 L
s
.43455 .76926 m
.43498 .76717 L
s
.43772 .75291 m
.43807 .75094 L
s
.43498 .76717 m
.4354 .76508 L
s
.43736 .7549 m
.43772 .75291 L
s
.4354 .76508 m
.43582 .76302 L
s
.43699 .75691 m
.43736 .7549 L
s
.43582 .76302 m
.43622 .76096 L
s
.43661 .75893 m
.43699 .75691 L
s
.43622 .76096 m
.43661 .75893 L
s
.098 .036 .682 r
.67101 .71939 m
.67147 .71831 L
s
.156 .65 .561 r
.32594 .52441 m
.32632 .52307 L
s
.921 .567 .212 r
.41469 .87578 m
.41471 .87432 L
s
.156 .65 .561 r
.32552 .52577 m
.32594 .52441 L
s
.921 .567 .212 r
.41469 .87721 m
.41469 .87578 L
s
.098 .036 .682 r
.67052 .72046 m
.67101 .71939 L
s
.156 .65 .561 r
.32508 .52713 m
.32552 .52577 L
s
.921 .567 .212 r
.41471 .87863 m
.41469 .87721 L
s
.156 .65 .561 r
.3246 .52851 m
.32508 .52713 L
s
.098 .036 .682 r
.67 .72151 m
.67052 .72046 L
s
.156 .65 .561 r
.3241 .52989 m
.3246 .52851 L
s
.921 .567 .212 r
.41474 .88003 m
.41471 .87863 L
s
.156 .65 .561 r
.32356 .53129 m
.3241 .52989 L
s
.098 .036 .682 r
.66945 .72256 m
.67 .72151 L
s
.921 .567 .212 r
.41479 .88142 m
.41474 .88003 L
s
.156 .65 .561 r
.32299 .53269 m
.32356 .53129 L
s
.098 .036 .682 r
.66887 .7236 m
.66945 .72256 L
s
.156 .65 .561 r
.32239 .5341 m
.32299 .53269 L
s
.921 .567 .212 r
.41486 .88279 m
.41479 .88142 L
s
.156 .65 .561 r
.32175 .53552 m
.32239 .5341 L
s
.921 .567 .212 r
.41495 .88414 m
.41486 .88279 L
s
.098 .036 .682 r
.66826 .72463 m
.66887 .7236 L
s
.156 .65 .561 r
.32108 .53695 m
.32175 .53552 L
s
.32037 .5384 m
.32108 .53695 L
s
.921 .567 .212 r
.41505 .88547 m
.41495 .88414 L
s
.098 .036 .682 r
.66763 .72565 m
.66826 .72463 L
s
.156 .65 .561 r
.31963 .53985 m
.32037 .5384 L
s
.31885 .54131 m
.31963 .53985 L
s
.921 .567 .212 r
.41517 .88679 m
.41505 .88547 L
s
.098 .036 .682 r
.66697 .72666 m
.66763 .72565 L
s
.156 .65 .561 r
.31804 .54278 m
.31885 .54131 L
s
.31719 .54427 m
.31804 .54278 L
s
.921 .567 .212 r
.4153 .8881 m
.41517 .88679 L
s
.156 .65 .561 r
.31629 .54576 m
.31719 .54427 L
s
.098 .036 .682 r
.66628 .72767 m
.66697 .72666 L
s
.712 .702 .795 r
.67779 .33936 m
.67722 .33831 L
s
.156 .65 .561 r
.31536 .54726 m
.31629 .54576 L
s
.921 .567 .212 r
.41545 .88939 m
.4153 .8881 L
s
.712 .702 .795 r
.6784 .3404 m
.67779 .33936 L
s
.156 .65 .561 r
.3144 .54878 m
.31536 .54726 L
s
.098 .036 .682 r
.66558 .72868 m
.66628 .72767 L
s
.156 .65 .561 r
.31339 .5503 m
.3144 .54878 L
s
.712 .702 .795 r
.67904 .34143 m
.6784 .3404 L
s
.921 .567 .212 r
.41562 .89068 m
.41545 .88939 L
s
.156 .65 .561 r
.31234 .55184 m
.31339 .5503 L
s
.098 .036 .682 r
.66485 .72968 m
.66558 .72868 L
s
.712 .702 .795 r
.67972 .34246 m
.67904 .34143 L
s
.156 .65 .561 r
.31125 .55339 m
.31234 .55184 L
s
.921 .567 .212 r
.4158 .89195 m
.41562 .89068 L
s
.156 .65 .561 r
.31011 .55494 m
.31125 .55339 L
s
.712 .702 .795 r
.68044 .34348 m
.67972 .34246 L
s
.156 .65 .561 r
.30894 .55651 m
.31011 .55494 L
s
.098 .036 .682 r
.6641 .73068 m
.66485 .72968 L
s
.712 .702 .795 r
.6812 .3445 m
.68044 .34348 L
s
.156 .65 .561 r
.30773 .55809 m
.30894 .55651 L
s
.921 .567 .212 r
.41599 .8932 m
.4158 .89195 L
s
.156 .65 .561 r
.30647 .55968 m
.30773 .55809 L
s
.712 .702 .795 r
.682 .34551 m
.6812 .3445 L
s
.098 .036 .682 r
.66334 .73168 m
.6641 .73068 L
s
.156 .65 .561 r
.30518 .56128 m
.30647 .55968 L
s
.921 .567 .212 r
.4162 .89445 m
.41599 .8932 L
s
.156 .65 .561 r
.30384 .56288 m
.30518 .56128 L
s
.712 .702 .795 r
.68284 .34651 m
.682 .34551 L
s
.156 .65 .561 r
.30246 .5645 m
.30384 .56288 L
s
.098 .036 .682 r
.66256 .73268 m
.66334 .73168 L
s
.156 .65 .561 r
.30104 .56613 m
.30246 .5645 L
s
.712 .702 .795 r
.68372 .3475 m
.68284 .34651 L
s
.921 .567 .212 r
.41643 .89569 m
.4162 .89445 L
s
.156 .65 .561 r
.29959 .56777 m
.30104 .56613 L
s
.712 .702 .795 r
.68465 .34849 m
.68372 .3475 L
s
.156 .65 .561 r
.29809 .56941 m
.29959 .56777 L
s
.098 .036 .682 r
.66177 .73368 m
.66256 .73268 L
s
.156 .65 .561 r
.29656 .57106 m
.29809 .56941 L
s
.921 .567 .212 r
.41666 .89692 m
.41643 .89569 L
s
.712 .702 .795 r
.68562 .34947 m
.68465 .34849 L
s
.156 .65 .561 r
.29499 .57273 m
.29656 .57106 L
s
.29338 .57439 m
.29499 .57273 L
s
.098 .036 .682 r
.66096 .73468 m
.66177 .73368 L
s
.712 .702 .795 r
.68664 .35045 m
.68562 .34947 L
s
.156 .65 .561 r
.29175 .57607 m
.29338 .57439 L
s
.921 .567 .212 r
.41691 .89815 m
.41666 .89692 L
s
.156 .65 .561 r
.29008 .57775 m
.29175 .57607 L
s
.28838 .57944 m
.29008 .57775 L
s
.712 .702 .795 r
.68771 .35141 m
.68664 .35045 L
s
.098 .036 .682 r
.66014 .73568 m
.66096 .73468 L
s
.156 .65 .561 r
.28665 .58114 m
.28838 .57944 L
s
.28489 .58284 m
.28665 .58114 L
s
.712 .702 .795 r
.68882 .35237 m
.68771 .35141 L
s
.921 .567 .212 r
.41717 .89936 m
.41691 .89815 L
s
.156 .65 .561 r
.28312 .58454 m
.28489 .58284 L
s
.28132 .58625 m
.28312 .58454 L
s
.098 .036 .682 r
.65932 .73668 m
.66014 .73568 L
s
.712 .702 .795 r
.68998 .35332 m
.68882 .35237 L
s
.156 .65 .561 r
.2795 .58796 m
.28132 .58625 L
s
.27766 .58968 m
.2795 .58796 L
s
.921 .567 .212 r
.41745 .90058 m
.41717 .89936 L
s
.156 .65 .561 r
.27582 .59139 m
.27766 .58968 L
s
.712 .702 .795 r
.69119 .35426 m
.68998 .35332 L
s
.156 .65 .561 r
.27396 .59311 m
.27582 .59139 L
s
.098 .036 .682 r
.65849 .73769 m
.65932 .73668 L
s
.156 .65 .561 r
.27209 .59482 m
.27396 .59311 L
s
.712 .702 .795 r
.69245 .35519 m
.69119 .35426 L
s
.156 .65 .561 r
.27022 .59654 m
.27209 .59482 L
s
.921 .567 .212 r
.41773 .90178 m
.41745 .90058 L
s
.156 .65 .561 r
.26835 .59826 m
.27022 .59654 L
s
.098 .036 .682 r
.65765 .73871 m
.65849 .73769 L
s
.156 .65 .561 r
.26647 .59997 m
.26835 .59826 L
s
.712 .702 .795 r
.69376 .35611 m
.69245 .35519 L
s
.156 .65 .561 r
.26461 .60169 m
.26647 .59997 L
s
.26274 .6034 m
.26461 .60169 L
s
.921 .567 .212 r
.41803 .90299 m
.41773 .90178 L
s
.712 .702 .795 r
.69511 .35703 m
.69376 .35611 L
s
.156 .65 .561 r
.26089 .6051 m
.26274 .6034 L
s
.098 .036 .682 r
.65681 .73973 m
.65765 .73871 L
s
.156 .65 .561 r
.25906 .60681 m
.26089 .6051 L
s
.25724 .6085 m
.25906 .60681 L
s
.712 .702 .795 r
.69652 .35793 m
.69511 .35703 L
s
.156 .65 .561 r
.25544 .6102 m
.25724 .6085 L
s
.921 .567 .212 r
.41833 .90419 m
.41803 .90299 L
s
.156 .65 .561 r
.25366 .61188 m
.25544 .6102 L
s
.098 .036 .682 r
.65596 .74075 m
.65681 .73973 L
s
.712 .702 .795 r
.69799 .35883 m
.69652 .35793 L
s
.156 .65 .561 r
.25191 .61356 m
.25366 .61188 L
s
.25019 .61524 m
.25191 .61356 L
s
.2485 .6169 m
.25019 .61524 L
s
.712 .702 .795 r
.6995 .35972 m
.69799 .35883 L
s
.921 .567 .212 r
.41865 .90539 m
.41833 .90419 L
s
.156 .65 .561 r
.24684 .61856 m
.2485 .6169 L
s
.098 .036 .682 r
.65512 .74179 m
.65596 .74075 L
s
.156 .65 .561 r
.24522 .62021 m
.24684 .61856 L
s
.712 .702 .795 r
.70106 .3606 m
.6995 .35972 L
s
.156 .65 .561 r
.24365 .62185 m
.24522 .62021 L
s
.24211 .62348 m
.24365 .62185 L
s
.098 .036 .682 r
.65428 .74283 m
.65512 .74179 L
s
.921 .567 .212 r
.41897 .90659 m
.41865 .90539 L
s
.156 .65 .561 r
.24062 .62511 m
.24211 .62348 L
s
.712 .702 .795 r
.70268 .36147 m
.70106 .3606 L
s
.156 .65 .561 r
.23917 .62672 m
.24062 .62511 L
s
.23777 .62832 m
.23917 .62672 L
s
.712 .702 .795 r
.70434 .36233 m
.70268 .36147 L
s
.098 .036 .682 r
.65344 .74389 m
.65428 .74283 L
s
.156 .65 .561 r
.23643 .62991 m
.23777 .62832 L
s
.921 .567 .212 r
.4193 .90779 m
.41897 .90659 L
s
.156 .65 .561 r
.23514 .6315 m
.23643 .62991 L
s
.712 .702 .795 r
.70605 .36318 m
.70434 .36233 L
s
.156 .65 .561 r
.2339 .63307 m
.23514 .6315 L
s
.098 .036 .682 r
.65261 .74495 m
.65344 .74389 L
s
.156 .65 .561 r
.23272 .63463 m
.2339 .63307 L
s
.921 .567 .212 r
.41964 .90899 m
.4193 .90779 L
s
.712 .702 .795 r
.70782 .36402 m
.70605 .36318 L
s
.156 .65 .561 r
.2316 .63618 m
.23272 .63463 L
s
.23054 .63771 m
.2316 .63618 L
s
.098 .036 .682 r
.65178 .74603 m
.65261 .74495 L
s
.712 .702 .795 r
.70963 .36486 m
.70782 .36402 L
s
.156 .65 .561 r
.22954 .63924 m
.23054 .63771 L
s
.921 .567 .212 r
.41998 .91019 m
.41964 .90899 L
s
.156 .65 .561 r
.2286 .64076 m
.22954 .63924 L
s
.712 .702 .795 r
.71149 .36568 m
.70963 .36486 L
s
.156 .65 .561 r
.22773 .64226 m
.2286 .64076 L
s
.098 .036 .682 r
.65097 .74711 m
.65178 .74603 L
s
.156 .65 .561 r
.22692 .64375 m
.22773 .64226 L
s
.712 .702 .795 r
.71339 .3665 m
.71149 .36568 L
s
.921 .567 .212 r
.42033 .9114 m
.41998 .91019 L
s
.156 .65 .561 r
.22618 .64524 m
.22692 .64375 L
s
.098 .036 .682 r
.65016 .74821 m
.65097 .74711 L
s
.156 .65 .561 r
.22551 .64671 m
.22618 .64524 L
s
.712 .702 .795 r
.71534 .36731 m
.71339 .3665 L
s
.156 .65 .561 r
.2249 .64817 m
.22551 .64671 L
s
.921 .567 .212 r
.42069 .91261 m
.42033 .9114 L
s
.098 .036 .682 r
.64936 .74933 m
.65016 .74821 L
s
.156 .65 .561 r
.22436 .64961 m
.2249 .64817 L
s
.712 .702 .795 r
.71734 .36811 m
.71534 .36731 L
s
.156 .65 .561 r
.22389 .65105 m
.22436 .64961 L
s
.712 .702 .795 r
.71937 .36891 m
.71734 .36811 L
s
.156 .65 .561 r
.22349 .65248 m
.22389 .65105 L
s
.098 .036 .682 r
.64858 .75045 m
.64936 .74933 L
s
.921 .567 .212 r
.42104 .91383 m
.42069 .91261 L
s
.156 .65 .561 r
.22316 .65389 m
.22349 .65248 L
s
.712 .702 .795 r
.72144 .3697 m
.71937 .36891 L
s
.156 .65 .561 r
.2229 .6553 m
.22316 .65389 L
s
.098 .036 .682 r
.64781 .75159 m
.64858 .75045 L
s
.921 .567 .212 r
.42141 .91505 m
.42104 .91383 L
s
.156 .65 .561 r
.22271 .65669 m
.2229 .6553 L
s
.712 .702 .795 r
.72354 .37048 m
.72144 .3697 L
s
.156 .65 .561 r
.22259 .65808 m
.22271 .65669 L
s
.098 .036 .682 r
.64705 .75275 m
.64781 .75159 L
s
.712 .702 .795 r
.72568 .37125 m
.72354 .37048 L
s
.156 .65 .561 r
.22254 .65945 m
.22259 .65808 L
s
.921 .567 .212 r
.42177 .91628 m
.42141 .91505 L
s
.098 .036 .682 r
.64631 .75391 m
.64705 .75275 L
s
.156 .65 .561 r
.22255 .66082 m
.22254 .65945 L
s
.712 .702 .795 r
.72785 .37203 m
.72568 .37125 L
s
.156 .65 .561 r
.22264 .66218 m
.22255 .66082 L
s
.921 .567 .212 r
.42214 .91752 m
.42177 .91628 L
s
.712 .702 .795 r
.73005 .37279 m
.72785 .37203 L
s
.098 .036 .682 r
.64559 .7551 m
.64631 .75391 L
s
.156 .65 .561 r
.2228 .66352 m
.22264 .66218 L
s
.22302 .66486 m
.2228 .66352 L
s
.712 .702 .795 r
.73227 .37355 m
.73005 .37279 L
s
.098 .036 .682 r
.64489 .7563 m
.64559 .7551 L
s
.268 .595 .352 r
.37672 .29117 m
.37713 .29024 L
s
.921 .567 .212 r
.4225 .91877 m
.42214 .91752 L
s
.156 .65 .561 r
.22331 .6662 m
.22302 .66486 L
s
.712 .702 .795 r
.73451 .37431 m
.73227 .37355 L
s
.268 .595 .352 r
.37627 .29209 m
.37672 .29117 L
s
.156 .65 .561 r
.22367 .66752 m
.22331 .6662 L
s
.098 .036 .682 r
.64421 .75751 m
.64489 .7563 L
s
.268 .595 .352 r
.3758 .29299 m
.37627 .29209 L
s
.921 .567 .212 r
.42287 .92003 m
.4225 .91877 L
s
.712 .702 .795 r
.73677 .37507 m
.73451 .37431 L
s
.156 .65 .561 r
.22409 .66884 m
.22367 .66752 L
s
.098 .036 .682 r
.64354 .75875 m
.64421 .75751 L
s
.268 .595 .352 r
.3753 .29388 m
.3758 .29299 L
s
.156 .65 .561 r
.22458 .67015 m
.22409 .66884 L
s
.712 .702 .795 r
.73905 .37582 m
.73677 .37507 L
s
.921 .567 .212 r
.42324 .9213 m
.42287 .92003 L
s
.268 .595 .352 r
.37477 .29475 m
.3753 .29388 L
s
.156 .65 .561 r
.22513 .67145 m
.22458 .67015 L
s
.098 .036 .682 r
.6429 .75999 m
.64354 .75875 L
s
.712 .702 .795 r
.74133 .37658 m
.73905 .37582 L
s
.156 .65 .561 r
.22575 .67275 m
.22513 .67145 L
s
.268 .595 .352 r
.37421 .2956 m
.37477 .29475 L
s
.098 .036 .682 r
.64227 .76126 m
.6429 .75999 L
s
.712 .702 .795 r
.74362 .37733 m
.74133 .37658 L
s
.921 .567 .212 r
.4236 .92258 m
.42324 .9213 L
s
.156 .65 .561 r
.22642 .67404 m
.22575 .67275 L
s
.268 .595 .352 r
.37362 .29643 m
.37421 .2956 L
s
.712 .702 .795 r
.74592 .37809 m
.74362 .37733 L
s
.098 .036 .682 r
.64167 .76254 m
.64227 .76126 L
s
.156 .65 .561 r
.22715 .67532 m
.22642 .67404 L
s
.268 .595 .352 r
.373 .29725 m
.37362 .29643 L
s
.921 .567 .212 r
.42397 .92387 m
.4236 .92258 L
s
.156 .65 .561 r
.22795 .67661 m
.22715 .67532 L
s
.712 .702 .795 r
.74821 .37884 m
.74592 .37809 L
s
.098 .036 .682 r
.6411 .76383 m
.64167 .76254 L
s
.268 .595 .352 r
.37235 .29804 m
.373 .29725 L
s
.156 .65 .561 r
.22879 .67788 m
.22795 .67661 L
s
.712 .702 .795 r
.7505 .3796 m
.74821 .37884 L
s
.268 .595 .352 r
.37166 .29882 m
.37235 .29804 L
s
.921 .567 .212 r
.42433 .92518 m
.42397 .92387 L
s
.098 .036 .682 r
.64054 .76515 m
.6411 .76383 L
s
.156 .65 .561 r
.22969 .67916 m
.22879 .67788 L
s
.712 .702 .795 r
.75278 .38036 m
.7505 .3796 L
s
.268 .595 .352 r
.37095 .29957 m
.37166 .29882 L
s
.098 .036 .682 r
.64001 .76648 m
.64054 .76515 L
s
.156 .65 .561 r
.23065 .68043 m
.22969 .67916 L
s
.921 .567 .212 r
.42468 .9265 m
.42433 .92518 L
s
.712 .702 .795 r
.75504 .38112 m
.75278 .38036 L
s
.268 .595 .352 r
.37019 .30031 m
.37095 .29957 L
s
.156 .65 .561 r
.23165 .6817 m
.23065 .68043 L
s
.098 .036 .682 r
.6395 .76782 m
.64001 .76648 L
s
.712 .702 .795 r
.75729 .38189 m
.75504 .38112 L
s
.268 .595 .352 r
.36941 .30102 m
.37019 .30031 L
s
.921 .567 .212 r
.42504 .92783 m
.42468 .9265 L
s
.156 .65 .561 r
.2327 .68297 m
.23165 .6817 L
s
.098 .036 .682 r
.63901 .76918 m
.6395 .76782 L
s
.712 .702 .795 r
.75952 .38267 m
.75729 .38189 L
s
.268 .595 .352 r
.36858 .30171 m
.36941 .30102 L
s
.156 .65 .561 r
.23379 .68423 m
.2327 .68297 L
s
.098 .036 .682 r
.63855 .77056 m
.63901 .76918 L
s
.921 .567 .212 r
.42538 .92918 m
.42504 .92783 L
s
.712 .702 .795 r
.76172 .38345 m
.75952 .38267 L
s
.156 .65 .561 r
.23493 .6855 m
.23379 .68423 L
s
.268 .595 .352 r
.36772 .30238 m
.36858 .30171 L
s
.098 .036 .682 r
.6381 .77196 m
.63855 .77056 L
s
.156 .65 .561 r
.23611 .68676 m
.23493 .6855 L
s
.712 .702 .795 r
.76389 .38424 m
.76172 .38345 L
s
.268 .595 .352 r
.36683 .30303 m
.36772 .30238 L
s
.098 .036 .682 r
.63769 .77336 m
.6381 .77196 L
s
.156 .65 .561 r
.23732 .68803 m
.23611 .68676 L
s
.712 .702 .795 r
.76603 .38504 m
.76389 .38424 L
s
.268 .595 .352 r
.36589 .30366 m
.36683 .30303 L
s
.098 .036 .682 r
.63729 .77479 m
.63769 .77336 L
s
.156 .65 .561 r
.23858 .68929 m
.23732 .68803 L
s
.712 .702 .795 r
.76814 .38585 m
.76603 .38504 L
s
.268 .595 .352 r
.36492 .30426 m
.36589 .30366 L
s
.098 .036 .682 r
.63692 .77623 m
.63729 .77479 L
s
.156 .65 .561 r
.23986 .69056 m
.23858 .68929 L
s
.712 .702 .795 r
.7702 .38667 m
.76814 .38585 L
s
.268 .595 .352 r
.36391 .30484 m
.36492 .30426 L
s
.098 .036 .682 r
.63658 .77769 m
.63692 .77623 L
s
.156 .65 .561 r
.24117 .69183 m
.23986 .69056 L
s
.712 .702 .795 r
.77222 .38749 m
.7702 .38667 L
s
.268 .595 .352 r
.36286 .3054 m
.36391 .30484 L
s
.156 .65 .561 r
.24251 .6931 m
.24117 .69183 L
s
.098 .036 .682 r
.63625 .77916 m
.63658 .77769 L
s
.712 .702 .795 r
.77419 .38833 m
.77222 .38749 L
s
.268 .595 .352 r
.36178 .30593 m
.36286 .3054 L
s
.156 .65 .561 r
.24387 .69438 m
.24251 .6931 L
s
.098 .036 .682 r
.63595 .78064 m
.63625 .77916 L
s
.712 .702 .795 r
.77611 .38919 m
.77419 .38833 L
s
.098 .036 .682 r
.63567 .78214 m
.63595 .78064 L
s
.712 .702 .795 r
.77797 .39005 m
.77611 .38919 L
s
.156 .65 .561 r
.24525 .69566 m
.24387 .69438 L
s
.268 .595 .352 r
.36065 .30644 m
.36178 .30593 L
s
.712 .702 .795 r
.77978 .39094 m
.77797 .39005 L
s
.098 .036 .682 r
.63541 .78365 m
.63567 .78214 L
s
.156 .65 .561 r
.24665 .69694 m
.24525 .69566 L
s
.268 .595 .352 r
.35948 .30693 m
.36065 .30644 L
s
.712 .702 .795 r
.78152 .39183 m
.77978 .39094 L
s
.098 .036 .682 r
.63518 .78518 m
.63541 .78365 L
s
.156 .65 .561 r
.24807 .69823 m
.24665 .69694 L
s
.268 .595 .352 r
.35828 .30739 m
.35948 .30693 L
s
.712 .702 .795 r
.7832 .39274 m
.78152 .39183 L
s
.098 .036 .682 r
.63496 .78673 m
.63518 .78518 L
s
.156 .65 .561 r
.24949 .69952 m
.24807 .69823 L
s
.712 .702 .795 r
.78482 .39367 m
.7832 .39274 L
s
.268 .595 .352 r
.35704 .30783 m
.35828 .30739 L
s
.098 .036 .682 r
.63477 .78828 m
.63496 .78673 L
s
.156 .65 .561 r
.25092 .70082 m
.24949 .69952 L
s
.712 .702 .795 r
.78636 .39461 m
.78482 .39367 L
s
.098 .036 .682 r
.6346 .78985 m
.63477 .78828 L
s
.268 .595 .352 r
.35575 .30825 m
.35704 .30783 L
s
.156 .65 .561 r
.25236 .70213 m
.25092 .70082 L
s
.712 .702 .795 r
.78784 .39557 m
.78636 .39461 L
s
.098 .036 .682 r
.63445 .79143 m
.6346 .78985 L
s
.156 .65 .561 r
.2538 .70344 m
.25236 .70213 L
s
.268 .595 .352 r
.35443 .30864 m
.35575 .30825 L
s
.712 .702 .795 r
.78924 .39655 m
.78784 .39557 L
s
.098 .036 .682 r
.63432 .79303 m
.63445 .79143 L
s
.156 .65 .561 r
.25524 .70477 m
.2538 .70344 L
s
.712 .702 .795 r
.79056 .39755 m
.78924 .39655 L
s
.098 .036 .682 r
.63421 .79464 m
.63432 .79303 L
s
.268 .595 .352 r
.35308 .30901 m
.35443 .30864 L
s
.712 .702 .795 r
.7918 .39857 m
.79056 .39755 L
s
.156 .65 .561 r
.25667 .70609 m
.25524 .70477 L
s
.098 .036 .682 r
.63412 .79626 m
.63421 .79464 L
s
.268 .595 .352 r
.35168 .30936 m
.35308 .30901 L
s
.712 .702 .795 r
.79296 .39961 m
.7918 .39857 L
s
.098 .036 .682 r
.63406 .79789 m
.63412 .79626 L
s
.156 .65 .561 r
.2581 .70743 m
.25667 .70609 L
s
.712 .702 .795 r
.79404 .40066 m
.79296 .39961 L
s
.098 .036 .682 r
.63401 .79954 m
.63406 .79789 L
s
.268 .595 .352 r
.35025 .30969 m
.35168 .30936 L
s
.156 .65 .561 r
.25952 .70878 m
.2581 .70743 L
s
.712 .702 .795 r
.79504 .40174 m
.79404 .40066 L
s
.098 .036 .682 r
.63398 .8012 m
.63401 .79954 L
s
.156 .65 .561 r
.26092 .71013 m
.25952 .70878 L
s
.712 .702 .795 r
.79595 .40284 m
.79504 .40174 L
s
.268 .595 .352 r
.34879 .30999 m
.35025 .30969 L
s
.098 .036 .682 r
.63397 .80287 m
.63398 .8012 L
s
.712 .702 .795 r
.79677 .40396 m
.79595 .40284 L
s
.156 .65 .561 r
.26231 .7115 m
.26092 .71013 L
s
.098 .036 .682 r
.63398 .80456 m
.63397 .80287 L
s
.712 .702 .795 r
.79751 .4051 m
.79677 .40396 L
s
.268 .595 .352 r
.34729 .31028 m
.34879 .30999 L
s
.098 .036 .682 r
.63401 .80625 m
.63398 .80456 L
s
.156 .65 .561 r
.26369 .71287 m
.26231 .7115 L
s
.712 .702 .795 r
.79816 .40626 m
.79751 .4051 L
s
.098 .036 .682 r
.63406 .80796 m
.63401 .80625 L
s
.268 .595 .352 r
.34576 .31055 m
.34729 .31028 L
s
.712 .702 .795 r
.79871 .40744 m
.79816 .40626 L
s
.156 .65 .561 r
.26504 .71426 m
.26369 .71287 L
s
.098 .036 .682 r
.63413 .80968 m
.63406 .80796 L
s
.712 .702 .795 r
.79918 .40865 m
.79871 .40744 L
s
.156 .65 .561 r
.26637 .71565 m
.26504 .71426 L
s
.098 .036 .682 r
.63422 .81141 m
.63413 .80968 L
s
.268 .595 .352 r
.34419 .3108 m
.34576 .31055 L
s
.712 .702 .795 r
.79955 .40988 m
.79918 .40865 L
s
.098 .036 .682 r
.63432 .81316 m
.63422 .81141 L
s
.712 .702 .795 r
.79984 .41113 m
.79955 .40988 L
s
.156 .65 .561 r
.26767 .71706 m
.26637 .71565 L
s
.098 .036 .682 r
.63445 .81491 m
.63432 .81316 L
s
.268 .595 .352 r
.3426 .31103 m
.34419 .3108 L
s
.712 .702 .795 r
.80003 .41241 m
.79984 .41113 L
s
.156 .65 .561 r
.26895 .71847 m
.26767 .71706 L
s
.098 .036 .682 r
.63459 .81668 m
.63445 .81491 L
s
.712 .702 .795 r
.80013 .4137 m
.80003 .41241 L
s
.80014 .41502 m
.80013 .4137 L
s
.098 .036 .682 r
.63476 .81846 m
.63459 .81668 L
s
.156 .65 .561 r
.2702 .7199 m
.26895 .71847 L
s
.268 .595 .352 r
.34099 .31125 m
.3426 .31103 L
s
.712 .702 .795 r
.80006 .41636 m
.80014 .41502 L
s
.098 .036 .682 r
.63494 .82025 m
.63476 .81846 L
s
.156 .65 .561 r
.27143 .72134 m
.2702 .7199 L
s
.712 .702 .795 r
.79989 .41773 m
.80006 .41636 L
s
.098 .036 .682 r
.63514 .82205 m
.63494 .82025 L
s
.268 .595 .352 r
.33934 .31145 m
.34099 .31125 L
s
.712 .702 .795 r
.79963 .41912 m
.79989 .41773 L
s
.156 .65 .561 r
.27262 .72279 m
.27143 .72134 L
s
.098 .036 .682 r
.63536 .82387 m
.63514 .82205 L
s
.712 .702 .795 r
.79928 .42053 m
.79963 .41912 L
s
.098 .036 .682 r
.6356 .8257 m
.63536 .82387 L
s
.268 .595 .352 r
.33768 .31165 m
.33934 .31145 L
s
.712 .702 .795 r
.79885 .42196 m
.79928 .42053 L
s
.156 .65 .561 r
.27377 .72425 m
.27262 .72279 L
s
.098 .036 .682 r
.63587 .82754 m
.6356 .8257 L
s
.712 .702 .795 r
.79832 .42341 m
.79885 .42196 L
s
.79771 .42489 m
.79832 .42341 L
s
.156 .65 .561 r
.27489 .72572 m
.27377 .72425 L
s
.098 .036 .682 r
.63615 .82939 m
.63587 .82754 L
s
.268 .595 .352 r
.33599 .31183 m
.33768 .31165 L
s
.712 .702 .795 r
.79702 .42638 m
.79771 .42489 L
s
.098 .036 .682 r
.63645 .83125 m
.63615 .82939 L
s
.156 .65 .561 r
.27598 .7272 m
.27489 .72572 L
s
.712 .702 .795 r
.79625 .4279 m
.79702 .42638 L
s
.098 .036 .682 r
.63677 .83313 m
.63645 .83125 L
s
.712 .702 .795 r
.7954 .42944 m
.79625 .4279 L
s
.268 .595 .352 r
.33429 .312 m
.33599 .31183 L
s
.098 .036 .682 r
.63712 .83502 m
.63677 .83313 L
s
.156 .65 .561 r
.27703 .72869 m
.27598 .7272 L
s
.712 .702 .795 r
.79446 .431 m
.7954 .42944 L
s
.79346 .43258 m
.79446 .431 L
s
.098 .036 .682 r
.63748 .83692 m
.63712 .83502 L
s
.712 .702 .795 r
.79237 .43418 m
.79346 .43258 L
s
.156 .65 .561 r
.27805 .7302 m
.27703 .72869 L
s
.098 .036 .682 r
.63787 .83883 m
.63748 .83692 L
s
.268 .595 .352 r
.33257 .31216 m
.33429 .312 L
s
.712 .702 .795 r
.79122 .4358 m
.79237 .43418 L
s
.098 .036 .682 r
.63827 .84076 m
.63787 .83883 L
s
.712 .702 .795 r
.79 .43744 m
.79122 .4358 L
s
.156 .65 .561 r
.27902 .73171 m
.27805 .7302 L
s
.098 .036 .682 r
.6387 .8427 m
.63827 .84076 L
s
.712 .702 .795 r
.78872 .4391 m
.79 .43744 L
s
.268 .595 .352 r
.33083 .31232 m
.33257 .31216 L
s
.712 .702 .795 r
.78737 .44077 m
.78872 .4391 L
s
.098 .036 .682 r
.63916 .84465 m
.6387 .8427 L
s
.156 .65 .561 r
.27996 .73324 m
.27902 .73171 L
s
.712 .702 .795 r
.78596 .44246 m
.78737 .44077 L
s
.098 .036 .682 r
.63963 .84661 m
.63916 .84465 L
s
.712 .702 .795 r
.7845 .44417 m
.78596 .44246 L
s
.156 .65 .561 r
.28086 .73478 m
.27996 .73324 L
s
.098 .036 .682 r
.64013 .84859 m
.63963 .84661 L
s
.712 .702 .795 r
.78299 .44589 m
.7845 .44417 L
s
.268 .595 .352 r
.32909 .31248 m
.33083 .31232 L
s
.712 .702 .795 r
.78142 .44763 m
.78299 .44589 L
s
.098 .036 .682 r
.64065 .85058 m
.64013 .84859 L
s
.712 .702 .795 r
.77981 .44938 m
.78142 .44763 L
s
.156 .65 .561 r
.28172 .73633 m
.28086 .73478 L
s
.098 .036 .682 r
.6412 .85258 m
.64065 .85058 L
s
.712 .702 .795 r
.77816 .45114 m
.77981 .44938 L
s
.098 .036 .682 r
.64177 .85459 m
.6412 .85258 L
s
.712 .702 .795 r
.77648 .45292 m
.77816 .45114 L
s
.268 .595 .352 r
.32734 .31263 m
.32909 .31248 L
s
.156 .65 .561 r
.28254 .73789 m
.28172 .73633 L
s
.712 .702 .795 r
.77475 .45471 m
.77648 .45292 L
s
.098 .036 .682 r
.64236 .85662 m
.64177 .85459 L
s
.712 .702 .795 r
.773 .4565 m
.77475 .45471 L
s
.098 .036 .682 r
.64298 .85866 m
.64236 .85662 L
s
.712 .702 .795 r
.77122 .45831 m
.773 .4565 L
s
.156 .65 .561 r
.28332 .73946 m
.28254 .73789 L
s
.098 .036 .682 r
.64362 .86071 m
.64298 .85866 L
s
.712 .702 .795 r
.76942 .46013 m
.77122 .45831 L
s
.268 .595 .352 r
.32558 .31278 m
.32734 .31263 L
s
.098 .036 .682 r
.64429 .86278 m
.64362 .86071 L
s
.712 .702 .795 r
.76761 .46196 m
.76942 .46013 L
s
.156 .65 .561 r
.28407 .74104 m
.28332 .73946 L
s
.098 .036 .682 r
.64499 .86486 m
.64429 .86278 L
s
.712 .702 .795 r
.76577 .46379 m
.76761 .46196 L
s
.098 .036 .682 r
.64571 .86695 m
.64499 .86486 L
s
.712 .702 .795 r
.76393 .46563 m
.76577 .46379 L
s
.76209 .46748 m
.76393 .46563 L
s
.098 .036 .682 r
.64645 .86905 m
.64571 .86695 L
s
.156 .65 .561 r
.28477 .74263 m
.28407 .74104 L
s
.268 .595 .352 r
.32383 .31294 m
.32558 .31278 L
s
.712 .702 .795 r
.76024 .46933 m
.76209 .46748 L
s
.098 .036 .682 r
.64723 .87116 m
.64645 .86905 L
s
.712 .702 .795 r
.75839 .47118 m
.76024 .46933 L
s
.098 .036 .682 r
.64802 .87329 m
.64723 .87116 L
s
.156 .65 .561 r
.28543 .74423 m
.28477 .74263 L
s
.098 .036 .682 r
.64884 .87543 m
.64802 .87329 L
s
.712 .702 .795 r
.75655 .47304 m
.75839 .47118 L
s
.098 .036 .682 r
.64969 .87758 m
.64884 .87543 L
s
.712 .702 .795 r
.75472 .4749 m
.75655 .47304 L
s
.268 .595 .352 r
.32207 .3131 m
.32383 .31294 L
s
.098 .036 .682 r
.65057 .87974 m
.64969 .87758 L
s
.712 .702 .795 r
.7529 .47676 m
.75472 .4749 L
s
.156 .65 .561 r
.28606 .74584 m
.28543 .74423 L
s
.098 .036 .682 r
.65146 .88191 m
.65057 .87974 L
s
.712 .702 .795 r
.7511 .47862 m
.7529 .47676 L
s
.098 .036 .682 r
.65239 .88409 m
.65146 .88191 L
s
.65333 .88628 m
.65239 .88409 L
s
.712 .702 .795 r
.74932 .48048 m
.7511 .47862 L
s
.098 .036 .682 r
.65431 .88848 m
.65333 .88628 L
s
.156 .65 .561 r
.28664 .74747 m
.28606 .74584 L
s
.712 .702 .795 r
.74756 .48234 m
.74932 .48048 L
s
.098 .036 .682 r
.6553 .89069 m
.65431 .88848 L
s
.268 .595 .352 r
.32032 .31326 m
.32207 .3131 L
s
.098 .036 .682 r
.65632 .89291 m
.6553 .89069 L
s
.712 .702 .795 r
.74583 .4842 m
.74756 .48234 L
s
.098 .036 .682 r
.65735 .89514 m
.65632 .89291 L
s
.65841 .89737 m
.65735 .89514 L
s
.156 .65 .561 r
.28719 .7491 m
.28664 .74747 L
s
.712 .702 .795 r
.74412 .48605 m
.74583 .4842 L
s
.098 .036 .682 r
.65949 .89961 m
.65841 .89737 L
s
.66059 .90186 m
.65949 .89961 L
s
.712 .702 .795 r
.74245 .48791 m
.74412 .48605 L
s
.098 .036 .682 r
.6617 .90411 m
.66059 .90186 L
s
.66283 .90637 m
.6617 .90411 L
s
.66398 .90863 m
.66283 .90637 L
s
.268 .595 .352 r
.31858 .31343 m
.32032 .31326 L
s
.712 .702 .795 r
.74082 .48976 m
.74245 .48791 L
s
.156 .65 .561 r
.2877 .75074 m
.28719 .7491 L
s
.712 .702 .795 r
.73922 .4916 m
.74082 .48976 L
s
.73765 .49344 m
.73922 .4916 L
s
.156 .65 .561 r
.28817 .75239 m
.2877 .75074 L
s
.712 .702 .795 r
.73613 .49528 m
.73765 .49344 L
s
.268 .595 .352 r
.31684 .31362 m
.31858 .31343 L
s
.712 .702 .795 r
.73465 .49711 m
.73613 .49528 L
s
.156 .65 .561 r
.2886 .75405 m
.28817 .75239 L
s
.712 .702 .795 r
.73321 .49894 m
.73465 .49711 L
s
.73182 .50076 m
.73321 .49894 L
s
.156 .65 .561 r
.289 .75572 m
.2886 .75405 L
s
.268 .595 .352 r
.31513 .31381 m
.31684 .31362 L
s
.712 .702 .795 r
.73048 .50257 m
.73182 .50076 L
s
.72918 .50438 m
.73048 .50257 L
s
.156 .65 .561 r
.28936 .75741 m
.289 .75572 L
s
.712 .702 .795 r
.72793 .50618 m
.72918 .50438 L
s
.268 .595 .352 r
.31343 .31403 m
.31513 .31381 L
s
.156 .65 .561 r
.28968 .75909 m
.28936 .75741 L
s
.712 .702 .795 r
.72672 .50797 m
.72793 .50618 L
s
.72557 .50975 m
.72672 .50797 L
s
.156 .65 .561 r
.28997 .76079 m
.28968 .75909 L
s
.712 .702 .795 r
.72446 .51153 m
.72557 .50975 L
s
.268 .595 .352 r
.31175 .31425 m
.31343 .31403 L
s
.712 .702 .795 r
.7234 .5133 m
.72446 .51153 L
s
.156 .65 .561 r
.29023 .7625 m
.28997 .76079 L
s
.712 .702 .795 r
.7224 .51507 m
.7234 .5133 L
s
.156 .65 .561 r
.29045 .76422 m
.29023 .7625 L
s
.712 .702 .795 r
.72144 .51683 m
.7224 .51507 L
s
.268 .595 .352 r
.31009 .3145 m
.31175 .31425 L
s
.712 .702 .795 r
.72053 .51858 m
.72144 .51683 L
s
.156 .65 .561 r
.29063 .76594 m
.29045 .76422 L
s
.712 .702 .795 r
.71966 .52032 m
.72053 .51858 L
s
.156 .65 .561 r
.29078 .76768 m
.29063 .76594 L
s
.268 .595 .352 r
.30846 .31477 m
.31009 .3145 L
s
.712 .702 .795 r
.71885 .52205 m
.71966 .52032 L
s
.71808 .52378 m
.71885 .52205 L
s
.156 .65 .561 r
.2909 .76942 m
.29078 .76768 L
s
.712 .702 .795 r
.71736 .5255 m
.71808 .52378 L
s
.268 .595 .352 r
.30686 .31506 m
.30846 .31477 L
s
.156 .65 .561 r
.29098 .77117 m
.2909 .76942 L
s
.712 .702 .795 r
.71669 .52722 m
.71736 .5255 L
s
.156 .65 .561 r
.29103 .77293 m
.29098 .77117 L
s
.712 .702 .795 r
.71606 .52893 m
.71669 .52722 L
s
.268 .595 .352 r
.30529 .31537 m
.30686 .31506 L
s
.712 .702 .795 r
.71547 .53063 m
.71606 .52893 L
s
.156 .65 .561 r
.29105 .7747 m
.29103 .77293 L
s
.712 .702 .795 r
.71493 .53232 m
.71547 .53063 L
s
.156 .65 .561 r
.29104 .77648 m
.29105 .7747 L
s
.268 .595 .352 r
.30376 .31572 m
.30529 .31537 L
s
.712 .702 .795 r
.71444 .53401 m
.71493 .53232 L
s
.156 .65 .561 r
.29099 .77826 m
.29104 .77648 L
s
.712 .702 .795 r
.71399 .5357 m
.71444 .53401 L
s
.268 .595 .352 r
.30226 .31609 m
.30376 .31572 L
s
.712 .702 .795 r
.71358 .53738 m
.71399 .5357 L
s
.156 .65 .561 r
.29091 .78006 m
.29099 .77826 L
s
.712 .702 .795 r
.71321 .53905 m
.71358 .53738 L
s
.156 .65 .561 r
.2908 .78186 m
.29091 .78006 L
s
.268 .595 .352 r
.30081 .31649 m
.30226 .31609 L
s
.712 .702 .795 r
.71288 .54072 m
.71321 .53905 L
s
.156 .65 .561 r
.29066 .78367 m
.2908 .78186 L
s
.712 .702 .795 r
.71259 .54238 m
.71288 .54072 L
s
.156 .65 .561 r
.29048 .78549 m
.29066 .78367 L
s
.268 .595 .352 r
.2994 .31692 m
.30081 .31649 L
s
.712 .702 .795 r
.71235 .54403 m
.71259 .54238 L
s
.156 .65 .561 r
.29028 .78732 m
.29048 .78549 L
s
.712 .702 .795 r
.71214 .54569 m
.71235 .54403 L
s
.268 .595 .352 r
.29804 .31739 m
.2994 .31692 L
s
.156 .65 .561 r
.29004 .78916 m
.29028 .78732 L
s
.712 .702 .795 r
.71197 .54733 m
.71214 .54569 L
s
.156 .65 .561 r
.28977 .79101 m
.29004 .78916 L
s
.712 .702 .795 r
.71184 .54898 m
.71197 .54733 L
s
.268 .595 .352 r
.29672 .31789 m
.29804 .31739 L
s
.712 .702 .795 r
.71174 .55062 m
.71184 .54898 L
s
.156 .65 .561 r
.28947 .79286 m
.28977 .79101 L
s
.176 .125 .589 r
.57677 .27477 m
.57725 .27232 L
s
.57631 .27719 m
.57677 .27477 L
s
.57588 .27956 m
.57631 .27719 L
s
.57725 .27232 m
.57774 .26982 L
s
.57546 .28188 m
.57588 .27956 L
s
.57774 .26982 m
.57826 .26729 L
s
.57507 .28417 m
.57546 .28188 L
s
.57826 .26729 m
.57879 .2647 L
s
.57469 .28642 m
.57507 .28417 L
s
.57879 .2647 m
.57935 .26208 L
s
.712 .702 .795 r
.71169 .55225 m
.71174 .55062 L
s
.176 .125 .589 r
.57434 .28862 m
.57469 .28642 L
s
.156 .65 .561 r
.28913 .79472 m
.28947 .79286 L
s
.176 .125 .589 r
.57935 .26208 m
.57992 .25942 L
s
.574 .29079 m
.57434 .28862 L
s
.268 .595 .352 r
.29546 .31843 m
.29672 .31789 L
s
.176 .125 .589 r
.57992 .25942 m
.58052 .25672 L
s
.57368 .29292 m
.574 .29079 L
s
.58052 .25672 m
.58113 .25398 L
s
.57338 .29501 m
.57368 .29292 L
s
.58113 .25398 m
.58176 .25119 L
s
.712 .702 .795 r
.71167 .55388 m
.71169 .55225 L
s
.156 .65 .561 r
.28876 .7966 m
.28913 .79472 L
s
.176 .125 .589 r
.5731 .29706 m
.57338 .29501 L
s
.58176 .25119 m
.58241 .24838 L
s
.57284 .29907 m
.5731 .29706 L
s
.58241 .24838 m
.58308 .24552 L
s
.5726 .30105 m
.57284 .29907 L
s
.58308 .24552 m
.58376 .24264 L
s
.268 .595 .352 r
.29425 .31901 m
.29546 .31843 L
s
.712 .702 .795 r
.71169 .55551 m
.71167 .55388 L
s
.156 .65 .561 r
.28836 .79848 m
.28876 .7966 L
s
.176 .125 .589 r
.58376 .24264 m
.58446 .23972 L
s
.57237 .30299 m
.5726 .30105 L
s
.58446 .23972 m
.58517 .23677 L
s
.57216 .3049 m
.57237 .30299 L
s
.712 .702 .795 r
.71174 .55713 m
.71169 .55551 L
s
.156 .65 .561 r
.28793 .80037 m
.28836 .79848 L
s
.176 .125 .589 r
.58517 .23677 m
.5859 .23379 L
s
.57197 .30678 m
.57216 .3049 L
s
.268 .595 .352 r
.29309 .31963 m
.29425 .31901 L
s
.176 .125 .589 r
.5859 .23379 m
.58663 .23079 L
s
.57179 .30862 m
.57197 .30678 L
s
.712 .702 .795 r
.71183 .55875 m
.71174 .55713 L
s
.156 .65 .561 r
.28746 .80226 m
.28793 .80037 L
s
.176 .125 .589 r
.58663 .23079 m
.58738 .22777 L
s
.57163 .31043 m
.57179 .30862 L
s
.58738 .22777 m
.58814 .22472 L
s
.57149 .31221 m
.57163 .31043 L
s
.712 .702 .795 r
.71196 .56037 m
.71183 .55875 L
s
.156 .65 .561 r
.28696 .80417 m
.28746 .80226 L
s
.268 .595 .352 r
.292 .32029 m
.29309 .31963 L
s
.176 .125 .589 r
.58814 .22472 m
.58891 .22166 L
s
.57136 .31396 m
.57149 .31221 L
s
.58891 .22166 m
.58968 .21858 L
s
.712 .702 .795 r
.71212 .56198 m
.71196 .56037 L
s
.156 .65 .561 r
.28642 .80609 m
.28696 .80417 L
s
.176 .125 .589 r
.57125 .31568 m
.57136 .31396 L
s
.58968 .21858 m
.59046 .2155 L
s
.268 .595 .352 r
.29096 .321 m
.292 .32029 L
s
.176 .125 .589 r
.57115 .31737 m
.57125 .31568 L
s
.712 .702 .795 r
.71232 .56359 m
.71212 .56198 L
s
.156 .65 .561 r
.28585 .80802 m
.28642 .80609 L
s
.176 .125 .589 r
.59046 .2155 m
.59124 .2124 L
s
.57107 .31903 m
.57115 .31737 L
s
.59124 .2124 m
.59202 .2093 L
s
.156 .65 .561 r
.28524 .80995 m
.28585 .80802 L
s
.712 .702 .795 r
.71256 .5652 m
.71232 .56359 L
s
.268 .595 .352 r
.28998 .32175 m
.29096 .321 L
s
.176 .125 .589 r
.59202 .2093 m
.59281 .20621 L
s
.571 .32067 m
.57107 .31903 L
s
.59281 .20621 m
.59359 .20311 L
s
.156 .65 .561 r
.28459 .8119 m
.28524 .80995 L
s
.176 .125 .589 r
.57095 .32227 m
.571 .32067 L
s
.712 .702 .795 r
.71283 .5668 m
.71256 .5652 L
s
.176 .125 .589 r
.59359 .20311 m
.59437 .20002 L
s
.268 .595 .352 r
.28907 .32254 m
.28998 .32175 L
s
.176 .125 .589 r
.57091 .32386 m
.57095 .32227 L
s
.156 .65 .561 r
.28391 .81385 m
.28459 .8119 L
s
.176 .125 .589 r
.59437 .20002 m
.59515 .19695 L
s
.712 .702 .795 r
.71314 .56841 m
.71283 .5668 L
s
.176 .125 .589 r
.59515 .19695 m
.59592 .19389 L
s
.57088 .32541 m
.57091 .32386 L
s
.156 .65 .561 r
.2832 .81581 m
.28391 .81385 L
s
.268 .595 .352 r
.28822 .32338 m
.28907 .32254 L
s
.712 .702 .795 r
.71349 .57 m
.71314 .56841 L
s
.176 .125 .589 r
.59592 .19389 m
.59668 .19084 L
s
.57087 .32694 m
.57088 .32541 L
s
.156 .65 .561 r
.28244 .81779 m
.2832 .81581 L
s
.176 .125 .589 r
.59668 .19084 m
.59744 .18783 L
s
.712 .702 .795 r
.71387 .5716 m
.71349 .57 L
s
.176 .125 .589 r
.59744 .18783 m
.59818 .18483 L
s
.57087 .32845 m
.57087 .32694 L
s
.268 .595 .352 r
.28743 .32426 m
.28822 .32338 L
s
.156 .65 .561 r
.28164 .81977 m
.28244 .81779 L
s
.176 .125 .589 r
.59818 .18483 m
.5989 .18187 L
s
.57088 .32993 m
.57087 .32845 L
s
.5989 .18187 m
.59962 .17894 L
s
.712 .702 .795 r
.71429 .57319 m
.71387 .5716 L
s
.156 .65 .561 r
.28081 .82176 m
.28164 .81977 L
s
.268 .595 .352 r
.28672 .32519 m
.28743 .32426 L
s
.176 .125 .589 r
.59962 .17894 m
.60031 .17606 L
s
.57091 .33139 m
.57088 .32993 L
s
.60031 .17606 m
.60099 .17321 L
s
.712 .702 .795 r
.71475 .57478 m
.71429 .57319 L
s
.156 .65 .561 r
.27994 .82376 m
.28081 .82176 L
s
.176 .125 .589 r
.60099 .17321 m
.60164 .17041 L
s
.60164 .17041 m
.60228 .16766 L
s
.268 .595 .352 r
.28607 .32618 m
.28672 .32519 L
s
.176 .125 .589 r
.57095 .33282 m
.57091 .33139 L
s
.156 .65 .561 r
.27902 .82577 m
.27994 .82376 L
s
.176 .125 .589 r
.60228 .16766 m
.60289 .16496 L
s
.712 .702 .795 r
.71525 .57637 m
.71475 .57478 L
s
.176 .125 .589 r
.60289 .16496 m
.60348 .16232 L
s
.60348 .16232 m
.60404 .15974 L
s
.57101 .33423 m
.57095 .33282 L
s
.60404 .15974 m
.60457 .15723 L
s
.156 .65 .561 r
.27807 .82779 m
.27902 .82577 L
s
.176 .125 .589 r
.60639 .14785 m
.60676 .14569 L
s
.60457 .15723 m
.60507 .15477 L
s
.268 .595 .352 r
.28549 .32721 m
.28607 .32618 L
s
.176 .125 .589 r
.60598 .15008 m
.60639 .14785 L
s
.60507 .15477 m
.60554 .15239 L
s
.60554 .15239 m
.60598 .15008 L
s
.712 .702 .795 r
.71578 .57796 m
.71525 .57637 L
s
.156 .65 .561 r
.27707 .82982 m
.27807 .82779 L
s
.176 .125 .589 r
.57108 .33561 m
.57101 .33423 L
s
.268 .595 .352 r
.28498 .32828 m
.28549 .32721 L
s
.712 .702 .795 r
.71636 .57954 m
.71578 .57796 L
s
.156 .65 .561 r
.27603 .83186 m
.27707 .82982 L
s
.176 .125 .589 r
.57116 .33698 m
.57108 .33561 L
s
.268 .595 .352 r
.28454 .32941 m
.28498 .32828 L
s
.156 .65 .561 r
.27495 .83391 m
.27603 .83186 L
s
.712 .702 .795 r
.71698 .58112 m
.71636 .57954 L
s
.176 .125 .589 r
.57125 .33832 m
.57116 .33698 L
s
.156 .65 .561 r
.27383 .83597 m
.27495 .83391 L
s
.268 .595 .352 r
.28418 .33059 m
.28454 .32941 L
s
.712 .702 .795 r
.71764 .5827 m
.71698 .58112 L
s
.176 .125 .589 r
.57136 .33963 m
.57125 .33832 L
s
.156 .65 .561 r
.27266 .83804 m
.27383 .83597 L
s
.268 .595 .352 r
.28388 .33182 m
.28418 .33059 L
s
.712 .702 .795 r
.71834 .58427 m
.71764 .5827 L
s
.156 .65 .561 r
.27145 .84012 m
.27266 .83804 L
s
.176 .125 .589 r
.57149 .34093 m
.57136 .33963 L
s
.268 .595 .352 r
.28366 .3331 m
.28388 .33182 L
s
.156 .65 .561 r
.27019 .84221 m
.27145 .84012 L
s
.712 .702 .795 r
.71908 .58584 m
.71834 .58427 L
s
.176 .125 .589 r
.57162 .3422 m
.57149 .34093 L
s
.268 .595 .352 r
.28351 .33444 m
.28366 .3331 L
s
.156 .65 .561 r
.26889 .8443 m
.27019 .84221 L
s
.712 .702 .795 r
.71986 .58741 m
.71908 .58584 L
s
.176 .125 .589 r
.57177 .34344 m
.57162 .3422 L
s
.156 .65 .561 r
.26755 .84641 m
.26889 .8443 L
s
.268 .595 .352 r
.28343 .33582 m
.28351 .33444 L
s
.156 .65 .561 r
.26616 .84852 m
.26755 .84641 L
s
.712 .702 .795 r
.72069 .58898 m
.71986 .58741 L
s
.268 .595 .352 r
.28342 .33725 m
.28343 .33582 L
s
.176 .125 .589 r
.57194 .34466 m
.57177 .34344 L
s
.156 .65 .561 r
.26473 .85064 m
.26616 .84852 L
s
.268 .595 .352 r
.28349 .33873 m
.28342 .33725 L
s
.712 .702 .795 r
.72157 .59054 m
.72069 .58898 L
s
.156 .65 .561 r
.26325 .85278 m
.26473 .85064 L
s
.176 .125 .589 r
.57212 .34586 m
.57194 .34466 L
s
.268 .595 .352 r
.28362 .34027 m
.28349 .33873 L
s
.156 .65 .561 r
.26173 .85491 m
.26325 .85278 L
s
.712 .702 .795 r
.72249 .5921 m
.72157 .59054 L
s
.268 .595 .352 r
.28383 .34185 m
.28362 .34027 L
s
.176 .125 .589 r
.57231 .34704 m
.57212 .34586 L
s
.156 .65 .561 r
.26017 .85706 m
.26173 .85491 L
s
.268 .595 .352 r
.28411 .34348 m
.28383 .34185 L
s
.156 .65 .561 r
.25856 .85922 m
.26017 .85706 L
s
.712 .702 .795 r
.72346 .59366 m
.72249 .5921 L
s
.268 .595 .352 r
.28446 .34516 m
.28411 .34348 L
s
.176 .125 .589 r
.57252 .34819 m
.57231 .34704 L
s
.156 .65 .561 r
.25691 .86138 m
.25856 .85922 L
s
.268 .595 .352 r
.28487 .34689 m
.28446 .34516 L
s
.712 .702 .795 r
.72448 .59522 m
.72346 .59366 L
s
.156 .65 .561 r
.25523 .86355 m
.25691 .86138 L
s
.268 .595 .352 r
.28536 .34867 m
.28487 .34689 L
s
.176 .125 .589 r
.57275 .34931 m
.57252 .34819 L
s
.268 .595 .352 r
.2859 .35049 m
.28536 .34867 L
s
.156 .65 .561 r
.2535 .86573 m
.25523 .86355 L
s
.268 .595 .352 r
.28652 .35235 m
.2859 .35049 L
s
.712 .702 .795 r
.72554 .59677 m
.72448 .59522 L
s
.156 .65 .561 r
.25173 .86791 m
.2535 .86573 L
s
.176 .125 .589 r
.57299 .35041 m
.57275 .34931 L
s
.268 .595 .352 r
.28719 .35426 m
.28652 .35235 L
s
.28793 .35622 m
.28719 .35426 L
s
.156 .65 .561 r
.24993 .8701 m
.25173 .86791 L
s
.712 .702 .795 r
.72666 .59831 m
.72554 .59677 L
s
.268 .595 .352 r
.28872 .35821 m
.28793 .35622 L
s
.156 .65 .561 r
.24809 .87229 m
.24993 .8701 L
s
.268 .595 .352 r
.28958 .36025 m
.28872 .35821 L
s
.176 .125 .589 r
.57324 .35148 m
.57299 .35041 L
s
.268 .595 .352 r
.29049 .36232 m
.28958 .36025 L
s
.29145 .36443 m
.29049 .36232 L
s
.156 .65 .561 r
.24622 .87449 m
.24809 .87229 L
s
.268 .595 .352 r
.29246 .36658 m
.29145 .36443 L
s
.712 .702 .795 r
.72783 .59986 m
.72666 .59831 L
s
.268 .595 .352 r
.29352 .36876 m
.29246 .36658 L
s
.156 .65 .561 r
.24432 .8767 m
.24622 .87449 L
s
.268 .595 .352 r
.29462 .37098 m
.29352 .36876 L
s
.29577 .37322 m
.29462 .37098 L
s
.176 .125 .589 r
.57352 .35253 m
.57324 .35148 L
s
.268 .595 .352 r
.29696 .3755 m
.29577 .37322 L
s
.29819 .3778 m
.29696 .3755 L
s
.29945 .38013 m
.29819 .3778 L
s
.156 .65 .561 r
.24238 .87891 m
.24432 .8767 L
s
.268 .595 .352 r
.30074 .38248 m
.29945 .38013 L
s
.30206 .38485 m
.30074 .38248 L
s
.3034 .38724 m
.30206 .38485 L
s
.30477 .38965 m
.3034 .38724 L
s
.31611 .40928 m
.31468 .40681 L
s
.31753 .41175 m
.31611 .40928 L
s
.31468 .40681 m
.31325 .40434 L
s
.31895 .41422 m
.31753 .41175 L
s
.30616 .39207 m
.30477 .38965 L
s
.31325 .40434 m
.31182 .40187 L
s
.31182 .40187 m
.31039 .39941 L
s
.32035 .41668 m
.31895 .41422 L
s
.30756 .39451 m
.30616 .39207 L
s
.31039 .39941 m
.30897 .39695 L
s
.30897 .39695 m
.30756 .39451 L
s
.32174 .41914 m
.32035 .41668 L
s
.712 .702 .795 r
.72904 .6014 m
.72783 .59986 L
s
.268 .595 .352 r
.32311 .42159 m
.32174 .41914 L
s
.32446 .42403 m
.32311 .42159 L
s
.32579 .42646 m
.32446 .42403 L
s
.32709 .42888 m
.32579 .42646 L
s
.32838 .43128 m
.32709 .42888 L
s
.32963 .43367 m
.32838 .43128 L
s
.156 .65 .561 r
.24042 .88112 m
.24238 .87891 L
s
.268 .595 .352 r
.33085 .43604 m
.32963 .43367 L
s
.33205 .4384 m
.33085 .43604 L
s
.176 .125 .589 r
.5738 .35355 m
.57352 .35253 L
s
.268 .595 .352 r
.33321 .44074 m
.33205 .4384 L
s
.33434 .44306 m
.33321 .44074 L
s
.33543 .44536 m
.33434 .44306 L
s
.712 .702 .795 r
.73032 .60293 m
.72904 .6014 L
s
.268 .595 .352 r
.33649 .44764 m
.33543 .44536 L
s
.33752 .44991 m
.33649 .44764 L
s
.33851 .45215 m
.33752 .44991 L
s
.176 .125 .589 r
.57411 .35454 m
.5738 .35355 L
s
.268 .595 .352 r
.33946 .45437 m
.33851 .45215 L
s
.712 .702 .795 r
.73164 .60447 m
.73032 .60293 L
s
.268 .595 .352 r
.34037 .45658 m
.33946 .45437 L
s
.34125 .45876 m
.34037 .45658 L
s
.34209 .46092 m
.34125 .45876 L
s
.176 .125 .589 r
.57444 .35551 m
.57411 .35454 L
s
.268 .595 .352 r
.34289 .46306 m
.34209 .46092 L
s
.712 .702 .795 r
.73302 .606 m
.73164 .60447 L
s
.268 .595 .352 r
.34366 .46518 m
.34289 .46306 L
s
.34438 .46728 m
.34366 .46518 L
s
.34507 .46935 m
.34438 .46728 L
s
.712 .702 .795 r
.73445 .60752 m
.73302 .606 L
s
.176 .125 .589 r
.57478 .35645 m
.57444 .35551 L
s
.268 .595 .352 r
.34573 .47141 m
.34507 .46935 L
s
.34634 .47345 m
.34573 .47141 L
s
.712 .702 .795 r
.73594 .60904 m
.73445 .60752 L
s
.268 .595 .352 r
.34693 .47547 m
.34634 .47345 L
s
.176 .125 .589 r
.57514 .35735 m
.57478 .35645 L
s
.268 .595 .352 r
.34747 .47747 m
.34693 .47547 L
s
.34798 .47945 m
.34747 .47747 L
s
.712 .702 .795 r
.73749 .61056 m
.73594 .60904 L
s
.176 .125 .589 r
.57552 .35823 m
.57514 .35735 L
s
.268 .595 .352 r
.34846 .48141 m
.34798 .47945 L
s
.3489 .48335 m
.34846 .48141 L
s
.712 .702 .795 r
.73909 .61207 m
.73749 .61056 L
s
.268 .595 .352 r
.34931 .48528 m
.3489 .48335 L
s
.176 .125 .589 r
.57591 .35908 m
.57552 .35823 L
s
.268 .595 .352 r
.34968 .48719 m
.34931 .48528 L
s
.712 .702 .795 r
.74074 .61358 m
.73909 .61207 L
s
.268 .595 .352 r
.35002 .48908 m
.34968 .48719 L
s
.176 .125 .589 r
.57633 .35989 m
.57591 .35908 L
s
.268 .595 .352 r
.35033 .49096 m
.35002 .48908 L
s
.712 .702 .795 r
.74246 .61508 m
.74074 .61358 L
s
.268 .595 .352 r
.35061 .49282 m
.35033 .49096 L
s
.176 .125 .589 r
.57677 .36067 m
.57633 .35989 L
s
.712 .702 .795 r
.74423 .61658 m
.74246 .61508 L
s
.268 .595 .352 r
.35086 .49466 m
.35061 .49282 L
s
.35108 .49649 m
.35086 .49466 L
s
.712 .702 .795 r
.74606 .61808 m
.74423 .61658 L
s
.176 .125 .589 r
.57723 .36142 m
.57677 .36067 L
s
.268 .595 .352 r
.35127 .4983 m
.35108 .49649 L
s
.35143 .5001 m
.35127 .4983 L
s
.712 .702 .795 r
.74794 .61957 m
.74606 .61808 L
s
.268 .595 .352 r
.35156 .50189 m
.35143 .5001 L
s
.176 .125 .589 r
.57771 .36214 m
.57723 .36142 L
s
.268 .595 .352 r
.35166 .50366 m
.35156 .50189 L
s
.712 .702 .795 r
.74988 .62105 m
.74794 .61957 L
s
.268 .595 .352 r
.35173 .50542 m
.35166 .50366 L
s
.176 .125 .589 r
.57821 .36282 m
.57771 .36214 L
s
.712 .702 .795 r
.75187 .62253 m
.74988 .62105 L
s
.268 .595 .352 r
.35177 .50717 m
.35173 .50542 L
s
.35179 .5089 m
.35177 .50717 L
s
.176 .125 .589 r
.57874 .36347 m
.57821 .36282 L
s
.712 .702 .795 r
.75392 .62401 m
.75187 .62253 L
s
.268 .595 .352 r
.35178 .51062 m
.35179 .5089 L
s
.712 .702 .795 r
.75602 .62549 m
.75392 .62401 L
s
.176 .125 .589 r
.57928 .36408 m
.57874 .36347 L
s
.268 .595 .352 r
.35174 .51233 m
.35178 .51062 L
s
.35167 .51403 m
.35174 .51233 L
s
.712 .702 .795 r
.75817 .62696 m
.75602 .62549 L
s
.176 .125 .589 r
.57985 .36466 m
.57928 .36408 L
s
.268 .595 .352 r
.35158 .51572 m
.35167 .51403 L
s
.712 .702 .795 r
.76038 .62842 m
.75817 .62696 L
s
.268 .595 .352 r
.35146 .51739 m
.35158 .51572 L
s
.176 .125 .589 r
.58044 .3652 m
.57985 .36466 L
s
.268 .595 .352 r
.35131 .51905 m
.35146 .51739 L
s
.712 .702 .795 r
.76263 .62988 m
.76038 .62842 L
s
.268 .595 .352 r
.35113 .52071 m
.35131 .51905 L
s
.712 .702 .795 r
.76492 .63134 m
.76263 .62988 L
s
.176 .125 .589 r
.58106 .3657 m
.58044 .3652 L
s
.268 .595 .352 r
.35093 .52235 m
.35113 .52071 L
s
.3507 .52398 m
.35093 .52235 L
s
.712 .702 .795 r
.76727 .6328 m
.76492 .63134 L
s
.176 .125 .589 r
.5817 .36617 m
.58106 .3657 L
s
.268 .595 .352 r
.35044 .5256 m
.3507 .52398 L
s
.712 .702 .795 r
.76965 .63426 m
.76727 .6328 L
s
.268 .595 .352 r
.35016 .52721 m
.35044 .5256 L
s
.176 .125 .589 r
.58236 .3666 m
.5817 .36617 L
s
.712 .702 .795 r
.77207 .63571 m
.76965 .63426 L
s
.268 .595 .352 r
.34984 .5288 m
.35016 .52721 L
s
.3495 .53039 m
.34984 .5288 L
s
.712 .702 .795 r
.77453 .63716 m
.77207 .63571 L
s
.176 .125 .589 r
.58305 .36699 m
.58236 .3666 L
s
.268 .595 .352 r
.34913 .53197 m
.3495 .53039 L
s
.712 .702 .795 r
.77702 .63861 m
.77453 .63716 L
s
.268 .595 .352 r
.34872 .53353 m
.34913 .53197 L
s
.176 .125 .589 r
.58376 .36735 m
.58305 .36699 L
s
.712 .702 .795 r
.77954 .64005 m
.77702 .63861 L
s
.268 .595 .352 r
.34829 .53509 m
.34872 .53353 L
s
.176 .125 .589 r
.58449 .36767 m
.58376 .36735 L
s
.712 .702 .795 r
.78209 .6415 m
.77954 .64005 L
s
.268 .595 .352 r
.34783 .53663 m
.34829 .53509 L
s
.34734 .53816 m
.34783 .53663 L
s
.712 .702 .795 r
.78466 .64295 m
.78209 .6415 L
s
.176 .125 .589 r
.58525 .36795 m
.58449 .36767 L
s
.268 .595 .352 r
.34681 .53968 m
.34734 .53816 L
s
.712 .702 .795 r
.78726 .64439 m
.78466 .64295 L
s
.268 .595 .352 r
.34625 .54119 m
.34681 .53968 L
s
.176 .125 .589 r
.58604 .36819 m
.58525 .36795 L
s
.712 .702 .795 r
.78986 .64584 m
.78726 .64439 L
s
.268 .595 .352 r
.34566 .54269 m
.34625 .54119 L
s
.712 .702 .795 r
.79248 .64729 m
.78986 .64584 L
s
.268 .595 .352 r
.34504 .54417 m
.34566 .54269 L
s
.176 .125 .589 r
.58684 .3684 m
.58604 .36819 L
s
.712 .702 .795 r
.79511 .64874 m
.79248 .64729 L
s
.268 .595 .352 r
.34438 .54565 m
.34504 .54417 L
s
.176 .125 .589 r
.58767 .36857 m
.58684 .3684 L
s
.268 .595 .352 r
.34368 .54711 m
.34438 .54565 L
s
.712 .702 .795 r
.79774 .6502 m
.79511 .64874 L
s
.268 .595 .352 r
.34295 .54855 m
.34368 .54711 L
s
.712 .702 .795 r
.80037 .65166 m
.79774 .6502 L
s
.176 .125 .589 r
.58853 .3687 m
.58767 .36857 L
s
.268 .595 .352 r
.34219 .54999 m
.34295 .54855 L
s
.712 .702 .795 r
.803 .65312 m
.80037 .65166 L
s
.268 .595 .352 r
.34138 .55141 m
.34219 .54999 L
s
.176 .125 .589 r
.5894 .3688 m
.58853 .3687 L
s
.712 .702 .795 r
.80561 .65459 m
.803 .65312 L
s
.268 .595 .352 r
.34054 .55282 m
.34138 .55141 L
s
.712 .702 .795 r
.80821 .65606 m
.80561 .65459 L
s
.176 .125 .589 r
.5903 .36887 m
.5894 .3688 L
s
.268 .595 .352 r
.33966 .55421 m
.34054 .55282 L
s
.712 .702 .795 r
.8108 .65753 m
.80821 .65606 L
s
.268 .595 .352 r
.33873 .55559 m
.33966 .55421 L
s
.176 .125 .589 r
.59122 .36891 m
.5903 .36887 L
s
.712 .702 .795 r
.81336 .65902 m
.8108 .65753 L
s
.268 .595 .352 r
.33777 .55696 m
.33873 .55559 L
s
.712 .702 .795 r
.81589 .66051 m
.81336 .65902 L
s
.176 .125 .589 r
.59217 .36892 m
.59122 .36891 L
s
.268 .595 .352 r
.33677 .55831 m
.33777 .55696 L
s
.712 .702 .795 r
.8184 .66201 m
.81589 .66051 L
s
.268 .595 .352 r
.33572 .55965 m
.33677 .55831 L
s
.712 .702 .795 r
.82086 .66352 m
.8184 .66201 L
s
.176 .125 .589 r
.59313 .36889 m
.59217 .36892 L
s
.268 .595 .352 r
.33463 .56097 m
.33572 .55965 L
s
.712 .702 .795 r
.82329 .66503 m
.82086 .66352 L
s
.268 .595 .352 r
.3335 .56228 m
.33463 .56097 L
s
.712 .702 .795 r
.82567 .66656 m
.82329 .66503 L
s
.176 .125 .589 r
.59411 .36885 m
.59313 .36889 L
s
.712 .702 .795 r
.82801 .6681 m
.82567 .66656 L
s
.268 .595 .352 r
.33233 .56357 m
.3335 .56228 L
s
.176 .125 .589 r
.59511 .36877 m
.59411 .36885 L
s
.712 .702 .795 r
.83029 .66964 m
.82801 .6681 L
s
.268 .595 .352 r
.33111 .56484 m
.33233 .56357 L
s
.712 .702 .795 r
.83252 .6712 m
.83029 .66964 L
s
.268 .595 .352 r
.32984 .5661 m
.33111 .56484 L
s
.176 .125 .589 r
.59612 .36867 m
.59511 .36877 L
s
.712 .702 .795 r
.83469 .67278 m
.83252 .6712 L
s
.268 .595 .352 r
.32854 .56735 m
.32984 .5661 L
s
.712 .702 .795 r
.8368 .67436 m
.83469 .67278 L
s
.176 .125 .589 r
.59716 .36855 m
.59612 .36867 L
s
.268 .595 .352 r
.32718 .56858 m
.32854 .56735 L
s
.712 .702 .795 r
.83883 .67596 m
.8368 .67436 L
s
.8408 .67757 m
.83883 .67596 L
s
.268 .595 .352 r
.32579 .56979 m
.32718 .56858 L
s
.176 .125 .589 r
.5982 .36842 m
.59716 .36855 L
s
.712 .702 .795 r
.8427 .67919 m
.8408 .67757 L
s
.268 .595 .352 r
.32434 .57099 m
.32579 .56979 L
s
.712 .702 .795 r
.84451 .68084 m
.8427 .67919 L
s
.176 .125 .589 r
.59926 .36826 m
.5982 .36842 L
s
.268 .595 .352 r
.32286 .57218 m
.32434 .57099 L
s
.712 .702 .795 r
.84625 .68249 m
.84451 .68084 L
s
.84791 .68416 m
.84625 .68249 L
s
.176 .125 .589 r
.60033 .3681 m
.59926 .36826 L
s
.268 .595 .352 r
.32133 .57335 m
.32286 .57218 L
s
.712 .702 .795 r
.84948 .68585 m
.84791 .68416 L
s
.268 .595 .352 r
.31976 .5745 m
.32133 .57335 L
s
.712 .702 .795 r
.85097 .68756 m
.84948 .68585 L
s
.176 .125 .589 r
.60142 .36792 m
.60033 .3681 L
s
.712 .702 .795 r
.85236 .68928 m
.85097 .68756 L
s
.268 .595 .352 r
.31814 .57565 m
.31976 .5745 L
s
.712 .702 .795 r
.85367 .69102 m
.85236 .68928 L
s
.176 .125 .589 r
.60251 .36774 m
.60142 .36792 L
s
.268 .595 .352 r
.31648 .57677 m
.31814 .57565 L
s
.712 .702 .795 r
.85488 .69277 m
.85367 .69102 L
s
.856 .69455 m
.85488 .69277 L
s
.268 .595 .352 r
.31478 .57789 m
.31648 .57677 L
s
.176 .125 .589 r
.6036 .36755 m
.60251 .36774 L
s
.712 .702 .795 r
.85702 .69634 m
.856 .69455 L
s
.85794 .69815 m
.85702 .69634 L
s
.268 .595 .352 r
.31305 .57899 m
.31478 .57789 L
s
.712 .702 .795 r
.85876 .69998 m
.85794 .69815 L
s
.176 .125 .589 r
.60471 .36736 m
.6036 .36755 L
s
.712 .702 .795 r
.85948 .70183 m
.85876 .69998 L
s
.268 .595 .352 r
.31127 .58008 m
.31305 .57899 L
s
.712 .702 .795 r
.86011 .7037 m
.85948 .70183 L
s
.176 .125 .589 r
.60581 .36717 m
.60471 .36736 L
s
.268 .595 .352 r
.30946 .58116 m
.31127 .58008 L
s
.712 .702 .795 r
.86063 .70559 m
.86011 .7037 L
s
.86105 .70749 m
.86063 .70559 L
s
.268 .595 .352 r
.30761 .58223 m
.30946 .58116 L
s
.712 .702 .795 r
.86136 .70942 m
.86105 .70749 L
s
.176 .125 .589 r
.60692 .36699 m
.60581 .36717 L
s
.712 .702 .795 r
.86158 .71137 m
.86136 .70942 L
s
.268 .595 .352 r
.30573 .58329 m
.30761 .58223 L
s
.712 .702 .795 r
.86169 .71333 m
.86158 .71137 L
s
.176 .125 .589 r
.60803 .36681 m
.60692 .36699 L
s
.712 .702 .795 r
.8617 .71532 m
.86169 .71333 L
s
.268 .595 .352 r
.30382 .58434 m
.30573 .58329 L
s
.712 .702 .795 r
.86161 .71732 m
.8617 .71532 L
s
.86142 .71935 m
.86161 .71732 L
s
.176 .125 .589 r
.60913 .36665 m
.60803 .36681 L
s
.712 .702 .795 r
.86113 .72139 m
.86142 .71935 L
s
.268 .595 .352 r
.30188 .58539 m
.30382 .58434 L
s
.712 .702 .795 r
.86075 .72345 m
.86113 .72139 L
s
.86026 .72554 m
.86075 .72345 L
s
.268 .595 .352 r
.29991 .58643 m
.30188 .58539 L
s
.176 .125 .589 r
.61023 .3665 m
.60913 .36665 L
s
.712 .702 .795 r
.85968 .72764 m
.86026 .72554 L
s
.85901 .72976 m
.85968 .72764 L
s
.85825 .7319 m
.85901 .72976 L
s
.268 .595 .352 r
.29792 .58746 m
.29991 .58643 L
s
.176 .125 .589 r
.61132 .36637 m
.61023 .3665 L
s
.712 .702 .795 r
.85739 .73406 m
.85825 .7319 L
s
.85645 .73623 m
.85739 .73406 L
s
.268 .595 .352 r
.29591 .5885 m
.29792 .58746 L
s
.712 .702 .795 r
.85543 .73843 m
.85645 .73623 L
s
.85432 .74064 m
.85543 .73843 L
s
.176 .125 .589 r
.61241 .36627 m
.61132 .36637 L
s
.712 .702 .795 r
.85313 .74287 m
.85432 .74064 L
s
.268 .595 .352 r
.29388 .58953 m
.29591 .5885 L
s
.712 .702 .795 r
.85187 .74512 m
.85313 .74287 L
s
.85053 .74738 m
.85187 .74512 L
s
.84913 .74966 m
.85053 .74738 L
s
.176 .125 .589 r
.61348 .36619 m
.61241 .36627 L
s
.268 .595 .352 r
.29183 .59055 m
.29388 .58953 L
s
.712 .702 .795 r
.84766 .75195 m
.84913 .74966 L
s
.84612 .75426 m
.84766 .75195 L
s
.84453 .75659 m
.84612 .75426 L
s
.176 .125 .589 r
.61455 .36614 m
.61348 .36619 L
s
.268 .595 .352 r
.28978 .59158 m
.29183 .59055 L
s
.712 .702 .795 r
.84288 .75893 m
.84453 .75659 L
s
.84118 .76128 m
.84288 .75893 L
s
.83943 .76365 m
.84118 .76128 L
s
.83765 .76603 m
.83943 .76365 L
s
.268 .595 .352 r
.28771 .59262 m
.28978 .59158 L
s
.176 .125 .589 r
.61559 .36612 m
.61455 .36614 L
s
.712 .702 .795 r
.83582 .76842 m
.83765 .76603 L
s
.83396 .77082 m
.83582 .76842 L
s
.83207 .77323 m
.83396 .77082 L
s
.268 .595 .352 r
.28563 .59365 m
.28771 .59262 L
s
.712 .702 .795 r
.83015 .77566 m
.83207 .77323 L
s
.176 .125 .589 r
.61663 .36614 m
.61559 .36612 L
s
.712 .702 .795 r
.82822 .77809 m
.83015 .77566 L
s
.82626 .78053 m
.82822 .77809 L
s
.8243 .78298 m
.82626 .78053 L
s
.268 .595 .352 r
.28356 .59469 m
.28563 .59365 L
s
.712 .702 .795 r
.82233 .78544 m
.8243 .78298 L
s
.82035 .78791 m
.82233 .78544 L
s
.176 .125 .589 r
.61764 .36619 m
.61663 .36614 L
s
.712 .702 .795 r
.81838 .79038 m
.82035 .78791 L
s
.268 .595 .352 r
.28148 .59574 m
.28356 .59469 L
s
.712 .702 .795 r
.81641 .79286 m
.81838 .79038 L
s
.81445 .79534 m
.81641 .79286 L
s
.176 .125 .589 r
.61863 .36629 m
.61764 .36619 L
s
.712 .702 .795 r
.8125 .79783 m
.81445 .79534 L
s
.81058 .80032 m
.8125 .79783 L
s
.268 .595 .352 r
.27941 .5968 m
.28148 .59574 L
s
.712 .702 .795 r
.80867 .80282 m
.81058 .80032 L
s
.80678 .80532 m
.80867 .80282 L
s
.176 .125 .589 r
.6196 .36644 m
.61863 .36629 L
s
.712 .702 .795 r
.80493 .80782 m
.80678 .80532 L
s
.268 .595 .352 r
.27735 .59786 m
.27941 .5968 L
s
.712 .702 .795 r
.8031 .81033 m
.80493 .80782 L
s
.176 .125 .589 r
.62055 .36663 m
.6196 .36644 L
s
.268 .595 .352 r
.2753 .59894 m
.27735 .59786 L
s
.27326 .60003 m
.2753 .59894 L
s
.176 .125 .589 r
.62147 .36688 m
.62055 .36663 L
s
.268 .595 .352 r
.27124 .60114 m
.27326 .60003 L
s
.176 .125 .589 r
.62237 .36718 m
.62147 .36688 L
s
.268 .595 .352 r
.26924 .60226 m
.27124 .60114 L
s
.176 .125 .589 r
.62323 .36753 m
.62237 .36718 L
s
.268 .595 .352 r
.26727 .60341 m
.26924 .60226 L
s
.176 .125 .589 r
.62407 .36795 m
.62323 .36753 L
s
.268 .595 .352 r
.26533 .60457 m
.26727 .60341 L
s
.176 .125 .589 r
.62487 .36843 m
.62407 .36795 L
s
.268 .595 .352 r
.26342 .60575 m
.26533 .60457 L
s
.176 .125 .589 r
.62564 .36898 m
.62487 .36843 L
s
.268 .595 .352 r
.26155 .60696 m
.26342 .60575 L
s
.176 .125 .589 r
.62637 .36959 m
.62564 .36898 L
s
.268 .595 .352 r
.25971 .60819 m
.26155 .60696 L
s
.176 .125 .589 r
.62706 .37028 m
.62637 .36959 L
s
.268 .595 .352 r
.25792 .60944 m
.25971 .60819 L
s
.176 .125 .589 r
.62772 .37103 m
.62706 .37028 L
s
.268 .595 .352 r
.25617 .61073 m
.25792 .60944 L
s
.176 .125 .589 r
.62834 .37186 m
.62772 .37103 L
s
.268 .595 .352 r
.25448 .61204 m
.25617 .61073 L
s
.176 .125 .589 r
.62892 .37277 m
.62834 .37186 L
s
.268 .595 .352 r
.25283 .61338 m
.25448 .61204 L
s
.176 .125 .589 r
.62945 .37375 m
.62892 .37277 L
s
.268 .595 .352 r
.25124 .61475 m
.25283 .61338 L
s
.176 .125 .589 r
.62994 .37481 m
.62945 .37375 L
s
.63039 .37595 m
.62994 .37481 L
s
.268 .595 .352 r
.24971 .61616 m
.25124 .61475 L
s
.176 .125 .589 r
.6308 .37717 m
.63039 .37595 L
s
.268 .595 .352 r
.24823 .6176 m
.24971 .61616 L
s
.176 .125 .589 r
.63116 .37847 m
.6308 .37717 L
s
.268 .595 .352 r
.24682 .61907 m
.24823 .6176 L
s
.176 .125 .589 r
.63148 .37986 m
.63116 .37847 L
s
.59875 .55003 m
.59935 .54697 L
s
.59817 .55306 m
.59875 .55003 L
s
.59762 .55606 m
.59817 .55306 L
s
.59935 .54697 m
.59997 .54387 L
s
.59709 .55903 m
.59762 .55606 L
s
.59997 .54387 m
.60062 .54074 L
s
.59658 .56196 m
.59709 .55903 L
s
.268 .595 .352 r
.24548 .62058 m
.24682 .61907 L
s
.176 .125 .589 r
.60062 .54074 m
.60128 .53758 L
s
.5961 .56486 m
.59658 .56196 L
s
.60128 .53758 m
.60197 .53438 L
s
.59563 .56773 m
.5961 .56486 L
s
.63175 .38133 m
.63148 .37986 L
s
.60197 .53438 m
.60268 .53116 L
s
.5952 .57057 m
.59563 .56773 L
s
.60268 .53116 m
.60341 .52791 L
s
.59478 .57337 m
.5952 .57057 L
s
.60341 .52791 m
.60416 .52463 L
s
.59439 .57614 m
.59478 .57337 L
s
.60416 .52463 m
.60493 .52132 L
s
.59402 .57888 m
.59439 .57614 L
s
.60493 .52132 m
.60571 .51799 L
s
.63197 .38288 m
.63175 .38133 L
s
.59368 .58159 m
.59402 .57888 L
s
.268 .595 .352 r
.2442 .62213 m
.24548 .62058 L
s
.176 .125 .589 r
.60571 .51799 m
.60651 .51463 L
s
.59335 .58427 m
.59368 .58159 L
s
.60651 .51463 m
.60732 .51126 L
s
.59305 .58692 m
.59335 .58427 L
s
.60732 .51126 m
.60815 .50786 L
s
.63214 .38451 m
.63197 .38288 L
s
.60815 .50786 m
.60899 .50444 L
s
.59277 .58955 m
.59305 .58692 L
s
.60899 .50444 m
.60985 .50101 L
s
.268 .595 .352 r
.24299 .62371 m
.2442 .62213 L
s
.176 .125 .589 r
.59251 .59214 m
.59277 .58955 L
s
.60985 .50101 m
.61071 .49756 L
s
.63227 .38623 m
.63214 .38451 L
s
.59227 .59471 m
.59251 .59214 L
s
.61071 .49756 m
.61158 .49411 L
s
.59205 .59725 m
.59227 .59471 L
s
.61158 .49411 m
.61245 .49064 L
s
.63236 .38803 m
.63227 .38623 L
s
.268 .595 .352 r
.24186 .62533 m
.24299 .62371 L
s
.176 .125 .589 r
.59186 .59977 m
.59205 .59725 L
s
.61245 .49064 m
.61333 .48717 L
s
.61333 .48717 m
.61421 .4837 L
s
.59168 .60226 m
.59186 .59977 L
s
.63239 .38991 m
.63236 .38803 L
s
.61421 .4837 m
.6151 .48022 L
s
.59152 .60473 m
.59168 .60226 L
s
.268 .595 .352 r
.2408 .62699 m
.24186 .62533 L
s
.176 .125 .589 r
.6151 .48022 m
.61598 .47675 L
s
.63238 .39188 m
.63239 .38991 L
s
.61598 .47675 m
.61686 .47329 L
s
.59138 .60717 m
.59152 .60473 L
s
.63233 .39392 m
.63238 .39188 L
s
.61686 .47329 m
.61773 .46984 L
s
.59126 .60959 m
.59138 .60717 L
s
.268 .595 .352 r
.23981 .62869 m
.2408 .62699 L
s
.176 .125 .589 r
.61773 .46984 m
.61859 .4664 L
s
.63223 .39605 m
.63233 .39392 L
s
.61859 .4664 m
.61945 .46297 L
s
.59117 .61199 m
.59126 .60959 L
s
.63208 .39826 m
.63223 .39605 L
s
.61945 .46297 m
.6203 .45957 L
s
.268 .595 .352 r
.2389 .63043 m
.23981 .62869 L
s
.176 .125 .589 r
.59108 .61436 m
.59117 .61199 L
s
.6203 .45957 m
.62113 .45619 L
s
.63188 .40054 m
.63208 .39826 L
s
.62113 .45619 m
.62194 .45283 L
s
.63165 .40291 m
.63188 .40054 L
s
.62194 .45283 m
.62274 .44951 L
s
.59102 .61671 m
.59108 .61436 L
s
.63137 .40535 m
.63165 .40291 L
s
.62274 .44951 m
.62352 .44622 L
s
.268 .595 .352 r
.23807 .63221 m
.2389 .63043 L
s
.176 .125 .589 r
.62352 .44622 m
.62428 .44296 L
s
.63104 .40786 m
.63137 .40535 L
s
.59098 .61905 m
.59102 .61671 L
s
.62428 .44296 m
.62501 .43974 L
s
.63068 .41044 m
.63104 .40786 L
s
.62501 .43974 m
.62572 .43657 L
s
.63027 .4131 m
.63068 .41044 L
s
.62572 .43657 m
.6264 .43345 L
s
.62983 .41582 m
.63027 .4131 L
s
.6264 .43345 m
.62706 .43037 L
s
.59095 .62136 m
.59098 .61905 L
s
.62934 .41861 m
.62983 .41582 L
s
.62706 .43037 m
.62768 .42734 L
s
.62882 .42146 m
.62934 .41861 L
s
.62768 .42734 m
.62827 .42437 L
s
.62827 .42437 m
.62882 .42146 L
s
.268 .595 .352 r
.23732 .63403 m
.23807 .63221 L
s
.176 .125 .589 r
.59094 .62366 m
.59095 .62136 L
s
.268 .595 .352 r
.23665 .63589 m
.23732 .63403 L
s
.176 .125 .589 r
.59096 .62593 m
.59094 .62366 L
s
.268 .595 .352 r
.23606 .6378 m
.23665 .63589 L
s
.176 .125 .589 r
.59098 .62819 m
.59096 .62593 L
s
.59103 .63043 m
.59098 .62819 L
s
.268 .595 .352 r
.23555 .63974 m
.23606 .6378 L
s
.176 .125 .589 r
.59109 .63265 m
.59103 .63043 L
s
.268 .595 .352 r
.23513 .64173 m
.23555 .63974 L
s
.176 .125 .589 r
.59117 .63485 m
.59109 .63265 L
s
.268 .595 .352 r
.23479 .64376 m
.23513 .64173 L
s
.176 .125 .589 r
.59127 .63704 m
.59117 .63485 L
s
.268 .595 .352 r
.23453 .64583 m
.23479 .64376 L
s
.176 .125 .589 r
.59139 .6392 m
.59127 .63704 L
s
.268 .595 .352 r
.23436 .64795 m
.23453 .64583 L
s
.176 .125 .589 r
.59152 .64136 m
.59139 .6392 L
s
.268 .595 .352 r
.23427 .6501 m
.23436 .64795 L
s
.23426 .6523 m
.23427 .6501 L
s
.176 .125 .589 r
.59167 .64349 m
.59152 .64136 L
s
.268 .595 .352 r
.23434 .65454 m
.23426 .6523 L
s
.176 .125 .589 r
.59184 .64561 m
.59167 .64349 L
s
.268 .595 .352 r
.23449 .65682 m
.23434 .65454 L
s
.176 .125 .589 r
.59203 .64772 m
.59184 .64561 L
s
.268 .595 .352 r
.23473 .65914 m
.23449 .65682 L
s
.23505 .6615 m
.23473 .65914 L
s
.176 .125 .589 r
.59224 .64981 m
.59203 .64772 L
s
.268 .595 .352 r
.23545 .6639 m
.23505 .6615 L
s
.23593 .66634 m
.23545 .6639 L
s
.176 .125 .589 r
.59246 .65188 m
.59224 .64981 L
s
.268 .595 .352 r
.23648 .66881 m
.23593 .66634 L
s
.23711 .67132 m
.23648 .66881 L
s
.176 .125 .589 r
.59271 .65393 m
.59246 .65188 L
s
.268 .595 .352 r
.23781 .67387 m
.23711 .67132 L
s
.23859 .67646 m
.23781 .67387 L
s
.176 .125 .589 r
.59297 .65597 m
.59271 .65393 L
s
.268 .595 .352 r
.23943 .67907 m
.23859 .67646 L
s
.24033 .68173 m
.23943 .67907 L
s
.24131 .68441 m
.24033 .68173 L
s
.24234 .68712 m
.24131 .68441 L
s
.176 .125 .589 r
.59325 .658 m
.59297 .65597 L
s
.268 .595 .352 r
.24343 .68987 m
.24234 .68712 L
s
.24458 .69264 m
.24343 .68987 L
s
.24578 .69544 m
.24458 .69264 L
s
.24703 .69826 m
.24578 .69544 L
s
.176 .125 .589 r
.59355 .66001 m
.59325 .658 L
s
.268 .595 .352 r
.24833 .70111 m
.24703 .69826 L
s
.24967 .70398 m
.24833 .70111 L
s
.25105 .70687 m
.24967 .70398 L
s
.25246 .70978 m
.25105 .70687 L
s
.25391 .71271 m
.25246 .70978 L
s
.25539 .71566 m
.25391 .71271 L
s
.2569 .71862 m
.25539 .71566 L
s
.176 .125 .589 r
.59387 .662 m
.59355 .66001 L
s
.268 .595 .352 r
.25842 .7216 m
.2569 .71862 L
s
.25997 .72459 m
.25842 .7216 L
s
.26153 .72759 m
.25997 .72459 L
s
.2631 .73059 m
.26153 .72759 L
s
.26468 .73361 m
.2631 .73059 L
s
.26626 .73663 m
.26468 .73361 L
s
.26785 .73966 m
.26626 .73663 L
s
.26943 .74269 m
.26785 .73966 L
s
.27101 .74572 m
.26943 .74269 L
s
.27257 .74876 m
.27101 .74572 L
s
.27413 .75179 m
.27257 .74876 L
s
.27566 .75482 m
.27413 .75179 L
s
.176 .125 .589 r
.59422 .66398 m
.59387 .662 L
s
.268 .595 .352 r
.27718 .75785 m
.27566 .75482 L
s
.27868 .76088 m
.27718 .75785 L
s
.28016 .7639 m
.27868 .76088 L
s
.28161 .76691 m
.28016 .7639 L
s
.176 .125 .589 r
.59458 .66594 m
.59422 .66398 L
s
.59496 .66788 m
.59458 .66594 L
s
.59537 .66981 m
.59496 .66788 L
s
.5958 .67172 m
.59537 .66981 L
s
.59625 .67361 m
.5958 .67172 L
s
.59672 .67549 m
.59625 .67361 L
s
.59722 .67735 m
.59672 .67549 L
s
.59774 .67919 m
.59722 .67735 L
s
.59829 .68101 m
.59774 .67919 L
s
.59886 .68281 m
.59829 .68101 L
s
.59946 .6846 m
.59886 .68281 L
s
.60009 .68637 m
.59946 .6846 L
s
.60074 .68812 m
.60009 .68637 L
s
.60141 .68984 m
.60074 .68812 L
s
.60212 .69155 m
.60141 .68984 L
s
.60285 .69324 m
.60212 .69155 L
s
.60362 .69491 m
.60285 .69324 L
s
.60441 .69656 m
.60362 .69491 L
s
.60523 .69819 m
.60441 .69656 L
s
.60608 .6998 m
.60523 .69819 L
s
.60696 .7014 m
.60608 .6998 L
s
.60787 .70297 m
.60696 .7014 L
s
.60881 .70452 m
.60787 .70297 L
s
.60978 .70606 m
.60881 .70452 L
s
.61078 .70757 m
.60978 .70606 L
s
.61181 .70907 m
.61078 .70757 L
s
.61286 .71055 m
.61181 .70907 L
s
.61395 .71202 m
.61286 .71055 L
s
.61506 .71347 m
.61395 .71202 L
s
.61621 .7149 m
.61506 .71347 L
s
.61738 .71632 m
.61621 .7149 L
s
.61857 .71773 m
.61738 .71632 L
s
.6198 .71912 m
.61857 .71773 L
s
.62104 .72051 m
.6198 .71912 L
s
0 g
.25 Mabswid
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
.5 .98974 m
1 .86603 L
s
.5798 .97 m
.57949 .96279 L
s
[(-2)] .58043 .98442 -0.04347 -1 Mshowa
.70833 .93819 m
.70751 .93102 L
s
[(0)] .70999 .95253 -0.11547 -1 Mshowa
.86437 .89959 m
.86291 .89252 L
s
[(2)] .86729 .91372 -0.20637 -1 Mshowa
.125 Mabswid
.60976 .96258 m
.6095 .95826 L
s
.64111 .95483 m
.64077 .95051 L
s
.67393 .94671 m
.67351 .9424 L
s
.74444 .92926 m
.74386 .92497 L
s
.78239 .91987 m
.78171 .91559 L
s
.82231 .90999 m
.82154 .90573 L
s
.55113 .97709 m
.55101 .97276 L
s
.52368 .98389 m
.52362 .97956 L
s
.90874 .88861 m
.90776 .88439 L
s
.95561 .87701 m
.95452 .87282 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 285},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017A000`40O003h00Oogoo8Goo002;Ool0
0`00Oomoo`2BOol008Yoo`<009=oo`00RGoo00D007oo001oo`00099oo`00R7oo00@007ooOol0009o
o`03001oogoo08moo`00Qgoo00D007ooOomoo`0000=oo`03001oogoo08ioo`00QWoo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol0SGoo0025Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`2<Ool008Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo08]oo`00Pgoo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol0RWoo0022Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`29Ool0085oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo08Qoo`00P7oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol0Qgoo001oOol00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`26Ool007ioo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo08Ioo`00OGoo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol0QGoo001lOol00`00Oomoo`0<Ool00`00Oomo
o`0;Ool00`00Oomoo`24Ool007]oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo08=oo`00
NWoo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol0PWoo001jOol00`00Oomoo`0>Ool00`00
Oomoo`0>Ool00`00Oomoo`21Ool007Uoo`03001oogoo00moo`03001oogoo00moo`03001oogoo081o
o`00N7oo00<007ooOol047oo00<007ooOol047oo00<007ooOol0Ogoo001gOol00`00Oomoo`0AOol0
0`00Oomoo`0AOol00`00Oomoo`1nOol007Ioo`03001oogoo019oo`03001oogoo019oo`03001oogoo
07eoo`00MGoo00<007ooOol04goo00<007ooOol04goo00<007ooOol0O7oo001dOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`1kOol007=oo`03001oogoo01Eoo`03001oogoo01Eoo`03001o
ogoo07Yoo`00LWoo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol0NGoo001aOol00`00Oomo
o`0GOol00`00Oomoo`0GOol00`00Oomoo`1hOol0071oo`03001oogoo01Qoo`03001oogoo01Qoo`03
001oogoo07Moo`00Kgoo00<007ooOol06Goo00<007ooOol06Goo00<007ooOol0MWoo001^Ool00`00
Oomoo`0JOol00`00Oomoo`0JOol00`00Oomoo`1eOol006eoo`03001oogoo01]oo`03001oogoo01]o
o`03001oogoo07Aoo`00K7oo00<007ooOol077oo00<007ooOol077oo00<007ooOol0Lgoo001[Ool0
0`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomoo`1bOol006Yoo`03001oogoo01ioo`03001oogoo
01ioo`03001oogoo075oo`00JGoo00<007ooOol07goo00<007ooOol07goo00<007ooOol0L7oo001X
Ool00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomoo`1_Ool006Moo`03001oogoo025oo`03001o
ogoo025oo`03001oogoo06ioo`00IWoo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0KGoo
001UOol00`00Oomoo`0SOol00`00Oomoo`0IOol0111A578@LAAb1Goo00<007ooOol0KGoo001TOol0
0`00Oomoo`0TOol00`00Oomoo`0IOol011Ab478DLQAb1Woo00<007ooOol0K7oo001SOol00`00Oomo
o`0UOol00`00Oomoo`0GOol01a1A578@LAAb454DLQ1a00Ioo`03001oogoo06]oo`00HWoo00<007oo
Ool09Woo00<007ooOol05goo00<DLQ1b57800QAb00<@LWooOol01Woo00<007ooOol0JWoo001QOol0
0`00Oomoo`0WOol00`00Oomoo`0GOol01Q1a578@DAAb474DLPUoo`03001oogoo06Uoo`00H7oo00<0
07ooOol0:7oo00<007ooOol05goo0aAb00<@LQAbOol02Woo00<007ooOol0J7oo001OOol00`00Oomo
o`0YOol00`00Oomoo`0GOol01A1A578@LAAb454037oo00<007ooOol0Igoo001NOol00`00Oomoo`0Z
Ool00`00Oomoo`0FOol257801A1b578DLQAb478037oo00<007ooOol0IWoo001MOol00`00Oomoo`0[
Ool00`00Oomoo`0FOol01QAb474DLQ1A578@L@ioo`03001oogoo06Eoo`00G7oo00<007ooOol0;7oo
00<007ooOol05Woo00H@LQAb578DLQ1b578?Ool00`00Oomoo`1TOol005]oo`03001oogoo02eoo`03
001oogoo01Ioo`05578@DAAb474DLP0AOol00`00Oomoo`1SOol005Yoo`03001oogoo02ioo`03001o
ogoo01Eoo`<DLP04478DLQAb578AOol00`00Oomoo`1ROol005Uoo`03001oogoo02moo`03001oogoo
01Eoo`06454DLQ1a578@DAAb4goo00<007ooOol0HGoo001IOol00`00Oomoo`0_Ool00`00Oomoo`0E
Ool00aAb478DLP0257800a1bOomoo`0BOol00`00Oomoo`1POol005Qoo`03001oogoo031oo`03001o
ogoo01Eoo`05474DLQ1A578@L@0FOol00`00Oomoo`1OOol005Moo`03001oogoo035oo`03001oogoo
01Eoo`<DLP03478DLQAb01Ioo`03001oogoo05ioo`00EWoo00<007ooOol0<Woo00<007ooOol057oo
00HDLQ1A578@LAAb454HOol00`00Oomoo`1MOol005Eoo`03001oogoo03=oo`03001oogoo01Aoo`8D
LP04478DLQAb578IOol00`00Oomoo`1LOol005Aoo`03001oogoo03Aoo`03001oogoo01Aoo`05578@
LAAb454DLP0KOol00`00Oomoo`1KOol005=oo`03001oogoo03Eoo`03001oogoo01Aoo`06478DLQAb
578@LQAb6goo00<007ooOol0FWoo001BOol00`00Oomoo`0fOol00`00Oomoo`0COol01Q1a578@DAAb
474DLQeoo`03001oogoo05Uoo`00DGoo00<007ooOol0=goo00<007ooOol057oo0QAb00<@LQAb5780
7Woo00<007ooOol0F7oo001@Ool00`00Oomoo`0hOol00`00Oomoo`0COol01A1A578@LAAb454087oo
00<007ooOol0Egoo001?Ool00`00Oomoo`0iOol00`00Oomoo`0COol00aAb478DLP02578QOol00`00
Oomoo`1FOol004ioo`03001oogoo03Yoo`03001oogoo01=oo`05474DLQ1A578@L@0ROol00`00Oomo
o`1EOol004eoo`03001oogoo03]oo`03001oogoo01=oo`<DLP03478DLWoo029oo`03001oogoo05Ao
o`00C7oo00<007ooOol0?7oo00<007ooOol04goo00@@DAAb474DLRAoo`03001oogoo05Aoo`00Bgoo
00<007ooOol0?Goo00<007ooOol04Goo0aAb00@@LQAb578DLRAoo`03001oogoo05=oo`00BWoo00<0
07ooOol0?Woo00<007ooOol04Goo00H@DAAb474DLQ1A578VOol00`00Oomoo`1BOol004Uoo`03001o
ogoo03moo`03001oogoo015oo`03578@LQAb008DLP03479oogoo02Eoo`03001oogoo055oo`00B7oo
00<007ooOol0@7oo00<007ooOol04Goo00D@LAAb454DLQ1a02Uoo`03001oogoo051oo`00Agoo00<0
07ooOol0@Goo00<007ooOol047oo00D@LQAb578DLQ1b008DLRUoo`03001oogoo04moo`00AWoo00<0
07ooOol0@Woo00<007ooOol047oo00HDLQ1A578@LAAb454[Ool00`00Oomoo`1>Ool004Eoo`03001o
ogoo04=oo`03001oogoo011oo`8DLP04478DLQAb578/Ool00`00Oomoo`1=Ool004Aoo`03001oogoo
04Aoo`03001oogoo011oo`05578@LAAb454DLP0^Ool00`00Oomoo`1<Ool004=oo`03001oogoo04Eo
o`03001oogoo011oo`05478DLQAb578@LP0_Ool00`00Oomoo`1;Ool0049oo`03001oogoo04Ioo`03
001oogoo00moo`07474DLQ1A578@LAAb4540;goo00<007ooOol0BWoo0011Ool00`00Oomoo`17Ool0
0`00Oomoo`0?Ool357800a1b578DLP0aOol00`00Oomoo`19Ool0041oo`03001oogoo04Qoo`03001o
ogoo00moo`06454DLQ1a578@DAAb<Woo00<007ooOol0B7oo000oOol00`00Oomoo`19Ool00`00Oomo
o`0?Ool00aAb478DLP02578dOol00`00Oomoo`17Ool003ioo`03001oogoo04Yoo`03001oogoo00mo
o`05474DLQ1A578@L@0eOol00`00Oomoo`16Ool003eoo`03001oogoo02Eoo`068TXNBR9:7TXRBQi:
87oo00<007ooOol03Woo00D@LQAb578DLQ1b008DLSEoo`03001oogoo04Eoo`00?7oo00<007ooOol0
9Woo00HNBR9;7TXRBai:8T/POol00`00Oomoo`0>Ool01QAb454DLQ1a578@DCMoo`03001oogoo04Ao
o`00>goo00<007ooOol09Woo00LNBR9:7TXRBQi:8TXNBP0POol00`00Oomoo`0>Ool25780111b578D
LQAb>7oo00<007ooOol0@goo000jOol00`00Oomoo`0VOol021i:8T/NBR9;7TXRBai:8T/POol00`00
Oomoo`0>Ool01AAb474DLQ1A5780>Woo00<007ooOol0@Woo000iOol00`00Oomoo`0UOol02B9:7TXR
BQi:8TXNBR9:7TXRBP0QOol00`00Oomoo`0>Ool01A1b578DLQAb4780>goo00<007ooOol0@Goo000h
Ool00`00Oomoo`0JOol00ai:8T]oo`05Ool031i:8T/NBR9;7TXRBai:8T/NBR9;7TXRBb9oo`03001o
ogoo00ioo`05578@DAAb474DLP0lOol00`00Oomoo`10Ool003Qoo`03001oogoo01Qoo`0F8TXNBR9:
7TXRBQi:8TXNBR9:7TXRBQi:8TXNBR9:7TXRBQi:8TXNBR9:7TXROol00`00Oomoo`0>Ool257800a1b
578DLP0mOol00`00Oomoo`0oOol003Moo`03001oogoo01Ioo`0G8T/NBR9;7TXRBai:8T/NBR9;7TXR
Bai:8T/NBR9;7TXRBai:8T/NBR9;7TXRB`0TOol00`00Oomoo`0>Ool01AAb474DLQ1A5780?Woo00<0
07ooOol0?Woo000fOol00`00Oomoo`0EOol05ai:8TXNBR9:7TXRBQi:8TXNBR9:7TXRBQi:8TXNBR9:
7TXRBQi:8TXNBR9:7TX09Woo00<007ooOol03Woo00D@LQAb578DLQ1b03moo`03001oogoo03eoo`00
=Goo00<007ooOol05Goo01@NBR9;7TXRBai:8T/NBR9;7TXRBai:8T/NBR9;7TXRBai:8T/NBR9;:Woo
00<007ooOol03Woo00DDLQ1A578@LAAb041oo`03001oogoo03aoo`00=7oo00<007ooOol05Goo00/N
BR9:7TXRBQi:8TXNBR9:7TXRBQi:03Aoo`03001oogoo00ioo`8DLP03478DLQAb045oo`03001oogoo
03]oo`00<goo00<007ooOol05Woo00PRBai:8T/NBR9;7TXRBai:=goo00<007ooOol03Woo00DDLQ1a
578@DAAb045oo`03001oogoo03]oo`00<Woo00<007ooOol05goo00HNBR9:7TXRBQi:8TXiOol00`00
Oomoo`0>Ool01A1b578DLQAb47806Woo00=JfEZhOol09Goo00<007ooOol0>Woo000aOol00`00Oomo
o`0HOol01B9;7TXRBai:8T/0>Woo00<007ooOol03Woo00DDLQ1A578@LAAb01Qoo`05E[QJfEJhF]UF
^00VOol00`00Oomoo`0iOol0031oo`03001oogoo01Uoo`057TXRBQi:8TXNBP0jOol00`00Oomoo`0>
Ool257800a1b578DLP0HOol01U[IF[QJ^5ZhF]UJ^2Ioo`03001oogoo03Qoo`00;goo00<007ooOol0
6Woo00DRBai:8T/NBR9;03Yoo`03001oogoo00ioo`05578@LAAb454DLP0HOol01eJhF]UF^5[IE[QJ
fEJh02Ioo`03001oogoo03Moo`00;Woo00<007ooOol06goo00DNBR9:7TXRBQi:03Yoo`03001oogoo
00ioo`05478DLQAb578@LP0HOol2F[P01U[IF[QJ^5ZhF]UJ^2Ioo`03001oogoo03Ioo`00;Goo00<0
07ooOol077oo00DRBai:8T/NBR9;03Yoo`03001oogoo00ioo`05578@DAAb474DLP0IOol025[IE[QJ
fEJhF]UF^5[IE[PVOol00`00Oomoo`0eOol002aoo`03001oogoo01eoo`067TXRBQi:8TXNBR9:>Goo
00<007ooOol03Woo0QAb00@@LQAb578DLQQoo`=J^006F]UJ^5ZhF[QJfEZh9Woo00<007ooOol0=7oo
000[Ool00`00Oomoo`0NOol01b9;7TXRBai:8T/NBR9;03Qoo`03001oogoo00ioo`07578@LAAb454D
LQ1a578067oo00YF^5[IE[QJfEJhF]UF^5[IE[QJfBEoo`03001oogoo03=oo`00:Woo00<007ooOol0
87oo00HRBQi:8TXNBR9:7TXhOol00`00Oomoo`0>Ool01A1b578DLQAb47800QAb6Goo0eZh00EJfEZh
F[QJ^5[I00=J^003F]Uoogoo025oo`03001oogoo039oo`00:Goo00<007ooOol08Goo00HNBR9;7TXR
Bai:8T/hOol00`00Oomoo`0?Ool04a1A578@LAAb454DLQ1a578@DAAb474DLQ1A578@LAAb454DLQ1a
00eoo`0<E[QJfEJhF]UF^5[IE[QJfEJhF]UF^5[I8goo00<007ooOol0<Goo000XOol00`00Oomoo`0R
Ool01b9:7TXRBQi:8TXNBR9:03Moo`03001oogoo00moo`03578@LQAb008DLP05478DLQAb578@LP03
57801A1b578DLQAb47800QAb3Woo0UZh00EJfEZhF[QJ^5[I00=J^003F]UJ^5Zh025oo`03001oogoo
031oo`009goo00<007ooOol097oo00HRBai:8T/NBR9;7TXgOol00`00Oomoo`0@Ool04aAb454DLQ1a
578@DAAb474DLQ1A578@LAAb454DLQ1a578@DAAb011oo`0@E[QJfEJhF]UF^5[IE[QJfEJhF]UF^5[I
E[QJfEJhF]TMOol00`00Oomoo`0_Ool002Moo`<002Eoo`068TXNBR9:7TXRBQi:=Woo00<007ooOol0
47oo0QAb00D@LQAb578DLQ1b00<DLP05478DLQAb578@LP0357800a1bOomoo`0@Ool01E[IF[QJ^5Zh
F]T00eZh00EJfEZhF[QJ^5[I00=J^003F]Uoogoo01Ioo`@0031oo`009Woo00@007ooOomoo`8002=o
o`077TXRBai:8T/NBR9;7TX0=Goo00<007ooOol04goo00L@DAAb474DLQ1A578@L@03Ool01a1a578@
DAAb474DLQ1A01Aoo`0?F]UF^5[IE[QJfEJhF]UF^5[IE[QJfEJhF]UF^5[I01Eoo`80009oo`80031o
o`009Woo00<007ooOol00goo0P008Goo00LRBQi:8TXNBR9:7TXRBP0eOol00`00Oomoo`0NOol25780
1A1b578DLQAb47805Goo00=J^5[IF[P00UZh00EJfEZhF[QJ^5[I00=J^003F]UJ^5Zh015oo`03001o
ogoo00=oo`03001oogoo02ioo`009Woo00<007ooOol01Goo00<007ooOol07goo00LRBai:8T/NBR9;
7TXRB`0dOol00`00Oomoo`0NOol01QAb474DLQ1A578@LAUoo`0?E[QJfEJhF]UF^5[IE[QJfEJhF]UF
^5[IE[QJfEJh00eoo`8000Ioo`03001oogoo02ioo`009Woo00<007ooOol01Woo0P007goo00LNBR9:
7TXRBQi:8TXNBP0dOol00`00Oomoo`0OOol357800a1b579oo`0KOol00eZhF]UJ^002F[P01E[IF[QJ
^5ZhF]T00eZh00=JfGooOol01goo0P0027oo00<007ooOol0;Woo000UOol00`00Oomoo`09Ool2000N
Ool01ai:8T/NBR9;7TXRBai:03=oo`03001oogoo01moo`05454DLQ1a578@D@0OOol035JhF]UF^5[I
E[QJfEJhF]UF^5[IE[QJf@Ioo`8000]oo`03001oogoo02eoo`009Goo00<007ooOol02goo00<007oo
Ool06goo00LRBQi:8TXNBR9:7TXRBP0cOol00`00Oomoo`0OOol00aAb478DLP02578ROol00eZhF]UJ
^002F[P01U[IF[QJ^5ZhF]UJ^0=oo`03001oogoo00Yoo`8002moo`009Goo00<007ooOol037oo0P00
7Goo00DNBR9;7TXRBai:03=oo`03001oogoo01moo`05474DLQ1A578@L@0TOol02U[IE[QJfEJhF]UF
^5[IE[QJfEJh0P003Woo00<007ooOol0;Goo000TOol00`00Oomoo`0?Ool2000KOol01R9:7TXRBQi:
8TXNBS9oo`03001oogoo01ioo`05478DLQAb578@LP02578UOol3F[P01E[IF[QJ^5ZhF]T04Goo00<0
07ooOol0;7oo000TOol00`00Oomoo`0AOol2000JOol01R9;7TXRBai:8T/NBS5oo`03001oogoo01io
o`06578@DAAb474DLQ1A9goo00MF^5[IE[QJfEJhF]UF^00AOol00`00Oomoo`0/Ool002Aoo`03001o
ogoo01=oo`03001oogoo01Moo`077TXRBQi:8TXNBR9:7TX0<7oo00<007ooOol07Woo0QAb00@@LQAb
578DLRQoo`=J^004F]UJ^5ZhF[P@Ool00`00Oomoo`0:Ool50002Ool20004Ool2000COol002Aoo`03
001oogoo01Aoo`8001Moo`078T/NBR9;7TXRBai:8T/0<7oo00<007ooOol07Woo00DDLQ1a578@DAAb
02Qoo`800007E[QJfEJhF]UF^5[IE[P03goo0P003Goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`0@Ool002=oo`03001oogoo01Moo`8001Ioo`078TXNBR9:7TXRBQi:8TX0;goo00<0
07ooOol07Woo00D@LQAb578DLQ1b02Ioo`80009oo`06F]UJ^5ZhF[QJfEZh47oo0P003Goo00<007oo
Ool017oo00@007ooOol0009oo`03001oogoo011oo`008goo00<007ooOol06Goo00<007ooOol04goo
00LNBR9;7TXRBai:8T/NBP0_Ool00`00Oomoo`0NOol01AAb454DLQ1a57809Goo00<007ooOol00Woo
00IF^5[IE[QJfEJhF]TAOol00`00Oomoo`03Ool40004Ool00`00Oomoo`02Ool20003Ool01000Oomo
o`004Woo000SOol00`00Oomoo`0JOol2000EOol01R9:7TXRBQi:8TXNBRioo`03001oogoo01ioo`8D
LP04478DLQAb578ROol20005Ool2F[P00e[IF[QJ^00BOol00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`004Woo000ROol00`00Oomoo`0MOol2000COol01Qi:8T/NBR9;7TXR
Bbioo`03001oogoo01eoo`06454DLQ1a578@DAAb8Goo0P001Woo00IJfEJhF]UF^5[IE[PCOol00`00
Oomoo`09Ool20004Ool30003Ool2000COol0029oo`03001oogoo01moo`80019oo`067TXRBQi:8TXN
BR9:;Goo00<007ooOol07Goo00<DLQ1b57800QAb00<@LWooOol07Woo00<007ooOol01Goo0UZh00EJ
fEZhF[QJ^5[I01=oo`03001oogoo02Yoo`008Woo00<007ooOol08Goo00DBTA9a4Y4>L1:A00eoo`06
8T/NBR9;7TXRBai:;Goo00<007ooOol07Goo00D@LAAb454DLQ1a01moo`8000Qoo`07E[QJfEJhF]UF
^5[IE[P04goo00<007ooOol0:Woo000ROol00`00Oomoo`0QOol64Y4=Ool01R9:7TXRBQi:8TXNBRao
o`03001oogoo01eoo`<DLP03478DLQAb01aoo`8000Uoo`03F[QJfEZh009J^003F]UJ^7oo019oo`03
001oo`0002]oo`008Goo00<007ooOol08Woo00PBT@i`4Y4BLA:A3W0BTA9a2goo00HNBR9;7TXRBai:
8T//Ool00`00Oomoo`0LOol01QAb454DLQ1a578@DAaoo`03001oogoo00Qoo`07E[QJfEJhF]UF^5[I
E[P05Woo00<007ooOol0:Goo000QOol00`00Oomoo`0ROol94Y4;Ool01Qi:8TXNBR9:7TXRBR]oo`03
001oogoo01eoo`03578@LQAb008DLQYoo`8000Yoo`03F[QJfEZh009J^003F]UJ^5Zh01Ioo`03001o
ogoo02Uoo`008Goo00<007ooOol08Woo00/BTA9a4Y4>L1:A4W4BT@i`4Y4BLA:A00Uoo`068T/NBR9;
7TXRBai::goo00<007ooOol07Goo00@@LAAb454DLQUoo`8000]oo`08E[QJfEJhF]UF^5[IE[QJfAMo
o`03001oogoo02Uoo`0087oo00<007ooOol09Goo2a:A27oo00DRBQi:8TXNBR9:02]oo`03001oogoo
01eoo`<DLP03479oogoo01Eoo`8000aoo`03F[QJfEZh009J^003F]UJ^5Zh01Uoo`03001oogoo02Qo
o`0087oo00<007ooOol09Woo00`BLA:A3W0BTA9a4Y4>L1:A4W4BT@i`4Y46Ool01Qi:8T/NBR9;7TXR
BbYoo`03001oogoo01aoo`06578@DAAb474DLQ1A5Goo00<007ooOol02goo00QF^5[IE[QJfEJhF]UF
^5[I6Goo0P00:Woo000POol00`00Oomoo`0XOol;4Y45Ool01b9:7TXRBQi:8TXNBR9:02Uoo`03001o
ogoo01]oo`<DLP03478DLQAb01Aoo`8000eoo`03F[QJfEZh009J^003F]UJ^5Zh01]oo`03001oogoo
02Qoo`0087oo00<007ooOol0:Woo00/>L1:A4W4BT@i`4Y4BLA:A3W0BTA9a00Aoo`058T/NBR9;7TXR
B`0ZOol00`00Oomoo`0LOol01AAb474DLQ1A57804Woo0P003Woo00QF^5[IE[QJfEJhF]UF^5[I7Goo
00<007ooOol09goo000OOol00`00Oomoo`0/Ool;4Y43Ool01Qi:8TXNBR9:7TXRBRUoo`03001oogoo
01aoo`04478DLQAb578BOol00`00Oomoo`0=Ool00eZhF]UJ^002F[P00e[IF[QJ^00NOol00`00Oomo
o`0WOol001moo`03001oogoo02ioo`0:4Y4BLA:A3W0BTA9a4Y4>L1:A4W42Ool01b9;7TXRBai:8T/N
BR9;02Qoo`03001oogoo01]oo`06474DLQ1A578@LAAb3goo0P003goo00QF^5[IE[QJfEJhF]UF^5[I
7goo00<007ooOol09goo000OOol00`00Oomoo`0`Ool94Y42Ool01B9:7TXRBQi:8TX0:Goo00<007oo
Ool06Woo00H@LQAb578DLQ1b578>Ool2000@Ool00eZhF]UJ^002F[P00e[IF[QJ^00POol00`00Oomo
o`0WOol001moo`03001oogoo035oo`0@4W4BT@i`4Y4BLA:A3W0BT@00OolNBR9;7TXRBai:8T/XOol0
0`00Oomoo`0KOol01A1A578@LAAb454037oo0P004Goo00QF^5[IE[QJfEJhF]UF^5[I8Goo0P00:7oo
000NOol00`00Oomoo`0dOol74Y4020008TXNBR9:7TXRBQi:8TXWOol00`00Oomoo`0KOol011Ab478D
LQAb37oo00<007ooOol047oo00=J^5[IF[P00UZh00=JfEZhF[P08goo00<007ooOol09Woo000NOol0
0`00Oomoo`0dOol03Q9a4Y4>L1:A4W4BT@i`4Y4NBR9;7TXRBai:8T/HOol0178UMTIb9GHV37oo00<0
07ooOol06Woo00HDLQ1a578@DAAb4745Ool010Pd33D8=0Pe0P004Woo00QF^5[IE[QJfEJhF]UF^5[I
97oo00<007ooOol09Woo000NOol00`00Oomoo`0eOol74Y401Woo7TXRBQi:8TXNBQMoo`03LRIf9W8V
009b9Paoo`03001oogoo01Uoo`03578@LQAb008DLP03479oogoo009oo`H8=AAoo`05F]UJ^5ZhF[QJ
f@02F[PVOol00`00Oomoo`0UOol001eoo`03001oogoo03Moo`0<4W4BT@i`4Y4BLA:A3W0RBai:8T/N
BR9;5goo00EfAW8UMRIb9GI600aoo`03001oogoo01Uoo`06474DLQ1A578@LAAb0goo00L8=@Pd33D8
=0Pe23@<=@0COol01e[IE[QJfEJhF]UF^5[I02Moo`03001oogoo02Eoo`007Goo00<007ooOol0=goo
1Q:A00Iooai:8TXNBR9:7TX2000EOol3LRH00gHVLRIoo`0;Ool00`00Oomoo`0IOol35780111b578D
LWoo2@Pe4Woo00EJfEZhF[QJ^5[I009J^2Qoo`03001oogoo02Eoo`007Goo00<007ooOol0>7oo00hB
TA9a4Y4>L1:AOolRBai:8T/NBR9;7TYoo`0057oo00Ef9W8UMTIb9GHV00aoo`03001oogoo01Qoo`0A
578@DAAb474DLQ1A33D8=0Pe23@<=@Pd23D8=0`e23@8=@0AOol025[IE[QJfEJhF]UF^5[IE[PXOol2
000VOol001eoo`03001oogoo03Qoo`DBT@07OolNBR9:7TXRBQi:8TX00Woo0P004Woo00=b9WHVLRH0
0W8V37oo00<007ooOol06Goo00<DLQ1b57800QAb2PPe4Goo00EJfEZhF[QJ^5[I00=J^2Uoo`8002Io
o`0077oo00<007ooOol0>Goo00`BT@i`4Y4BLA:AOolRBai:8T/NBR9;7TX4Ool2000@Ool01GI6LREf
9W8UMTH037oo00<007ooOol06Goo00h@LAAb454DLPPd23D8=0`e23@8=@Pd33D8=0Pe4Woo00MF^5[I
E[QJfEJhF]UF^00[Ool00`00Oomoo`0TOol001aoo`03001oogoo03Uoo`DBT@9oo`058TXNBR9:7TXR
BP06Ool2000=Ool01GHVLRIb9W8VMRH00W8V2goo00<007ooOol06Goo0aAb00<@LPPe23D01PPe4goo
0eZh00AJfEZhF[QJ^2aoo`03001oogoo02Aoo`0077oo00<007ooOol0>Goo00dBTA9a4Y4>L1:AOolR
Bai:8T/NBR9;7TXRB`07Ool00`00Oomoo`0:Ool01W8UMRIb9GI6LREf9Paoo`03001oogoo01Qoo`0;
578@DAAb474DLQ1A33D8=0Pe23@<=@0EOol01U[IE[QJfEJhF]UF^2ioo`03001oogoo02=oo`006goo
00<007ooOol0>Woo1A:A00Mooai:8TXNBR9:7TXRBP09Ool2000:Ool2LRH017HVLRIb9W8V37oo00<0
07ooOol05goo0aAb00<@LQAb578010Pe5Woo0UZh00EJfEZhF[QJ^5[I02ioo`03001oogoo02=oo`00
6goo00<007ooOol0>Goo00dBLA:A3W0BTA9a4Y4>L29;7TXRBai:8T/NBP0;Ool20008Ool01G8UMTIb
9GHVLRD03Goo00<007ooOol067oo00PDLQ1a578@DAAb23@8=@Pd5goo00IF^5[IE[QJfEJhF]T_Ool0
0`00Oomoo`0SOol001]oo`03001oogoo03Uoo`HBT@06OolNBR9:7TXRBQi:3Woo00<007ooOol01Goo
00Ef9W8VLRIb9WHV00eoo`03001oogoo01Ioo`800004478DLQAb578323DGOol00eZhF]UJ^002F[P0
0e[IF[Qoo`0^Ool2000;Ool50002Ool20004Ool2000:Ool001]oo`03001oogoo03Uoo`0<3W0BTA9a
4Y4>L1:AOolRBai:8T/NBR9;3goo0P001Goo00Eb9GHVLREfAW8U00eoo`03001oogoo01Eoo`0:001o
oa1a578@DAAb474DLPPd33DGOol01U[IE[QJfEJhF]UF^35oo`03001oogoo00]oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol01goo000JOol00`00Oomoo`0iOol74Y401Woo7TXRBQi:
8TXNBQ5oo`80009oo`=b9P03MRIb9W8V00eoo`03001oogoo01=oo`800003Ool@LQAb008DLP04478D
LPPe23DHOol3F[P00e[IF[QJ^00aOol00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo00Moo`006Woo00<007ooOol0>Goo00dBTA9a4Y4>L1:A4W5ooai:8T/NBR9;7TXR
B`0COol200001WHVLREfAW8UMRIb9@eoo`03001oogoo015oo`8000Aoo`07454DLQ1a578@D@`e23@0
5goo00IF^5[IE[QJfEJhF]TbOol00`00Oomoo`03Ool40004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Moo`006Woo00<007ooOol0>7oo1a:A00Moob9:7TXRBQi:8TXNBP0EOol0
0g8VMRIb9P02LRH00gHVOomoo`0;Ool00`00Oomoo`0?Ool20005Ool257800a1b578DLP0323DGOol2
F[P015[IF[QJ^5Zh<goo00<007ooOol02Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`07Ool001Uoo`03001oogoo03Uoo`0>4W4BT@i`4Y4BLA:AOolRBai:8T/NBR9;7TXRBaEoo`05
MTIb9GHVLREfAP0>Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool021Ab474DLQ1A5788=0Pe23@GOol0
1UJhF]UF^5[IE[QJfC=oo`03001oogoo00Uoo`8000Aoo`8000Aoo`8000Yoo`006Goo00<007ooOol0
>7oo1a:A00Mooai:8TXNBR9:7TXRBP0EOol01GHVLRIb9W8VMRH00W8V3Goo00<007ooOol037oo0P00
27oo00H@LQAb578DLQ1b578223DGOol01E[IF[QJ^5ZhF]T0=7oo0P008Woo000IOol00`00Oomoo`0g
Ool03a9a4Y4>L1:A4W4BT@i`OolNBR9;7TXRBai:8T/NBP0EOol01W8UMRIb9GI6LREf9P8000aoo`03
001oogoo00Yoo`8000Uoo`09474DLQ1A578@LAAb23@<=@Pd01Moo`05E[QJfEJhF]UF^00cOol2000S
Ool001Uoo`03001oogoo03Moo`LBT@07OolRBQi:8TXNBR9:7TX05Woo0W8V00Af9W8VLRIb9P9oo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`8DLP03478DLQAb00<8=AMoo`9J^003F]UJ
^5Zh03Eoo`03001oogoo021oo`0067oo00<007ooOol0=goo00lBT@i`4Y4BLA:A3W0BTGoo8T/NBR9;
7TXRBai:8T/05Woo00Eb9GI6LREf9W8U00Aoo`8000Uoo`03001oogoo00Moo`8000aoo`09454DLQ1a
578@D@`e23@8=@Pd01Moo`05E[QJfEJhF]UF^00eOol00`00Oomoo`0POol001Qoo`03001oogoo03Io
o`PBT@078TXNBR9:7TXRBQi:8TX05goo00Ef9W8VLRIb9WHV00Ioo`8000Moo`03001oogoo00Eoo`80
00ioo`03578@LQAb008DLPD8=AIoo`05F]UJ^5ZhF[QJf@0eOol00`00Oomoo`0POol001Qoo`03001o
ogoo03Eoo`0@4Y4>L1:A4W4BT@i`4Y4BLB9;7TXRBai:8T/NBR9;7TXFOol01WI6LREf9W8UMTIb9@Qo
o`03001oogoo00Aoo`03001oogoo00=oo`80011oo`0:474DLQ1A578@L@Pe23@<=@Pd23DFOol01EJh
F]UF^5[IE[P0=Woo00<007ooOol07goo000GOol00`00Oomoo`0eOol84Y40229:7TXRBQi:8TXNBR9:
7TXGOol3LRH00gHVLRIb9P09Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool357800a1b578D
LP0423DFOol2F[P00e[IF[QJ^00fOol00`00Oomoo`0OOol001Moo`03001oogoo03Aoo`0@4Y4>L1:A
4W4BT@i`4Y4BLB9;7TXRBai:8T/NBR9;7TXHOol01WHVLREfAW8UMRIb9@]oo`80009oo`03001oogoo
0080019oo`0;578@DAAb474DLQ1A33D8=0Pe23@<=@0FOol01UJhF]UF^5[IE[QJfCEoo`80021oo`00
5goo00<007ooOol0<goo1a:A00TNBR9:7TXRBQi:8TXNBR9:7TX06Goo00=b9WHVLRH00W8V3Woo1@00
57oo0QAb00@@LQAb578DLPH8=AEoo`05F]UJ^5ZhF[QJf@02F[PcOol3000POol001Moo`03001oogoo
039oo`0@4Y4>L1:A4W4BT@i`8T/NBR9;7TXRBai:8T/NBR9;7TXIOol01W8UMTIb9GHVLREfAQ1oo`03
001oogoo01Aoo`0<578@LAAb454DLWoo23D8=0`e23@8=@Pd5Goo00MF^5[IE[QJfEJhF]UF^00eOol0
0`00Oomoo`0NOol001Ioo`03001oogoo039oo`DBT@0;7TXRBQi:8TXNBR9:7TXRBQi:8TXNBP0JOol0
1WHVLRIb9W8VMRIb9Pioo`D001Aoo`06478DLQAb578@LWoo1PPe5Woo00=J^5[IF[P00UZh00=JfGoo
Ool0<goo00<007ooOol07Woo000FOol00`00Oomoo`0aOol041:A3W0BTA9a8T/NBR9;7TXRBai:8T/N
BR9;7TXRBai:6goo00Ib9GHVLREfAW8UMRH<Ool20002Ool00`00Oomoo`02000BOol01AAb454DLQ1a
57800Woo00H8=0Pe23@<=@Pd23DEOol01e[IE[QJfEJhF]UF^5[I03Aoo`03001oogoo01ioo`005Woo
00<007ooOol0<7oo0a:A00`NBR9:7TXRBQi:8TXNBR9:7TXRBQi:8TXMOol2LRH00gHVLRIb9P0;Ool2
0004Ool00`00Oomoo`02Ool2000@Ool257800a1b578DLP02Ool723DEOol2F[P015[IF[QJ^5Zh=Goo
00<007ooOol07Goo000EOol00`00Oomoo`0`Ool03Q:A3W0RBai:8T/NBR9;7TXRBai:8T/NBR9;7TXN
Ool01gHVLREfAW8UMRIb9GI600Uoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00eoo`05
578@LAAb454DLP02Ool01`Pd33D8=0Pe23@<=@Pd01Eoo`07E[QJfEJhF]UF^5[IE[P0=7oo00<007oo
Ool07Goo000EOol00`00Oomoo`0_Ool24Y40329:7TXRBQi:8TXNBR9:7TXRBQi:8TXNBQmoo`03LRIf
9W8V009b9P03MRIoogoo00Ioo`8000Moo`03001oogoo00Eoo`8000eoo`06478DLQAb578@LQAb0Woo
1PPe5Goo00EJfEZhF[QJ^5[I00=J^3=oo`03001oogoo01eoo`005Goo00<007ooOol0;Woo00`BTAi:
8T/NBR9;7TXRBai:8T/NBR9;7TXROol01WI6LREf9W8UMTIb9@Ioo`8000Uoo`03001oogoo00Moo`80
00Yoo`06474DLQ1A578@LAAb0goo00H8=@Pd33D8=0Pe23@FOol01e[IE[QJfEJhF]UF^5[I03=oo`80
01ioo`005Goo00<007ooOol0;Goo00`RBQi:8TXNBR9:7TXRBQi:8TXNBR9:7TXSOol3LRH00gHVLRIo
o`04Ool2000;Ool00`00Oomoo`09Ool20008Ool357800a1b578DLP04Ool623DFOol01E[IF[QJ^5Zh
F]T00UZh<goo00<007ooOol077oo000DOol00`00Oomoo`0]Ool02R9;7TXRBai:8T/NBR9;7TXRBai:
9Woo00Ef9W8UMTIb9GHV00Aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Eoo`05454D
LQ1a578@D@05Ool01`Pd23D8=0`e23@8=@Pd01Eoo`08E[QJfEJhF]UF^5[IE[QJfC9oo`03001oogoo
01aoo`0057oo00<007ooOol0;7oo00XRBQi:8TXNBR9:7TXRBQi:8TXNBRIoo`9b9P04MRIb9W8VLRH2
Ool2000>Ool00`00Oomoo`0<Ool20005Ool00aAb478DLP025785Ool723DFOol00eZhF]UJ^002F[P0
15[IF[QJ^5Zh<7oo00<007ooOol077oo000DOol00`00Oomoo`0[Ool02B9;7TXRBai:8T/NBR9;7TXR
B`0XOol01W8UMTIb9GHVLREfAP80011oo`03001oogoo00ioo`8000=oo`05474DLQ1A578@L@06Ool0
1``e23@8=@Pd33D8=0Pe01Ioo`09E[QJfEJhF]UF^5[IE[QJfEJh031oo`03001oogoo01]oo`004goo
00<007ooOol0:goo00PRBQi:8TXNBR9:7TXRBQi::Woo00If9W8VLRIb9WHV000BOol00`00Oomoo`0@
Ool00`00Oomoo`0357800a1b579oo`05Ool723DGOol00eZhF]UJ^002F[P015[IF[QJ^5Zh;goo00<0
07ooOol06goo000COol00`00Oomoo`0ZOol0229;7TXRBai:8T/NBR9;7TX[Ool00g8UMRIb9@020000
0gHVOomoo`0@Ool00`00Oomoo`0AOol200001A1A578@LAAb45401goo00L8=0`e23@8=@Pd33D8=00G
Ool02UJhF]UF^5[IE[QJfEJhF]UF^5[I;Goo00<007ooOol06goo000COol00`00Oomoo`0YOol021:A
7TXRBQi:8TXNBR9:7TX/Ool00g8V00000002LRHCOol00`00Oomoo`0COol200035788Ool623DHOol0
0eZhF]UJ^002F[P01E[IF[QJ^5ZhF]T0;Goo00<007ooOol06Woo000COol00`00Oomoo`0XOol021:A
7TXRBai:8T/NBR9;7TX/Ool2000017I6LREf9W8U4goo00<007ooOol04goo00D@LAAb0000011a00Qo
o`0723D8=0`e23@8=@Pd33D06Goo00YJfEJhF]UF^5[IE[QJfEJhF]UF^2Yoo`8001aoo`004Woo00<0
07ooOol0:7oo0Q:A00HRBQi:8TXNBR9:7TX/Ool00`00Oomf9P03LRH00gHVOomoo`0AOol00`00Oomo
o`0COol357800a1b001oo`08Ool723DIOol01E[IF[QJ^5ZhF]T00eZh00=JfEZhOol0:Goo00<007oo
Ool06Woo000BOol00`00Oomoo`0WOol02A:A3W0RBai:8T/NBR9;7TXRB`0ZOol20002Ool01W8UMRIb
9GI6LREf9Q9oo`03001oogoo01=oo`05454DLQ1a578@D@020007Ool01`Pd23D8=0`e23@8=@Pd01Yo
o`0<F]UF^5[IE[QJfEJhF]UF^5[IE[QJfEJh9goo00<007ooOol06Woo000BOol00`00Oomoo`0WOol2
4Y401Qi:8TXNBR9:7TXRBRUoo`8000Aoo`9b9P04MRIb9W8VLRHBOol00`00Oomoo`0COol00aAb478D
LP025782Ool20006Ool723DKOol3F[P01E[IF[QJ^5ZhF]T00eZh9goo00<007ooOol06Goo000BOol0
0`00Oomoo`0VOol02@i`4Y4BLB9;7TXRBai:8T/NBP0WOol20006Ool01g8UMTIb9GHVLREfAW8U015o
o`03001oogoo01=oo`06474DLQ1A578@LAAb0goo0P001Goo00H8=0Pe23@<=@Pd23DMOol02U[IE[QJ
fEJhF]UF^5[IE[QJfEJh9Woo00<007ooOol06Goo000AOol00`00Oomoo`0WOol34Y401Ai:8TXNBR9:
7TX09goo00<007ooOol01goo0g8V00Af9W8VLRIb9Q1oo`03001oogoo01=oo`<DLP03478DLQAb00Eo
o`03001oogoo009oo`L8=Aioo`03F[QJfEZh009J^006F]UJ^5ZhF[QJfEZh8goo00<007ooOol06Goo
000AOol00`00Oomoo`0WOol0219a4Y4>L29;7TXRBai:8T/UOol2000:Ool027HVLREfAW8UMRIb9GI6
LRD?Ool00`00Oomoo`0COol01Q1A578@LAAb454DLPIoo`8000=oo`0633D8=0Pe23@<=@Pd7goo00aF
^5[IE[QJfEJhF]UF^5[IE[QJfEJhF]TROol00`00Oomoo`0HOol0015oo`03001oogoo02Moo`<BT@05
7TXRBQi:8TXNBP0SOol2000=Ool01GHVLRIb9W8VMRH00W8V3goo00<007ooOol057oo00D@LQAb578D
LQ1b00Qoo`800003Ool8=@Pe00D8=B1oo`05F]UJ^5ZhF[QJf@03F[P00e[IF[QJ^00POol2000JOol0
011oo`03001oogoo02Qoo`083W0BTA9a8T/NBR9;7TXRBb5oo`8000moo`07LREf9W8UMTIb9GHVLRD0
3goo00<007ooOol057oo00DDLQ1A578@LAAb00Yoo`80000723@<=@Pd23D8=0`e23@08Goo00]F^5[I
E[QJfEJhF]UF^5[IE[QJfEJh01moo`03001oogoo01Qoo`0047oo00<007ooOol0:7oo0a:A00DNBR9:
7TXRBQi:021oo`03001oogoo011oo`03LRIf9W8V009b9P03MRIb9Woo00eoo`03001oogoo01Aoo`8D
LP03478DLQAb00aoo`030008=@Pe00@8=B=oo`9J^005F]UJ^5ZhF[QJf@03F[P00e[IOomoo`0KOol0
0`00Oomoo`0;Ool20004Ool20005Ool0011oo`03001oogoo02Qoo`084W4BT@i`8T/NBR9;7TXRBaio
o`8001Aoo`06LREf9W8UMTIb9GHV3Woo00<007ooOol057oo00DDLQ1a578@DAAb00eoo`80000533D8
=0Pe23@<=@0SOol02e[IE[QJfEJhF]UF^5[IE[QJfEJhF]T07Goo00<007ooOol02Goo00@007ooOol0
009oo`04001oogoo0004Ool0011oo`03001oogoo02Qoo`<BT@067TXRBQi:8TXNBR9:6goo0P005Woo
0W8V00Af9W8VLRIb9Pioo`03001oogoo01Aoo`06478DLQAb578@LQAb37oo0PPe0P000`Pe9Woo00EJ
fEZhF[QJ^5[I00=J^003F]Uoogoo01Yoo`03001oogoo00aoo`04001oogoo0002Ool00`00Oomoo`02
Ool000moo`03001oogoo02Uoo`0:3W0BTA9a8T/NBR9;7TXRBai:8T/HOol2000IOol01GI6LREf9W8U
MTH03Woo00<007ooOol057oo00LDLQ1A578@LAAb454DLP0<Ool00`Pd23D8=00200000`Pe23Aoo`0U
Ool02E[IE[QJfEJhF]UF^5[IE[QJf@0KOol00`00Oomoo`03Ool40003Ool20003Ool01000Oomoo`00
17oo000?Ool00`00Oomoo`0YOol34Y401Qi:8TXNBR9:7TXRBQQoo`03001oogoo01Uoo`=b9P03MRIb
9Woo00eoo`03001oogoo01Aoo`8DLP04478DLQAb578=Ool523D00`0023Eoo`0VOol01E[IF[QJ^5Zh
F]T00eZh00=JfGooOol06Goo00<007ooOol02Goo00<007ooOol00Woo00@007ooOol000Aoo`003goo
00<007ooOol0:Goo00TBLA:A3W0BTAi:8T/NBR9;7TX05Woo0P0077oo00Ef9W8UMTIb9GHV00ioo`03
001oogoo01Eoo`05474DLQ1A578@L@0>Ool01@`e23@8=@Pd33D00P00:7oo00UF^5[IE[QJfEJhF]UF
^5[IE[P06Goo00<007ooOol02Goo0`000goo0P001Goo000>Ool00`00Oomoo`0[Ool34Y401R9:7TXR
BQi:8TXNBQ=oo`8001ioo`03LRIf9W8V009b9Pioo`03001oogoo01Eoo`<DLP03478DLQAb00eoo`L8
=@8002Moo`=J^006F]UJ^5ZhF[QJfEZh67oo00<007ooOol05Woo000>Ool00`00Oomoo`0/Ool02A9a
4Y4>L29;7TXRBai:8T/NBP0AOol00`00Oomoo`0NOol01GI6LREf9W8UMTH03Woo00<007ooOol05Goo
00L@DAAb474DLQ1A578@L@0=Ool01PPd33D8=0Pe23@<=@9oo`03001oogoo02Eoo`08E[QJfEJhF]UF
^5[IE[QJfAMoo`03001oo`0001Moo`003Woo00<007ooOol0;7oo0a:A00HNBR9:7TXRBQi:8TX?Ool2
000QOol3LRH00gHVLRIoo`0=Ool00`00Oomoo`0EOol00aAb478DLP0257800a1b579oo`0<Ool623D3
Ool2000VOol3F[P01E[IF[QJ^5ZhF]T067oo00<007ooOol05Goo000>Ool00`00Oomoo`0]Ool02A:A
4W4RBai:8T/NBR9;7TXRB`0<Ool2000SOol01GHVLREfAW8UMRH03Woo00<007ooOol05Woo00HDLQ1A
578@LAAb454=Ool01PPd23D8=0`e23@8=@Eoo`8002Ioo`07F]UF^5[IE[QJfEJhF]T05goo00<007oo
Ool05Goo000=Ool00`00Oomoo`0_Ool24Y401R9:7TXRBQi:8TXNBPYoo`8002Eoo`03LRIf9W8V009b
9Pioo`03001oogoo01Ioo`8DLP05478DLQAb578@LP0=Ool523D7Ool2000TOol3F[P015[IF[QJ^5Zh
5goo00<007ooOol05Goo000=Ool00`00Oomoo`0`Ool02A:A7TXRBai:8T/NBR9;7TXBT@07Ool00`00
Oomoo`0UOol01GI6LREf9W8UMTH03Woo00<007ooOol05goo00H@LAAb454DLQ1a578=Ool01@`e23@8
=@Pd33D02Goo00<007ooOol08Woo00IF^5[IE[QJfEJhF]THOol00`00Oomoo`0DOol000eoo`03001o
ogoo035oo`068TXNBR9:7TXRBQi:0a:A17oo0P00:7oo0g8V00=f9W8VOol03Goo00<007ooOol05goo
0aAb00@@LQAb578DLPaoo`D8=@Yoo`8002=oo`=J^003F]UJ^7oo01Moo`03001oogoo01Aoo`0037oo
00<007ooOol0<goo00XRBai:8T/NBR9;7TXBT@i`4Y5oo`8002Yoo`05MRIb9GI6LREf9P0>Ool00`00
Oomoo`0HOol01aAb474DLQ1A578@LAAb00]oo`0523D8=0`e23@8=@0<Ool2000QOol01U[IE[QJfEJh
F]UF^1Moo`03001oogoo01Aoo`0037oo00<007ooOol0=7oo00LRBQi:8TXNBR9:7TXBT@02000/Ool0
0g8VMRIb9P02LRH>Ool00`00Oomoo`0HOol01A1b578DLQAb47800aAb2Woo1@Pe3Woo0P007goo00=J
^5[IF[P00UZh00=JfEZhOol05Woo00<007ooOol04goo000<Ool00`00Oomoo`0dOol02Qi:8T/NBR9;
7TXRB`004Y4>L1:A:goo00EfAW8UMRIb9GI600ioo`03001oogoo01Uoo`07454DLQ1a578@DAAb4740
2Woo00D<=@Pd23D8=0`e011oo`03001oogoo01eoo`05E[QJfEJhF]UF^00GOol2000EOol000aoo`03
001oogoo03Aoo`048TXNBR9:7TX20000129:4Y4BTA:A:goo0g8V00=f9W8VOol03Goo00<007ooOol0
6Woo00D@LQAb578DLQ1b008DLPQoo`L8=A1oo`8001eoo`9J^003F]UJ^5Zh01Qoo`03001oogoo01=o
o`002goo00<007ooOol0=goo0P0000LNBR9;7TXRBa9a4Y4>L00ZOol01GHVLREfAW8UMRH03Woo00<0
07ooOol06Woo00PDLQ1A578@LAAb454DLQ1a1goo00H8=0Pe23@<=@Pd23DCOol2000KOol01EJhF]UF
^5[IE[P067oo00<007ooOol04goo000;Ool00`00Oomoo`0eOol200001R9:7TXRBQi:8TXNBP@BTBUo
o`03LRIf9W8V009b9Pioo`03001oogoo01]oo`03578@LQAb008DLP03479oogoo00Eoo`L8=AEoo`80
01Qoo`03F[QJfEZh009J^003F]Uoogoo01Moo`03001oogoo019oo`002goo00<007ooOol0=7oo00h0
07ooOomoob9;7TXRBai:8T/>L1:A4W4BT@i`9goo00Ib9GI6LREf9W8UMTH>Ool00`00Oomoo`0NOol0
0aAb475oo`06Ool01`Pd23D8=0`e23@8=@Pd01Qoo`03001oogoo01Eoo`06F]UF^5[IE[QJfEJh6Goo
00<007ooOol04Woo000:Ool00`00Oomoo`0cOol20004Ool01Qi:8TXNBR9:7TXRBP@BTBMoo`06MRIb
9W8VLRIf9W8V3Woo00<007ooOol09Woo20Pe6Goo0P005Goo0eZh00=JfEZhOol06Goo00<007ooOol0
4Woo000:Ool00`00Oomoo`0aOol20006Ool02b9;7TXRBai:8T/NBR9;3W0BTA9a4Y409Woo00Ib9GHV
LREfAW8UMRH>Ool00`00Oomoo`0VOol01`Pe23@<=@Pd23D8=0`e01aoo`80019oo`06E[QJfEJhF]UF
^5[I6goo00<007ooOol04Goo000:Ool00`00Oomoo`0_Ool20009Ool01R9:7TXRBQi:8TXNBP@BTBIo
o`9b9P03MRIb9W8V00moo`03001oogoo02Eoo`L8=Amoo`8000moo`=J^004F]UJ^5ZhF[PKOol00`00
Oomoo`0AOol000Yoo`03001oogoo02ioo`03001oogoo00Yoo`098T/NBR9;7TXRBai:4Y4>L1:A02Io
o`05LREfAW8UMRIb9@0?Ool00`00Oomoo`0TOol020Pe23@<=@Pd23D8=0`e23@QOol00`00Oomoo`0<
Ool01U[IE[QJfEJhF]UF^1aoo`03001oogoo015oo`002Goo00<007ooOol0;Goo0P003Goo00HNBR9:
7TXRBQi:8TX44Y4UOol01GHVLRIb9W8VMRH03goo00<007ooOol08goo20Pe8goo0P002goo0UZh00EJ
fEZhF[QJ^5[I01]oo`8001=oo`002Goo00<007ooOol0:goo0P0047oo00XNBR9;7TXRBai:4Y4BLA:A
3W0BTB=oo`07MTIb9GHVLREfAW8UMRH03Woo00<007ooOol08goo00L8=0`e23@8=@Pd33D8=00VOol2
0009Ool01UJhF]UF^5[IE[QJfAioo`03001oogoo011oo`002Goo00<007ooOol0:Goo0P004Woo00HR
BQi:8TXNBR9:7TX34Y4TOol3LRH00gHVLRIb9P0?Ool00`00Oomoo`0ROol723DYOol20006Ool00eZh
F]UJ^002F[P00e[IF[Qoo`0MOol00`00Oomoo`0@Ool000Qoo`03001oogoo02Uoo`03001oogoo019o
o`097TXRBai:8T/NBR9;7TXBTA9a02Aoo`06MRIb9GI6LREf9W8U3goo00<007ooOol08Woo00H<=@Pd
23D8=0`e23@/Ool00`00Oomoo`03Ool01U[IE[QJfEJhF]UF^1moo`03001oogoo011oo`0027oo00<0
07ooOol09goo0P005Woo00HNBR9:7TXRBQi:8TX34Y4SOol00g8VMRIb9P02LRH@Ool00`00Oomoo`0Q
Ool723D]Ool200000gooF[QJf@03F[P00e[IF[Qoo`0POol00`00Oomoo`0?Ool000Qoo`03001oogoo
02Eoo`8001Uoo`087TXRBai:8T/NBR9;3W0BTB=oo`05MTIb9GHVLREfAP0@Ool00`00Oomoo`0QOol0
1PPd23D8=0`e23@8=C1oo`800006E[QJfEJhF]UF^5[I8Goo00<007ooOol03goo0008Ool00`00Oomo
o`0TOol00`00Oomoo`0IOol01B9:7TXRBQi:8TX00a:A8Woo00Ef9W8VLRIb9WHV009b9Pmoo`03001o
ogoo021oo`L8=C1oo`05F]UJ^000F[QJf@02F[PROol00`00Oomoo`0?Ool000Moo`03001oogoo02=o
o`8001eoo`078T/NBR9;7TXBTA9a4Y408Woo00Ib9GHVLREfAW8UMRH@Ool00`00Oomoo`0POol01PPe
23@<=@Pd23D8=35oo`03E[QJfEJh00800003F]Uoogoo025oo`03001oogoo00moo`001goo00<007oo
Ool08Goo0P007goo00@NBR9:7TXRBP<BTB9oo`9b9P04MRIb9W8VLRH@Ool00`00Oomoo`0POol623D_
Ool01E[IF[QJ^5ZhF]T00UZh0P008goo00<007ooOol03Woo0007Ool00`00Oomoo`0OOol2000SOol0
1A:A4W4BT@i`4Y408Woo00Eb9GI6LREf9W8U015oo`03001oogoo021oo`0533D8=0Pe23@<=@0`Ool0
1eJhF]UF^5[IE[QJfEJh009oo`80021oo`80011oo`001Woo00<007ooOol07goo00<007ooOol08Woo
1a:A8Goo00Ef9W8VLRIb9WHV015oo`03001oogoo021oo`D8=Bmoo`=J^004F]UJ^5ZhF[P5Ool00`00
Oomoo`0NOol00`00Oomoo`0>Ool000Ioo`03001oogoo01eoo`8002Eoo`064W4BT@i`4Y4BLA:A8Goo
00MfAW8UMRIb9GI6LREf9P0@Ool00`00Oomoo`0OOol01PPd23D8=0`e23@8=Bmoo`06F]UF^5[IE[QJ
fEJh1goo0P007goo00<007ooOol03Goo0006Ool00`00Oomoo`0KOol2000WOol64Y4QOol3LRH00gHV
LRIb9P0AOol00`00Oomoo`0OOol623D]Ool3F[P015[IF[QJ^5Zh2Woo0P007Goo00<007ooOol03Goo
0006Ool00`00Oomoo`0IOol2000YOol01@i`4Y4BLA:A3W008Woo00If9W8UMTIb9GHVLRDAOol00`00
Oomoo`0OOol01PPd33D8=0Pe23@<=Beoo`07F]UF^5[IE[QJfEJhF]T037oo0P006goo00<007ooOol0
3Goo0005Ool00`00Oomoo`0IOol00`00Oomoo`0YOol54Y4ROol00g8VMRIb9P02LRHBOol00`00Oomo
o`0OOol523D]Ool2F[P01E[IF[QJ^5ZhF]T03goo00<007ooOol067oo00<007ooOol03Goo0005Ool0
0`00Oomoo`0GOol2000[Ool01a:A4W4BT@i`4Y4BLA:A021oo`07LREfAW8UMRIb9GI6LRD04Goo00<0
07ooOol07goo00D8=0Pe23@<=@Pd02aoo`07F]UF^5[IE[QJfEJhF]T04Goo0P006Goo00<007ooOol0
37oo0005Ool00`00Oomoo`0EOol2000]Ool64Y4QOol01WHVLRIb9W8VMRIb9Q9oo`03001oogoo01mo
o`D8=Baoo`03F[QJfEZh009J^003F]Uoogoo019oo`8001Moo`03001oogoo00aoo`001Goo00<007oo
Ool04goo0P00;goo00HBT@i`4Y4BLA:A3W0QOol01W8UMRIb9GI6LREf9Q9oo`03001oogoo01moo`05
23@<=@Pd23D8=00[Ool01UJhF]UF^5[IE[QJfAMoo`8001Eoo`03001oogoo00aoo`0017oo00<007oo
Ool04goo00<007ooOol0;goo1A:A8Woo0W8V00=f9W8VLRH04goo00<007ooOol07goo1@Pe:Woo00=J
^5[IF[P00UZh00=JfEZhOol067oo00<007ooOol04Woo0P003Goo0004Ool00`00Oomoo`0AOol2000a
Ool01Pi`4Y4BLA:A3W0BTB9oo`06LREfAW8UMRIb9GI64Woo00<007ooOol07goo00D8=0Pe23@<=@Pd
02]oo`05E[QJfEJhF]UF^00KOol2000COol00`00Oomoo`0;Ool000Aoo`03001oogoo00moo`8003=o
o`HBTB5oo`03LRIf9W8V009b9P03MRIoogoo015oo`03001oogoo01moo`H8=B]oo`03F[QJfGoo01io
o`80015oo`03001oogoo00]oo`000goo00<007ooOol03Woo0P00=Goo00HBLA:A3W0BTA9a4Y4QOol0
1WI6LREf9W8UMTIb9A=oo`03001oogoo01moo`0723@<=@Pd23D8=0`e23@0CGoo0P0047oo00<007oo
Ool02Woo0003Ool00`00Oomoo`0=Ool00`00Oomoo`0dOol64Y4ROol3LRH00gHVLRIoo`0COol00`00
Oomoo`0OOol623E@Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool000=oo`03001oogoo00]oo`8003Io
o`074W4BT@i`4Y4BLA:A3W008Woo00Ef9W8UMTIb9GHV01Aoo`03001oogoo021oo`0523D8=0`e23@8
=@1AOol2000=Ool00`00Oomoo`05Ool20003Ool000=oo`03001oogoo00Uoo`8003Qoo`HBTB=oo`03
LRIf9W8V009b9QAoo`03001oogoo021oo`D8=E=oo`8000]oo`03001oogoo00Aoo`04001oogoo0002
Ool0009oo`03001oogoo00Uoo`03001oogoo03Qoo`063W0BTA9a4Y4>L1:A8Woo00Ib9GI6LREf9W8U
MTHDOol00`00Oomoo`0POol01@`e23@8=@Pd33D0EGoo00<007ooOol02Goo00<007ooOol00goo00@0
07ooOol0009oo`000Woo00<007ooOol01goo0P00>Woo1Q:A8goo00If9W8VLRIb9WHVLRHDOol00`00
Oomoo`0POol623EEOol20009Ool00`00Oomoo`03Ool01000Oomoo`000Woo0002Ool00`00Oomoo`05
Ool2000kOol01`i`4Y4BLA:A3W0BTA9a02=oo`06LREf9W8UMTIb9GHV57oo00<007ooOol087oo00L8
=@Pd33D8=0Pe23@<=@1FOol20007Ool00`00Oomoo`03Ool01000Oomoo`000Woo00000goo001oo`05
Ool2000lOol74Y4TOol2LRH00gHVLRIb9P0EOol00`00Oomoo`0POol623EIOol20004Ool30005Ool2
0003Ool00003Ool007oo00Aoo`03001oogoo03aoo`074Y4BLA:A3W0BTA9a4Y4097oo00Eb9GI6LREf
9W8U01Eoo`03001oogoo025oo`0523@8=@Pd33D8=01KOol00`00Oomoo`03Ool00`00Oomoo`08Ool0
0003Ool007oo009oo`8003ioo`LBTBAoo`03LRIf9W8V009b9P03MRIb9Woo01=oo`03001oogoo025o
o`H8=E]oo`8000=oo`03001oogoo00Qoo`0000=oo`00Ool00P00?goo00LBTA9a4Y4>L1:A4W4BT@0U
Ool01WI6LREf9W8UMTIb9AEoo`03001oogoo025oo`0723@<=@Pd23D8=0`e23@0G7oo0P0000=oo`00
Ool02Goo00030011Ool64Y4VOol3LRH00gHVLRIb9P0EOol00`00Oomoo`0ROol523EOOol30009Ool0
0080045oo`074W4BT@i`4Y4BLA:A3W009Woo00Ef9W8UMTIb9GHV01Ioo`03001oogoo029oo`0623D8
=0`e23@8=@PdGgoo0P002Goo0002Ool4000mOol64Y4WOol00g8VMRIb9P02LRHFOol00`00Oomoo`0R
Ool723EJOol4000;Ool000Ioo`@00003Ool007oo03Aoo`074W4BT@i`4Y4BLA:A3W00:7oo00EfAW8U
MRIb9GI601Ioo`03001oogoo029oo`0733D8=0Pe23@<=@Pd23D0Dgoo00<007ooOol010003goo000:
Ool4000bOol84Y4XOol3LRH00gHVLRIoo`0EOol00`00Oomoo`0SOol623EBOol4000COol000ioo`@0
02ioo`074Y4>L1:A4W4BT@i`4Y40:Goo00Ef9W8UMTIb9GHV01Ioo`03001oogoo02=oo`0623@<=@Pd
23D8=0`eCWoo10005goo000BOol400000goo001oo`0WOol64Y4ZOol00g8VMRIb9P02LRHFOol00`00
Oomoo`0TOol623E5Ool01000Oomoogoo10006goo000FOol4000VOol01A:A4W4BT@i`4Y40:goo00Ef
AW8UMRIb9GI601Ioo`03001oogoo02Aoo`0723D8=0`e23@8=@Pd33D0A7oo10007goo000JOol40004
Ool00`00Oomoo`1;Ool3LRH00gHVLRIb9P0EOol00`00Oomoo`0TOol723E0Ool4000SOol001ioo`@0
04ioo`06MRIb9GI6LREf9W8U5Goo00<007ooOol09Goo00H8=0Pe23@<=@Pd23DgOol00`00Oomoo`02
Ool4000WOol0025oo`D000Ioo`03001oogoo045oo`03LRIf9W8V009b9P03MRIoogoo01=oo`03001o
ogoo02Ioo`H8=CIoo`D002]oo`009Woo10000Woo00<007ooOol0@Woo00Eb9GHVLREfAW8U01Eoo`03
001oogoo02Ioo`0633D8=0Pe23@<=@Pd<goo1000;goo000ZOol40013Ool2LRH017HVLRIb9W8V57oo
00<007ooOol09goo1PPe:Goo00<007ooOol00Woo1000<goo000^Ool40004Ool00`00Oomoo`0hOol0
1W8UMTIb9GHVLREfAQAoo`03001oogoo02Moo`0723@<=@Pd23D8=0`e23@0:Goo1000=goo000bOol5
000jOol01WHVLRIb9W8VMRIb9QAoo`03001oogoo02Moo`H8=BIoo`@003]oo`00=Woo1000=goo00Ib
9GHVLREfAW8UMRHDOol00`00Oomoo`0ZOol00``e23Aoo`0NOol01000Oomoogoo1000?goo000jOol4
00000goo001oo`0aOol00g8VMRIb9P02LRH00gHVOomoo`0AOol00`00Oomoo`1;Ool40013Ool003io
o`@0031oo`06MTIb9GHVLREfAW8U4goo00<007ooOol0Agoo1000Agoo0012Ool40003Ool00`00Oomo
o`0VOol3LRH00gHVLRIb9P0COol00`00Oomoo`11Ool00`00Ool00003000KOol4000/Ool004Ioo`@0
00Moo`03001oogoo01moo`05LREfAW8UMRIb9@0COol00`00Oomoo`0gOol00`00Oomoo`05Ool4000O
Ool00`00Oomoo`0]Ool002Qoo`@001ioo`@000=oo`03001oogoo01moo`05MRIb9W8VLRIf9P0COol0
0`00Oomoo`0gOol01000Oomoogoo100097oo00<007ooOol0;7oo000XOol00`00Oomoo`0SOol4000R
Ool017HVLREfAW8U4goo00<007ooOol0=goo1000:Goo00<007ooOol0:goo000YOol00`00Oomoo`0V
Ool40004Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool4000[Ool01000Oomoo`00
;7oo000ZOol00`00Oomoo`0YOol4000aOol00`00Oomoo`0]Ool00`00Ool00003000`Ool2000]Ool0
02Qoo`04001oogoo000^Ool40004Ool00`00Oomoo`0VOol00`00Oomoo`0[Ool4001SOol002Uoo`80
03=oo`D002Qoo`03001oogoo02Aoo`03001oogoo00@006Moo`00HWoo10000goo00<007ooOol07goo
00<007ooOol08goo1000Jgoo001VOol40007Ool00`00Oomoo`0GOol00`00Oomoo`0KOol01000Oomo
ogoo1000Kgoo001ZOol40003Ool00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`05Ool4001c
Ool004moo`8001eoo`@001Uoo`03001oogoo01=oo`04001oogooOol4000LOol2001IOol004ioo`04
001oogoo000POol40002Ool00`00Oomoo`0@Ool00`00Oomoo`0COol4000OOol01000Oomoo`00F7oo
001>Ool01000Oomoo`0097oo10001Goo00<007ooOol02Goo00<007ooOol02goo00@007ooOomoo`@0
02=oo`04001oogoo001HOol004ioo`04001oogoo000XOol400000goo001oo`0:Ool00`00Oomoo`0;
Ool4000WOol01000Oomoo`00F7oo001>Ool01000Oomoo`00;7oo10000goo00<007ooOol00goo00<0
07ooOol00goo00@007ooOomoo`@002]oo`04001oogoo001HOol004moo`80035oo`@000Eoo`03001o
ogoo00=oo`@0031oo`8005Uoo`00QWoo100000=oo`00Ool01000Sgoo002:Ool3002COol0075oo`@0
0:]oo`00LGoo00<007ooOol0;goo1000NGoo001bOol00`00Oomoo`0^Ool00`00Oomoo`1jOol006]o
o`@000Aoo`03001oogoo02ioo`03001oogoo07Uoo`00LGoo00@007ooOol002Qoo`@000Aoo`03001o
ogoo07Qoo`00LWoo0P00;goo00@007ooOol007Uoo`00Y7oo0P00NWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {284, 0}} -> {0.066983, -0.000983914, \
0.00310728, 0.00310728}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Two spheres sedimenting in a Newtonian fluid. They rotate in opposite \
directions as they fall. In fact, we find that the rotational velocities are \
UNEW[7]=0.665346 and UNEW[10]= -0.665346.\
\>", "Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["<<Graphics`Graphics3D`", "Input"],

Cell["FU={0,0,-10,0,0,-10,0,0,0,0,0,0};", "Input"],

Cell["X[1]=0;Y[1]=2;Z[1]=0;X[2]=0;Y[2]=-2;Z[2]=0;", "Input"],

Cell["dt=0.1;", "Input"],

Cell["NSPHR=2;NDIM=6 NSPHR;Ng=3 NSPHR; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\StokesianDynamics\\\\data.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\StokesianDynamics\\data.m", 10]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<100,{<<\"C:\\\\StokesianDynamics\\\\NEWTON2.m\";
X[1,t]=X[1,t-1]+UNEW[1]*dt;Y[1,t]=Y[1,t-1]+UNEW[2]*dt;Z[1,t]=Z[1,t-1]+UNEW[3]*\
dt;X[2,t]=X[2,t-1]+UNEW[4]*dt;Y[2,t]=Y[2,t-1]+UNEW[5]*dt;Z[2,t]=Z[2,t-1]+UNEW[\
6]*dt;Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[UNEW[i],{i,1,12}]", "Input"],

Cell[BoxData[
    \({0.`, 0.`, \(-12.370706165529572`\), 0.`, 
      0.`, \(-12.370706165529572`\), 0.6653460385300247`, 0.`, 
      0.`, \(-0.6653460385300249`\), 0.`, 0.`}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{538, 617},
WindowMargins->{{2, Automatic}, {Automatic, 5}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 686, 20, 262, "Title"],
Cell[2465, 75, 1419, 26, 548, "Subsubtitle"],
Cell[3887, 103, 352, 9, 87, "Subsubtitle"],
Cell[4242, 114, 228, 5, 86, "Subsubtitle"],

Cell[CellGroupData[{
Cell[4495, 123, 220, 4, 86, "Subsubtitle"],
Cell[4718, 129, 39, 0, 30, "Input"],
Cell[4760, 131, 50, 0, 30, "Input"],
Cell[4813, 133, 59, 0, 30, "Input"],
Cell[4875, 135, 24, 0, 30, "Input"],
Cell[4902, 137, 50, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[4977, 141, 66, 0, 30, "Input"],
Cell[5046, 143, 81, 1, 29, "Output"]
}, Open  ]],
Cell[5142, 147, 42, 0, 30, "Input"],
Cell[5187, 149, 294, 12, 210, "Input"],
Cell[5484, 163, 98, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[5607, 170, 264, 5, 84, "Input"],
Cell[5874, 177, 34, 1, 25, "Print"],
Cell[5911, 180, 34, 1, 25, "Print"],
Cell[5948, 183, 34, 1, 25, "Print"],
Cell[5985, 186, 34, 1, 25, "Print"],
Cell[6022, 189, 34, 1, 25, "Print"],
Cell[6059, 192, 34, 1, 25, "Print"],
Cell[6096, 195, 34, 1, 25, "Print"],
Cell[6133, 198, 34, 1, 25, "Print"],
Cell[6170, 201, 34, 1, 25, "Print"],
Cell[6207, 204, 35, 1, 25, "Print"],
Cell[6245, 207, 35, 1, 25, "Print"],
Cell[6283, 210, 35, 1, 25, "Print"],
Cell[6321, 213, 35, 1, 25, "Print"],
Cell[6359, 216, 35, 1, 25, "Print"],
Cell[6397, 219, 35, 1, 25, "Print"],
Cell[6435, 222, 35, 1, 25, "Print"],
Cell[6473, 225, 35, 1, 25, "Print"],
Cell[6511, 228, 35, 1, 25, "Print"],
Cell[6549, 231, 35, 1, 25, "Print"],
Cell[6587, 234, 35, 1, 25, "Print"],
Cell[6625, 237, 35, 1, 25, "Print"],
Cell[6663, 240, 35, 1, 25, "Print"],
Cell[6701, 243, 35, 1, 25, "Print"],
Cell[6739, 246, 35, 1, 25, "Print"],
Cell[6777, 249, 35, 1, 25, "Print"],
Cell[6815, 252, 35, 1, 25, "Print"],
Cell[6853, 255, 35, 1, 25, "Print"],
Cell[6891, 258, 35, 1, 25, "Print"],
Cell[6929, 261, 35, 1, 25, "Print"],
Cell[6967, 264, 35, 1, 25, "Print"],
Cell[7005, 267, 35, 1, 25, "Print"],
Cell[7043, 270, 35, 1, 25, "Print"],
Cell[7081, 273, 35, 1, 25, "Print"],
Cell[7119, 276, 35, 1, 25, "Print"],
Cell[7157, 279, 35, 1, 25, "Print"],
Cell[7195, 282, 35, 1, 25, "Print"],
Cell[7233, 285, 35, 1, 25, "Print"],
Cell[7271, 288, 35, 1, 25, "Print"],
Cell[7309, 291, 35, 1, 25, "Print"],
Cell[7347, 294, 35, 1, 25, "Print"],
Cell[7385, 297, 35, 1, 25, "Print"],
Cell[7423, 300, 35, 1, 25, "Print"],
Cell[7461, 303, 35, 1, 25, "Print"],
Cell[7499, 306, 35, 1, 25, "Print"],
Cell[7537, 309, 35, 1, 25, "Print"],
Cell[7575, 312, 35, 1, 25, "Print"],
Cell[7613, 315, 35, 1, 25, "Print"],
Cell[7651, 318, 35, 1, 25, "Print"],
Cell[7689, 321, 35, 1, 25, "Print"],
Cell[7727, 324, 35, 1, 25, "Print"],
Cell[7765, 327, 35, 1, 25, "Print"],
Cell[7803, 330, 35, 1, 25, "Print"],
Cell[7841, 333, 35, 1, 25, "Print"],
Cell[7879, 336, 35, 1, 25, "Print"],
Cell[7917, 339, 35, 1, 25, "Print"],
Cell[7955, 342, 35, 1, 25, "Print"],
Cell[7993, 345, 35, 1, 25, "Print"],
Cell[8031, 348, 35, 1, 25, "Print"],
Cell[8069, 351, 35, 1, 25, "Print"],
Cell[8107, 354, 35, 1, 25, "Print"],
Cell[8145, 357, 35, 1, 25, "Print"],
Cell[8183, 360, 35, 1, 25, "Print"],
Cell[8221, 363, 35, 1, 25, "Print"],
Cell[8259, 366, 35, 1, 25, "Print"],
Cell[8297, 369, 35, 1, 25, "Print"],
Cell[8335, 372, 35, 1, 25, "Print"],
Cell[8373, 375, 35, 1, 25, "Print"],
Cell[8411, 378, 35, 1, 25, "Print"],
Cell[8449, 381, 35, 1, 25, "Print"],
Cell[8487, 384, 35, 1, 25, "Print"],
Cell[8525, 387, 35, 1, 25, "Print"],
Cell[8563, 390, 35, 1, 25, "Print"],
Cell[8601, 393, 35, 1, 25, "Print"],
Cell[8639, 396, 35, 1, 25, "Print"],
Cell[8677, 399, 35, 1, 25, "Print"],
Cell[8715, 402, 35, 1, 25, "Print"],
Cell[8753, 405, 35, 1, 25, "Print"],
Cell[8791, 408, 35, 1, 25, "Print"],
Cell[8829, 411, 35, 1, 25, "Print"],
Cell[8867, 414, 35, 1, 25, "Print"],
Cell[8905, 417, 35, 1, 25, "Print"],
Cell[8943, 420, 35, 1, 25, "Print"],
Cell[8981, 423, 35, 1, 25, "Print"],
Cell[9019, 426, 35, 1, 25, "Print"],
Cell[9057, 429, 35, 1, 25, "Print"],
Cell[9095, 432, 35, 1, 25, "Print"],
Cell[9133, 435, 35, 1, 25, "Print"],
Cell[9171, 438, 35, 1, 25, "Print"],
Cell[9209, 441, 35, 1, 25, "Print"],
Cell[9247, 444, 35, 1, 25, "Print"],
Cell[9285, 447, 35, 1, 25, "Print"],
Cell[9323, 450, 35, 1, 25, "Print"],
Cell[9361, 453, 35, 1, 25, "Print"],
Cell[9399, 456, 35, 1, 25, "Print"],
Cell[9437, 459, 35, 1, 25, "Print"],
Cell[9475, 462, 35, 1, 25, "Print"],
Cell[9513, 465, 35, 1, 25, "Print"],
Cell[9551, 468, 35, 1, 25, "Print"],
Cell[9589, 471, 35, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9661, 477, 293, 8, 84, "Input"],
Cell[9957, 487, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10126, 495, 348, 11, 102, "Input"],
Cell[10477, 508, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10646, 516, 94, 2, 48, "Input"],
Cell[10743, 520, 32230, 1176, 271, 10847, 908, "GraphicsData", "PostScript", \
"Graphics"],
Cell[42976, 1698, 132, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[43157, 1707, 267, 5, 108, "Subsubtitle"],
Cell[43427, 1714, 74, 0, 30, "Input"],
Cell[43504, 1716, 115, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[43644, 1723, 282, 5, 102, "Input"],
Cell[43929, 1730, 52340, 752, 752, 1454, 119, "GraphicsData", "PostScript", \
"Graphics"],
Cell[96272, 2484, 132, 3, 29, "Output"]
}, Open  ]],
Cell[96419, 2490, 25, 0, 30, "Input"],
Cell[96447, 2492, 50, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[96522, 2496, 66, 0, 30, "Input"],
Cell[96591, 2498, 81, 1, 29, "Output"]
}, Open  ]],
Cell[96687, 2502, 42, 0, 30, "Input"],
Cell[96732, 2504, 294, 12, 210, "Input"],
Cell[97029, 2518, 172, 5, 84, "Input"],

Cell[CellGroupData[{
Cell[97226, 2527, 433, 7, 138, "Input"],
Cell[97662, 2536, 34, 1, 25, "Print"],
Cell[97699, 2539, 34, 1, 25, "Print"],
Cell[97736, 2542, 34, 1, 25, "Print"],
Cell[97773, 2545, 34, 1, 25, "Print"],
Cell[97810, 2548, 34, 1, 25, "Print"],
Cell[97847, 2551, 34, 1, 25, "Print"],
Cell[97884, 2554, 34, 1, 25, "Print"],
Cell[97921, 2557, 34, 1, 25, "Print"],
Cell[97958, 2560, 34, 1, 25, "Print"],
Cell[97995, 2563, 35, 1, 25, "Print"],
Cell[98033, 2566, 35, 1, 25, "Print"],
Cell[98071, 2569, 35, 1, 25, "Print"],
Cell[98109, 2572, 35, 1, 25, "Print"],
Cell[98147, 2575, 35, 1, 25, "Print"],
Cell[98185, 2578, 35, 1, 25, "Print"],
Cell[98223, 2581, 35, 1, 25, "Print"],
Cell[98261, 2584, 35, 1, 25, "Print"],
Cell[98299, 2587, 35, 1, 25, "Print"],
Cell[98337, 2590, 35, 1, 25, "Print"],
Cell[98375, 2593, 35, 1, 25, "Print"],
Cell[98413, 2596, 35, 1, 25, "Print"],
Cell[98451, 2599, 35, 1, 25, "Print"],
Cell[98489, 2602, 35, 1, 25, "Print"],
Cell[98527, 2605, 35, 1, 25, "Print"],
Cell[98565, 2608, 35, 1, 25, "Print"],
Cell[98603, 2611, 35, 1, 25, "Print"],
Cell[98641, 2614, 35, 1, 25, "Print"],
Cell[98679, 2617, 35, 1, 25, "Print"],
Cell[98717, 2620, 35, 1, 25, "Print"],
Cell[98755, 2623, 35, 1, 25, "Print"],
Cell[98793, 2626, 35, 1, 25, "Print"],
Cell[98831, 2629, 35, 1, 25, "Print"],
Cell[98869, 2632, 35, 1, 25, "Print"],
Cell[98907, 2635, 35, 1, 25, "Print"],
Cell[98945, 2638, 35, 1, 25, "Print"],
Cell[98983, 2641, 35, 1, 25, "Print"],
Cell[99021, 2644, 35, 1, 25, "Print"],
Cell[99059, 2647, 35, 1, 25, "Print"],
Cell[99097, 2650, 35, 1, 25, "Print"],
Cell[99135, 2653, 35, 1, 25, "Print"],
Cell[99173, 2656, 35, 1, 25, "Print"],
Cell[99211, 2659, 35, 1, 25, "Print"],
Cell[99249, 2662, 35, 1, 25, "Print"],
Cell[99287, 2665, 35, 1, 25, "Print"],
Cell[99325, 2668, 35, 1, 25, "Print"],
Cell[99363, 2671, 35, 1, 25, "Print"],
Cell[99401, 2674, 35, 1, 25, "Print"],
Cell[99439, 2677, 35, 1, 25, "Print"],
Cell[99477, 2680, 35, 1, 25, "Print"],
Cell[99515, 2683, 35, 1, 25, "Print"],
Cell[99553, 2686, 35, 1, 25, "Print"],
Cell[99591, 2689, 35, 1, 25, "Print"],
Cell[99629, 2692, 35, 1, 25, "Print"],
Cell[99667, 2695, 35, 1, 25, "Print"],
Cell[99705, 2698, 35, 1, 25, "Print"],
Cell[99743, 2701, 35, 1, 25, "Print"],
Cell[99781, 2704, 35, 1, 25, "Print"],
Cell[99819, 2707, 35, 1, 25, "Print"],
Cell[99857, 2710, 35, 1, 25, "Print"],
Cell[99895, 2713, 35, 1, 25, "Print"],
Cell[99933, 2716, 35, 1, 25, "Print"],
Cell[99971, 2719, 35, 1, 25, "Print"],
Cell[100009, 2722, 35, 1, 25, "Print"],
Cell[100047, 2725, 35, 1, 25, "Print"],
Cell[100085, 2728, 35, 1, 25, "Print"],
Cell[100123, 2731, 35, 1, 25, "Print"],
Cell[100161, 2734, 35, 1, 25, "Print"],
Cell[100199, 2737, 35, 1, 25, "Print"],
Cell[100237, 2740, 35, 1, 25, "Print"],
Cell[100275, 2743, 35, 1, 25, "Print"],
Cell[100313, 2746, 35, 1, 25, "Print"],
Cell[100351, 2749, 35, 1, 25, "Print"],
Cell[100389, 2752, 35, 1, 25, "Print"],
Cell[100427, 2755, 35, 1, 25, "Print"],
Cell[100465, 2758, 35, 1, 25, "Print"],
Cell[100503, 2761, 35, 1, 25, "Print"],
Cell[100541, 2764, 35, 1, 25, "Print"],
Cell[100579, 2767, 35, 1, 25, "Print"],
Cell[100617, 2770, 35, 1, 25, "Print"],
Cell[100655, 2773, 35, 1, 25, "Print"],
Cell[100693, 2776, 35, 1, 25, "Print"],
Cell[100731, 2779, 35, 1, 25, "Print"],
Cell[100769, 2782, 35, 1, 25, "Print"],
Cell[100807, 2785, 35, 1, 25, "Print"],
Cell[100845, 2788, 35, 1, 25, "Print"],
Cell[100883, 2791, 35, 1, 25, "Print"],
Cell[100921, 2794, 35, 1, 25, "Print"],
Cell[100959, 2797, 35, 1, 25, "Print"],
Cell[100997, 2800, 35, 1, 25, "Print"],
Cell[101035, 2803, 35, 1, 25, "Print"],
Cell[101073, 2806, 35, 1, 25, "Print"],
Cell[101111, 2809, 35, 1, 25, "Print"],
Cell[101149, 2812, 35, 1, 25, "Print"],
Cell[101187, 2815, 35, 1, 25, "Print"],
Cell[101225, 2818, 35, 1, 25, "Print"],
Cell[101263, 2821, 35, 1, 25, "Print"],
Cell[101301, 2824, 35, 1, 25, "Print"],
Cell[101339, 2827, 35, 1, 25, "Print"],
Cell[101377, 2830, 35, 1, 25, "Print"],
Cell[101415, 2833, 36, 1, 25, "Print"],
Cell[101454, 2836, 36, 1, 25, "Print"],
Cell[101493, 2839, 36, 1, 25, "Print"],
Cell[101532, 2842, 36, 1, 25, "Print"],
Cell[101571, 2845, 36, 1, 25, "Print"],
Cell[101610, 2848, 36, 1, 25, "Print"],
Cell[101649, 2851, 36, 1, 25, "Print"],
Cell[101688, 2854, 36, 1, 25, "Print"],
Cell[101727, 2857, 36, 1, 25, "Print"],
Cell[101766, 2860, 36, 1, 25, "Print"],
Cell[101805, 2863, 36, 1, 25, "Print"],
Cell[101844, 2866, 36, 1, 25, "Print"],
Cell[101883, 2869, 36, 1, 25, "Print"],
Cell[101922, 2872, 36, 1, 25, "Print"],
Cell[101961, 2875, 36, 1, 25, "Print"],
Cell[102000, 2878, 36, 1, 25, "Print"],
Cell[102039, 2881, 36, 1, 25, "Print"],
Cell[102078, 2884, 36, 1, 25, "Print"],
Cell[102117, 2887, 36, 1, 25, "Print"],
Cell[102156, 2890, 36, 1, 25, "Print"],
Cell[102195, 2893, 36, 1, 25, "Print"],
Cell[102234, 2896, 36, 1, 25, "Print"],
Cell[102273, 2899, 36, 1, 25, "Print"],
Cell[102312, 2902, 36, 1, 25, "Print"],
Cell[102351, 2905, 36, 1, 25, "Print"],
Cell[102390, 2908, 36, 1, 25, "Print"],
Cell[102429, 2911, 36, 1, 25, "Print"],
Cell[102468, 2914, 36, 1, 25, "Print"],
Cell[102507, 2917, 36, 1, 25, "Print"],
Cell[102546, 2920, 36, 1, 25, "Print"],
Cell[102585, 2923, 36, 1, 25, "Print"],
Cell[102624, 2926, 36, 1, 25, "Print"],
Cell[102663, 2929, 36, 1, 25, "Print"],
Cell[102702, 2932, 36, 1, 25, "Print"],
Cell[102741, 2935, 36, 1, 25, "Print"],
Cell[102780, 2938, 36, 1, 25, "Print"],
Cell[102819, 2941, 36, 1, 25, "Print"],
Cell[102858, 2944, 36, 1, 25, "Print"],
Cell[102897, 2947, 36, 1, 25, "Print"],
Cell[102936, 2950, 36, 1, 25, "Print"],
Cell[102975, 2953, 36, 1, 25, "Print"],
Cell[103014, 2956, 36, 1, 25, "Print"],
Cell[103053, 2959, 36, 1, 25, "Print"],
Cell[103092, 2962, 36, 1, 25, "Print"],
Cell[103131, 2965, 36, 1, 25, "Print"],
Cell[103170, 2968, 36, 1, 25, "Print"],
Cell[103209, 2971, 36, 1, 25, "Print"],
Cell[103248, 2974, 36, 1, 25, "Print"],
Cell[103287, 2977, 36, 1, 25, "Print"],
Cell[103326, 2980, 36, 1, 25, "Print"],
Cell[103365, 2983, 36, 1, 25, "Print"],
Cell[103404, 2986, 36, 1, 25, "Print"],
Cell[103443, 2989, 36, 1, 25, "Print"],
Cell[103482, 2992, 36, 1, 25, "Print"],
Cell[103521, 2995, 36, 1, 25, "Print"],
Cell[103560, 2998, 36, 1, 25, "Print"],
Cell[103599, 3001, 36, 1, 25, "Print"],
Cell[103638, 3004, 36, 1, 25, "Print"],
Cell[103677, 3007, 36, 1, 25, "Print"],
Cell[103716, 3010, 36, 1, 25, "Print"],
Cell[103755, 3013, 36, 1, 25, "Print"],
Cell[103794, 3016, 36, 1, 25, "Print"],
Cell[103833, 3019, 36, 1, 25, "Print"],
Cell[103872, 3022, 36, 1, 25, "Print"],
Cell[103911, 3025, 36, 1, 25, "Print"],
Cell[103950, 3028, 36, 1, 25, "Print"],
Cell[103989, 3031, 36, 1, 25, "Print"],
Cell[104028, 3034, 36, 1, 25, "Print"],
Cell[104067, 3037, 36, 1, 25, "Print"],
Cell[104106, 3040, 36, 1, 25, "Print"],
Cell[104145, 3043, 36, 1, 25, "Print"],
Cell[104184, 3046, 36, 1, 25, "Print"],
Cell[104223, 3049, 36, 1, 25, "Print"],
Cell[104262, 3052, 36, 1, 25, "Print"],
Cell[104301, 3055, 36, 1, 25, "Print"],
Cell[104340, 3058, 36, 1, 25, "Print"],
Cell[104379, 3061, 36, 1, 25, "Print"],
Cell[104418, 3064, 36, 1, 25, "Print"],
Cell[104457, 3067, 36, 1, 25, "Print"],
Cell[104496, 3070, 36, 1, 25, "Print"],
Cell[104535, 3073, 36, 1, 25, "Print"],
Cell[104574, 3076, 36, 1, 25, "Print"],
Cell[104613, 3079, 36, 1, 25, "Print"],
Cell[104652, 3082, 36, 1, 25, "Print"],
Cell[104691, 3085, 36, 1, 25, "Print"],
Cell[104730, 3088, 36, 1, 25, "Print"],
Cell[104769, 3091, 36, 1, 25, "Print"],
Cell[104808, 3094, 36, 1, 25, "Print"],
Cell[104847, 3097, 36, 1, 25, "Print"],
Cell[104886, 3100, 36, 1, 25, "Print"],
Cell[104925, 3103, 36, 1, 25, "Print"],
Cell[104964, 3106, 36, 1, 25, "Print"],
Cell[105003, 3109, 36, 1, 25, "Print"],
Cell[105042, 3112, 36, 1, 25, "Print"],
Cell[105081, 3115, 36, 1, 25, "Print"],
Cell[105120, 3118, 36, 1, 25, "Print"],
Cell[105159, 3121, 36, 1, 25, "Print"],
Cell[105198, 3124, 36, 1, 25, "Print"],
Cell[105237, 3127, 36, 1, 25, "Print"],
Cell[105276, 3130, 36, 1, 25, "Print"],
Cell[105315, 3133, 36, 1, 25, "Print"],
Cell[105354, 3136, 36, 1, 25, "Print"],
Cell[105393, 3139, 36, 1, 25, "Print"],
Cell[105432, 3142, 36, 1, 25, "Print"],
Cell[105471, 3145, 36, 1, 25, "Print"],
Cell[105510, 3148, 36, 1, 25, "Print"],
Cell[105549, 3151, 36, 1, 25, "Print"],
Cell[105588, 3154, 36, 1, 25, "Print"],
Cell[105627, 3157, 36, 1, 25, "Print"],
Cell[105666, 3160, 36, 1, 25, "Print"],
Cell[105705, 3163, 36, 1, 25, "Print"],
Cell[105744, 3166, 36, 1, 25, "Print"],
Cell[105783, 3169, 36, 1, 25, "Print"],
Cell[105822, 3172, 36, 1, 25, "Print"],
Cell[105861, 3175, 36, 1, 25, "Print"],
Cell[105900, 3178, 36, 1, 25, "Print"],
Cell[105939, 3181, 36, 1, 25, "Print"],
Cell[105978, 3184, 36, 1, 25, "Print"],
Cell[106017, 3187, 36, 1, 25, "Print"],
Cell[106056, 3190, 36, 1, 25, "Print"],
Cell[106095, 3193, 36, 1, 25, "Print"],
Cell[106134, 3196, 36, 1, 25, "Print"],
Cell[106173, 3199, 36, 1, 25, "Print"],
Cell[106212, 3202, 36, 1, 25, "Print"],
Cell[106251, 3205, 36, 1, 25, "Print"],
Cell[106290, 3208, 36, 1, 25, "Print"],
Cell[106329, 3211, 36, 1, 25, "Print"],
Cell[106368, 3214, 36, 1, 25, "Print"],
Cell[106407, 3217, 36, 1, 25, "Print"],
Cell[106446, 3220, 36, 1, 25, "Print"],
Cell[106485, 3223, 36, 1, 25, "Print"],
Cell[106524, 3226, 36, 1, 25, "Print"],
Cell[106563, 3229, 36, 1, 25, "Print"],
Cell[106602, 3232, 36, 1, 25, "Print"],
Cell[106641, 3235, 36, 1, 25, "Print"],
Cell[106680, 3238, 36, 1, 25, "Print"],
Cell[106719, 3241, 36, 1, 25, "Print"],
Cell[106758, 3244, 36, 1, 25, "Print"],
Cell[106797, 3247, 36, 1, 25, "Print"],
Cell[106836, 3250, 36, 1, 25, "Print"],
Cell[106875, 3253, 36, 1, 25, "Print"],
Cell[106914, 3256, 36, 1, 25, "Print"],
Cell[106953, 3259, 36, 1, 25, "Print"],
Cell[106992, 3262, 36, 1, 25, "Print"],
Cell[107031, 3265, 36, 1, 25, "Print"],
Cell[107070, 3268, 36, 1, 25, "Print"],
Cell[107109, 3271, 36, 1, 25, "Print"],
Cell[107148, 3274, 36, 1, 25, "Print"],
Cell[107187, 3277, 36, 1, 25, "Print"],
Cell[107226, 3280, 36, 1, 25, "Print"],
Cell[107265, 3283, 36, 1, 25, "Print"],
Cell[107304, 3286, 36, 1, 25, "Print"],
Cell[107343, 3289, 36, 1, 25, "Print"],
Cell[107382, 3292, 36, 1, 25, "Print"],
Cell[107421, 3295, 36, 1, 25, "Print"],
Cell[107460, 3298, 36, 1, 25, "Print"],
Cell[107499, 3301, 36, 1, 25, "Print"],
Cell[107538, 3304, 36, 1, 25, "Print"],
Cell[107577, 3307, 36, 1, 25, "Print"],
Cell[107616, 3310, 36, 1, 25, "Print"],
Cell[107655, 3313, 36, 1, 25, "Print"],
Cell[107694, 3316, 36, 1, 25, "Print"],
Cell[107733, 3319, 36, 1, 25, "Print"],
Cell[107772, 3322, 36, 1, 25, "Print"],
Cell[107811, 3325, 36, 1, 25, "Print"],
Cell[107850, 3328, 36, 1, 25, "Print"],
Cell[107889, 3331, 36, 1, 25, "Print"],
Cell[107928, 3334, 36, 1, 25, "Print"],
Cell[107967, 3337, 36, 1, 25, "Print"],
Cell[108006, 3340, 36, 1, 25, "Print"],
Cell[108045, 3343, 36, 1, 25, "Print"],
Cell[108084, 3346, 36, 1, 25, "Print"],
Cell[108123, 3349, 36, 1, 25, "Print"],
Cell[108162, 3352, 36, 1, 25, "Print"],
Cell[108201, 3355, 36, 1, 25, "Print"],
Cell[108240, 3358, 36, 1, 25, "Print"],
Cell[108279, 3361, 36, 1, 25, "Print"],
Cell[108318, 3364, 36, 1, 25, "Print"],
Cell[108357, 3367, 36, 1, 25, "Print"],
Cell[108396, 3370, 36, 1, 25, "Print"],
Cell[108435, 3373, 36, 1, 25, "Print"],
Cell[108474, 3376, 36, 1, 25, "Print"],
Cell[108513, 3379, 36, 1, 25, "Print"],
Cell[108552, 3382, 36, 1, 25, "Print"],
Cell[108591, 3385, 36, 1, 25, "Print"],
Cell[108630, 3388, 36, 1, 25, "Print"],
Cell[108669, 3391, 36, 1, 25, "Print"],
Cell[108708, 3394, 36, 1, 25, "Print"],
Cell[108747, 3397, 36, 1, 25, "Print"],
Cell[108786, 3400, 36, 1, 25, "Print"],
Cell[108825, 3403, 36, 1, 25, "Print"],
Cell[108864, 3406, 36, 1, 25, "Print"],
Cell[108903, 3409, 36, 1, 25, "Print"],
Cell[108942, 3412, 36, 1, 25, "Print"],
Cell[108981, 3415, 36, 1, 25, "Print"],
Cell[109020, 3418, 36, 1, 25, "Print"],
Cell[109059, 3421, 36, 1, 25, "Print"],
Cell[109098, 3424, 36, 1, 25, "Print"],
Cell[109137, 3427, 36, 1, 25, "Print"],
Cell[109176, 3430, 36, 1, 25, "Print"],
Cell[109215, 3433, 36, 1, 25, "Print"],
Cell[109254, 3436, 36, 1, 25, "Print"],
Cell[109293, 3439, 36, 1, 25, "Print"],
Cell[109332, 3442, 36, 1, 25, "Print"],
Cell[109371, 3445, 36, 1, 25, "Print"],
Cell[109410, 3448, 36, 1, 25, "Print"],
Cell[109449, 3451, 36, 1, 25, "Print"],
Cell[109488, 3454, 36, 1, 25, "Print"],
Cell[109527, 3457, 36, 1, 25, "Print"],
Cell[109566, 3460, 36, 1, 25, "Print"],
Cell[109605, 3463, 36, 1, 25, "Print"],
Cell[109644, 3466, 36, 1, 25, "Print"],
Cell[109683, 3469, 36, 1, 25, "Print"],
Cell[109722, 3472, 36, 1, 25, "Print"],
Cell[109761, 3475, 36, 1, 25, "Print"],
Cell[109800, 3478, 36, 1, 25, "Print"],
Cell[109839, 3481, 36, 1, 25, "Print"],
Cell[109878, 3484, 36, 1, 25, "Print"],
Cell[109917, 3487, 36, 1, 25, "Print"],
Cell[109956, 3490, 36, 1, 25, "Print"],
Cell[109995, 3493, 36, 1, 25, "Print"],
Cell[110034, 3496, 36, 1, 25, "Print"],
Cell[110073, 3499, 36, 1, 25, "Print"],
Cell[110112, 3502, 36, 1, 25, "Print"],
Cell[110151, 3505, 36, 1, 25, "Print"],
Cell[110190, 3508, 36, 1, 25, "Print"],
Cell[110229, 3511, 36, 1, 25, "Print"],
Cell[110268, 3514, 36, 1, 25, "Print"],
Cell[110307, 3517, 36, 1, 25, "Print"],
Cell[110346, 3520, 36, 1, 25, "Print"],
Cell[110385, 3523, 36, 1, 25, "Print"],
Cell[110424, 3526, 36, 1, 25, "Print"],
Cell[110463, 3529, 36, 1, 25, "Print"],
Cell[110502, 3532, 36, 1, 25, "Print"],
Cell[110541, 3535, 36, 1, 25, "Print"],
Cell[110580, 3538, 36, 1, 25, "Print"],
Cell[110619, 3541, 36, 1, 25, "Print"],
Cell[110658, 3544, 36, 1, 25, "Print"],
Cell[110697, 3547, 36, 1, 25, "Print"],
Cell[110736, 3550, 36, 1, 25, "Print"],
Cell[110775, 3553, 36, 1, 25, "Print"],
Cell[110814, 3556, 36, 1, 25, "Print"],
Cell[110853, 3559, 36, 1, 25, "Print"],
Cell[110892, 3562, 36, 1, 25, "Print"],
Cell[110931, 3565, 36, 1, 25, "Print"],
Cell[110970, 3568, 36, 1, 25, "Print"],
Cell[111009, 3571, 36, 1, 25, "Print"],
Cell[111048, 3574, 36, 1, 25, "Print"],
Cell[111087, 3577, 36, 1, 25, "Print"],
Cell[111126, 3580, 36, 1, 25, "Print"],
Cell[111165, 3583, 36, 1, 25, "Print"],
Cell[111204, 3586, 36, 1, 25, "Print"],
Cell[111243, 3589, 36, 1, 25, "Print"],
Cell[111282, 3592, 36, 1, 25, "Print"],
Cell[111321, 3595, 36, 1, 25, "Print"],
Cell[111360, 3598, 36, 1, 25, "Print"],
Cell[111399, 3601, 36, 1, 25, "Print"],
Cell[111438, 3604, 36, 1, 25, "Print"],
Cell[111477, 3607, 36, 1, 25, "Print"],
Cell[111516, 3610, 36, 1, 25, "Print"],
Cell[111555, 3613, 36, 1, 25, "Print"],
Cell[111594, 3616, 36, 1, 25, "Print"],
Cell[111633, 3619, 36, 1, 25, "Print"],
Cell[111672, 3622, 36, 1, 25, "Print"],
Cell[111711, 3625, 36, 1, 25, "Print"],
Cell[111750, 3628, 36, 1, 25, "Print"],
Cell[111789, 3631, 36, 1, 25, "Print"],
Cell[111828, 3634, 36, 1, 25, "Print"],
Cell[111867, 3637, 36, 1, 25, "Print"],
Cell[111906, 3640, 36, 1, 25, "Print"],
Cell[111945, 3643, 36, 1, 25, "Print"],
Cell[111984, 3646, 36, 1, 25, "Print"],
Cell[112023, 3649, 36, 1, 25, "Print"],
Cell[112062, 3652, 36, 1, 25, "Print"],
Cell[112101, 3655, 36, 1, 25, "Print"],
Cell[112140, 3658, 36, 1, 25, "Print"],
Cell[112179, 3661, 36, 1, 25, "Print"],
Cell[112218, 3664, 36, 1, 25, "Print"],
Cell[112257, 3667, 36, 1, 25, "Print"],
Cell[112296, 3670, 36, 1, 25, "Print"],
Cell[112335, 3673, 36, 1, 25, "Print"],
Cell[112374, 3676, 36, 1, 25, "Print"],
Cell[112413, 3679, 36, 1, 25, "Print"],
Cell[112452, 3682, 36, 1, 25, "Print"],
Cell[112491, 3685, 36, 1, 25, "Print"],
Cell[112530, 3688, 36, 1, 25, "Print"],
Cell[112569, 3691, 36, 1, 25, "Print"],
Cell[112608, 3694, 36, 1, 25, "Print"],
Cell[112647, 3697, 36, 1, 25, "Print"],
Cell[112686, 3700, 36, 1, 25, "Print"],
Cell[112725, 3703, 36, 1, 25, "Print"],
Cell[112764, 3706, 36, 1, 25, "Print"],
Cell[112803, 3709, 36, 1, 25, "Print"],
Cell[112842, 3712, 36, 1, 25, "Print"],
Cell[112881, 3715, 36, 1, 25, "Print"],
Cell[112920, 3718, 36, 1, 25, "Print"],
Cell[112959, 3721, 36, 1, 25, "Print"],
Cell[112998, 3724, 36, 1, 25, "Print"],
Cell[113037, 3727, 36, 1, 25, "Print"],
Cell[113076, 3730, 36, 1, 25, "Print"],
Cell[113115, 3733, 36, 1, 25, "Print"],
Cell[113154, 3736, 36, 1, 25, "Print"],
Cell[113193, 3739, 36, 1, 25, "Print"],
Cell[113232, 3742, 36, 1, 25, "Print"],
Cell[113271, 3745, 36, 1, 25, "Print"],
Cell[113310, 3748, 36, 1, 25, "Print"],
Cell[113349, 3751, 36, 1, 25, "Print"],
Cell[113388, 3754, 36, 1, 25, "Print"],
Cell[113427, 3757, 36, 1, 25, "Print"],
Cell[113466, 3760, 36, 1, 25, "Print"],
Cell[113505, 3763, 36, 1, 25, "Print"],
Cell[113544, 3766, 36, 1, 25, "Print"],
Cell[113583, 3769, 36, 1, 25, "Print"],
Cell[113622, 3772, 36, 1, 25, "Print"],
Cell[113661, 3775, 36, 1, 25, "Print"],
Cell[113700, 3778, 36, 1, 25, "Print"],
Cell[113739, 3781, 36, 1, 25, "Print"],
Cell[113778, 3784, 36, 1, 25, "Print"],
Cell[113817, 3787, 36, 1, 25, "Print"],
Cell[113856, 3790, 36, 1, 25, "Print"],
Cell[113895, 3793, 36, 1, 25, "Print"],
Cell[113934, 3796, 36, 1, 25, "Print"],
Cell[113973, 3799, 36, 1, 25, "Print"],
Cell[114012, 3802, 36, 1, 25, "Print"],
Cell[114051, 3805, 36, 1, 25, "Print"],
Cell[114090, 3808, 36, 1, 25, "Print"],
Cell[114129, 3811, 36, 1, 25, "Print"],
Cell[114168, 3814, 36, 1, 25, "Print"],
Cell[114207, 3817, 36, 1, 25, "Print"],
Cell[114246, 3820, 36, 1, 25, "Print"],
Cell[114285, 3823, 36, 1, 25, "Print"],
Cell[114324, 3826, 36, 1, 25, "Print"],
Cell[114363, 3829, 36, 1, 25, "Print"],
Cell[114402, 3832, 36, 1, 25, "Print"],
Cell[114441, 3835, 36, 1, 25, "Print"],
Cell[114480, 3838, 36, 1, 25, "Print"],
Cell[114519, 3841, 36, 1, 25, "Print"],
Cell[114558, 3844, 36, 1, 25, "Print"],
Cell[114597, 3847, 36, 1, 25, "Print"],
Cell[114636, 3850, 36, 1, 25, "Print"],
Cell[114675, 3853, 36, 1, 25, "Print"],
Cell[114714, 3856, 36, 1, 25, "Print"],
Cell[114753, 3859, 36, 1, 25, "Print"],
Cell[114792, 3862, 36, 1, 25, "Print"],
Cell[114831, 3865, 36, 1, 25, "Print"],
Cell[114870, 3868, 36, 1, 25, "Print"],
Cell[114909, 3871, 36, 1, 25, "Print"],
Cell[114948, 3874, 36, 1, 25, "Print"],
Cell[114987, 3877, 36, 1, 25, "Print"],
Cell[115026, 3880, 36, 1, 25, "Print"],
Cell[115065, 3883, 36, 1, 25, "Print"],
Cell[115104, 3886, 36, 1, 25, "Print"],
Cell[115143, 3889, 36, 1, 25, "Print"],
Cell[115182, 3892, 36, 1, 25, "Print"],
Cell[115221, 3895, 36, 1, 25, "Print"],
Cell[115260, 3898, 36, 1, 25, "Print"],
Cell[115299, 3901, 36, 1, 25, "Print"],
Cell[115338, 3904, 36, 1, 25, "Print"],
Cell[115377, 3907, 36, 1, 25, "Print"],
Cell[115416, 3910, 36, 1, 25, "Print"],
Cell[115455, 3913, 36, 1, 25, "Print"],
Cell[115494, 3916, 36, 1, 25, "Print"],
Cell[115533, 3919, 36, 1, 25, "Print"],
Cell[115572, 3922, 36, 1, 25, "Print"],
Cell[115611, 3925, 36, 1, 25, "Print"],
Cell[115650, 3928, 36, 1, 25, "Print"],
Cell[115689, 3931, 36, 1, 25, "Print"],
Cell[115728, 3934, 36, 1, 25, "Print"],
Cell[115767, 3937, 36, 1, 25, "Print"],
Cell[115806, 3940, 36, 1, 25, "Print"],
Cell[115845, 3943, 36, 1, 25, "Print"],
Cell[115884, 3946, 36, 1, 25, "Print"],
Cell[115923, 3949, 36, 1, 25, "Print"],
Cell[115962, 3952, 36, 1, 25, "Print"],
Cell[116001, 3955, 36, 1, 25, "Print"],
Cell[116040, 3958, 36, 1, 25, "Print"],
Cell[116079, 3961, 36, 1, 25, "Print"],
Cell[116118, 3964, 36, 1, 25, "Print"],
Cell[116157, 3967, 36, 1, 25, "Print"],
Cell[116196, 3970, 36, 1, 25, "Print"],
Cell[116235, 3973, 36, 1, 25, "Print"],
Cell[116274, 3976, 36, 1, 25, "Print"],
Cell[116313, 3979, 36, 1, 25, "Print"],
Cell[116352, 3982, 36, 1, 25, "Print"],
Cell[116391, 3985, 36, 1, 25, "Print"],
Cell[116430, 3988, 36, 1, 25, "Print"],
Cell[116469, 3991, 36, 1, 25, "Print"],
Cell[116508, 3994, 36, 1, 25, "Print"],
Cell[116547, 3997, 36, 1, 25, "Print"],
Cell[116586, 4000, 36, 1, 25, "Print"],
Cell[116625, 4003, 36, 1, 25, "Print"],
Cell[116664, 4006, 36, 1, 25, "Print"],
Cell[116703, 4009, 36, 1, 25, "Print"],
Cell[116742, 4012, 36, 1, 25, "Print"],
Cell[116781, 4015, 36, 1, 25, "Print"],
Cell[116820, 4018, 36, 1, 25, "Print"],
Cell[116859, 4021, 36, 1, 25, "Print"],
Cell[116898, 4024, 36, 1, 25, "Print"],
Cell[116937, 4027, 36, 1, 25, "Print"],
Cell[116976, 4030, 36, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117049, 4036, 330, 5, 120, "Input"],
Cell[117382, 4043, 32347, 505, 467, 1476, 119, "GraphicsData", "PostScript", \
"Graphics"],
Cell[149732, 4550, 132, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[149913, 4559, 239, 5, 88, "Subsubtitle"],
Cell[150155, 4566, 86, 2, 48, "Input"],
Cell[150244, 4570, 131, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[150400, 4577, 282, 5, 102, "Input"],
Cell[150685, 4584, 21602, 372, 322, 1449, 119, "GraphicsData", "PostScript", \
"Graphics"],
Cell[172290, 4958, 132, 3, 29, "Output"]
}, Open  ]],
Cell[172437, 4964, 25, 0, 30, "Input"],
Cell[172465, 4966, 50, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[172540, 4970, 66, 0, 30, "Input"],
Cell[172609, 4972, 81, 1, 29, "Output"]
}, Open  ]],
Cell[172705, 4976, 42, 0, 30, "Input"],
Cell[172750, 4978, 294, 12, 210, "Input"],
Cell[173047, 4992, 172, 5, 84, "Input"],

Cell[CellGroupData[{
Cell[173244, 5001, 433, 7, 138, "Input"],
Cell[173680, 5010, 34, 1, 25, "Print"],
Cell[173717, 5013, 34, 1, 25, "Print"],
Cell[173754, 5016, 34, 1, 25, "Print"],
Cell[173791, 5019, 34, 1, 25, "Print"],
Cell[173828, 5022, 34, 1, 25, "Print"],
Cell[173865, 5025, 34, 1, 25, "Print"],
Cell[173902, 5028, 34, 1, 25, "Print"],
Cell[173939, 5031, 34, 1, 25, "Print"],
Cell[173976, 5034, 34, 1, 25, "Print"],
Cell[174013, 5037, 35, 1, 25, "Print"],
Cell[174051, 5040, 35, 1, 25, "Print"],
Cell[174089, 5043, 35, 1, 25, "Print"],
Cell[174127, 5046, 35, 1, 25, "Print"],
Cell[174165, 5049, 35, 1, 25, "Print"],
Cell[174203, 5052, 35, 1, 25, "Print"],
Cell[174241, 5055, 35, 1, 25, "Print"],
Cell[174279, 5058, 35, 1, 25, "Print"],
Cell[174317, 5061, 35, 1, 25, "Print"],
Cell[174355, 5064, 35, 1, 25, "Print"],
Cell[174393, 5067, 35, 1, 25, "Print"],
Cell[174431, 5070, 35, 1, 25, "Print"],
Cell[174469, 5073, 35, 1, 25, "Print"],
Cell[174507, 5076, 35, 1, 25, "Print"],
Cell[174545, 5079, 35, 1, 25, "Print"],
Cell[174583, 5082, 35, 1, 25, "Print"],
Cell[174621, 5085, 35, 1, 25, "Print"],
Cell[174659, 5088, 35, 1, 25, "Print"],
Cell[174697, 5091, 35, 1, 25, "Print"],
Cell[174735, 5094, 35, 1, 25, "Print"],
Cell[174773, 5097, 35, 1, 25, "Print"],
Cell[174811, 5100, 35, 1, 25, "Print"],
Cell[174849, 5103, 35, 1, 25, "Print"],
Cell[174887, 5106, 35, 1, 25, "Print"],
Cell[174925, 5109, 35, 1, 25, "Print"],
Cell[174963, 5112, 35, 1, 25, "Print"],
Cell[175001, 5115, 35, 1, 25, "Print"],
Cell[175039, 5118, 35, 1, 25, "Print"],
Cell[175077, 5121, 35, 1, 25, "Print"],
Cell[175115, 5124, 35, 1, 25, "Print"],
Cell[175153, 5127, 35, 1, 25, "Print"],
Cell[175191, 5130, 35, 1, 25, "Print"],
Cell[175229, 5133, 35, 1, 25, "Print"],
Cell[175267, 5136, 35, 1, 25, "Print"],
Cell[175305, 5139, 35, 1, 25, "Print"],
Cell[175343, 5142, 35, 1, 25, "Print"],
Cell[175381, 5145, 35, 1, 25, "Print"],
Cell[175419, 5148, 35, 1, 25, "Print"],
Cell[175457, 5151, 35, 1, 25, "Print"],
Cell[175495, 5154, 35, 1, 25, "Print"],
Cell[175533, 5157, 35, 1, 25, "Print"],
Cell[175571, 5160, 35, 1, 25, "Print"],
Cell[175609, 5163, 35, 1, 25, "Print"],
Cell[175647, 5166, 35, 1, 25, "Print"],
Cell[175685, 5169, 35, 1, 25, "Print"],
Cell[175723, 5172, 35, 1, 25, "Print"],
Cell[175761, 5175, 35, 1, 25, "Print"],
Cell[175799, 5178, 35, 1, 25, "Print"],
Cell[175837, 5181, 35, 1, 25, "Print"],
Cell[175875, 5184, 35, 1, 25, "Print"],
Cell[175913, 5187, 35, 1, 25, "Print"],
Cell[175951, 5190, 35, 1, 25, "Print"],
Cell[175989, 5193, 35, 1, 25, "Print"],
Cell[176027, 5196, 35, 1, 25, "Print"],
Cell[176065, 5199, 35, 1, 25, "Print"],
Cell[176103, 5202, 35, 1, 25, "Print"],
Cell[176141, 5205, 35, 1, 25, "Print"],
Cell[176179, 5208, 35, 1, 25, "Print"],
Cell[176217, 5211, 35, 1, 25, "Print"],
Cell[176255, 5214, 35, 1, 25, "Print"],
Cell[176293, 5217, 35, 1, 25, "Print"],
Cell[176331, 5220, 35, 1, 25, "Print"],
Cell[176369, 5223, 35, 1, 25, "Print"],
Cell[176407, 5226, 35, 1, 25, "Print"],
Cell[176445, 5229, 35, 1, 25, "Print"],
Cell[176483, 5232, 35, 1, 25, "Print"],
Cell[176521, 5235, 35, 1, 25, "Print"],
Cell[176559, 5238, 35, 1, 25, "Print"],
Cell[176597, 5241, 35, 1, 25, "Print"],
Cell[176635, 5244, 35, 1, 25, "Print"],
Cell[176673, 5247, 35, 1, 25, "Print"],
Cell[176711, 5250, 35, 1, 25, "Print"],
Cell[176749, 5253, 35, 1, 25, "Print"],
Cell[176787, 5256, 35, 1, 25, "Print"],
Cell[176825, 5259, 35, 1, 25, "Print"],
Cell[176863, 5262, 35, 1, 25, "Print"],
Cell[176901, 5265, 35, 1, 25, "Print"],
Cell[176939, 5268, 35, 1, 25, "Print"],
Cell[176977, 5271, 35, 1, 25, "Print"],
Cell[177015, 5274, 35, 1, 25, "Print"],
Cell[177053, 5277, 35, 1, 25, "Print"],
Cell[177091, 5280, 35, 1, 25, "Print"],
Cell[177129, 5283, 35, 1, 25, "Print"],
Cell[177167, 5286, 35, 1, 25, "Print"],
Cell[177205, 5289, 35, 1, 25, "Print"],
Cell[177243, 5292, 35, 1, 25, "Print"],
Cell[177281, 5295, 35, 1, 25, "Print"],
Cell[177319, 5298, 35, 1, 25, "Print"],
Cell[177357, 5301, 35, 1, 25, "Print"],
Cell[177395, 5304, 35, 1, 25, "Print"],
Cell[177433, 5307, 36, 1, 25, "Print"],
Cell[177472, 5310, 36, 1, 25, "Print"],
Cell[177511, 5313, 36, 1, 25, "Print"],
Cell[177550, 5316, 36, 1, 25, "Print"],
Cell[177589, 5319, 36, 1, 25, "Print"],
Cell[177628, 5322, 36, 1, 25, "Print"],
Cell[177667, 5325, 36, 1, 25, "Print"],
Cell[177706, 5328, 36, 1, 25, "Print"],
Cell[177745, 5331, 36, 1, 25, "Print"],
Cell[177784, 5334, 36, 1, 25, "Print"],
Cell[177823, 5337, 36, 1, 25, "Print"],
Cell[177862, 5340, 36, 1, 25, "Print"],
Cell[177901, 5343, 36, 1, 25, "Print"],
Cell[177940, 5346, 36, 1, 25, "Print"],
Cell[177979, 5349, 36, 1, 25, "Print"],
Cell[178018, 5352, 36, 1, 25, "Print"],
Cell[178057, 5355, 36, 1, 25, "Print"],
Cell[178096, 5358, 36, 1, 25, "Print"],
Cell[178135, 5361, 36, 1, 25, "Print"],
Cell[178174, 5364, 36, 1, 25, "Print"],
Cell[178213, 5367, 36, 1, 25, "Print"],
Cell[178252, 5370, 36, 1, 25, "Print"],
Cell[178291, 5373, 36, 1, 25, "Print"],
Cell[178330, 5376, 36, 1, 25, "Print"],
Cell[178369, 5379, 36, 1, 25, "Print"],
Cell[178408, 5382, 36, 1, 25, "Print"],
Cell[178447, 5385, 36, 1, 25, "Print"],
Cell[178486, 5388, 36, 1, 25, "Print"],
Cell[178525, 5391, 36, 1, 25, "Print"],
Cell[178564, 5394, 36, 1, 25, "Print"],
Cell[178603, 5397, 36, 1, 25, "Print"],
Cell[178642, 5400, 36, 1, 25, "Print"],
Cell[178681, 5403, 36, 1, 25, "Print"],
Cell[178720, 5406, 36, 1, 25, "Print"],
Cell[178759, 5409, 36, 1, 25, "Print"],
Cell[178798, 5412, 36, 1, 25, "Print"],
Cell[178837, 5415, 36, 1, 25, "Print"],
Cell[178876, 5418, 36, 1, 25, "Print"],
Cell[178915, 5421, 36, 1, 25, "Print"],
Cell[178954, 5424, 36, 1, 25, "Print"],
Cell[178993, 5427, 36, 1, 25, "Print"],
Cell[179032, 5430, 36, 1, 25, "Print"],
Cell[179071, 5433, 36, 1, 25, "Print"],
Cell[179110, 5436, 36, 1, 25, "Print"],
Cell[179149, 5439, 36, 1, 25, "Print"],
Cell[179188, 5442, 36, 1, 25, "Print"],
Cell[179227, 5445, 36, 1, 25, "Print"],
Cell[179266, 5448, 36, 1, 25, "Print"],
Cell[179305, 5451, 36, 1, 25, "Print"],
Cell[179344, 5454, 36, 1, 25, "Print"],
Cell[179383, 5457, 36, 1, 25, "Print"],
Cell[179422, 5460, 36, 1, 25, "Print"],
Cell[179461, 5463, 36, 1, 25, "Print"],
Cell[179500, 5466, 36, 1, 25, "Print"],
Cell[179539, 5469, 36, 1, 25, "Print"],
Cell[179578, 5472, 36, 1, 25, "Print"],
Cell[179617, 5475, 36, 1, 25, "Print"],
Cell[179656, 5478, 36, 1, 25, "Print"],
Cell[179695, 5481, 36, 1, 25, "Print"],
Cell[179734, 5484, 36, 1, 25, "Print"],
Cell[179773, 5487, 36, 1, 25, "Print"],
Cell[179812, 5490, 36, 1, 25, "Print"],
Cell[179851, 5493, 36, 1, 25, "Print"],
Cell[179890, 5496, 36, 1, 25, "Print"],
Cell[179929, 5499, 36, 1, 25, "Print"],
Cell[179968, 5502, 36, 1, 25, "Print"],
Cell[180007, 5505, 36, 1, 25, "Print"],
Cell[180046, 5508, 36, 1, 25, "Print"],
Cell[180085, 5511, 36, 1, 25, "Print"],
Cell[180124, 5514, 36, 1, 25, "Print"],
Cell[180163, 5517, 36, 1, 25, "Print"],
Cell[180202, 5520, 36, 1, 25, "Print"],
Cell[180241, 5523, 36, 1, 25, "Print"],
Cell[180280, 5526, 36, 1, 25, "Print"],
Cell[180319, 5529, 36, 1, 25, "Print"],
Cell[180358, 5532, 36, 1, 25, "Print"],
Cell[180397, 5535, 36, 1, 25, "Print"],
Cell[180436, 5538, 36, 1, 25, "Print"],
Cell[180475, 5541, 36, 1, 25, "Print"],
Cell[180514, 5544, 36, 1, 25, "Print"],
Cell[180553, 5547, 36, 1, 25, "Print"],
Cell[180592, 5550, 36, 1, 25, "Print"],
Cell[180631, 5553, 36, 1, 25, "Print"],
Cell[180670, 5556, 36, 1, 25, "Print"],
Cell[180709, 5559, 36, 1, 25, "Print"],
Cell[180748, 5562, 36, 1, 25, "Print"],
Cell[180787, 5565, 36, 1, 25, "Print"],
Cell[180826, 5568, 36, 1, 25, "Print"],
Cell[180865, 5571, 36, 1, 25, "Print"],
Cell[180904, 5574, 36, 1, 25, "Print"],
Cell[180943, 5577, 36, 1, 25, "Print"],
Cell[180982, 5580, 36, 1, 25, "Print"],
Cell[181021, 5583, 36, 1, 25, "Print"],
Cell[181060, 5586, 36, 1, 25, "Print"],
Cell[181099, 5589, 36, 1, 25, "Print"],
Cell[181138, 5592, 36, 1, 25, "Print"],
Cell[181177, 5595, 36, 1, 25, "Print"],
Cell[181216, 5598, 36, 1, 25, "Print"],
Cell[181255, 5601, 36, 1, 25, "Print"],
Cell[181294, 5604, 36, 1, 25, "Print"],
Cell[181333, 5607, 36, 1, 25, "Print"],
Cell[181372, 5610, 36, 1, 25, "Print"],
Cell[181411, 5613, 36, 1, 25, "Print"],
Cell[181450, 5616, 36, 1, 25, "Print"],
Cell[181489, 5619, 36, 1, 25, "Print"],
Cell[181528, 5622, 36, 1, 25, "Print"],
Cell[181567, 5625, 36, 1, 25, "Print"],
Cell[181606, 5628, 36, 1, 25, "Print"],
Cell[181645, 5631, 36, 1, 25, "Print"],
Cell[181684, 5634, 36, 1, 25, "Print"],
Cell[181723, 5637, 36, 1, 25, "Print"],
Cell[181762, 5640, 36, 1, 25, "Print"],
Cell[181801, 5643, 36, 1, 25, "Print"],
Cell[181840, 5646, 36, 1, 25, "Print"],
Cell[181879, 5649, 36, 1, 25, "Print"],
Cell[181918, 5652, 36, 1, 25, "Print"],
Cell[181957, 5655, 36, 1, 25, "Print"],
Cell[181996, 5658, 36, 1, 25, "Print"],
Cell[182035, 5661, 36, 1, 25, "Print"],
Cell[182074, 5664, 36, 1, 25, "Print"],
Cell[182113, 5667, 36, 1, 25, "Print"],
Cell[182152, 5670, 36, 1, 25, "Print"],
Cell[182191, 5673, 36, 1, 25, "Print"],
Cell[182230, 5676, 36, 1, 25, "Print"],
Cell[182269, 5679, 36, 1, 25, "Print"],
Cell[182308, 5682, 36, 1, 25, "Print"],
Cell[182347, 5685, 36, 1, 25, "Print"],
Cell[182386, 5688, 36, 1, 25, "Print"],
Cell[182425, 5691, 36, 1, 25, "Print"],
Cell[182464, 5694, 36, 1, 25, "Print"],
Cell[182503, 5697, 36, 1, 25, "Print"],
Cell[182542, 5700, 36, 1, 25, "Print"],
Cell[182581, 5703, 36, 1, 25, "Print"],
Cell[182620, 5706, 36, 1, 25, "Print"],
Cell[182659, 5709, 36, 1, 25, "Print"],
Cell[182698, 5712, 36, 1, 25, "Print"],
Cell[182737, 5715, 36, 1, 25, "Print"],
Cell[182776, 5718, 36, 1, 25, "Print"],
Cell[182815, 5721, 36, 1, 25, "Print"],
Cell[182854, 5724, 36, 1, 25, "Print"],
Cell[182893, 5727, 36, 1, 25, "Print"],
Cell[182932, 5730, 36, 1, 25, "Print"],
Cell[182971, 5733, 36, 1, 25, "Print"],
Cell[183010, 5736, 36, 1, 25, "Print"],
Cell[183049, 5739, 36, 1, 25, "Print"],
Cell[183088, 5742, 36, 1, 25, "Print"],
Cell[183127, 5745, 36, 1, 25, "Print"],
Cell[183166, 5748, 36, 1, 25, "Print"],
Cell[183205, 5751, 36, 1, 25, "Print"],
Cell[183244, 5754, 36, 1, 25, "Print"],
Cell[183283, 5757, 36, 1, 25, "Print"],
Cell[183322, 5760, 36, 1, 25, "Print"],
Cell[183361, 5763, 36, 1, 25, "Print"],
Cell[183400, 5766, 36, 1, 25, "Print"],
Cell[183439, 5769, 36, 1, 25, "Print"],
Cell[183478, 5772, 36, 1, 25, "Print"],
Cell[183517, 5775, 36, 1, 25, "Print"],
Cell[183556, 5778, 36, 1, 25, "Print"],
Cell[183595, 5781, 36, 1, 25, "Print"],
Cell[183634, 5784, 36, 1, 25, "Print"],
Cell[183673, 5787, 36, 1, 25, "Print"],
Cell[183712, 5790, 36, 1, 25, "Print"],
Cell[183751, 5793, 36, 1, 25, "Print"],
Cell[183790, 5796, 36, 1, 25, "Print"],
Cell[183829, 5799, 36, 1, 25, "Print"],
Cell[183868, 5802, 36, 1, 25, "Print"],
Cell[183907, 5805, 36, 1, 25, "Print"],
Cell[183946, 5808, 36, 1, 25, "Print"],
Cell[183985, 5811, 36, 1, 25, "Print"],
Cell[184024, 5814, 36, 1, 25, "Print"],
Cell[184063, 5817, 36, 1, 25, "Print"],
Cell[184102, 5820, 36, 1, 25, "Print"],
Cell[184141, 5823, 36, 1, 25, "Print"],
Cell[184180, 5826, 36, 1, 25, "Print"],
Cell[184219, 5829, 36, 1, 25, "Print"],
Cell[184258, 5832, 36, 1, 25, "Print"],
Cell[184297, 5835, 36, 1, 25, "Print"],
Cell[184336, 5838, 36, 1, 25, "Print"],
Cell[184375, 5841, 36, 1, 25, "Print"],
Cell[184414, 5844, 36, 1, 25, "Print"],
Cell[184453, 5847, 36, 1, 25, "Print"],
Cell[184492, 5850, 36, 1, 25, "Print"],
Cell[184531, 5853, 36, 1, 25, "Print"],
Cell[184570, 5856, 36, 1, 25, "Print"],
Cell[184609, 5859, 36, 1, 25, "Print"],
Cell[184648, 5862, 36, 1, 25, "Print"],
Cell[184687, 5865, 36, 1, 25, "Print"],
Cell[184726, 5868, 36, 1, 25, "Print"],
Cell[184765, 5871, 36, 1, 25, "Print"],
Cell[184804, 5874, 36, 1, 25, "Print"],
Cell[184843, 5877, 36, 1, 25, "Print"],
Cell[184882, 5880, 36, 1, 25, "Print"],
Cell[184921, 5883, 36, 1, 25, "Print"],
Cell[184960, 5886, 36, 1, 25, "Print"],
Cell[184999, 5889, 36, 1, 25, "Print"],
Cell[185038, 5892, 36, 1, 25, "Print"],
Cell[185077, 5895, 36, 1, 25, "Print"],
Cell[185116, 5898, 36, 1, 25, "Print"],
Cell[185155, 5901, 36, 1, 25, "Print"],
Cell[185194, 5904, 36, 1, 25, "Print"],
Cell[185233, 5907, 36, 1, 25, "Print"],
Cell[185272, 5910, 36, 1, 25, "Print"],
Cell[185311, 5913, 36, 1, 25, "Print"],
Cell[185350, 5916, 36, 1, 25, "Print"],
Cell[185389, 5919, 36, 1, 25, "Print"],
Cell[185428, 5922, 36, 1, 25, "Print"],
Cell[185467, 5925, 36, 1, 25, "Print"],
Cell[185506, 5928, 36, 1, 25, "Print"],
Cell[185545, 5931, 36, 1, 25, "Print"],
Cell[185584, 5934, 36, 1, 25, "Print"],
Cell[185623, 5937, 36, 1, 25, "Print"],
Cell[185662, 5940, 36, 1, 25, "Print"],
Cell[185701, 5943, 36, 1, 25, "Print"],
Cell[185740, 5946, 36, 1, 25, "Print"],
Cell[185779, 5949, 36, 1, 25, "Print"],
Cell[185818, 5952, 36, 1, 25, "Print"],
Cell[185857, 5955, 36, 1, 25, "Print"],
Cell[185896, 5958, 36, 1, 25, "Print"],
Cell[185935, 5961, 36, 1, 25, "Print"],
Cell[185974, 5964, 36, 1, 25, "Print"],
Cell[186013, 5967, 36, 1, 25, "Print"],
Cell[186052, 5970, 36, 1, 25, "Print"],
Cell[186091, 5973, 36, 1, 25, "Print"],
Cell[186130, 5976, 36, 1, 25, "Print"],
Cell[186169, 5979, 36, 1, 25, "Print"],
Cell[186208, 5982, 36, 1, 25, "Print"],
Cell[186247, 5985, 36, 1, 25, "Print"],
Cell[186286, 5988, 36, 1, 25, "Print"],
Cell[186325, 5991, 36, 1, 25, "Print"],
Cell[186364, 5994, 36, 1, 25, "Print"],
Cell[186403, 5997, 36, 1, 25, "Print"],
Cell[186442, 6000, 36, 1, 25, "Print"],
Cell[186481, 6003, 36, 1, 25, "Print"],
Cell[186520, 6006, 36, 1, 25, "Print"],
Cell[186559, 6009, 36, 1, 25, "Print"],
Cell[186598, 6012, 36, 1, 25, "Print"],
Cell[186637, 6015, 36, 1, 25, "Print"],
Cell[186676, 6018, 36, 1, 25, "Print"],
Cell[186715, 6021, 36, 1, 25, "Print"],
Cell[186754, 6024, 36, 1, 25, "Print"],
Cell[186793, 6027, 36, 1, 25, "Print"],
Cell[186832, 6030, 36, 1, 25, "Print"],
Cell[186871, 6033, 36, 1, 25, "Print"],
Cell[186910, 6036, 36, 1, 25, "Print"],
Cell[186949, 6039, 36, 1, 25, "Print"],
Cell[186988, 6042, 36, 1, 25, "Print"],
Cell[187027, 6045, 36, 1, 25, "Print"],
Cell[187066, 6048, 36, 1, 25, "Print"],
Cell[187105, 6051, 36, 1, 25, "Print"],
Cell[187144, 6054, 36, 1, 25, "Print"],
Cell[187183, 6057, 36, 1, 25, "Print"],
Cell[187222, 6060, 36, 1, 25, "Print"],
Cell[187261, 6063, 36, 1, 25, "Print"],
Cell[187300, 6066, 36, 1, 25, "Print"],
Cell[187339, 6069, 36, 1, 25, "Print"],
Cell[187378, 6072, 36, 1, 25, "Print"],
Cell[187417, 6075, 36, 1, 25, "Print"],
Cell[187456, 6078, 36, 1, 25, "Print"],
Cell[187495, 6081, 36, 1, 25, "Print"],
Cell[187534, 6084, 36, 1, 25, "Print"],
Cell[187573, 6087, 36, 1, 25, "Print"],
Cell[187612, 6090, 36, 1, 25, "Print"],
Cell[187651, 6093, 36, 1, 25, "Print"],
Cell[187690, 6096, 36, 1, 25, "Print"],
Cell[187729, 6099, 36, 1, 25, "Print"],
Cell[187768, 6102, 36, 1, 25, "Print"],
Cell[187807, 6105, 36, 1, 25, "Print"],
Cell[187846, 6108, 36, 1, 25, "Print"],
Cell[187885, 6111, 36, 1, 25, "Print"],
Cell[187924, 6114, 36, 1, 25, "Print"],
Cell[187963, 6117, 36, 1, 25, "Print"],
Cell[188002, 6120, 36, 1, 25, "Print"],
Cell[188041, 6123, 36, 1, 25, "Print"],
Cell[188080, 6126, 36, 1, 25, "Print"],
Cell[188119, 6129, 36, 1, 25, "Print"],
Cell[188158, 6132, 36, 1, 25, "Print"],
Cell[188197, 6135, 36, 1, 25, "Print"],
Cell[188236, 6138, 36, 1, 25, "Print"],
Cell[188275, 6141, 36, 1, 25, "Print"],
Cell[188314, 6144, 36, 1, 25, "Print"],
Cell[188353, 6147, 36, 1, 25, "Print"],
Cell[188392, 6150, 36, 1, 25, "Print"],
Cell[188431, 6153, 36, 1, 25, "Print"],
Cell[188470, 6156, 36, 1, 25, "Print"],
Cell[188509, 6159, 36, 1, 25, "Print"],
Cell[188548, 6162, 36, 1, 25, "Print"],
Cell[188587, 6165, 36, 1, 25, "Print"],
Cell[188626, 6168, 36, 1, 25, "Print"],
Cell[188665, 6171, 36, 1, 25, "Print"],
Cell[188704, 6174, 36, 1, 25, "Print"],
Cell[188743, 6177, 36, 1, 25, "Print"],
Cell[188782, 6180, 36, 1, 25, "Print"],
Cell[188821, 6183, 36, 1, 25, "Print"],
Cell[188860, 6186, 36, 1, 25, "Print"],
Cell[188899, 6189, 36, 1, 25, "Print"],
Cell[188938, 6192, 36, 1, 25, "Print"],
Cell[188977, 6195, 36, 1, 25, "Print"],
Cell[189016, 6198, 36, 1, 25, "Print"],
Cell[189055, 6201, 36, 1, 25, "Print"],
Cell[189094, 6204, 36, 1, 25, "Print"],
Cell[189133, 6207, 36, 1, 25, "Print"],
Cell[189172, 6210, 36, 1, 25, "Print"],
Cell[189211, 6213, 36, 1, 25, "Print"],
Cell[189250, 6216, 36, 1, 25, "Print"],
Cell[189289, 6219, 36, 1, 25, "Print"],
Cell[189328, 6222, 36, 1, 25, "Print"],
Cell[189367, 6225, 36, 1, 25, "Print"],
Cell[189406, 6228, 36, 1, 25, "Print"],
Cell[189445, 6231, 36, 1, 25, "Print"],
Cell[189484, 6234, 36, 1, 25, "Print"],
Cell[189523, 6237, 36, 1, 25, "Print"],
Cell[189562, 6240, 36, 1, 25, "Print"],
Cell[189601, 6243, 36, 1, 25, "Print"],
Cell[189640, 6246, 36, 1, 25, "Print"],
Cell[189679, 6249, 36, 1, 25, "Print"],
Cell[189718, 6252, 36, 1, 25, "Print"],
Cell[189757, 6255, 36, 1, 25, "Print"],
Cell[189796, 6258, 36, 1, 25, "Print"],
Cell[189835, 6261, 36, 1, 25, "Print"],
Cell[189874, 6264, 36, 1, 25, "Print"],
Cell[189913, 6267, 36, 1, 25, "Print"],
Cell[189952, 6270, 36, 1, 25, "Print"],
Cell[189991, 6273, 36, 1, 25, "Print"],
Cell[190030, 6276, 36, 1, 25, "Print"],
Cell[190069, 6279, 36, 1, 25, "Print"],
Cell[190108, 6282, 36, 1, 25, "Print"],
Cell[190147, 6285, 36, 1, 25, "Print"],
Cell[190186, 6288, 36, 1, 25, "Print"],
Cell[190225, 6291, 36, 1, 25, "Print"],
Cell[190264, 6294, 36, 1, 25, "Print"],
Cell[190303, 6297, 36, 1, 25, "Print"],
Cell[190342, 6300, 36, 1, 25, "Print"],
Cell[190381, 6303, 36, 1, 25, "Print"],
Cell[190420, 6306, 36, 1, 25, "Print"],
Cell[190459, 6309, 36, 1, 25, "Print"],
Cell[190498, 6312, 36, 1, 25, "Print"],
Cell[190537, 6315, 36, 1, 25, "Print"],
Cell[190576, 6318, 36, 1, 25, "Print"],
Cell[190615, 6321, 36, 1, 25, "Print"],
Cell[190654, 6324, 36, 1, 25, "Print"],
Cell[190693, 6327, 36, 1, 25, "Print"],
Cell[190732, 6330, 36, 1, 25, "Print"],
Cell[190771, 6333, 36, 1, 25, "Print"],
Cell[190810, 6336, 36, 1, 25, "Print"],
Cell[190849, 6339, 36, 1, 25, "Print"],
Cell[190888, 6342, 36, 1, 25, "Print"],
Cell[190927, 6345, 36, 1, 25, "Print"],
Cell[190966, 6348, 36, 1, 25, "Print"],
Cell[191005, 6351, 36, 1, 25, "Print"],
Cell[191044, 6354, 36, 1, 25, "Print"],
Cell[191083, 6357, 36, 1, 25, "Print"],
Cell[191122, 6360, 36, 1, 25, "Print"],
Cell[191161, 6363, 36, 1, 25, "Print"],
Cell[191200, 6366, 36, 1, 25, "Print"],
Cell[191239, 6369, 36, 1, 25, "Print"],
Cell[191278, 6372, 36, 1, 25, "Print"],
Cell[191317, 6375, 36, 1, 25, "Print"],
Cell[191356, 6378, 36, 1, 25, "Print"],
Cell[191395, 6381, 36, 1, 25, "Print"],
Cell[191434, 6384, 36, 1, 25, "Print"],
Cell[191473, 6387, 36, 1, 25, "Print"],
Cell[191512, 6390, 36, 1, 25, "Print"],
Cell[191551, 6393, 36, 1, 25, "Print"],
Cell[191590, 6396, 36, 1, 25, "Print"],
Cell[191629, 6399, 36, 1, 25, "Print"],
Cell[191668, 6402, 36, 1, 25, "Print"],
Cell[191707, 6405, 36, 1, 25, "Print"],
Cell[191746, 6408, 36, 1, 25, "Print"],
Cell[191785, 6411, 36, 1, 25, "Print"],
Cell[191824, 6414, 36, 1, 25, "Print"],
Cell[191863, 6417, 36, 1, 25, "Print"],
Cell[191902, 6420, 36, 1, 25, "Print"],
Cell[191941, 6423, 36, 1, 25, "Print"],
Cell[191980, 6426, 36, 1, 25, "Print"],
Cell[192019, 6429, 36, 1, 25, "Print"],
Cell[192058, 6432, 36, 1, 25, "Print"],
Cell[192097, 6435, 36, 1, 25, "Print"],
Cell[192136, 6438, 36, 1, 25, "Print"],
Cell[192175, 6441, 36, 1, 25, "Print"],
Cell[192214, 6444, 36, 1, 25, "Print"],
Cell[192253, 6447, 36, 1, 25, "Print"],
Cell[192292, 6450, 36, 1, 25, "Print"],
Cell[192331, 6453, 36, 1, 25, "Print"],
Cell[192370, 6456, 36, 1, 25, "Print"],
Cell[192409, 6459, 36, 1, 25, "Print"],
Cell[192448, 6462, 36, 1, 25, "Print"],
Cell[192487, 6465, 36, 1, 25, "Print"],
Cell[192526, 6468, 36, 1, 25, "Print"],
Cell[192565, 6471, 36, 1, 25, "Print"],
Cell[192604, 6474, 36, 1, 25, "Print"],
Cell[192643, 6477, 36, 1, 25, "Print"],
Cell[192682, 6480, 36, 1, 25, "Print"],
Cell[192721, 6483, 36, 1, 25, "Print"],
Cell[192760, 6486, 36, 1, 25, "Print"],
Cell[192799, 6489, 36, 1, 25, "Print"],
Cell[192838, 6492, 36, 1, 25, "Print"],
Cell[192877, 6495, 36, 1, 25, "Print"],
Cell[192916, 6498, 36, 1, 25, "Print"],
Cell[192955, 6501, 36, 1, 25, "Print"],
Cell[192994, 6504, 36, 1, 25, "Print"],
Cell[193033, 6507, 36, 1, 25, "Print"],
Cell[193072, 6510, 36, 1, 25, "Print"],
Cell[193111, 6513, 36, 1, 25, "Print"],
Cell[193150, 6516, 36, 1, 25, "Print"],
Cell[193189, 6519, 36, 1, 25, "Print"],
Cell[193228, 6522, 36, 1, 25, "Print"],
Cell[193267, 6525, 36, 1, 25, "Print"],
Cell[193306, 6528, 36, 1, 25, "Print"],
Cell[193345, 6531, 36, 1, 25, "Print"],
Cell[193384, 6534, 36, 1, 25, "Print"],
Cell[193423, 6537, 36, 1, 25, "Print"],
Cell[193462, 6540, 36, 1, 25, "Print"],
Cell[193501, 6543, 36, 1, 25, "Print"],
Cell[193540, 6546, 36, 1, 25, "Print"],
Cell[193579, 6549, 36, 1, 25, "Print"],
Cell[193618, 6552, 36, 1, 25, "Print"],
Cell[193657, 6555, 36, 1, 25, "Print"],
Cell[193696, 6558, 36, 1, 25, "Print"],
Cell[193735, 6561, 36, 1, 25, "Print"],
Cell[193774, 6564, 36, 1, 25, "Print"],
Cell[193813, 6567, 36, 1, 25, "Print"],
Cell[193852, 6570, 36, 1, 25, "Print"],
Cell[193891, 6573, 36, 1, 25, "Print"],
Cell[193930, 6576, 36, 1, 25, "Print"],
Cell[193969, 6579, 36, 1, 25, "Print"],
Cell[194008, 6582, 36, 1, 25, "Print"],
Cell[194047, 6585, 36, 1, 25, "Print"],
Cell[194086, 6588, 36, 1, 25, "Print"],
Cell[194125, 6591, 36, 1, 25, "Print"],
Cell[194164, 6594, 36, 1, 25, "Print"],
Cell[194203, 6597, 36, 1, 25, "Print"],
Cell[194242, 6600, 36, 1, 25, "Print"],
Cell[194281, 6603, 36, 1, 25, "Print"],
Cell[194320, 6606, 36, 1, 25, "Print"],
Cell[194359, 6609, 36, 1, 25, "Print"],
Cell[194398, 6612, 36, 1, 25, "Print"],
Cell[194437, 6615, 36, 1, 25, "Print"],
Cell[194476, 6618, 36, 1, 25, "Print"],
Cell[194515, 6621, 36, 1, 25, "Print"],
Cell[194554, 6624, 36, 1, 25, "Print"],
Cell[194593, 6627, 36, 1, 25, "Print"],
Cell[194632, 6630, 36, 1, 25, "Print"],
Cell[194671, 6633, 36, 1, 25, "Print"],
Cell[194710, 6636, 36, 1, 25, "Print"],
Cell[194749, 6639, 36, 1, 25, "Print"],
Cell[194788, 6642, 36, 1, 25, "Print"],
Cell[194827, 6645, 36, 1, 25, "Print"],
Cell[194866, 6648, 36, 1, 25, "Print"],
Cell[194905, 6651, 36, 1, 25, "Print"],
Cell[194944, 6654, 36, 1, 25, "Print"],
Cell[194983, 6657, 36, 1, 25, "Print"],
Cell[195022, 6660, 36, 1, 25, "Print"],
Cell[195061, 6663, 36, 1, 25, "Print"],
Cell[195100, 6666, 36, 1, 25, "Print"],
Cell[195139, 6669, 36, 1, 25, "Print"],
Cell[195178, 6672, 36, 1, 25, "Print"],
Cell[195217, 6675, 36, 1, 25, "Print"],
Cell[195256, 6678, 36, 1, 25, "Print"],
Cell[195295, 6681, 36, 1, 25, "Print"],
Cell[195334, 6684, 36, 1, 25, "Print"],
Cell[195373, 6687, 36, 1, 25, "Print"],
Cell[195412, 6690, 36, 1, 25, "Print"],
Cell[195451, 6693, 36, 1, 25, "Print"],
Cell[195490, 6696, 36, 1, 25, "Print"],
Cell[195529, 6699, 36, 1, 25, "Print"],
Cell[195568, 6702, 36, 1, 25, "Print"],
Cell[195607, 6705, 36, 1, 25, "Print"],
Cell[195646, 6708, 36, 1, 25, "Print"],
Cell[195685, 6711, 36, 1, 25, "Print"],
Cell[195724, 6714, 36, 1, 25, "Print"],
Cell[195763, 6717, 36, 1, 25, "Print"],
Cell[195802, 6720, 36, 1, 25, "Print"],
Cell[195841, 6723, 36, 1, 25, "Print"],
Cell[195880, 6726, 36, 1, 25, "Print"],
Cell[195919, 6729, 36, 1, 25, "Print"],
Cell[195958, 6732, 36, 1, 25, "Print"],
Cell[195997, 6735, 36, 1, 25, "Print"],
Cell[196036, 6738, 36, 1, 25, "Print"],
Cell[196075, 6741, 36, 1, 25, "Print"],
Cell[196114, 6744, 36, 1, 25, "Print"],
Cell[196153, 6747, 36, 1, 25, "Print"],
Cell[196192, 6750, 36, 1, 25, "Print"],
Cell[196231, 6753, 36, 1, 25, "Print"],
Cell[196270, 6756, 36, 1, 25, "Print"],
Cell[196309, 6759, 36, 1, 25, "Print"],
Cell[196348, 6762, 36, 1, 25, "Print"],
Cell[196387, 6765, 36, 1, 25, "Print"],
Cell[196426, 6768, 36, 1, 25, "Print"],
Cell[196465, 6771, 36, 1, 25, "Print"],
Cell[196504, 6774, 36, 1, 25, "Print"],
Cell[196543, 6777, 36, 1, 25, "Print"],
Cell[196582, 6780, 36, 1, 25, "Print"],
Cell[196621, 6783, 36, 1, 25, "Print"],
Cell[196660, 6786, 36, 1, 25, "Print"],
Cell[196699, 6789, 36, 1, 25, "Print"],
Cell[196738, 6792, 36, 1, 25, "Print"],
Cell[196777, 6795, 36, 1, 25, "Print"],
Cell[196816, 6798, 36, 1, 25, "Print"],
Cell[196855, 6801, 36, 1, 25, "Print"],
Cell[196894, 6804, 36, 1, 25, "Print"],
Cell[196933, 6807, 36, 1, 25, "Print"],
Cell[196972, 6810, 36, 1, 25, "Print"],
Cell[197011, 6813, 36, 1, 25, "Print"],
Cell[197050, 6816, 36, 1, 25, "Print"],
Cell[197089, 6819, 36, 1, 25, "Print"],
Cell[197128, 6822, 36, 1, 25, "Print"],
Cell[197167, 6825, 36, 1, 25, "Print"],
Cell[197206, 6828, 36, 1, 25, "Print"],
Cell[197245, 6831, 36, 1, 25, "Print"],
Cell[197284, 6834, 36, 1, 25, "Print"],
Cell[197323, 6837, 36, 1, 25, "Print"],
Cell[197362, 6840, 36, 1, 25, "Print"],
Cell[197401, 6843, 36, 1, 25, "Print"],
Cell[197440, 6846, 36, 1, 25, "Print"],
Cell[197479, 6849, 36, 1, 25, "Print"],
Cell[197518, 6852, 36, 1, 25, "Print"],
Cell[197557, 6855, 36, 1, 25, "Print"],
Cell[197596, 6858, 36, 1, 25, "Print"],
Cell[197635, 6861, 36, 1, 25, "Print"],
Cell[197674, 6864, 36, 1, 25, "Print"],
Cell[197713, 6867, 36, 1, 25, "Print"],
Cell[197752, 6870, 36, 1, 25, "Print"],
Cell[197791, 6873, 36, 1, 25, "Print"],
Cell[197830, 6876, 36, 1, 25, "Print"],
Cell[197869, 6879, 36, 1, 25, "Print"],
Cell[197908, 6882, 36, 1, 25, "Print"],
Cell[197947, 6885, 36, 1, 25, "Print"],
Cell[197986, 6888, 36, 1, 25, "Print"],
Cell[198025, 6891, 36, 1, 25, "Print"],
Cell[198064, 6894, 36, 1, 25, "Print"],
Cell[198103, 6897, 36, 1, 25, "Print"],
Cell[198142, 6900, 36, 1, 25, "Print"],
Cell[198181, 6903, 36, 1, 25, "Print"],
Cell[198220, 6906, 36, 1, 25, "Print"],
Cell[198259, 6909, 36, 1, 25, "Print"],
Cell[198298, 6912, 36, 1, 25, "Print"],
Cell[198337, 6915, 36, 1, 25, "Print"],
Cell[198376, 6918, 36, 1, 25, "Print"],
Cell[198415, 6921, 36, 1, 25, "Print"],
Cell[198454, 6924, 36, 1, 25, "Print"],
Cell[198493, 6927, 36, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198566, 6933, 290, 8, 84, "Input"],
Cell[198859, 6943, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[199028, 6951, 314, 9, 84, "Input"],
Cell[199345, 6962, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[199514, 6970, 314, 9, 84, "Input"],
Cell[199831, 6981, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200000, 6989, 292, 8, 84, "Input"],
Cell[200295, 6999, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200464, 7007, 81, 2, 30, "Input"],
Cell[200548, 7011, 152261, 10298, 296, 121364, 9912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[352812, 17311, 132, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[352993, 17320, 184, 4, 68, "Subsubtitle"],
Cell[353180, 17326, 116, 3, 48, "Input"],
Cell[353299, 17331, 292, 7, 120, "Input"],

Cell[CellGroupData[{
Cell[353616, 17342, 421, 7, 138, "Input"],
Cell[354040, 17351, 20437, 360, 296, 1497, 122, "GraphicsData", "PostScript", \
"Graphics"],
Cell[374480, 17713, 132, 3, 29, "Output"]
}, Open  ]],
Cell[374627, 17719, 25, 0, 30, "Input"],
Cell[374655, 17721, 50, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[374730, 17725, 66, 0, 30, "Input"],
Cell[374799, 17727, 81, 1, 29, "Output"]
}, Open  ]],
Cell[374895, 17731, 42, 0, 30, "Input"],
Cell[374940, 17733, 294, 12, 210, "Input"],
Cell[375237, 17747, 246, 7, 120, "Input"],

Cell[CellGroupData[{
Cell[375508, 17758, 605, 9, 192, "Input"],
Cell[376116, 17769, 34, 1, 25, "Print"],
Cell[376153, 17772, 34, 1, 25, "Print"],
Cell[376190, 17775, 34, 1, 25, "Print"],
Cell[376227, 17778, 34, 1, 25, "Print"],
Cell[376264, 17781, 34, 1, 25, "Print"],
Cell[376301, 17784, 34, 1, 25, "Print"],
Cell[376338, 17787, 34, 1, 25, "Print"],
Cell[376375, 17790, 34, 1, 25, "Print"],
Cell[376412, 17793, 34, 1, 25, "Print"],
Cell[376449, 17796, 35, 1, 25, "Print"],
Cell[376487, 17799, 35, 1, 25, "Print"],
Cell[376525, 17802, 35, 1, 25, "Print"],
Cell[376563, 17805, 35, 1, 25, "Print"],
Cell[376601, 17808, 35, 1, 25, "Print"],
Cell[376639, 17811, 35, 1, 25, "Print"],
Cell[376677, 17814, 35, 1, 25, "Print"],
Cell[376715, 17817, 35, 1, 25, "Print"],
Cell[376753, 17820, 35, 1, 25, "Print"],
Cell[376791, 17823, 35, 1, 25, "Print"],
Cell[376829, 17826, 35, 1, 25, "Print"],
Cell[376867, 17829, 35, 1, 25, "Print"],
Cell[376905, 17832, 35, 1, 25, "Print"],
Cell[376943, 17835, 35, 1, 25, "Print"],
Cell[376981, 17838, 35, 1, 25, "Print"],
Cell[377019, 17841, 35, 1, 25, "Print"],
Cell[377057, 17844, 35, 1, 25, "Print"],
Cell[377095, 17847, 35, 1, 25, "Print"],
Cell[377133, 17850, 35, 1, 25, "Print"],
Cell[377171, 17853, 35, 1, 25, "Print"],
Cell[377209, 17856, 35, 1, 25, "Print"],
Cell[377247, 17859, 35, 1, 25, "Print"],
Cell[377285, 17862, 35, 1, 25, "Print"],
Cell[377323, 17865, 35, 1, 25, "Print"],
Cell[377361, 17868, 35, 1, 25, "Print"],
Cell[377399, 17871, 35, 1, 25, "Print"],
Cell[377437, 17874, 35, 1, 25, "Print"],
Cell[377475, 17877, 35, 1, 25, "Print"],
Cell[377513, 17880, 35, 1, 25, "Print"],
Cell[377551, 17883, 35, 1, 25, "Print"],
Cell[377589, 17886, 35, 1, 25, "Print"],
Cell[377627, 17889, 35, 1, 25, "Print"],
Cell[377665, 17892, 35, 1, 25, "Print"],
Cell[377703, 17895, 35, 1, 25, "Print"],
Cell[377741, 17898, 35, 1, 25, "Print"],
Cell[377779, 17901, 35, 1, 25, "Print"],
Cell[377817, 17904, 35, 1, 25, "Print"],
Cell[377855, 17907, 35, 1, 25, "Print"],
Cell[377893, 17910, 35, 1, 25, "Print"],
Cell[377931, 17913, 35, 1, 25, "Print"],
Cell[377969, 17916, 35, 1, 25, "Print"],
Cell[378007, 17919, 35, 1, 25, "Print"],
Cell[378045, 17922, 35, 1, 25, "Print"],
Cell[378083, 17925, 35, 1, 25, "Print"],
Cell[378121, 17928, 35, 1, 25, "Print"],
Cell[378159, 17931, 35, 1, 25, "Print"],
Cell[378197, 17934, 35, 1, 25, "Print"],
Cell[378235, 17937, 35, 1, 25, "Print"],
Cell[378273, 17940, 35, 1, 25, "Print"],
Cell[378311, 17943, 35, 1, 25, "Print"],
Cell[378349, 17946, 35, 1, 25, "Print"],
Cell[378387, 17949, 35, 1, 25, "Print"],
Cell[378425, 17952, 35, 1, 25, "Print"],
Cell[378463, 17955, 35, 1, 25, "Print"],
Cell[378501, 17958, 35, 1, 25, "Print"],
Cell[378539, 17961, 35, 1, 25, "Print"],
Cell[378577, 17964, 35, 1, 25, "Print"],
Cell[378615, 17967, 35, 1, 25, "Print"],
Cell[378653, 17970, 35, 1, 25, "Print"],
Cell[378691, 17973, 35, 1, 25, "Print"],
Cell[378729, 17976, 35, 1, 25, "Print"],
Cell[378767, 17979, 35, 1, 25, "Print"],
Cell[378805, 17982, 35, 1, 25, "Print"],
Cell[378843, 17985, 35, 1, 25, "Print"],
Cell[378881, 17988, 35, 1, 25, "Print"],
Cell[378919, 17991, 35, 1, 25, "Print"],
Cell[378957, 17994, 35, 1, 25, "Print"],
Cell[378995, 17997, 35, 1, 25, "Print"],
Cell[379033, 18000, 35, 1, 25, "Print"],
Cell[379071, 18003, 35, 1, 25, "Print"],
Cell[379109, 18006, 35, 1, 25, "Print"],
Cell[379147, 18009, 35, 1, 25, "Print"],
Cell[379185, 18012, 35, 1, 25, "Print"],
Cell[379223, 18015, 35, 1, 25, "Print"],
Cell[379261, 18018, 35, 1, 25, "Print"],
Cell[379299, 18021, 35, 1, 25, "Print"],
Cell[379337, 18024, 35, 1, 25, "Print"],
Cell[379375, 18027, 35, 1, 25, "Print"],
Cell[379413, 18030, 35, 1, 25, "Print"],
Cell[379451, 18033, 35, 1, 25, "Print"],
Cell[379489, 18036, 35, 1, 25, "Print"],
Cell[379527, 18039, 35, 1, 25, "Print"],
Cell[379565, 18042, 35, 1, 25, "Print"],
Cell[379603, 18045, 35, 1, 25, "Print"],
Cell[379641, 18048, 35, 1, 25, "Print"],
Cell[379679, 18051, 35, 1, 25, "Print"],
Cell[379717, 18054, 35, 1, 25, "Print"],
Cell[379755, 18057, 35, 1, 25, "Print"],
Cell[379793, 18060, 35, 1, 25, "Print"],
Cell[379831, 18063, 35, 1, 25, "Print"],
Cell[379869, 18066, 36, 1, 25, "Print"],
Cell[379908, 18069, 36, 1, 25, "Print"],
Cell[379947, 18072, 36, 1, 25, "Print"],
Cell[379986, 18075, 36, 1, 25, "Print"],
Cell[380025, 18078, 36, 1, 25, "Print"],
Cell[380064, 18081, 36, 1, 25, "Print"],
Cell[380103, 18084, 36, 1, 25, "Print"],
Cell[380142, 18087, 36, 1, 25, "Print"],
Cell[380181, 18090, 36, 1, 25, "Print"],
Cell[380220, 18093, 36, 1, 25, "Print"],
Cell[380259, 18096, 36, 1, 25, "Print"],
Cell[380298, 18099, 36, 1, 25, "Print"],
Cell[380337, 18102, 36, 1, 25, "Print"],
Cell[380376, 18105, 36, 1, 25, "Print"],
Cell[380415, 18108, 36, 1, 25, "Print"],
Cell[380454, 18111, 36, 1, 25, "Print"],
Cell[380493, 18114, 36, 1, 25, "Print"],
Cell[380532, 18117, 36, 1, 25, "Print"],
Cell[380571, 18120, 36, 1, 25, "Print"],
Cell[380610, 18123, 36, 1, 25, "Print"],
Cell[380649, 18126, 36, 1, 25, "Print"],
Cell[380688, 18129, 36, 1, 25, "Print"],
Cell[380727, 18132, 36, 1, 25, "Print"],
Cell[380766, 18135, 36, 1, 25, "Print"],
Cell[380805, 18138, 36, 1, 25, "Print"],
Cell[380844, 18141, 36, 1, 25, "Print"],
Cell[380883, 18144, 36, 1, 25, "Print"],
Cell[380922, 18147, 36, 1, 25, "Print"],
Cell[380961, 18150, 36, 1, 25, "Print"],
Cell[381000, 18153, 36, 1, 25, "Print"],
Cell[381039, 18156, 36, 1, 25, "Print"],
Cell[381078, 18159, 36, 1, 25, "Print"],
Cell[381117, 18162, 36, 1, 25, "Print"],
Cell[381156, 18165, 36, 1, 25, "Print"],
Cell[381195, 18168, 36, 1, 25, "Print"],
Cell[381234, 18171, 36, 1, 25, "Print"],
Cell[381273, 18174, 36, 1, 25, "Print"],
Cell[381312, 18177, 36, 1, 25, "Print"],
Cell[381351, 18180, 36, 1, 25, "Print"],
Cell[381390, 18183, 36, 1, 25, "Print"],
Cell[381429, 18186, 36, 1, 25, "Print"],
Cell[381468, 18189, 36, 1, 25, "Print"],
Cell[381507, 18192, 36, 1, 25, "Print"],
Cell[381546, 18195, 36, 1, 25, "Print"],
Cell[381585, 18198, 36, 1, 25, "Print"],
Cell[381624, 18201, 36, 1, 25, "Print"],
Cell[381663, 18204, 36, 1, 25, "Print"],
Cell[381702, 18207, 36, 1, 25, "Print"],
Cell[381741, 18210, 36, 1, 25, "Print"],
Cell[381780, 18213, 36, 1, 25, "Print"],
Cell[381819, 18216, 36, 1, 25, "Print"],
Cell[381858, 18219, 36, 1, 25, "Print"],
Cell[381897, 18222, 36, 1, 25, "Print"],
Cell[381936, 18225, 36, 1, 25, "Print"],
Cell[381975, 18228, 36, 1, 25, "Print"],
Cell[382014, 18231, 36, 1, 25, "Print"],
Cell[382053, 18234, 36, 1, 25, "Print"],
Cell[382092, 18237, 36, 1, 25, "Print"],
Cell[382131, 18240, 36, 1, 25, "Print"],
Cell[382170, 18243, 36, 1, 25, "Print"],
Cell[382209, 18246, 36, 1, 25, "Print"],
Cell[382248, 18249, 36, 1, 25, "Print"],
Cell[382287, 18252, 36, 1, 25, "Print"],
Cell[382326, 18255, 36, 1, 25, "Print"],
Cell[382365, 18258, 36, 1, 25, "Print"],
Cell[382404, 18261, 36, 1, 25, "Print"],
Cell[382443, 18264, 36, 1, 25, "Print"],
Cell[382482, 18267, 36, 1, 25, "Print"],
Cell[382521, 18270, 36, 1, 25, "Print"],
Cell[382560, 18273, 36, 1, 25, "Print"],
Cell[382599, 18276, 36, 1, 25, "Print"],
Cell[382638, 18279, 36, 1, 25, "Print"],
Cell[382677, 18282, 36, 1, 25, "Print"],
Cell[382716, 18285, 36, 1, 25, "Print"],
Cell[382755, 18288, 36, 1, 25, "Print"],
Cell[382794, 18291, 36, 1, 25, "Print"],
Cell[382833, 18294, 36, 1, 25, "Print"],
Cell[382872, 18297, 36, 1, 25, "Print"],
Cell[382911, 18300, 36, 1, 25, "Print"],
Cell[382950, 18303, 36, 1, 25, "Print"],
Cell[382989, 18306, 36, 1, 25, "Print"],
Cell[383028, 18309, 36, 1, 25, "Print"],
Cell[383067, 18312, 36, 1, 25, "Print"],
Cell[383106, 18315, 36, 1, 25, "Print"],
Cell[383145, 18318, 36, 1, 25, "Print"],
Cell[383184, 18321, 36, 1, 25, "Print"],
Cell[383223, 18324, 36, 1, 25, "Print"],
Cell[383262, 18327, 36, 1, 25, "Print"],
Cell[383301, 18330, 36, 1, 25, "Print"],
Cell[383340, 18333, 36, 1, 25, "Print"],
Cell[383379, 18336, 36, 1, 25, "Print"],
Cell[383418, 18339, 36, 1, 25, "Print"],
Cell[383457, 18342, 36, 1, 25, "Print"],
Cell[383496, 18345, 36, 1, 25, "Print"],
Cell[383535, 18348, 36, 1, 25, "Print"],
Cell[383574, 18351, 36, 1, 25, "Print"],
Cell[383613, 18354, 36, 1, 25, "Print"],
Cell[383652, 18357, 36, 1, 25, "Print"],
Cell[383691, 18360, 36, 1, 25, "Print"],
Cell[383730, 18363, 36, 1, 25, "Print"],
Cell[383769, 18366, 36, 1, 25, "Print"],
Cell[383808, 18369, 36, 1, 25, "Print"],
Cell[383847, 18372, 36, 1, 25, "Print"],
Cell[383886, 18375, 36, 1, 25, "Print"],
Cell[383925, 18378, 36, 1, 25, "Print"],
Cell[383964, 18381, 36, 1, 25, "Print"],
Cell[384003, 18384, 36, 1, 25, "Print"],
Cell[384042, 18387, 36, 1, 25, "Print"],
Cell[384081, 18390, 36, 1, 25, "Print"],
Cell[384120, 18393, 36, 1, 25, "Print"],
Cell[384159, 18396, 36, 1, 25, "Print"],
Cell[384198, 18399, 36, 1, 25, "Print"],
Cell[384237, 18402, 36, 1, 25, "Print"],
Cell[384276, 18405, 36, 1, 25, "Print"],
Cell[384315, 18408, 36, 1, 25, "Print"],
Cell[384354, 18411, 36, 1, 25, "Print"],
Cell[384393, 18414, 36, 1, 25, "Print"],
Cell[384432, 18417, 36, 1, 25, "Print"],
Cell[384471, 18420, 36, 1, 25, "Print"],
Cell[384510, 18423, 36, 1, 25, "Print"],
Cell[384549, 18426, 36, 1, 25, "Print"],
Cell[384588, 18429, 36, 1, 25, "Print"],
Cell[384627, 18432, 36, 1, 25, "Print"],
Cell[384666, 18435, 36, 1, 25, "Print"],
Cell[384705, 18438, 36, 1, 25, "Print"],
Cell[384744, 18441, 36, 1, 25, "Print"],
Cell[384783, 18444, 36, 1, 25, "Print"],
Cell[384822, 18447, 36, 1, 25, "Print"],
Cell[384861, 18450, 36, 1, 25, "Print"],
Cell[384900, 18453, 36, 1, 25, "Print"],
Cell[384939, 18456, 36, 1, 25, "Print"],
Cell[384978, 18459, 36, 1, 25, "Print"],
Cell[385017, 18462, 36, 1, 25, "Print"],
Cell[385056, 18465, 36, 1, 25, "Print"],
Cell[385095, 18468, 36, 1, 25, "Print"],
Cell[385134, 18471, 36, 1, 25, "Print"],
Cell[385173, 18474, 36, 1, 25, "Print"],
Cell[385212, 18477, 36, 1, 25, "Print"],
Cell[385251, 18480, 36, 1, 25, "Print"],
Cell[385290, 18483, 36, 1, 25, "Print"],
Cell[385329, 18486, 36, 1, 25, "Print"],
Cell[385368, 18489, 36, 1, 25, "Print"],
Cell[385407, 18492, 36, 1, 25, "Print"],
Cell[385446, 18495, 36, 1, 25, "Print"],
Cell[385485, 18498, 36, 1, 25, "Print"],
Cell[385524, 18501, 36, 1, 25, "Print"],
Cell[385563, 18504, 36, 1, 25, "Print"],
Cell[385602, 18507, 36, 1, 25, "Print"],
Cell[385641, 18510, 36, 1, 25, "Print"],
Cell[385680, 18513, 36, 1, 25, "Print"],
Cell[385719, 18516, 36, 1, 25, "Print"],
Cell[385758, 18519, 36, 1, 25, "Print"],
Cell[385797, 18522, 36, 1, 25, "Print"],
Cell[385836, 18525, 36, 1, 25, "Print"],
Cell[385875, 18528, 36, 1, 25, "Print"],
Cell[385914, 18531, 36, 1, 25, "Print"],
Cell[385953, 18534, 36, 1, 25, "Print"],
Cell[385992, 18537, 36, 1, 25, "Print"],
Cell[386031, 18540, 36, 1, 25, "Print"],
Cell[386070, 18543, 36, 1, 25, "Print"],
Cell[386109, 18546, 36, 1, 25, "Print"],
Cell[386148, 18549, 36, 1, 25, "Print"],
Cell[386187, 18552, 36, 1, 25, "Print"],
Cell[386226, 18555, 36, 1, 25, "Print"],
Cell[386265, 18558, 36, 1, 25, "Print"],
Cell[386304, 18561, 36, 1, 25, "Print"],
Cell[386343, 18564, 36, 1, 25, "Print"],
Cell[386382, 18567, 36, 1, 25, "Print"],
Cell[386421, 18570, 36, 1, 25, "Print"],
Cell[386460, 18573, 36, 1, 25, "Print"],
Cell[386499, 18576, 36, 1, 25, "Print"],
Cell[386538, 18579, 36, 1, 25, "Print"],
Cell[386577, 18582, 36, 1, 25, "Print"],
Cell[386616, 18585, 36, 1, 25, "Print"],
Cell[386655, 18588, 36, 1, 25, "Print"],
Cell[386694, 18591, 36, 1, 25, "Print"],
Cell[386733, 18594, 36, 1, 25, "Print"],
Cell[386772, 18597, 36, 1, 25, "Print"],
Cell[386811, 18600, 36, 1, 25, "Print"],
Cell[386850, 18603, 36, 1, 25, "Print"],
Cell[386889, 18606, 36, 1, 25, "Print"],
Cell[386928, 18609, 36, 1, 25, "Print"],
Cell[386967, 18612, 36, 1, 25, "Print"],
Cell[387006, 18615, 36, 1, 25, "Print"],
Cell[387045, 18618, 36, 1, 25, "Print"],
Cell[387084, 18621, 36, 1, 25, "Print"],
Cell[387123, 18624, 36, 1, 25, "Print"],
Cell[387162, 18627, 36, 1, 25, "Print"],
Cell[387201, 18630, 36, 1, 25, "Print"],
Cell[387240, 18633, 36, 1, 25, "Print"],
Cell[387279, 18636, 36, 1, 25, "Print"],
Cell[387318, 18639, 36, 1, 25, "Print"],
Cell[387357, 18642, 36, 1, 25, "Print"],
Cell[387396, 18645, 36, 1, 25, "Print"],
Cell[387435, 18648, 36, 1, 25, "Print"],
Cell[387474, 18651, 36, 1, 25, "Print"],
Cell[387513, 18654, 36, 1, 25, "Print"],
Cell[387552, 18657, 36, 1, 25, "Print"],
Cell[387591, 18660, 36, 1, 25, "Print"],
Cell[387630, 18663, 36, 1, 25, "Print"],
Cell[387669, 18666, 36, 1, 25, "Print"],
Cell[387708, 18669, 36, 1, 25, "Print"],
Cell[387747, 18672, 36, 1, 25, "Print"],
Cell[387786, 18675, 36, 1, 25, "Print"],
Cell[387825, 18678, 36, 1, 25, "Print"],
Cell[387864, 18681, 36, 1, 25, "Print"],
Cell[387903, 18684, 36, 1, 25, "Print"],
Cell[387942, 18687, 36, 1, 25, "Print"],
Cell[387981, 18690, 36, 1, 25, "Print"],
Cell[388020, 18693, 36, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[388093, 18699, 290, 8, 84, "Input"],
Cell[388386, 18709, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[388555, 18717, 314, 9, 84, "Input"],
Cell[388872, 18728, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389041, 18736, 320, 9, 84, "Input"],
Cell[389364, 18747, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389533, 18755, 292, 8, 84, "Input"],
Cell[389828, 18765, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389997, 18773, 292, 8, 84, "Input"],
Cell[390292, 18783, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[390461, 18791, 298, 8, 84, "Input"],
Cell[390762, 18801, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[390931, 18809, 87, 2, 30, "Input"],
Cell[391021, 18813, 122690, 7762, 296, 91560, 7373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[513714, 26577, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[513883, 26585, 90, 2, 48, "Input"],
Cell[513976, 26589, 125175, 7668, 293, 88992, 7217, "GraphicsData", \
"PostScript", "Graphics"],
Cell[639154, 34259, 132, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[639335, 34268, 263, 5, 88, "Subsubtitle"],
Cell[639601, 34275, 39, 0, 30, "Input"],
Cell[639643, 34277, 50, 0, 30, "Input"],
Cell[639696, 34279, 60, 0, 30, "Input"],
Cell[639759, 34281, 24, 0, 30, "Input"],
Cell[639786, 34283, 50, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[639861, 34287, 66, 0, 30, "Input"],
Cell[639930, 34289, 82, 1, 29, "Output"]
}, Open  ]],
Cell[640027, 34293, 42, 0, 30, "Input"],
Cell[640072, 34295, 294, 12, 210, "Input"],
Cell[640369, 34309, 98, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[640492, 34316, 264, 5, 84, "Input"],
Cell[640759, 34323, 34, 1, 25, "Print"],
Cell[640796, 34326, 34, 1, 25, "Print"],
Cell[640833, 34329, 34, 1, 25, "Print"],
Cell[640870, 34332, 34, 1, 25, "Print"],
Cell[640907, 34335, 34, 1, 25, "Print"],
Cell[640944, 34338, 34, 1, 25, "Print"],
Cell[640981, 34341, 34, 1, 25, "Print"],
Cell[641018, 34344, 34, 1, 25, "Print"],
Cell[641055, 34347, 34, 1, 25, "Print"],
Cell[641092, 34350, 35, 1, 25, "Print"],
Cell[641130, 34353, 35, 1, 25, "Print"],
Cell[641168, 34356, 35, 1, 25, "Print"],
Cell[641206, 34359, 35, 1, 25, "Print"],
Cell[641244, 34362, 35, 1, 25, "Print"],
Cell[641282, 34365, 35, 1, 25, "Print"],
Cell[641320, 34368, 35, 1, 25, "Print"],
Cell[641358, 34371, 35, 1, 25, "Print"],
Cell[641396, 34374, 35, 1, 25, "Print"],
Cell[641434, 34377, 35, 1, 25, "Print"],
Cell[641472, 34380, 35, 1, 25, "Print"],
Cell[641510, 34383, 35, 1, 25, "Print"],
Cell[641548, 34386, 35, 1, 25, "Print"],
Cell[641586, 34389, 35, 1, 25, "Print"],
Cell[641624, 34392, 35, 1, 25, "Print"],
Cell[641662, 34395, 35, 1, 25, "Print"],
Cell[641700, 34398, 35, 1, 25, "Print"],
Cell[641738, 34401, 35, 1, 25, "Print"],
Cell[641776, 34404, 35, 1, 25, "Print"],
Cell[641814, 34407, 35, 1, 25, "Print"],
Cell[641852, 34410, 35, 1, 25, "Print"],
Cell[641890, 34413, 35, 1, 25, "Print"],
Cell[641928, 34416, 35, 1, 25, "Print"],
Cell[641966, 34419, 35, 1, 25, "Print"],
Cell[642004, 34422, 35, 1, 25, "Print"],
Cell[642042, 34425, 35, 1, 25, "Print"],
Cell[642080, 34428, 35, 1, 25, "Print"],
Cell[642118, 34431, 35, 1, 25, "Print"],
Cell[642156, 34434, 35, 1, 25, "Print"],
Cell[642194, 34437, 35, 1, 25, "Print"],
Cell[642232, 34440, 35, 1, 25, "Print"],
Cell[642270, 34443, 35, 1, 25, "Print"],
Cell[642308, 34446, 35, 1, 25, "Print"],
Cell[642346, 34449, 35, 1, 25, "Print"],
Cell[642384, 34452, 35, 1, 25, "Print"],
Cell[642422, 34455, 35, 1, 25, "Print"],
Cell[642460, 34458, 35, 1, 25, "Print"],
Cell[642498, 34461, 35, 1, 25, "Print"],
Cell[642536, 34464, 35, 1, 25, "Print"],
Cell[642574, 34467, 35, 1, 25, "Print"],
Cell[642612, 34470, 35, 1, 25, "Print"],
Cell[642650, 34473, 35, 1, 25, "Print"],
Cell[642688, 34476, 35, 1, 25, "Print"],
Cell[642726, 34479, 35, 1, 25, "Print"],
Cell[642764, 34482, 35, 1, 25, "Print"],
Cell[642802, 34485, 35, 1, 25, "Print"],
Cell[642840, 34488, 35, 1, 25, "Print"],
Cell[642878, 34491, 35, 1, 25, "Print"],
Cell[642916, 34494, 35, 1, 25, "Print"],
Cell[642954, 34497, 35, 1, 25, "Print"],
Cell[642992, 34500, 35, 1, 25, "Print"],
Cell[643030, 34503, 35, 1, 25, "Print"],
Cell[643068, 34506, 35, 1, 25, "Print"],
Cell[643106, 34509, 35, 1, 25, "Print"],
Cell[643144, 34512, 35, 1, 25, "Print"],
Cell[643182, 34515, 35, 1, 25, "Print"],
Cell[643220, 34518, 35, 1, 25, "Print"],
Cell[643258, 34521, 35, 1, 25, "Print"],
Cell[643296, 34524, 35, 1, 25, "Print"],
Cell[643334, 34527, 35, 1, 25, "Print"],
Cell[643372, 34530, 35, 1, 25, "Print"],
Cell[643410, 34533, 35, 1, 25, "Print"],
Cell[643448, 34536, 35, 1, 25, "Print"],
Cell[643486, 34539, 35, 1, 25, "Print"],
Cell[643524, 34542, 35, 1, 25, "Print"],
Cell[643562, 34545, 35, 1, 25, "Print"],
Cell[643600, 34548, 35, 1, 25, "Print"],
Cell[643638, 34551, 35, 1, 25, "Print"],
Cell[643676, 34554, 35, 1, 25, "Print"],
Cell[643714, 34557, 35, 1, 25, "Print"],
Cell[643752, 34560, 35, 1, 25, "Print"],
Cell[643790, 34563, 35, 1, 25, "Print"],
Cell[643828, 34566, 35, 1, 25, "Print"],
Cell[643866, 34569, 35, 1, 25, "Print"],
Cell[643904, 34572, 35, 1, 25, "Print"],
Cell[643942, 34575, 35, 1, 25, "Print"],
Cell[643980, 34578, 35, 1, 25, "Print"],
Cell[644018, 34581, 35, 1, 25, "Print"],
Cell[644056, 34584, 35, 1, 25, "Print"],
Cell[644094, 34587, 35, 1, 25, "Print"],
Cell[644132, 34590, 35, 1, 25, "Print"],
Cell[644170, 34593, 35, 1, 25, "Print"],
Cell[644208, 34596, 35, 1, 25, "Print"],
Cell[644246, 34599, 35, 1, 25, "Print"],
Cell[644284, 34602, 35, 1, 25, "Print"],
Cell[644322, 34605, 35, 1, 25, "Print"],
Cell[644360, 34608, 35, 1, 25, "Print"],
Cell[644398, 34611, 35, 1, 25, "Print"],
Cell[644436, 34614, 35, 1, 25, "Print"],
Cell[644474, 34617, 35, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[644546, 34623, 40, 0, 30, "Input"],
Cell[644589, 34625, 187, 3, 48, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

